@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_ENZYMES_TASK_H_
-#define _U2_FIND_ENZYMES_TASK_H_
+#pragma once
 
 #include <QMutex>
 
@@ -38,7 +37,7 @@ public:
     FindAlgorithmTaskSettings()
         : searchIsCircular(false), countTask(true) {
     }
-    FindAlgorithmTaskSettings(const FindAlgorithmSettings &f)
+    FindAlgorithmTaskSettings(const FindAlgorithmSettings& f)
         : FindAlgorithmSettings(f), searchIsCircular(false), countTask(true) {
     }
 
@@ -51,14 +50,14 @@ public:
 class U2ALGORITHM_EXPORT FindAlgorithmTask : public Task, public FindAlgorithmResultsListener {
     Q_OBJECT
 public:
-    FindAlgorithmTask(const FindAlgorithmTaskSettings &s);
+    FindAlgorithmTask(const FindAlgorithmTaskSettings& s);
 
     virtual void run();
-    virtual void onResult(const FindAlgorithmResult &r);
+    virtual void onResult(const FindAlgorithmResult& r);
 
     QList<FindAlgorithmResult> popResults();
 
-    const FindAlgorithmTaskSettings &getSettings() const {
+    const FindAlgorithmTaskSettings& getSettings() const {
         return config;
     }
 
@@ -73,14 +72,14 @@ class Document;
 class U2ALGORITHM_EXPORT LoadPatternsFileTask : public Task {
     Q_OBJECT
 public:
-    LoadPatternsFileTask(const QString &_filePath, const QString &annotationName = QString());
+    LoadPatternsFileTask(const QString& _filePath, const QString& annotationName = QString());
     QList<QPair<QString, QString>> getNamesPatterns() {
         return namesPatterns;
     }
     void run();
 
 private:
-    Document *getDocumentFromFilePath();
+    Document* getDocumentFromFilePath();
 
     QString filePath;
     QList<QPair<QString, QString>> namesPatterns;
@@ -89,5 +88,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
