@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GENOME_ASSEMBLY_MULTI_TASK_
-#define _U2_GENOME_ASSEMBLY_MULTI_TASK_
+#pragma once
 
 #include <U2Algorithm/GenomeAssemblyRegistry.h>
 
@@ -34,21 +33,20 @@ class Document;
 class U2ALGORITHM_EXPORT GenomeAssemblyMultiTask : public Task {
     Q_OBJECT
 public:
-    GenomeAssemblyMultiTask(const GenomeAssemblyTaskSettings &settings);
+    GenomeAssemblyMultiTask(const GenomeAssemblyTaskSettings& settings);
     virtual void prepare();
     virtual ReportResult report();
     virtual QString generateReport() const;
     QString getResultUrl() const;
-    QList<Task *> onSubTaskFinished(Task *subTask);
-    const GenomeAssemblyTaskSettings &getSettings() const {
+    QList<Task*> onSubTaskFinished(Task* subTask);
+    const GenomeAssemblyTaskSettings& getSettings() const {
         return settings;
     }
-    GenomeAssemblyTask *getAssemblyTask() const;
+    GenomeAssemblyTask* getAssemblyTask() const;
 
 private:
     GenomeAssemblyTaskSettings settings;
-    GenomeAssemblyTask *assemblyTask;
+    GenomeAssemblyTask* assemblyTask;
 };
 
 }  // namespace U2
-#endif
