@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_REPEAT_FINDER_TASK_FACTORY_H_
-#define _U2_REPEAT_FINDER_TASK_FACTORY_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -30,13 +29,11 @@ namespace U2 {
 
 class RepeatFinderTaskFactory {
 public:
-    virtual Task *getTaskInstance(const RepeatFinderSettings &config) const = 0;
+    virtual Task* getTaskInstance(const RepeatFinderSettings& config) const = 0;
     virtual ~RepeatFinderTaskFactory() {
     }
 
-    virtual void setRFResultsListener(Task *, RFResultsListener *) = 0;
+    virtual void setRFResultsListener(Task*, RFResultsListener*) = 0;
 };
 
 }  // namespace U2
-
-#endif
