@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,20 +19,24 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ROLLING_MATRIX_H_
-#define _U2_ROLLING_MATRIX_H_
+#pragma once
 
 #include <cstdio>
 
+#include <U2Core/U2OpStatus.h>
+
 namespace U2 {
 
 // TODO: rename n,m to rows, columns
 
 class U2ALGORITHM_EXPORT RollingMatrix {
 public:
-    RollingMatrix(int _n, int _m)
-        : n(_n), m(_m), column0(0) {
-        data = new int[n * m];
+    //Use isAcceptableMatrixDimensions(int sizeX, int sizeY) to check your matrix dimensions before construction
+    RollingMatrix(int _sizeX, int _sizeY)
+        : sizeX(_sizeX), sizeY(_sizeY), column0(0) {
+        SAFE_POINT(sizeX >= 0 && sizeY >= 0, "Incorrect matrix size.", );
+        SAFE_POINT(getMatrixSizeInBytes(sizeX, sizeY) < INT_MAX, "Matrix size in bytes more than INT_MAX.", );
+        data = new int[sizeX * sizeY];
     }
 
     virtual ~RollingMatrix() {
@@ -55,47 +59,53 @@ public:
 
     void dump() const {
         printf("----------------\n");
-        for (int j = 0; j < m; j++) {
-            for (int i = 0; i < n; i++) {
-                printf("%x ", get(i, j));
+        for (int y = 0; y < sizeY; y++) {
+            for (int x = 0; x < sizeX; x++) {
+                printf("%x ", get(x, y));
             }
             printf("\n");
         }
     }
 
     void shiftColumn() {
-        if (++column0 == n) {
+        if (++column0 == sizeX) {
             column0 = 0;
         }
     }
 
-    static quint64 getMatrixSizeInBytes(const int _n, const int _m) {
-        return _n * _m * sizeof(int);
+    static bool isAcceptableMatrixDimensions(int sizeX, int sizeY) {
+        return getMatrixSizeInBytes(sizeX, sizeY) < INT_MAX;
+    }
+    
+    static qint64 getMatrixSizeInBytes(int sizeX, int sizeY) {
+        return (qint64)sizeX * sizeY * (int)sizeof(int);
     }
 
 private:
     int getIdx(int x, int y) const {
-        assert(x >= 0 && y >= 0 && x < n && y < m);
-        return x * m + y;
+        SAFE_POINT(x >= 0 && y >= 0 && x < sizeX && y < sizeY, "Coordinates are out of range.", 0);
+        return x * sizeY + y;
     }
 
     int transposeX(int x) const {
-        assert(x >= 0 && x < n);
-        return (column0 + x) % n;
+#ifndef U2_SUPPRESS_GCC_5_4_FALSE_WARNINGS
+        SAFE_POINT(x >= 0 && x < sizeX, "Coordinate is out of range.", 0);
+#endif
+        return (column0 + x) % sizeX;
     }
 
     int transposeY(int y) const {
-        assert(y >= 0 && y < m);
+#ifndef U2_SUPPRESS_GCC_5_4_FALSE_WARNINGS
+        SAFE_POINT(y >= 0 && y < sizeY, "Coordinate is out of range.", 0);
+#endif
         return y;
     }
 
 protected:
-    int n;
-    int m;
-    int *data;
+    const int sizeX;
+    const int sizeY;
+    int* data = nullptr;
     int column0;
 };
 
 }  // namespace U2
-
-#endif
