@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_CONTENT_FILTER_TASK_H_
-#define _U2_SEQUENCE_CONTENT_FILTER_TASK_H_
+#pragma once
 
 #include <U2Algorithm/FindAlgorithm.h>
 
@@ -37,19 +36,19 @@ class U2SequenceObject;
 class SequenceContentFilterTask : public AbstractProjectFilterTask, public FindAlgorithmResultsListener {
     Q_OBJECT
 public:
-    SequenceContentFilterTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document>> &docs);
+    SequenceContentFilterTask(const ProjectTreeControllerModeSettings& settings, const QList<QPointer<Document>>& docs);
 
-    void onResult(const FindAlgorithmResult &r);
+    void onResult(const FindAlgorithmResult& r);
 
 protected:
-    bool filterAcceptsObject(GObject *obj);
+    bool filterAcceptsObject(GObject* obj);
 
 private:
-    bool sequenceContainsPattern(U2SequenceObject *seqObject, const QString &pattern, const FindAlgorithmSettings &findSettings);
-    void searchThroughRegion(U2SequenceObject *seqObject, const U2Region &searchRegion, const QString &pattern, const FindAlgorithmSettings &findSettings);
+    bool sequenceContainsPattern(U2SequenceObject* seqObject, const QString& pattern, const FindAlgorithmSettings& findSettings);
+    void searchThroughRegion(U2SequenceObject* seqObject, const U2Region& searchRegion, const QString& pattern, const FindAlgorithmSettings& findSettings);
 
-    static bool patternFitsSequenceAlphabet(U2SequenceObject *seqObject, const QString &pattern);
-    static bool initFindAlgorithmSettings(U2SequenceObject *seqObject, FindAlgorithmSettings &findSettings);
+    static bool patternFitsSequenceAlphabet(U2SequenceObject* seqObject, const QString& pattern);
+    static bool initFindAlgorithmSettings(U2SequenceObject* seqObject, FindAlgorithmSettings& findSettings);
 
     int searchStopFlag;
 
@@ -62,10 +61,8 @@ private:
 
 class U2ALGORITHM_EXPORT SequenceContentFilterTaskFactory : public ProjectFilterTaskFactory {
 protected:
-    AbstractProjectFilterTask *createNewTask(const ProjectTreeControllerModeSettings &settings,
-                                             const QList<QPointer<Document>> &docs) const;
+    AbstractProjectFilterTask* createNewTask(const ProjectTreeControllerModeSettings& settings,
+                                             const QList<QPointer<Document>>& docs) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SEQUENCE_CONTENT_FILTER_TASK_H_
