@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BIOSTRUCT3D_MOLECULAR_SURFACE_H_
-#define _U2_BIOSTRUCT3D_MOLECULAR_SURFACE_H_
+#pragma once
 
 #include <limits>
 
@@ -36,7 +35,7 @@
 namespace U2 {
 
 template<class T>
-inline T sqr(const T &x) {
+inline T sqr(const T& x) {
     return x * x;
 }
 
@@ -58,14 +57,14 @@ class U2ALGORITHM_EXPORT MolecularSurface {
 public:
     virtual ~MolecularSurface();
 
-    virtual void calculate(const QList<SharedAtom> &atoms, int &progress) = 0;
+    virtual void calculate(const QList<SharedAtom>& atoms, int& progress) = 0;
     virtual qint64 estimateMemoryUsage(int numberOfAtoms);
 
-    const QVector<Face> &getFaces() const;
+    const QVector<Face>& getFaces() const;
 
-    static QList<SharedAtom> findAtomNeighbors(const SharedAtom &a, const QList<SharedAtom> &atoms);
-    static GeodesicSphere getAtomSurfaceDots(const SharedAtom &a, int detaillevel);
-    static bool vertexNeighboursOneOf(const Vector3D &v, const QList<SharedAtom> &atoms);
+    static QList<SharedAtom> findAtomNeighbors(const SharedAtom& a, const QList<SharedAtom>& atoms);
+    static GeodesicSphere getAtomSurfaceDots(const SharedAtom& a, int detaillevel);
+    static bool vertexNeighboursOneOf(const Vector3D& v, const QList<SharedAtom>& atoms);
 
 protected:
     QVector<Face> faces;
@@ -74,26 +73,24 @@ protected:
 
 class U2ALGORITHM_EXPORT MolecularSurfaceCalcTask : public Task {
     Q_OBJECT
-    MolecularSurface *molSurface;
+    MolecularSurface* molSurface;
     QString typeName;
     const QList<SharedAtom> atoms;
 
 public:
-    MolecularSurfaceCalcTask(const QString &surfaceTypeName, const QList<SharedAtom> &atoms);
-    MolecularSurface *getCalculatedSurface();
+    MolecularSurfaceCalcTask(const QString& surfaceTypeName, const QList<SharedAtom>& atoms);
+    MolecularSurface* getCalculatedSurface();
     virtual void run();
     virtual ReportResult report();
 };
 
 class U2ALGORITHM_EXPORT MolecularSurfaceFactory {
 public:
-    virtual ~MolecularSurfaceFactory();
-    virtual MolecularSurface *createInstance() const = 0;
-    virtual bool hasConstraints(const BioStruct3D &) const {
+    virtual ~MolecularSurfaceFactory() = default;
+    virtual MolecularSurface* createInstance() const = 0;
+    virtual bool hasConstraints(const BioStruct3D&) const {
         return false;
     }
 };
 
 }  // namespace U2
-
-#endif  //_U2_BIOSTRUCT3D_MOLECULAR_SURFACE_H_
