@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ABSTRACT_ALIGNMENT_TASK_H_
-#define _U2_ABSTRACT_ALIGNMENT_TASK_H_
+#pragma once
 
 #include <QByteArray>
 #include <QString>
@@ -38,13 +37,13 @@ namespace U2 {
 class U2ALGORITHM_EXPORT AbstractAlignmentTaskSettings {
 public:
     AbstractAlignmentTaskSettings();
-    AbstractAlignmentTaskSettings(const QVariantMap &someSettings);
-    AbstractAlignmentTaskSettings(const AbstractAlignmentTaskSettings &s);
+    AbstractAlignmentTaskSettings(const QVariantMap& someSettings);
+    AbstractAlignmentTaskSettings(const AbstractAlignmentTaskSettings& s);
     virtual ~AbstractAlignmentTaskSettings();
 
-    void appendCustomSettings(const QVariantMap &settings);
-    QVariant getCustomValue(const QString &optionName, const QVariant &defaultVal) const;
-    void setCustomValue(const QString &optionName, const QVariant &val);
+    void appendCustomSettings(const QVariantMap& settings);
+    QVariant getCustomValue(const QString& optionName, const QVariant& defaultVal) const;
+    void setCustomValue(const QString& optionName, const QVariant& val);
     virtual bool convertCustomSettings();
     virtual bool isValid() const;
 
@@ -69,15 +68,13 @@ class U2ALGORITHM_EXPORT AbstractAlignmentTask : public Task {
     Q_OBJECT
 
 public:
-    AbstractAlignmentTask(const QString &taskName, TaskFlags flags);
+    AbstractAlignmentTask(const QString& taskName, TaskFlags flags);
 };
 
 class U2ALGORITHM_EXPORT AbstractAlignmentTaskFactory {
 public:
-    virtual AbstractAlignmentTask *getTaskInstance(AbstractAlignmentTaskSettings *settings) const = 0;
+    virtual AbstractAlignmentTask* getTaskInstance(AbstractAlignmentTaskSettings* settings) const = 0;
     virtual ~AbstractAlignmentTaskFactory();
 };
 
 }  // namespace U2
-
-#endif  // _U2_ABSTRACT_ALIGNMENT_TASK_H_
