@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BASE_ALIGNMENT_ALGORITHM_IDS_H_
-#define _U2_BASE_ALIGNMENT_ALGORITHM_IDS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -31,8 +30,14 @@ public:
     // align sequences to alignment algorithms
     static const QString ALIGN_SEQUENCES_TO_ALIGNMENT_BY_UGENE;
     static const QString ALIGN_SEQUENCES_TO_ALIGNMENT_BY_MAFFT;
+
+    /**
+     * Built-in algorithm ids for "Align selected sequences" to alignment.
+     * TODO: these are the same algorithm as 'ALIGN_SEQUENCES_TO_ALIGNMENT' but with a separate visual (action) names.
+     *  This should be changed and action names assigned in UI. The algorithm must hold only generic name: MAFFT, UGENE...
+     *  TO be fixed as a part of UGENE-7499.
+     */
+    static const QString ALIGN_SELECTED_SEQUENCES_TO_ALIGNMENT_BY_MAFFT;
 };
 
 }  // namespace U2
-
-#endif  // _U2_BASE_ALIGNMENT_ALGORITHM_IDS_H_
