@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SIMPLE_ADDING_TO_ALIGNMENT_H_
-#define _U2_SIMPLE_ADDING_TO_ALIGNMENT_H_
+#pragma once
 
 #include <U2Algorithm/AlignSequencesToAlignmentTaskSettings.h>
 #include <U2Algorithm/AlignmentAlgorithmsRegistry.h>
@@ -33,9 +32,9 @@ namespace U2 {
 class SimpleAddToAlignmentTask : public AbstractAlignmentTask {
     Q_OBJECT
 public:
-    SimpleAddToAlignmentTask(const AlignSequencesToAlignmentTaskSettings &settings);
+    SimpleAddToAlignmentTask(const AlignSequencesToAlignmentTaskSettings& settings);
     void prepare();
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
 
     ReportResult report();
 
@@ -49,14 +48,14 @@ private:
 class BestPositionFindTask : public Task {
     Q_OBJECT
 public:
-    BestPositionFindTask(const MultipleSequenceAlignment &alignment, const U2EntityRef &sequenceRef, const QString &sequenceId, int referenceRowId);
+    BestPositionFindTask(const MultipleSequenceAlignment& alignment, const U2EntityRef& sequenceRef, const QString& sequenceId, int referenceRowId);
     void run();
 
     int getPosition() const;
-    const QString &getSequenceId() const;
+    const QString& getSequenceId() const;
 
 private:
-    const MultipleSequenceAlignment &inputMsa;
+    const MultipleSequenceAlignment& inputMsa;
     U2EntityRef sequenceRef;
     QString sequenceId;
     int bestPosition;
@@ -65,7 +64,7 @@ private:
 
 class SimpleAddToAlignmentTaskFactory : public AbstractAlignmentTaskFactory {
 public:
-    virtual AbstractAlignmentTask *getTaskInstance(AbstractAlignmentTaskSettings *_settings) const;
+    virtual AbstractAlignmentTask* getTaskInstance(AbstractAlignmentTaskSettings* _settings) const;
 };
 
 class SimpleAddToAlignmentAlgorithm : public AlignmentAlgorithm {
@@ -74,5 +73,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // _U2_PAIRWISE_ALIGNER_H_
