@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,18 +23,16 @@
 
 namespace U2 {
 
-const QString PairwiseAlignmentTaskSettings::PA_FIRST_SEQUENCE_REF("firstSequenceRef");
-const QString PairwiseAlignmentTaskSettings::PA_SECOND_SEQUENCE_REF("secondSequenceRef");
-const QString PairwiseAlignmentTaskSettings::DEFAULT_NAME("PairwiseAlignmentResult.aln");
+const QString PairwiseAlignmentTaskSettings::DEFAULT_RESULT_FILE_NAME("pairwise-alignment.aln");
 
 PairwiseAlignmentTaskSettings::PairwiseAlignmentTaskSettings() {
 }
 
-PairwiseAlignmentTaskSettings::PairwiseAlignmentTaskSettings(const QVariantMap &someSettings)
+PairwiseAlignmentTaskSettings::PairwiseAlignmentTaskSettings(const QVariantMap& someSettings)
     : AbstractAlignmentTaskSettings(someSettings) {
 }
 
-PairwiseAlignmentTaskSettings::PairwiseAlignmentTaskSettings(const PairwiseAlignmentTaskSettings &s)
+PairwiseAlignmentTaskSettings::PairwiseAlignmentTaskSettings(const PairwiseAlignmentTaskSettings& s)
     : AbstractAlignmentTaskSettings(s),
       firstSequenceRef(s.firstSequenceRef),
       secondSequenceRef(s.secondSequenceRef) {
