@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PAIRWISE_ALIGNMENT_TASK_H_
-#define _U2_PAIRWISE_ALIGNMENT_TASK_H_
+#pragma once
 
 #include <U2Algorithm/AlignmentAlgorithmsRegistry.h>
 
@@ -28,23 +27,20 @@
 
 namespace U2 {
 
-class PairwiseAlignmentSettings;
 class PairwiseAlignmentTask;
 
 class U2ALGORITHM_EXPORT PairwiseAlignmentTaskSettings : public AbstractAlignmentTaskSettings {
 public:
     PairwiseAlignmentTaskSettings();
-    PairwiseAlignmentTaskSettings(const QVariantMap &someSettings);
-    PairwiseAlignmentTaskSettings(const PairwiseAlignmentTaskSettings &s);
+    PairwiseAlignmentTaskSettings(const QVariantMap& someSettings);
+    PairwiseAlignmentTaskSettings(const PairwiseAlignmentTaskSettings& s);
 
-    virtual bool isValid() const;
+    bool isValid() const override;
 
     U2EntityRef firstSequenceRef;  // couldn't be in customSettings. Set manually.
     U2EntityRef secondSequenceRef;  // couldn't be in customSettings. Set manually.
 
-    static const QString PA_FIRST_SEQUENCE_REF;
-    static const QString PA_SECOND_SEQUENCE_REF;
-    static const QString DEFAULT_NAME;
+    static const QString DEFAULT_RESULT_FILE_NAME;
 };
 
 class U2ALGORITHM_EXPORT PairwiseAlignmentTask : public AbstractAlignmentTask {
@@ -58,5 +54,3 @@ protected:
     QByteArray second;
 };
 }  // namespace U2
-
-#endif  // _U2_PAIRWISE_ALIGNMENT_TASK_H_
