@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __PHYTREEGENERATORTASK_H
-#define __PHYTREEGENERATORTASK_H
+#pragma once
 
 #include <U2Algorithm/CreatePhyTreeSettings.h>
 
@@ -33,17 +32,13 @@ namespace U2 {
 class U2ALGORITHM_EXPORT PhyTreeGeneratorTask : public Task {
     Q_OBJECT
 public:
-    PhyTreeGeneratorTask(const MultipleSequenceAlignment &ma, const CreatePhyTreeSettings &_settings);
-    ~PhyTreeGeneratorTask() {
-    }
-    void run();
-    PhyTree getResult() {
-        return result;
-    }
-    const CreatePhyTreeSettings &getSettings() {
-        return settings;
-    }
-    ReportResult report();
+    PhyTreeGeneratorTask(const MultipleSequenceAlignment& ma,
+                         const CreatePhyTreeSettings& settings,
+                         const TaskFlags& taskFlags = TaskFlag_NoRun | TaskFlag_FailOnSubtaskError);
+
+    const PhyTree& getResult() const;
+
+    const CreatePhyTreeSettings& getSettings() const;
 
 protected:
     const MultipleSequenceAlignment inputMA;
@@ -51,44 +46,23 @@ protected:
     CreatePhyTreeSettings settings;
 };
 
-class SeqNamesConvertor {
-public:
-    SeqNamesConvertor()
-        : lastIdStr("a") {
-    }
-
-    void replaceNamesWithAlphabeticIds(MultipleSequenceAlignment &ma);
-    void restoreNames(const PhyTree &tree);
-
-private:
-    const QString &generateNewAlphabeticId();
-
-    QString lastIdStr;
-    QMap<QString, QString> namesMap;
-};
-
 class U2ALGORITHM_EXPORT PhyTreeGeneratorLauncherTask : public Task {
     Q_OBJECT
 public:
-    PhyTreeGeneratorLauncherTask(const MultipleSequenceAlignment &ma, const CreatePhyTreeSettings &_settings);
-    ~PhyTreeGeneratorLauncherTask() {};
-    PhyTree getResult() {
-        return result;
-    }
-    void prepare();
-    void run() {};
-    ReportResult report();
-private slots:
+    PhyTreeGeneratorLauncherTask(const MultipleSequenceAlignment& ma, const CreatePhyTreeSettings& _settings);
+    const PhyTree& getResult() const;
+    void prepare() override;
+    ReportResult report() override;
+
+public slots:
     void sl_onCalculationCanceled();
 
 private:
     MultipleSequenceAlignment inputMA;
+    QStringList originalRowNameByIndex;
     PhyTree result;
     CreatePhyTreeSettings settings;
-    PhyTreeGeneratorTask *task;
-    SeqNamesConvertor namesConvertor;
+    PhyTreeGeneratorTask* task = nullptr;
 };
 
 }  // namespace U2
-
-#endif
