@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_ASSEMBLY_ALG_REGISTRY_H_
-#define _U2_DNA_ASSEMBLY_ALG_REGISTRY_H_
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -39,37 +38,37 @@ class DnaAssemblyAlgorithmEnv;
 class U2ALGORITHM_EXPORT DnaAssemblyAlgRegistry : public QObject {
     Q_OBJECT
 public:
-    DnaAssemblyAlgRegistry(QObject *pOwn = 0);
+    DnaAssemblyAlgRegistry(QObject* pOwn = 0);
     ~DnaAssemblyAlgRegistry();
 
-    bool registerAlgorithm(DnaAssemblyAlgorithmEnv *env);
-    DnaAssemblyAlgorithmEnv *unregisterAlgorithm(const QString &id);
-    DnaAssemblyAlgorithmEnv *getAlgorithm(const QString &id) const;
+    bool registerAlgorithm(DnaAssemblyAlgorithmEnv* env);
+    DnaAssemblyAlgorithmEnv* unregisterAlgorithm(const QString& id);
+    DnaAssemblyAlgorithmEnv* getAlgorithm(const QString& id) const;
 
     QStringList getRegisteredAlgorithmIds() const;
     QStringList getRegisteredAlgorithmsWithIndexFileSupport() const;
 
 private:
     mutable QMutex mutex;
-    QMap<QString, DnaAssemblyAlgorithmEnv *> algorithms;
+    QMap<QString, DnaAssemblyAlgorithmEnv*> algorithms;
 
     Q_DISABLE_COPY(DnaAssemblyAlgRegistry);
 };
 
 class U2ALGORITHM_EXPORT DnaAssemblyAlgorithmEnv {
 public:
-    DnaAssemblyAlgorithmEnv(const QString &id,
-                            DnaAssemblyToRefTaskFactory *tf,
-                            DnaAssemblyGUIExtensionsFactory *guiExt,
+    DnaAssemblyAlgorithmEnv(const QString& id,
+                            DnaAssemblyToRefTaskFactory* tf,
+                            DnaAssemblyGUIExtensionsFactory* guiExt,
                             bool supportsIndexFiles,
                             bool supportsDbi,
                             bool supportsPairedEndLibrary,
-                            const QStringList &refrerenceFormats,
-                            const QStringList &readsFormats);
+                            const QStringList& refrerenceFormats,
+                            const QStringList& readsFormats);
 
     virtual ~DnaAssemblyAlgorithmEnv();
 
-    const QString &getId() const {
+    const QString& getId() const {
         return id;
     }
     bool isIndexFilesSupported() const {
@@ -88,10 +87,10 @@ public:
         return readsFormats;
     }
 
-    DnaAssemblyToRefTaskFactory *getTaskFactory() const {
+    DnaAssemblyToRefTaskFactory* getTaskFactory() const {
         return taskFactory;
     }
-    DnaAssemblyGUIExtensionsFactory *getGUIExtFactory() const {
+    DnaAssemblyGUIExtensionsFactory* getGUIExtFactory() const {
         return guiExtFactory;
     }
 
@@ -100,8 +99,8 @@ private:
 
 protected:
     QString id;
-    DnaAssemblyToRefTaskFactory *taskFactory;
-    DnaAssemblyGUIExtensionsFactory *guiExtFactory;
+    DnaAssemblyToRefTaskFactory* taskFactory;
+    DnaAssemblyGUIExtensionsFactory* guiExtFactory;
     bool supportsIndexFiles;
     bool supportsDbi;
     bool supportsPEReads;
@@ -110,5 +109,3 @@ protected:
 };
 
 }  // namespace U2
-
-#endif
