@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_REPEAT_FINDER_ALG_REGISTRY_H_
-#define _U2_REPEAT_FINDER_ALG_REGISTRY_H_
+#pragma once
 
 #include <QHash>
 #include <QMutex>
@@ -38,19 +37,17 @@ enum RepeatFinderTaskFactoryId {};
 class U2ALGORITHM_EXPORT RepeatFinderTaskFactoryRegistry : public QObject {
     Q_OBJECT
 public:
-    RepeatFinderTaskFactoryRegistry(QObject *pOwn = 0);
+    RepeatFinderTaskFactoryRegistry(QObject* pOwn = 0);
     ~RepeatFinderTaskFactoryRegistry();
 
-    bool registerFactory(RepeatFinderTaskFactory *factory, const QString &factoryId);
-    bool hadRegistered(const QString &factoryId);
-    RepeatFinderTaskFactory *getFactory(const QString &factoryId);
+    bool registerFactory(RepeatFinderTaskFactory* factory, const QString& factoryId);
+    bool hadRegistered(const QString& factoryId);
+    RepeatFinderTaskFactory* getFactory(const QString& factoryId);
     QStringList getListFactoryNames();
 
 private:
     QMutex mutex;
-    QHash<QString, RepeatFinderTaskFactory *> factories;
+    QHash<QString, RepeatFinderTaskFactory*> factories;
 };
 
 }  // namespace U2
-
-#endif
