@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SPLICED_ALIGNMENT_TASK_H_
-#define _U2_SPLICED_ALIGNMENT_TASK_H_
+#pragma once
 
 #include <U2Core/AnnotationData.h>
 #include <U2Core/DNASequenceObject.h>
@@ -30,20 +29,20 @@ namespace U2 {
 
 class SplicedAlignmentTaskConfig {
 public:
-    SplicedAlignmentTaskConfig(U2SequenceObject *cDna, U2SequenceObject *genomic)
+    SplicedAlignmentTaskConfig(U2SequenceObject* cDna, U2SequenceObject* genomic)
         : cDnaObj(cDna), genomicSeqObj(genomic) {
     }
 
-    U2SequenceObject *getGenomicSequence() {
+    U2SequenceObject* getGenomicSequence() {
         return genomicSeqObj;
     }
-    U2SequenceObject *getCDnaSequence() {
+    U2SequenceObject* getCDnaSequence() {
         return cDnaObj;
     }
 
 private:
-    U2SequenceObject *cDnaObj;
-    U2SequenceObject *genomicSeqObj;
+    U2SequenceObject* cDnaObj;
+    U2SequenceObject* genomicSeqObj;
     QVariantMap customOptions;
 };
 
@@ -52,8 +51,8 @@ private:
 class U2ALGORITHM_EXPORT SplicedAlignmentTask : public Task {
     Q_OBJECT
 public:
-    SplicedAlignmentTask(const SplicedAlignmentTaskConfig &cfg);
-    SplicedAlignmentTask(const QString &taskName, TaskFlags flags, const SplicedAlignmentTaskConfig &cfg);
+    SplicedAlignmentTask(const SplicedAlignmentTaskConfig& cfg);
+    SplicedAlignmentTask(const QString& taskName, TaskFlags flags, const SplicedAlignmentTaskConfig& cfg);
     virtual QList<SharedAnnotationData> getAlignmentResult() = 0;
 
 protected:
@@ -64,11 +63,9 @@ protected:
 
 class U2ALGORITHM_EXPORT SplicedAlignmentTaskFactory {
 public:
-    virtual SplicedAlignmentTask *createTaskInstance(const SplicedAlignmentTaskConfig &config) = 0;
+    virtual SplicedAlignmentTask* createTaskInstance(const SplicedAlignmentTaskConfig& config) = 0;
     virtual ~SplicedAlignmentTaskFactory() {
     }
 };
 
 }  // namespace U2
-
-#endif  // _U2_SPLICED_ALIGNMENT_TASK_H
