@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SPLICED_ALIGNMENT_TASK_REGISTRY_H_
-#define _U2_SPLICED_ALIGNMENT_TASK_REGISTRY_H_
+#pragma once
 
 #include <QMap>
 #include <QMutex>
@@ -37,20 +36,18 @@ class SplicedAlignmentTask;
 class U2ALGORITHM_EXPORT SplicedAlignmentTaskRegistry : public QObject {
     Q_OBJECT
 public:
-    explicit SplicedAlignmentTaskRegistry(QObject *parent = 0);
+    explicit SplicedAlignmentTaskRegistry(QObject* parent = 0);
     ~SplicedAlignmentTaskRegistry();
-    bool registerTaskFactory(SplicedAlignmentTaskFactory *alg, const QString &algId);
-    void unregisterTaskFactory(const QString &algId);
-    bool hadRegistered(const QString &algId);
-    SplicedAlignmentTaskFactory *getAlgorithm(const QString &algId);
+    bool registerTaskFactory(SplicedAlignmentTaskFactory* alg, const QString& algId);
+    void unregisterTaskFactory(const QString& algId);
+    bool hadRegistered(const QString& algId);
+    SplicedAlignmentTaskFactory* getAlgorithm(const QString& algId);
     QStringList getAlgNameList();
 
 private:
     QMutex mutex;
-    QMap<QString, SplicedAlignmentTaskFactory *> algMap;
+    QMap<QString, SplicedAlignmentTaskFactory*> algMap;
     Q_DISABLE_COPY(SplicedAlignmentTaskRegistry)
 };
 
 }  // namespace U2
-
-#endif  // _U2_SPLICED_ALIGNMENT_TASK_REGISTRY_H_
