@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SW_MUL_ALIGN_POS_NUMBER_TAG_H_
-#define _U2_SW_MUL_ALIGN_POS_NUMBER_TAG_H_
+#pragma once
 
 #include "SWMulAlignResultNamesTag.h"
 
@@ -35,7 +34,7 @@ public:
     };
 
     inline SWMulAlignExternalPropTag(const QString _shorthand, const QString _label, Type _type);
-    virtual QString expandTag(const QVariant &argument) const;
+    virtual QString expandTag(const QVariant& argument) const;
     inline void resetCounter();
     inline Type getType() const;
 
@@ -59,5 +58,3 @@ inline SWMulAlignExternalPropTag::Type SWMulAlignExternalPropTag::getType() cons
 }
 
 }  // namespace U2
-
-#endif  // _U2_SW_MUL_ALIGN_POS_NUMBER_TAG_H_
