@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SW_MUL_ALIGN_RESULT_NAMES_TAGS_H_
-#define _U2_SW_MUL_ALIGN_RESULT_NAMES_TAGS_H_
+#pragma once
 
 #include <QString>
 #include <QVariant>
@@ -34,11 +33,11 @@ public:
     inline SWMulAlignResultNamesTag(const QString _shorthand, const QString _label);
     virtual ~SWMulAlignResultNamesTag() {
     }
-    virtual QString expandTag(const QVariant &argument = QVariant()) const = 0;
+    virtual QString expandTag(const QVariant& argument = QVariant()) const = 0;
 
-    inline const QString &getShorthand() const;
-    inline const QString &getLabel() const;
-    inline const bool &isAcceptableForSubseqNamesOnly() const;
+    inline const QString& getShorthand() const;
+    inline const QString& getLabel() const;
+    inline const bool& isAcceptableForSubseqNamesOnly() const;
 
 protected:
     bool acceptableForSubseqNamesOnly;
@@ -52,18 +51,16 @@ inline SWMulAlignResultNamesTag::SWMulAlignResultNamesTag(const QString _shortha
     : shorthand(_shorthand), label(_label) {
 }
 
-inline const QString &SWMulAlignResultNamesTag::getShorthand() const {
+inline const QString& SWMulAlignResultNamesTag::getShorthand() const {
     return shorthand;
 }
 
-inline const QString &SWMulAlignResultNamesTag::getLabel() const {
+inline const QString& SWMulAlignResultNamesTag::getLabel() const {
     return label;
 }
 
-inline const bool &SWMulAlignResultNamesTag::isAcceptableForSubseqNamesOnly() const {
+inline const bool& SWMulAlignResultNamesTag::isAcceptableForSubseqNamesOnly() const {
     return acceptableForSubseqNamesOnly;
 }
 
 }  // namespace U2
-
-#endif  // _U2_SW_MUL_ALIGN_RESULT_NAMES_TAGS_H_
