@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SW_MUL_ALIGN_SEQ_PREFIX_TAG_H_
-#define _U2_SW_MUL_ALIGN_SEQ_PREFIX_TAG_H_
+#pragma once
 
 #include "SWMulAlignResultNamesTag.h"
 
@@ -29,7 +28,7 @@ namespace U2 {
 class SWMulAlignSeqPrefixTag : public SWMulAlignResultNamesTag {
 public:
     inline SWMulAlignSeqPrefixTag(const QString _shorthand, const QString _label, const quint32 _prefixLength);
-    virtual QString expandTag(const QVariant &argument) const;
+    virtual QString expandTag(const QVariant& argument) const;
 
 private:
     quint32 prefixLength;
@@ -41,5 +40,3 @@ inline SWMulAlignSeqPrefixTag::SWMulAlignSeqPrefixTag(const QString _shorthand,
 }
 
 }  // namespace U2
-
-#endif  // _U2_SW_MUL_ALIGN_SEQ_PREFIX_TAG_H_
