@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SMITH_WATERMAN_TASK_FACTORY_H_
-#define _U2_SMITH_WATERMAN_TASK_FACTORY_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -30,8 +29,8 @@ namespace U2 {
 
 class SmithWatermanTaskFactory {  // for ADV search only
 public:
-    virtual Task *getTaskInstance(const SmithWatermanSettings &config,
-                                  const QString &taskName) const = 0;
+    virtual Task* getTaskInstance(const SmithWatermanSettings& config,
+                                  const QString& taskName) const = 0;
     virtual bool hasAdvancedSettings() const {
         return false;
     }
@@ -42,5 +41,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
