@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SMITH_WATERMAN_ALG_REGISTRY_H_
-#define _U2_SMITH_WATERMAN_ALG_REGISTRY_H_
+#pragma once
 
 #include <QHash>
 #include <QMutex>
@@ -36,19 +35,17 @@ namespace U2 {
 class U2ALGORITHM_EXPORT SmithWatermanTaskFactoryRegistry : public QObject {
     Q_OBJECT
 public:
-    SmithWatermanTaskFactoryRegistry(QObject *pOwn = 0);
+    SmithWatermanTaskFactoryRegistry(QObject* pOwn = 0);
     ~SmithWatermanTaskFactoryRegistry();
 
-    bool registerFactory(SmithWatermanTaskFactory *factory, const QString &factoryId);
-    bool hadRegistered(const QString &factoryId);
-    SmithWatermanTaskFactory *getFactory(const QString &factoryId);
+    bool registerFactory(SmithWatermanTaskFactory* factory, const QString& factoryId);
+    bool hadRegistered(const QString& factoryId);
+    SmithWatermanTaskFactory* getFactory(const QString& factoryId);
     QStringList getListFactoryNames();
 
 private:
     QMutex mutex;
-    QHash<QString, SmithWatermanTaskFactory *> factories;
+    QHash<QString, SmithWatermanTaskFactory*> factories;
 };
 
 }  // namespace U2
-
-#endif
