@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_STRUCTURAL_ALIGNMENT_ALGORITHM_FACTORY_H_
-#define _U2_STRUCTURAL_ALIGNMENT_ALGORITHM_FACTORY_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -33,9 +32,7 @@ public:
     virtual ~StructuralAlignmentAlgorithmFactory() {
     }
 
-    virtual StructuralAlignmentAlgorithm *create() = 0;
+    virtual StructuralAlignmentAlgorithm* create() = 0;
 };
 
 }  // namespace U2
-
-#endif  // #ifndef _U2_STRUCTURAL_ALIGNMENT_ALGORITHM_FACTORY_H_
