@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_CONSENSUS_ALGORITHM_H_
-#define _U2_ASSEMBLY_CONSENSUS_ALGORITHM_H_
+#pragma once
 
 #include <U2Core/U2Assembly.h>
 #include <U2Core/U2OpStatus.h>
@@ -34,7 +33,7 @@ class AssemblyConsensusAlgorithm;
 class U2ALGORITHM_EXPORT AssemblyConsensusAlgorithmFactory : public QObject {
     Q_OBJECT
 public:
-    AssemblyConsensusAlgorithmFactory(const QString &algoId)
+    AssemblyConsensusAlgorithmFactory(const QString& algoId)
         : algorithmId(algoId) {
     }
 
@@ -45,7 +44,7 @@ public:
     virtual QString getDescription() const = 0;
     virtual QString getName() const = 0;
 
-    virtual AssemblyConsensusAlgorithm *createAlgorithm() = 0;
+    virtual AssemblyConsensusAlgorithm* createAlgorithm() = 0;
 
 private:
     QString algorithmId;
@@ -53,12 +52,12 @@ private:
 
 class U2ALGORITHM_EXPORT AssemblyConsensusAlgorithm {
 public:
-    AssemblyConsensusAlgorithm(AssemblyConsensusAlgorithmFactory *factory_)
+    AssemblyConsensusAlgorithm(AssemblyConsensusAlgorithmFactory* factory_)
         : factory(factory_) {
     }
     virtual ~AssemblyConsensusAlgorithm();
 
-    AssemblyConsensusAlgorithmFactory *getFactory() {
+    AssemblyConsensusAlgorithmFactory* getFactory() {
         return factory;
     }
 
@@ -72,15 +71,13 @@ public:
         return factory->getId();
     }
 
-    virtual QByteArray getConsensusRegion(const U2Region &region, U2DbiIterator<U2AssemblyRead> *reads, QByteArray referenceFragment, U2OpStatus &os) = 0;
+    virtual QByteArray getConsensusRegion(const U2Region& region, U2DbiIterator<U2AssemblyRead>* reads, QByteArray referenceFragment, U2OpStatus& os) = 0;
 
     /** The character that will be placed in consensus array if it is undefined (no bases covered current position) */
     static const char EMPTY_CHAR = '-';
 
 private:
-    AssemblyConsensusAlgorithmFactory *factory;
+    AssemblyConsensusAlgorithmFactory* factory;
 };
 
 }  // namespace U2
-
-#endif
