@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_CONSENSUS_ALGORITHM_DEFAULT_H_
-#define _U2_ASSEMBLY_CONSENSUS_ALGORITHM_DEFAULT_H_
+#pragma once
 
 #include "AssemblyConsensusAlgorithm.h"
 
@@ -33,18 +32,16 @@ public:
     virtual QString getDescription() const;
     virtual QString getName() const;
 
-    virtual AssemblyConsensusAlgorithm *createAlgorithm();
+    virtual AssemblyConsensusAlgorithm* createAlgorithm();
 };
 
 class U2ALGORITHM_EXPORT AssemblyConsensusAlgorithmDefault : public AssemblyConsensusAlgorithm {
 public:
-    AssemblyConsensusAlgorithmDefault(AssemblyConsensusAlgorithmFactoryDefault *factory)
+    AssemblyConsensusAlgorithmDefault(AssemblyConsensusAlgorithmFactoryDefault* factory)
         : AssemblyConsensusAlgorithm(factory) {
     }
 
-    virtual QByteArray getConsensusRegion(const U2Region &region, U2DbiIterator<U2AssemblyRead> *reads, QByteArray referenceFragment, U2OpStatus &os);
+    virtual QByteArray getConsensusRegion(const U2Region& region, U2DbiIterator<U2AssemblyRead>* reads, QByteArray referenceFragment, U2OpStatus& os);
 };
 
 }  // namespace U2
-
-#endif
