@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_CONSENSUS_ALGORITHM_REGISTRY_H_
-#define _U2_ASSEMBLY_CONSENSUS_ALGORITHM_REGISTRY_H_
+#pragma once
 
 #include <QMap>
 #include <QStringList>
@@ -37,20 +36,18 @@ public:
 
     ~AssemblyConsensusAlgorithmRegistry();
 
-    AssemblyConsensusAlgorithmFactory *getAlgorithmFactory(const QString &algoId);
-    void addAlgorithmFactory(AssemblyConsensusAlgorithmFactory *algo);
+    AssemblyConsensusAlgorithmFactory* getAlgorithmFactory(const QString& algoId);
+    void addAlgorithmFactory(AssemblyConsensusAlgorithmFactory* algo);
 
     QList<QString> getAlgorithmIds() const {
         return algorithms.keys();
     }
-    QList<AssemblyConsensusAlgorithmFactory *> getAlgorithmFactories() const {
+    QList<AssemblyConsensusAlgorithmFactory*> getAlgorithmFactories() const {
         return algorithms.values();
     }
 
 private:
-    QMap<QString, AssemblyConsensusAlgorithmFactory *> algorithms;
+    QMap<QString, AssemblyConsensusAlgorithmFactory*> algorithms;
 };
 
 }  // namespace U2
-
-#endif
