@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,11 +34,11 @@ namespace U2 {
 //////////////////////////////////////////////////////////////////////////
 // Factory
 
-MSAConsensusAlgorithmFactory::MSAConsensusAlgorithmFactory(const QString &algoId, ConsensusAlgorithmFlags _flags, QObject *p)
+MSAConsensusAlgorithmFactory::MSAConsensusAlgorithmFactory(const QString& algoId, ConsensusAlgorithmFlags _flags, QObject* p)
     : QObject(p), algorithmId(algoId), flags(_flags) {
 }
 
-ConsensusAlgorithmFlags MSAConsensusAlgorithmFactory::getAphabetFlags(const DNAAlphabet *al) {
+ConsensusAlgorithmFlags MSAConsensusAlgorithmFactory::getAphabetFlags(const DNAAlphabet* al) {
     if (al->getType() == DNAAlphabet_AMINO) {
         return ConsensusAlgorithmFlag_Amino;
     } else if (al->getType() == DNAAlphabet_NUCL) {
@@ -52,19 +52,19 @@ ConsensusAlgorithmFlags MSAConsensusAlgorithmFactory::getAphabetFlags(const DNAA
 // Algorithm
 
 char MSAConsensusAlgorithm::INVALID_CONS_CHAR = '\0';
-MSAConsensusAlgorithm::MSAConsensusAlgorithm(MSAConsensusAlgorithmFactory *_factory, bool ignoreTrailingLeadingGaps, QObject *p)
+MSAConsensusAlgorithm::MSAConsensusAlgorithm(MSAConsensusAlgorithmFactory* _factory, bool ignoreTrailingLeadingGaps, QObject* p)
     : QObject(p), factory(_factory),
       threshold(0),
       ignoreTrailingAndLeadingGaps(ignoreTrailingLeadingGaps) {
 }
 
-MSAConsensusAlgorithm::MSAConsensusAlgorithm(const MSAConsensusAlgorithm &algorithm)
+MSAConsensusAlgorithm::MSAConsensusAlgorithm(const MSAConsensusAlgorithm& algorithm)
     : QObject(algorithm.parent()), factory(algorithm.factory),
       threshold(algorithm.threshold),
       ignoreTrailingAndLeadingGaps(algorithm.ignoreTrailingAndLeadingGaps) {
 }
 
-char MSAConsensusAlgorithm::getConsensusCharAndScore(const MultipleAlignment &ma, int column, int &score, QVector<int> seqIdx) const {
+char MSAConsensusAlgorithm::getConsensusCharAndScore(const MultipleAlignment& ma, int column, int& score, QVector<int> seqIdx) const {
     char consensusChar = getConsensusChar(ma, column, seqIdx);
 
     // now compute score using most freq character
@@ -85,14 +85,14 @@ void MSAConsensusAlgorithm::setThreshold(int val) {
     emit si_thresholdChanged(newThreshold);
 }
 
-bool MSAConsensusAlgorithm::filterIdx(QVector<int> &seqIdx, const MultipleAlignment &ma, const int pos) const {
+bool MSAConsensusAlgorithm::filterIdx(QVector<int>& seqIdx, const MultipleAlignment& ma, const int pos) const {
     CHECK(ignoreTrailingAndLeadingGaps, true);
 
     QVector<int> tmp;
-    int nSeq = seqIdx.isEmpty() ? ma->getNumRows() : seqIdx.size();
+    int nSeq = seqIdx.isEmpty() ? ma->getRowCount() : seqIdx.size();
     for (int seq = 0; seq < nSeq; seq++) {
         int rowNum = seqIdx.isEmpty() ? seq : seqIdx[seq];
-        const MultipleAlignmentRow &row = ma->getRow(rowNum);
+        const MultipleAlignmentRow& row = ma->getRow(rowNum);
         if (row->isTrailingOrLeadingGap(pos)) {
             continue;
         }
