@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@
 
 namespace U2 {
 
-MSAConsensusAlgorithmFactoryLevitsky::MSAConsensusAlgorithmFactoryLevitsky(QObject *p)
+MSAConsensusAlgorithmFactoryLevitsky::MSAConsensusAlgorithmFactoryLevitsky(QObject* p)
     : MSAConsensusAlgorithmFactory(BuiltInConsensusAlgorithms::LEVITSKY_ALGO,
                                    ConsensusAlgorithmFlag_Nucleic | ConsensusAlgorithmFlag_SupportThreshold,
                                    p) {
@@ -42,7 +42,7 @@ QString MSAConsensusAlgorithmFactoryLevitsky::getName() const {
     return tr("Levitsky");
 }
 
-MSAConsensusAlgorithm *MSAConsensusAlgorithmFactoryLevitsky::createAlgorithm(const MultipleAlignment &ma, bool ignoreTrailingLeadingGaps, QObject *p) {
+MSAConsensusAlgorithm* MSAConsensusAlgorithmFactoryLevitsky::createAlgorithm(const MultipleAlignment& ma, bool ignoreTrailingLeadingGaps, QObject* p) {
     return new MSAConsensusAlgorithmLevitsky(this, ma, ignoreTrailingLeadingGaps, p);
 }
 
@@ -69,7 +69,7 @@ N       A,T,G,C 4       Any
 
 */
 
-static void registerHit(int *data, char c) {
+static void registerHit(int* data, char c) {
     int idx = uchar(c);
     data[idx]++;
     switch (c) {
@@ -113,14 +113,13 @@ static void registerHit(int *data, char c) {
     }
 }
 
-MSAConsensusAlgorithmLevitsky::MSAConsensusAlgorithmLevitsky(MSAConsensusAlgorithmFactoryLevitsky *f, const MultipleAlignment &ma, bool ignoreTrailingLeadingGaps, QObject *p)
-    : MSAConsensusAlgorithm(f, ignoreTrailingLeadingGaps, p) {
-    globalFreqs.resize(256);
-    memset(globalFreqs.data(), 0, globalFreqs.size() * 4);
-
+MSAConsensusAlgorithmLevitsky::MSAConsensusAlgorithmLevitsky(MSAConsensusAlgorithmFactoryLevitsky* f, const MultipleAlignment& ma, bool ignoreTrailingLeadingGaps, QObject* p)
+    : MSAConsensusAlgorithm(f, ignoreTrailingLeadingGaps, p)
+    , globalFreqs(QVarLengthArray<int>(256)) {
     int *freqsData = globalFreqs.data();
+    std::fill(globalFreqs.begin(), globalFreqs.end(), 0);
     int len = ma->getLength();
-    foreach (const MultipleAlignmentRow &row, ma->getRows()) {
+    foreach (const MultipleAlignmentRow& row, ma->getRows()) {
         for (int i = 0; i < len; i++) {
             char c = row->charAt(i);
             registerHit(freqsData, c);
@@ -128,40 +127,39 @@ MSAConsensusAlgorithmLevitsky::MSAConsensusAlgorithmLevitsky(MSAConsensusAlgorit
     }
 }
 
-char MSAConsensusAlgorithmLevitsky::getConsensusChar(const MultipleAlignment &ma, int column, QVector<int> seqIdx) const {
+char MSAConsensusAlgorithmLevitsky::getConsensusChar(const MultipleAlignment& ma, int column, QVector<int> seqIdx) const {
     CHECK(filterIdx(seqIdx, ma, column), INVALID_CONS_CHAR);
 
     // count local freqs first
     QVarLengthArray<int> localFreqs(256);
-    memset(localFreqs.data(), 0, localFreqs.size() * 4);
-
-    int *freqsData = localFreqs.data();
-    int nSeq = (seqIdx.isEmpty() ? ma->getNumRows() : seqIdx.size());
+    int* freqsData = localFreqs.data();
+    std::fill(localFreqs.begin(), localFreqs.end(), 0);
+    int nSeq = (seqIdx.isEmpty() ? ma->getRowCount() : seqIdx.size());
     for (int seq = 0; seq < nSeq; seq++) {
         char c = ma->charAt(seqIdx.isEmpty() ? seq : seqIdx[seq], column);
         registerHit(freqsData, c);
     }
-
     // find all symbols with freq > threshold, select one with the lowest global freq
     char selectedChar = U2Msa::GAP_CHAR;
-    int selectedGlobalFreq = nSeq * ma->getLength();
-    int thresholdScore = getThreshold();
-    int minFreq = int(float(nSeq) * thresholdScore / 100);
+    double selectedGlobalPercentage = 1;
+    bool firstConsensusCharFound = false;
+    double thresholdScore = getThreshold() / 100.0;
     for (int c = 'A'; c <= 'Y'; c++) {
-        int localFreq = freqsData[uchar(c)];
-        if (localFreq < minFreq) {
+        double localPercentage = (double)freqsData[uchar(c)] / nSeq;
+        if (localPercentage < thresholdScore) {
             continue;
         }
-        int globalFreq = globalFreqs[uchar(c)];
-        if (globalFreq < selectedGlobalFreq) {
-            selectedGlobalFreq = globalFreq;
+        double globalPercentage = (double)globalFreqs[uchar(c)] / (nSeq * ma->getLength());
+        if ((globalPercentage < selectedGlobalPercentage) || (!firstConsensusCharFound && (globalPercentage == selectedGlobalPercentage))) {
+            firstConsensusCharFound = true;
+            selectedGlobalPercentage = globalPercentage;
             selectedChar = c;
         }
     }
     return selectedChar;
 }
 
-MSAConsensusAlgorithmLevitsky *MSAConsensusAlgorithmLevitsky::clone() const {
+MSAConsensusAlgorithmLevitsky* MSAConsensusAlgorithmLevitsky::clone() const {
     return new MSAConsensusAlgorithmLevitsky(*this);
 }
 
