@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,7 +29,7 @@
 
 namespace U2 {
 
-MSAConsensusAlgorithmFactoryStrict::MSAConsensusAlgorithmFactoryStrict(QObject *p)
+MSAConsensusAlgorithmFactoryStrict::MSAConsensusAlgorithmFactoryStrict(QObject* p)
     : MSAConsensusAlgorithmFactory(BuiltInConsensusAlgorithms::STRICT_ALGO, ConsensusAlgorithmFlags_AllAlphabets | ConsensusAlgorithmFlag_SupportThreshold | ConsensusAlgorithmFlag_AvailableForChromatogram, p) {
 }
 
@@ -41,14 +41,14 @@ QString MSAConsensusAlgorithmFactoryStrict::getName() const {
     return tr("Strict");
 }
 
-MSAConsensusAlgorithm *MSAConsensusAlgorithmFactoryStrict::createAlgorithm(const MultipleAlignment &, bool ignoreTrailingLeadingGaps, QObject *p) {
+MSAConsensusAlgorithm* MSAConsensusAlgorithmFactoryStrict::createAlgorithm(const MultipleAlignment&, bool ignoreTrailingLeadingGaps, QObject* p) {
     return new MSAConsensusAlgorithmStrict(this, ignoreTrailingLeadingGaps, p);
 }
 
 //////////////////////////////////////////////////////////////////////////
 // Algorithm
 
-char MSAConsensusAlgorithmStrict::getConsensusChar(const MultipleAlignment &ma, int column, QVector<int> seqIdx) const {
+char MSAConsensusAlgorithmStrict::getConsensusChar(const MultipleAlignment& ma, int column, QVector<int> seqIdx) const {
     CHECK(filterIdx(seqIdx, ma, column), INVALID_CONS_CHAR);
 
     QVector<int> freqsByChar(256, 0);
@@ -56,15 +56,15 @@ char MSAConsensusAlgorithmStrict::getConsensusChar(const MultipleAlignment &ma,
     uchar topChar = MSAConsensusUtils::getColumnFreqs(ma, column, freqsByChar, nonGaps, seqIdx);
 
     // use gap is top char frequency is lower than threshold
-    int nSeq = (seqIdx.isEmpty() ? ma->getNumRows() : seqIdx.size());
+    int nSeq = (seqIdx.isEmpty() ? ma->getRowCount() : seqIdx.size());
     int currentThreshold = getThreshold();
-    int cntToUseGap = int(currentThreshold / 100.0 * nSeq);
-    int topFreq = freqsByChar[topChar];
+    double cntToUseGap = currentThreshold / 100.0 * nSeq;
+    double topFreq = freqsByChar[topChar];
     char res = topFreq < cntToUseGap ? U2Msa::GAP_CHAR : (char)topChar;
     return res;
 }
 
-MSAConsensusAlgorithmStrict *MSAConsensusAlgorithmStrict::clone() const {
+MSAConsensusAlgorithmStrict* MSAConsensusAlgorithmStrict::clone() const {
     return new MSAConsensusAlgorithmStrict(*this);
 }
 
