@@ -1,6 +1,6 @@
 ﻿/**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_DISTANCE_ALGORITHM_H_
-#define _U2_MSA_DISTANCE_ALGORITHM_H_
+#pragma once
 
 #include <QMutex>
 #include <QVarLengthArray>
@@ -50,9 +49,9 @@ typedef QFlags<DistanceAlgorithmFlag> DistanceAlgorithmFlags;
 class U2ALGORITHM_EXPORT MSADistanceAlgorithmFactory : public QObject {
     Q_OBJECT
 public:
-    MSADistanceAlgorithmFactory(const QString &algoId, DistanceAlgorithmFlags flags, QObject *p = nullptr);
+    MSADistanceAlgorithmFactory(const QString& algoId, DistanceAlgorithmFlags flags, QObject* p = nullptr);
 
-    virtual MSADistanceAlgorithm *createAlgorithm(const MultipleSequenceAlignment &ma, QObject *parent = nullptr) = 0;
+    virtual MSADistanceAlgorithm* createAlgorithm(const MultipleSequenceAlignment& ma, QObject* parent = nullptr) = 0;
 
     QString getId() const {
         return algorithmId;
@@ -70,7 +69,7 @@ public:
     virtual QString getName() const = 0;
 
     // utility method
-    static DistanceAlgorithmFlags getAphabetFlags(const DNAAlphabet *al);
+    static DistanceAlgorithmFlags getAphabetFlags(const DNAAlphabet* al);
 
 protected:
     QString algorithmId;
@@ -84,7 +83,7 @@ class U2ALGORITHM_EXPORT MSADistanceMatrix {
 
 private:
     MSADistanceMatrix();
-    MSADistanceMatrix(const MultipleSequenceAlignment &ma, bool _excludeGaps, bool _usePercents);
+    MSADistanceMatrix(const MultipleSequenceAlignment& ma, bool _excludeGaps, bool _usePercents);
 
 public:
     bool isEmpty() {
@@ -111,11 +110,11 @@ class U2ALGORITHM_EXPORT MSADistanceAlgorithm : public Task {
     Q_OBJECT
 
 public:
-    MSADistanceAlgorithm(MSADistanceAlgorithmFactory *factory, const MultipleSequenceAlignment &ma);
+    MSADistanceAlgorithm(MSADistanceAlgorithmFactory* factory, const MultipleSequenceAlignment& ma);
 
     int getSimilarity(int row1, int row2, bool usePercents);
 
-    const MSADistanceMatrix &getMatrix() const;
+    const MSADistanceMatrix& getMatrix() const;
 
     virtual QString getDescription() const {
         return factory->getDescription();
@@ -135,7 +134,7 @@ public:
 
     void setExcludeGaps(bool _excludeGaps);
 
-    MSADistanceAlgorithmFactory *getFactory() const {
+    MSADistanceAlgorithmFactory* getFactory() const {
         return factory;
     }
 
@@ -147,7 +146,7 @@ public:
 
 private:
     MSADistanceMatrix distanceMatrix;
-    MSADistanceAlgorithmFactory *factory;
+    MSADistanceAlgorithmFactory* factory;
     MemoryLocker memoryLocker;
 
 protected:
@@ -162,5 +161,3 @@ protected:
 };
 
 }  // namespace U2
-
-#endif
