@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_DISTANCE_ALGORITHM_HAMMING_COMPL_H_
-#define _U2_MSA_DISTANCE_ALGORITHM_HAMMING_COMPL_H_
+#pragma once
 
 #include "BuiltInDistanceAlgorithms.h"
 #include "MSADistanceAlgorithm.h"
@@ -31,9 +30,9 @@ namespace U2 {
 class U2ALGORITHM_EXPORT MSADistanceAlgorithmFactoryHammingRevCompl : public MSADistanceAlgorithmFactory {
     Q_OBJECT
 public:
-    MSADistanceAlgorithmFactoryHammingRevCompl(QObject *p = nullptr);
+    MSADistanceAlgorithmFactoryHammingRevCompl(QObject* p = nullptr);
 
-    virtual MSADistanceAlgorithm *createAlgorithm(const MultipleSequenceAlignment &ma, QObject *parent);
+    virtual MSADistanceAlgorithm* createAlgorithm(const MultipleSequenceAlignment& ma, QObject* parent);
 
     virtual QString getDescription() const;
 
@@ -43,7 +42,7 @@ public:
 class U2ALGORITHM_EXPORT MSADistanceAlgorithmHammingRevCompl : public MSADistanceAlgorithm {
     Q_OBJECT
 public:
-    MSADistanceAlgorithmHammingRevCompl(MSADistanceAlgorithmFactoryHammingRevCompl *f, const MultipleSequenceAlignment &ma)
+    MSADistanceAlgorithmHammingRevCompl(MSADistanceAlgorithmFactoryHammingRevCompl* f, const MultipleSequenceAlignment& ma)
         : MSADistanceAlgorithm(f, ma) {
     }
 
@@ -51,5 +50,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
