@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_DISTANCE_ALGORITHM_REGISTRY_H_
-#define _U2_MSA_DISTANCE_ALGORITHM_REGISTRY_H_
+#pragma once
 
 #include <QStringList>
 
@@ -34,26 +33,24 @@ class U2ALGORITHM_EXPORT MSADistanceAlgorithmRegistry : public QObject {
     Q_OBJECT
 
 public:
-    MSADistanceAlgorithmRegistry(QObject *p = nullptr);
+    MSADistanceAlgorithmRegistry(QObject* p = nullptr);
 
     ~MSADistanceAlgorithmRegistry();
 
-    MSADistanceAlgorithmFactory *getAlgorithmFactory(const QString &algoId);
+    MSADistanceAlgorithmFactory* getAlgorithmFactory(const QString& algoId);
 
-    void addAlgorithm(MSADistanceAlgorithmFactory *algo);
+    void addAlgorithm(MSADistanceAlgorithmFactory* algo);
 
     QStringList getAlgorithmIds() const;
 
-    QList<MSADistanceAlgorithmFactory *> getAlgorithmFactories() const {
+    QList<MSADistanceAlgorithmFactory*> getAlgorithmFactories() const {
         return algorithms.values();
     }
 
-    QList<MSADistanceAlgorithmFactory *> getAlgorithmFactories(DistanceAlgorithmFlags flags) const;
+    QList<MSADistanceAlgorithmFactory*> getAlgorithmFactories(DistanceAlgorithmFlags flags) const;
 
 private:
-    QMap<QString, MSADistanceAlgorithmFactory *> algorithms;
+    QMap<QString, MSADistanceAlgorithmFactory*> algorithms;
 };
 
 }  // namespace U2
-
-#endif
