@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@
 
 namespace U2 {
 
-MSADistanceAlgorithmFactorySimilarity::MSADistanceAlgorithmFactorySimilarity(QObject *p)
+MSADistanceAlgorithmFactorySimilarity::MSADistanceAlgorithmFactorySimilarity(QObject* p)
     : MSADistanceAlgorithmFactory(BuiltInDistanceAlgorithms::SIMILARITY_ALGO, DistanceAlgorithmFlags_NuclAmino, p) {
 }
 
@@ -37,8 +37,8 @@ QString MSADistanceAlgorithmFactorySimilarity::getName() const {
     return tr("Similarity");
 }
 
-MSADistanceAlgorithm *MSADistanceAlgorithmFactorySimilarity::createAlgorithm(const MultipleSequenceAlignment &ma, QObject *) {
-    MSADistanceAlgorithm *res = new MSADistanceAlgorithmSimilarity(this, ma);
+MSADistanceAlgorithm* MSADistanceAlgorithmFactorySimilarity::createAlgorithm(const MultipleSequenceAlignment& ma, QObject*) {
+    MSADistanceAlgorithm* res = new MSADistanceAlgorithmSimilarity(this, ma);
     if (flags.testFlag(DistanceAlgorithmFlag_ExcludeGaps)) {
         res->setExcludeGaps(true);
     } else {
@@ -51,7 +51,7 @@ MSADistanceAlgorithm *MSADistanceAlgorithmFactorySimilarity::createAlgorithm(con
 // Algorithm
 
 void MSADistanceAlgorithmSimilarity::run() {
-    int nSeq = ma->getNumRows();
+    int nSeq = ma->getRowCount();
     for (int i = 0; i < nSeq; i++) {
         for (int j = i; j < nSeq; j++) {
             int sim = 0;
