@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CREATE_SUBALIGNMENT_TASK_H_
-#define _U2_CREATE_SUBALIGNMENT_TASK_H_
+#pragma once
 
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentProviderTask.h>
@@ -33,12 +32,12 @@ namespace U2 {
 
 class U2ALGORITHM_EXPORT CreateSubalignmentSettings {
 public:
-    CreateSubalignmentSettings(const QList<qint64> &rowIds,
-                               const U2Region &columnRange,
-                               const GUrl &url,
+    CreateSubalignmentSettings(const QList<qint64>& rowIds,
+                               const U2Region& columnRange,
+                               const GUrl& url,
                                bool saveImmediately,
                                bool addToProject,
-                               const DocumentFormatId &formatIdToSave);
+                               const DocumentFormatId& formatIdToSave);
 
     /** Row ids to export. */
     QList<qint64> rowIds;
@@ -55,22 +54,20 @@ public:
 class U2ALGORITHM_EXPORT CreateSubalignmentTask : public DocumentProviderTask {
     Q_OBJECT
 public:
-    CreateSubalignmentTask(MultipleSequenceAlignmentObject *_maObj, const CreateSubalignmentSettings &settings);
+    CreateSubalignmentTask(MultipleSequenceAlignmentObject* _maObj, const CreateSubalignmentSettings& settings);
 
     virtual void prepare();
-    const CreateSubalignmentSettings &getSettings() {
+    const CreateSubalignmentSettings& getSettings() {
         return cfg;
     }
 
 private:
-    Document *origDoc;
-    MultipleSequenceAlignmentObject *origMAObj;
-    MultipleSequenceAlignmentObject *resultMAObj;
+    Document* origDoc;
+    MultipleSequenceAlignmentObject* origMAObj;
+    MultipleSequenceAlignmentObject* resultMAObj;
 
     CreateSubalignmentSettings cfg;
     bool createCopy;
 };
 
 }  // namespace U2
-
-#endif
