@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_UTIL_TASKS
-#define _U2_MSA_UTIL_TASKS
+#pragma once
 
 #include <U2Core/MultipleSequenceAlignmentObject.h>
 #include <U2Core/Task.h>
@@ -37,9 +36,9 @@ class DNATranslation;
 class U2ALGORITHM_EXPORT TranslateMsa2AminoTask : public Task {
     Q_OBJECT
 public:
-    TranslateMsa2AminoTask(MultipleSequenceAlignmentObject *obj);
-    TranslateMsa2AminoTask(MultipleSequenceAlignmentObject *obj, const QString &trId);
-    const MultipleSequenceAlignment &getTaskResult() {
+    TranslateMsa2AminoTask(MultipleSequenceAlignmentObject* obj);
+    TranslateMsa2AminoTask(MultipleSequenceAlignmentObject* obj, const QString& trId);
+    const MultipleSequenceAlignment& getTaskResult() {
         return resultMA;
     }
     void run();
@@ -47,8 +46,8 @@ public:
 
 private:
     MultipleSequenceAlignment resultMA;
-    MultipleSequenceAlignmentObject *maObj;
-    DNATranslation *translation;
+    MultipleSequenceAlignmentObject* maObj;
+    DNATranslation* translation;
 };
 
 /**
@@ -58,13 +57,13 @@ private:
 class U2ALGORITHM_EXPORT AlignGObjectTask : public Task {
     Q_OBJECT
 public:
-    AlignGObjectTask(const QString &taskName, TaskFlags f, MultipleSequenceAlignmentObject *maobj)
+    AlignGObjectTask(const QString& taskName, TaskFlags f, MultipleSequenceAlignmentObject* maobj)
         : Task(taskName, f), obj(maobj) {
     }
-    virtual void setMAObject(MultipleSequenceAlignmentObject *maobj) {
+    virtual void setMAObject(MultipleSequenceAlignmentObject* maobj) {
         obj = maobj;
     }
-    MultipleSequenceAlignmentObject *getMAObject() {
+    MultipleSequenceAlignmentObject* getMAObject() {
         return obj;
     }
 
@@ -83,7 +82,7 @@ class U2ALGORITHM_EXPORT AlignInAminoFormTask : public Task {
     Q_OBJECT
     Q_DISABLE_COPY(AlignInAminoFormTask)
 public:
-    AlignInAminoFormTask(MultipleSequenceAlignmentObject *obj, AlignGObjectTask *alignTask, const QString &traslId);
+    AlignInAminoFormTask(MultipleSequenceAlignmentObject* obj, AlignGObjectTask* alignTask, const QString& traslId);
     ~AlignInAminoFormTask();
 
     virtual void prepare();
@@ -91,14 +90,12 @@ public:
     virtual ReportResult report();
 
 protected:
-    AlignGObjectTask *alignTask;
+    AlignGObjectTask* alignTask;
     MultipleSequenceAlignmentObject *maObj, *clonedObj;
     QString traslId;
-    Document *tmpDoc;
-    QMap<qint64, QList<U2MsaGap>> rowsGapModel;
-    QMap<qint64, QList<U2MsaGap>> emptyGapModel;
+    Document* tmpDoc;
+    QMap<qint64, QVector<U2MsaGap>> rowsGapModel;
+    QMap<qint64, QVector<U2MsaGap>> emptyGapModel;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_UTIL_TASKS
