@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_COLOR_SCHEME_UTILS_H_
-#define _U2_COLOR_SCHEME_UTILS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -30,13 +29,13 @@ namespace U2 {
 
 class U2ALGORITHM_EXPORT ColorSchemeUtils {
 public:
-    static bool getSchemaColors(ColorSchemeData &customScheme);
+    static bool getSchemaColors(ColorSchemeData& customScheme);
     static QList<ColorSchemeData> getSchemas();
     static QString getColorsDir();
-    static void getDefaultUgeneColors(DNAAlphabetType type, QMap<char, QColor> &alphColors);
+    static void getDefaultUgeneColors(DNAAlphabetType type, QMap<char, QColor>& alphColors);
     static QMap<char, QColor> getDefaultSchemaColors(DNAAlphabetType type, bool defaultAlpType);
-    static void setColorsDir(const QString &colorsDir);
-    static void fillEmptyColorScheme(QVector<QColor> &colorsPerChar);
+    static void setColorsDir(const QString& colorsDir);
+    static void fillEmptyColorScheme(QVector<QColor>& colorsPerChar);
 
     static const QString COLOR_SCHEME_AMINO_KEYWORD;
     static const QString COLOR_SCHEME_NUCL_KEYWORD;
@@ -50,5 +49,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // _U2_COLOR_SCHEME_UTILS_H_
