@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_COLOR_SCHEME_CUSTOM_H_
-#define _U2_MSA_COLOR_SCHEME_CUSTOM_H_
+#pragma once
 
 #include <QColor>
 #include <QVector>
@@ -32,19 +31,17 @@ namespace U2 {
 class U2ALGORITHM_EXPORT MsaColorSchemeCustomFactory : public MsaColorSchemeFactory {
     Q_OBJECT
 public:
-    MsaColorSchemeCustomFactory(QObject *parent, const ColorSchemeData &scheme);
+    MsaColorSchemeCustomFactory(QObject* parent, const ColorSchemeData& scheme);
 
-    MsaColorScheme *create(QObject *p, MultipleAlignmentObject *obj) const;
-    bool isEqualTo(const ColorSchemeData &scheme) const;
+    MsaColorScheme* create(QObject* p, MultipleAlignmentObject* obj) const;
+    bool isEqualTo(const ColorSchemeData& scheme) const;
 
-    void setScheme(const ColorSchemeData &scheme);
+    void setScheme(const ColorSchemeData& scheme);
 
 private:
-    static QVector<QColor> colorMapToColorVector(const QMap<char, QColor> &map);
+    static QVector<QColor> colorMapToColorVector(const QMap<char, QColor>& map);
 
     QVector<QColor> colorsPerChar;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_COLOR_SCHEME_CUSTOM_H_
