@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_COLOR_SCHEME_PERCENTAGE_IDENTENTITY_COLORED_FACTORY_H_
-#define _U2_MSA_COLOR_SCHEME_PERCENTAGE_IDENTENTITY_COLORED_FACTORY_H_
+#pragma once
 
 #include "../../MsaColorSchemePercentageIdentity.h"
 
@@ -29,11 +28,9 @@ namespace U2 {
 class MsaColorSchemePercentageIdententityColoredFactory : public MsaColorSchemeFactory {
     Q_OBJECT
 public:
-    MsaColorSchemePercentageIdententityColoredFactory(QObject *parent, const QString &id, const QString &name, const AlphabetFlags &supportedAlphabets);
+    MsaColorSchemePercentageIdententityColoredFactory(QObject* parent, const QString& id, const QString& name, const AlphabetFlags& supportedAlphabets);
 
-    MsaColorScheme *create(QObject *parent, MultipleAlignmentObject *maObj) const;
+    MsaColorScheme* create(QObject* parent, MultipleAlignmentObject* maObj) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_COLOR_SCHEME_PERCENTAGE_IDENTENTITY_COLORED_FACTORY_H_
