@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_HIGHLIGHTING_SCHEME_H_
-#define _U2_MSA_HIGHLIGHTING_SCHEME_H_
+#pragma once
 
 #include <QObject>
 
@@ -36,15 +35,15 @@ class MsaHighlightingSchemeFactory;
 class U2ALGORITHM_EXPORT MsaHighlightingScheme : public QObject {
     Q_OBJECT
 public:
-    MsaHighlightingScheme(QObject *parent, const MsaHighlightingSchemeFactory *factory, MultipleAlignmentObject *maObj);
+    MsaHighlightingScheme(QObject* parent, const MsaHighlightingSchemeFactory* factory, MultipleAlignmentObject* maObj);
 
-    virtual void process(const char refChar, char &seqChar, QColor &color, bool &highlight, int refCharColumn, int refCharRow) const;
-    const MsaHighlightingSchemeFactory *getFactory() const;
+    virtual void process(const char refChar, char& seqChar, QColor& color, bool& highlight, int refCharColumn, int refCharRow) const;
+    const MsaHighlightingSchemeFactory* getFactory() const;
 
     void setUseDots(bool use);
     bool getUseDots() const;
 
-    virtual void applySettings(const QVariantMap &settings);
+    virtual void applySettings(const QVariantMap& settings);
     virtual QVariantMap getSettings() const;
 
     static const QString EMPTY;
@@ -59,24 +58,24 @@ public:
     static const QString LESS_THAN_THRESHOLD_PARAMETER_NAME;
 
 protected:
-    const MsaHighlightingSchemeFactory *factory;
-    MultipleAlignmentObject *maObj;
+    const MsaHighlightingSchemeFactory* factory;
+    MultipleAlignmentObject* maObj;
     bool useDots;
 };
 
 class U2ALGORITHM_EXPORT MsaHighlightingSchemeFactory : public QObject {
     Q_OBJECT
 public:
-    MsaHighlightingSchemeFactory(QObject *parent, const QString &id, const QString &name, const AlphabetFlags &supportedAlphabets, bool refFree = false, bool needThreshold = false);
+    MsaHighlightingSchemeFactory(QObject* parent, const QString& id, const QString& name, const AlphabetFlags& supportedAlphabets, bool refFree = false, bool needThreshold = false);
 
-    virtual MsaHighlightingScheme *create(QObject *parent, MultipleAlignmentObject *maObj) const = 0;
+    virtual MsaHighlightingScheme* create(QObject* parent, MultipleAlignmentObject* maObj) const = 0;
 
-    const QString &getId() const;
-    const QString &getName() const;
+    const QString& getId() const;
+    const QString& getName() const;
     bool isRefFree() const;
     bool isNeedThreshold() const;
     bool isAlphabetTypeSupported(DNAAlphabetType alphabetType) const;
-    const AlphabetFlags &getSupportedAlphabets() const;
+    const AlphabetFlags& getSupportedAlphabets() const;
 
 private:
     QString id;
@@ -92,15 +91,13 @@ public:
     MsaHighlightingSchemeRegistry();
     ~MsaHighlightingSchemeRegistry();
 
-    MsaHighlightingSchemeFactory *getSchemeFactoryById(const QString &id) const;
-    MsaHighlightingSchemeFactory *getEmptySchemeFactory() const;
-    QList<MsaHighlightingSchemeFactory *> getAllSchemes(DNAAlphabetType alphabetType) const;
-    QMap<AlphabetFlags, QList<MsaHighlightingSchemeFactory *>> getAllSchemesGrouped() const;
+    MsaHighlightingSchemeFactory* getSchemeFactoryById(const QString& id) const;
+    MsaHighlightingSchemeFactory* getEmptySchemeFactory() const;
+    QList<MsaHighlightingSchemeFactory*> getAllSchemes(DNAAlphabetType alphabetType) const;
+    QMap<AlphabetFlags, QList<MsaHighlightingSchemeFactory*>> getAllSchemesGrouped() const;
 
 private:
-    QList<MsaHighlightingSchemeFactory *> schemes;
+    QList<MsaHighlightingSchemeFactory*> schemes;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_HIGHLIGHTING_SCHEME_H_
