@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_HIGHLIGHTING_SCHEME_TRANSVERSIONS_H_
-#define _U2_MSA_HIGHLIGHTING_SCHEME_TRANSVERSIONS_H_
+#pragma once
 
 #include "MsaHighlightingScheme.h"
 
@@ -29,18 +28,16 @@ namespace U2 {
 class MsaHighlightingSchemeTransversions : public MsaHighlightingScheme {
     Q_OBJECT
 public:
-    MsaHighlightingSchemeTransversions(QObject *parent, const MsaHighlightingSchemeFactory *factory, MultipleAlignmentObject *maObj);
+    MsaHighlightingSchemeTransversions(QObject* parent, const MsaHighlightingSchemeFactory* factory, MultipleAlignmentObject* maObj);
 
-    void process(const char refChar, char &seqChar, QColor &color, bool &highlight, int refCharColumn, int refCharRow) const;
+    void process(const char refChar, char& seqChar, QColor& color, bool& highlight, int refCharColumn, int refCharRow) const;
 };
 
 class U2ALGORITHM_EXPORT MsaHighlightingSchemeTransversionsFactory : public MsaHighlightingSchemeFactory {
 public:
-    MsaHighlightingSchemeTransversionsFactory(QObject *parent, const QString &id, const QString &name, const AlphabetFlags &supportedAlphabets);
+    MsaHighlightingSchemeTransversionsFactory(QObject* parent, const QString& id, const QString& name, const AlphabetFlags& supportedAlphabets);
 
-    MsaHighlightingScheme *create(QObject *parent, MultipleAlignmentObject *maObj) const;
+    MsaHighlightingScheme* create(QObject* parent, MultipleAlignmentObject* maObj) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_HIGHLIGHTING_SCHEME_TRANSVERSIONS_H_
