@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SARRAY_BASED_FIND_TASK_H_
-#define _U2_SARRAY_BASED_FIND_TASK_H_
+#pragma once
 
 #include <QMutex>
 
@@ -44,7 +43,7 @@ struct U2ALGORITHM_EXPORT SArrayBasedSearchSettings {
     bool useBitMask;
     char unknownChar;
     quint32 bitMaskCharBitsNum;
-    const quint32 *bitMask;
+    const quint32* bitMask;
     int ptMismatches;
     int nMismatches;
     bool absMismatches;
@@ -53,26 +52,24 @@ struct U2ALGORITHM_EXPORT SArrayBasedSearchSettings {
 class U2ALGORITHM_EXPORT SArrayBasedFindTask : public Task {
     Q_OBJECT
 public:
-    SArrayBasedFindTask(SArrayIndex *i, const SArrayBasedSearchSettings &s, bool onlyFirstMatch = false);
+    SArrayBasedFindTask(SArrayIndex* i, const SArrayBasedSearchSettings& s, bool onlyFirstMatch = false);
     virtual void run();
     virtual void cleanup();
-    const QList<int> &getResults() const {
+    const QList<int>& getResults() const {
         return results;
     }
-    const QByteArray &getQuery() const {
+    const QByteArray& getQuery() const {
         return config->query;
     }
 
 private:
     void runSearch();
     void runSearchWithMismatches();
-    SArrayIndex *index;
-    SArrayBasedSearchSettings *config;
+    SArrayIndex* index;
+    SArrayBasedSearchSettings* config;
     QList<int> results;
     QMutex lock;
     bool onlyFirstMatch;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SARRAY_BASED_FIND_TASK_H_
