@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PWM_CONVERSION_ALGORITHM_H_
-#define _U2_PWM_CONVERSION_ALGORITHM_H_
+#pragma once
 
 #include <U2Core/PFMatrix.h>
 #include <U2Core/PWMatrix.h>
@@ -33,9 +32,9 @@ class PWMConversionAlgorithm;
 class U2ALGORITHM_EXPORT PWMConversionAlgorithmFactory : public QObject {
     Q_OBJECT
 public:
-    PWMConversionAlgorithmFactory(const QString &algoId, QObject *p = nullptr);
+    PWMConversionAlgorithmFactory(const QString& algoId, QObject* p = nullptr);
 
-    virtual PWMConversionAlgorithm *createAlgorithm(QObject *parent = nullptr) = 0;
+    virtual PWMConversionAlgorithm* createAlgorithm(QObject* parent = nullptr) = 0;
 
     QString getId() const {
         return algorithmId;
@@ -52,18 +51,16 @@ private:
 class U2ALGORITHM_EXPORT PWMConversionAlgorithm : public QObject {
     Q_OBJECT
 public:
-    PWMConversionAlgorithm(PWMConversionAlgorithmFactory *factory, QObject *p = nullptr);
+    PWMConversionAlgorithm(PWMConversionAlgorithmFactory* factory, QObject* p = nullptr);
 
-    virtual PWMatrix convert(const PFMatrix &matrix) = 0;
+    virtual PWMatrix convert(const PFMatrix& matrix) = 0;
 
     QString getId() const {
         return factory->getId();
     }
 
 private:
-    PWMConversionAlgorithmFactory *factory;
+    PWMConversionAlgorithmFactory* factory;
 };
 
 }  // namespace U2
-
-#endif
