@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PWM_CONVERSION_ALGORITHM_NLG_H_
-#define _U2_PWM_CONVERSION_ALGORITHM_NLG_H_
+#pragma once
 
 #include <U2Core/PFMatrix.h>
 #include <U2Core/PWMatrix.h>
@@ -34,9 +33,9 @@ namespace U2 {
 class U2ALGORITHM_EXPORT PWMConversionAlgorithmFactoryNLG : public PWMConversionAlgorithmFactory {
     Q_OBJECT
 public:
-    PWMConversionAlgorithmFactoryNLG(QObject *p = nullptr);
+    PWMConversionAlgorithmFactoryNLG(QObject* p = nullptr);
 
-    virtual PWMConversionAlgorithm *createAlgorithm(QObject *parent);
+    virtual PWMConversionAlgorithm* createAlgorithm(QObject* parent);
 
     virtual QString getDescription() const;
 
@@ -46,11 +45,9 @@ public:
 class U2ALGORITHM_EXPORT PWMConversionAlgorithmNLG : public PWMConversionAlgorithm {
     Q_OBJECT
 public:
-    PWMConversionAlgorithmNLG(PWMConversionAlgorithmFactory *factory, QObject *p = nullptr);
+    PWMConversionAlgorithmNLG(PWMConversionAlgorithmFactory* factory, QObject* p = nullptr);
 
-    virtual PWMatrix convert(const PFMatrix &matrix);
+    virtual PWMatrix convert(const PFMatrix& matrix);
 };
 
 }  // namespace U2
-
-#endif
