@@ -3,90 +3,24 @@
 <TS version="2.1" language="ru">
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="62"/>
-        <source>Loading OPENCL driver library</source>
-        <translation>Загрузка драйверов библиотеки OPENCL</translation>
-    </message>
-    <message>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="66"/>
-        <source>Cannot load OpenCL library. Error while loading %1</source>
-        <translation>Невозможно загрузить OpenCL библиотеку. Ошибка в процессе загрузки %1</translation>
-    </message>
-    <message>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="73"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="80"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="87"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="94"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="103"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="110"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="117"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="124"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="131"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="138"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="145"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="152"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="159"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="166"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="173"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="180"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="187"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="194"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="201"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="208"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="215"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="222"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="229"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="236"/>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="243"/>
-        <source>Cannot resolve symbol %1</source>
-        <translation>Невозможно разрешить символ %1</translation>
-    </message>
-    <message>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="258"/>
-        <source>Cannot load library: %1</source>
-        <translation>Невозможно загрузить библиотеку: %1</translation>
-    </message>
-    <message>
-        <location filename="../src/util_gpu/opencl/OpenCLHelper.cpp" line="261"/>
-        <source>Some errors occurs in library: %1</source>
-        <translation>Найдены ошибки в библиотеке: %1</translation>
-    </message>
     <message>
         <location filename="../src/util_msa_consensus/MSAConsensusUtils.cpp" line="118"/>
         <source>Gaps:</source>
         <translation>Пробелы:</translation>
     </message>
     <message>
-        <location filename="../src/misc/BinaryFindOpenCL.cpp" line="70"/>
-        <source>clear OpenCL resources</source>
-        <translation>очистка OpenCL ресурсов</translation>
+        <location filename="../src/misc/FindAlgorithm.cpp" line="160"/>
+        <location filename="../src/misc/FindAlgorithm.cpp" line="824"/>
+        <source>The search pattern is too long.</source>
+        <translation></translation>
     </message>
+</context>
+<context>
+    <name>RoughTmCalculatorCmdFactory</name>
     <message>
-        <location filename="../src/misc/BinaryFindOpenCL.cpp" line="174"/>
-        <source>GPU memory usage: %1 Mb</source>
-        <translation>Использование памяти: %1 Mb</translation>
-    </message>
-    <message>
-        <location filename="../src/misc/BinaryFindOpenCL.cpp" line="190"/>
-        <source>Device&apos;s preferred work group size multiple is %1</source>
-        <translation>Предпочтительный размер рабочей группы кратен %1</translation>
-    </message>
-    <message>
-        <location filename="../src/util_gpu/opencl/OpenCLUtils.cpp" line="72"/>
-        <source>OPENCL: BUILD LOG 
- ******************** 
- %1 
- ********************</source>
-        <translation>OPENCL: BUILD LOG 
- ******************** 
- %1 
- ********************</translation>
-    </message>
-    <message>
-        <location filename="../src/util_gpu/opencl/OpenCLUtils.cpp" line="73"/>
-        <source>OPENCL: Program::build() failed. (%1)</source>
-        <translation>OPENCL: Program::build() failed. (%1)</translation>
+        <location filename="../src/temperature/rough/RoughTmCalculatorCmdFactory.cpp" line="28"/>
+        <source>Rough</source>
+        <translation>Приблизительный</translation>
     </message>
 </context>
 <context>
@@ -96,11 +30,6 @@
         <source>Align in amino form</source>
         <translation>Выравнивание в амино форму</translation>
     </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="103"/>
-        <source>Invalid MSA object detected</source>
-        <translation>Обнаружен некорректный MSA объект</translation>
-    </message>
     <message>
         <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="104"/>
         <source>AlignInAminoFormTask: Input alphabet is not nucleic!</source>
@@ -111,31 +40,6 @@
         <source>AlignInAminoFormTask: Input alignment is empty!</source>
         <translation>AlignInAminoFormTask: Входное выравнивание пустое!</translation>
     </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="112"/>
-        <source>Invalid applications settings detected</source>
-        <translation>Обнаружены некорректные настройки приложений</translation>
-    </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="115"/>
-        <source>Invalid users applications settings detected</source>
-        <translation>Обнаружены некорректные настройки приложений</translation>
-    </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="122"/>
-        <source>Invalid MSA document detected</source>
-        <translation>Обнаружен некорректный MSA документ</translation>
-    </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="142"/>
-        <source>NULL clonedObj in AlignInAminoFormTask::prepare!</source>
-        <translation>NULL clonedObj in AlignInAminoFormTask::prepare!</translation>
-    </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="151"/>
-        <source>Can not find row %1 in original alignment.</source>
-        <translation>Строка %1 не может быть найдена в исходном выравнивании.</translation>
-    </message>
 </context>
 <context>
     <name>U2::AlignmentAlgorithmsRegistry</name>
@@ -161,27 +65,27 @@
 <context>
     <name>U2::AssemblyConsensusAlgorithmFactorySamtools</name>
     <message>
-        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="45"/>
+        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="44"/>
         <source>SAMtools</source>
         <translation>SAMtools</translation>
     </message>
     <message>
-        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="49"/>
+        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="48"/>
         <source>Uses SAMtools to calculate consensus with regard to quality of reads</source>
         <translation>Использует SAMtools для расчета консенсуса по отношению к качеству ридов</translation>
     </message>
     <message>
-        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="70"/>
+        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="69"/>
         <source>Fetching reads from database and converting to SAMtools format</source>
         <translation>Выборка ридов из базы данных и преобразование в формат SAMtools</translation>
     </message>
     <message>
-        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="73"/>
+        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="72"/>
         <source>Sorting reads</source>
         <translation>Сортировка ридов</translation>
     </message>
     <message>
-        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="76"/>
+        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="75"/>
         <source>Calculating consensus</source>
         <translation>Вычисление консенсуса</translation>
     </message>
@@ -191,7 +95,7 @@
     <message>
         <location filename="../src/msa_alignment/SimpleAddingToAlignment.cpp" line="153"/>
         <source>Best position find task</source>
-        <translation>Best position find task</translation>
+        <translation>Задача поиска лучшей позиции</translation>
     </message>
 </context>
 <context>
@@ -220,7 +124,7 @@
     <message>
         <location filename="../src/registry/DnaAssemblyTask.cpp" line="37"/>
         <source>Align short reads</source>
-        <translation>Align short reads</translation>
+        <translation>Выравнивание коротких ридов</translation>
     </message>
 </context>
 <context>
@@ -236,38 +140,38 @@
     <message>
         <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="80"/>
         <source>Assembly cannot be performed.</source>
-        <translation>Assembly cannot be performed.</translation>
+        <translation>Сборка не может быть выполнена.</translation>
     </message>
     <message>
         <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="98"/>
         <source>Assembly task finished with error: %1</source>
-        <translation>Assembly task finished with error: %1</translation>
+        <translation>Сборка завершилась с ошибкой: %1</translation>
     </message>
     <message>
         <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="100"/>
         <source>Assembly task wasn&apos;t set</source>
-        <translation>Assembly task wasn&apos;t set</translation>
+        <translation>Задача сборки не установлена</translation>
     </message>
     <message>
         <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="103"/>
         <source>Assembly was finished successfully</source>
-        <translation>Assembly was finished successfully</translation>
+        <translation>Сборка завершилась корректно</translation>
     </message>
     <message>
         <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="105"/>
         <source>Assembly failed.</source>
-        <translation>Assembly failed.</translation>
+        <translation>Сборка не удалась.</translation>
     </message>
 </context>
 <context>
     <name>U2::LoadPatternsFileTask</name>
     <message>
-        <location filename="../src/misc/FindAlgorithmTask.cpp" line="106"/>
+        <location filename="../src/misc/FindAlgorithmTask.cpp" line="104"/>
         <source>Load pattern from file</source>
         <translation>Загрузить паттерн из файла</translation>
     </message>
     <message>
-        <location filename="../src/misc/FindAlgorithmTask.cpp" line="115"/>
+        <location filename="../src/misc/FindAlgorithmTask.cpp" line="113"/>
         <source>Detecting format error for file %1</source>
         <translation>Ошибка распознавания формата для файла %1</translation>
     </message>
@@ -581,22 +485,27 @@ For every column selects the most rare symbol in the whole alignment with percen
 <context>
     <name>U2::PairwiseAlignmentTask</name>
     <message>
-        <location filename="../src/pairwise_alignment/PairwiseAlignmentTask.cpp" line="48"/>
+        <location filename="../src/pairwise_alignment/PairwiseAlignmentTask.cpp" line="46"/>
         <source>Pairwise alignment task</source>
-        <translation>Pairwise alignment task</translation>
+        <translation>Задача парного выравнивания</translation>
     </message>
 </context>
 <context>
     <name>U2::PhyTreeGeneratorLauncherTask</name>
     <message>
-        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="45"/>
+        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="46"/>
         <source>Calculating Phylogenetic Tree</source>
         <translation>Создание филогенетического дерева</translation>
     </message>
     <message>
-        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="53"/>
-        <source>Tree construction algorithm %1 not found</source>
-        <translation>Алгоритм %1 построения дерева не найден</translation>
+        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="56"/>
+        <source>Tree algorithm %1 is not found</source>
+        <translation>Алгоритм дерева %1 не найден</translation>
+    </message>
+    <message>
+        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="81"/>
+        <source>Failed to map row name: %1</source>
+        <translation>Не удалось сопоставить имя строки: %1</translation>
     </message>
 </context>
 <context>
@@ -620,7 +529,7 @@ For every column selects the most rare symbol in the whole alignment with percen
     <message>
         <location filename="../src/misc/SequenceContentFilterTask.cpp" line="39"/>
         <source>Sequence content</source>
-        <translation>Sequence content</translation>
+        <translation>Содержание последовательности</translation>
     </message>
 </context>
 <context>
@@ -628,7 +537,7 @@ For every column selects the most rare symbol in the whole alignment with percen
     <message>
         <location filename="../src/msa_alignment/SimpleAddingToAlignment.cpp" line="51"/>
         <source>Align sequences to alignment with UGENE started</source>
-        <translation>Align sequences to alignment with UGENE started</translation>
+        <translation>Выравнивание последовательностей на выравнивание началось</translation>
     </message>
     <message>
         <location filename="../src/msa_alignment/SimpleAddingToAlignment.cpp" line="136"/>
@@ -674,13 +583,13 @@ For every column selects the most rare symbol in the whole alignment with percen
     </message>
     <message>
         <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="261"/>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="338"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="335"/>
         <source>Smith-Waterman pairwise alignment: no results</source>
         <translation>Парное выравнивание Smith-Waterman: нет результатов</translation>
     </message>
     <message>
         <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="268"/>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="343"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="340"/>
         <source>Sequences aren&apos;t stored in the source msa dbi</source>
         <translation>Последовательности не хранятся в источнике msa dbi</translation>
     </message>
@@ -692,27 +601,27 @@ For every column selects the most rare symbol in the whole alignment with percen
     <message>
         <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="290"/>
         <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="292"/>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="352"/>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="354"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="349"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="351"/>
         <source>Failed to get the sequence object.</source>
         <translation>Неудачная попытка получения объекта последовательности.</translation>
     </message>
     <message>
         <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="306"/>
         <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="308"/>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="368"/>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="372"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="365"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="369"/>
         <source>Failed to get the sequence data.</source>
         <translation>Неудачная попытка получения данных последовательности.</translation>
     </message>
     <message>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="381"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="378"/>
         <source>Failed to get msa from dbi</source>
         <translation>Неудачная попытка получения msa из dbi</translation>
     </message>
     <message>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="404"/>
-        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="406"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="401"/>
+        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="403"/>
         <source>Failed to update row gap model</source>
         <translation>Неудачная попытка обновить модель пробелов строк</translation>
     </message>
@@ -721,8 +630,8 @@ For every column selects the most rare symbol in the whole alignment with percen
     <name>U2::SplicedAlignmentTask</name>
     <message>
         <location filename="../src/registry/SplicedAlignmentTask.cpp" line="27"/>
-        <source>SplicedAlignmentTask</source>
-        <translation>SplicedAlignmentTask</translation>
+        <source>Partial Alignment Task</source>
+        <translation>Частичное выравнивание</translation>
     </message>
 </context>
 <context>
@@ -786,7 +695,7 @@ For every column selects the most rare symbol in the whole alignment with percen
     <message>
         <location filename="../src/registry/SubstMatrixRegistry.cpp" line="204"/>
         <source>Can&apos;t parse numeric value &apos;%1&apos;, line %2</source>
-        <translation>Не могу распознать числовое значение &quot;%1&quot; в строке &quot;%2&quot;</translation>
+        <translation>Невозможно распознать числовое значение &quot;%1&quot; в строке &quot;%2&quot;</translation>
     </message>
     <message>
         <location filename="../src/registry/SubstMatrixRegistry.cpp" line="213"/>
@@ -802,27 +711,10 @@ For every column selects the most rare symbol in the whole alignment with percen
         <source>Translate nucleic alignment to amino</source>
         <translation>Трансляция нуклеотидного выравнивания в амино</translation>
     </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="48"/>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="60"/>
-        <source>Invalid MSA object detected</source>
-        <translation>Обнаружен некорректный MSA объект</translation>
-    </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="49"/>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="61"/>
-        <source>Multiple alignment already has amino-acid alphabet</source>
-        <translation>Выравнивание уже имеет аминокислотный алфавит</translation>
-    </message>
     <message>
         <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="53"/>
         <source>Unable to find suitable translation for %1</source>
         <translation>Невозможно найти подходящую трансляцию для %1</translation>
     </message>
-    <message>
-        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="67"/>
-        <source>Invalid translation object</source>
-        <translation>Некорректный объект трансляции</translation>
-    </message>
 </context>
 </TS>
