@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -55,35 +55,35 @@ const QString CMDLineCoreOptions::USE_SAME_INI_FOR_TESTS = "use-same-ini-for-tes
 const QString CMDLineCoreOptions::DONT_USE_NATIVE_MENUBAR = "dont-use-native-menubar";
 
 void CMDLineCoreOptions::initHelp() {
-    CMDLineRegistry *cmdLineRegistry = AppContext::getCMDLineRegistry();
-    assert(nullptr != cmdLineRegistry);
+    CMDLineRegistry* cmdLineRegistry = AppContext::getCMDLineRegistry();
+    assert(cmdLineRegistry != nullptr);
 
-    CMDLineHelpProvider *helpSection = new CMDLineHelpProvider(
+    CMDLineHelpProvider* helpSection = new CMDLineHelpProvider(
         HELP,
         tr("Shows help information."),
         "",  // No full description
         "",  // No arguments
         HELP_SHORT);
 
-    CMDLineHelpProvider *loadSettingsFileSection = new CMDLineHelpProvider(
+    CMDLineHelpProvider* loadSettingsFileSection = new CMDLineHelpProvider(
         INI_FILE,
         tr("Loads UGENE configuration."),
         tr("Loads configuration from the specified .ini file. By default the UGENE.ini file is used."),
         tr("<path_to_file>"));
 
-    CMDLineHelpProvider *translSection = new CMDLineHelpProvider(
+    CMDLineHelpProvider* translSection = new CMDLineHelpProvider(
         TRANSLATION,
         tr("Specifies the language to use."),
-        tr("Specifies the language to use. The following values are available: CS, EN, RU, ZH."),
+        tr("Specifies the language to use. The following values are available: EN, RU, TR."),
         tr("<language_code>"));
 
-    CMDLineHelpProvider *tmpDirSection = new CMDLineHelpProvider(
+    CMDLineHelpProvider* tmpDirSection = new CMDLineHelpProvider(
         TMP_DIR,
         "Path to temporary folder",
         "",
         tr("<path_to_file>"));
 
-    CMDLineHelpProvider *sessionDatabaseSection = new CMDLineHelpProvider(
+    CMDLineHelpProvider* sessionDatabaseSection = new CMDLineHelpProvider(
         SESSION_DB,
         tr("Path to the session database file"),
         tr("Session database is stored in the temporary file that is created for every UGENE run.\n"
