@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CMD_LINE_HELP_PROVIDER_
-#define _U2_CMD_LINE_HELP_PROVIDER_
+#pragma once
 
 #include "U2Core/global.h"
 
@@ -29,11 +28,11 @@ namespace U2 {
 class U2CORE_EXPORT CMDLineHelpProvider {
 public:
     CMDLineHelpProvider(
-        const QString &_fullName,  // Name of the option (e.g. "version")
-        const QString &_shortDescription,  // Description shown in the options list
-        const QString &_fullDescription = QString(),  // Description shown in the option's help
-        const QString &_argsDescription = QString(),  // Description of the option arguments
-        const QString &_shortName = QString())  // Short name of the option (e.g. "v")
+        const QString& _fullName,  // Name of the option (e.g. "version")
+        const QString& _shortDescription,  // Description shown in the options list
+        const QString& _fullDescription = QString(),  // Description shown in the option's help
+        const QString& _argsDescription = QString(),  // Description of the option arguments
+        const QString& _shortName = QString())  // Short name of the option (e.g. "v")
         : fullName(_fullName),
           shortDescription(_shortDescription),
           fullDescription(_fullDescription),
@@ -79,5 +78,3 @@ private:
 };  // CMDLineHelpProvider
 
 }  // namespace U2
-
-#endif
