@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CMDLINE_UTILS_H_
-#define _U2_CMDLINE_UTILS_H_
+#pragma once
 
 #include <QList>
 #include <QString>
@@ -32,11 +31,11 @@ namespace U2 {
 class U2CORE_EXPORT CMDLineRegistryUtils {
 public:
     // -1 if not found
-    static int getParameterIndex(const QString &paramName, int startWith = 0);
+    static int getParameterIndex(const QString& paramName, int startWith = 0);
     // in case: '-t a b c' return {a, b, c}
-    static QStringList getParameterValues(const QString &paramName, int startWith = 0);
+    static QStringList getParameterValues(const QString& paramName, int startWith = 0);
     // in case '-t "a b" c' return {a, b, c} not {"a b", c}
-    static QStringList getParameterValuesByWords(const QString &paramName, int startWith = 0);
+    static QStringList getParameterValuesByWords(const QString& paramName, int startWith = 0);
     // return list of all values that doesn't have keys ("", paramValue)
     // search starts at startWithIdx, stops at first (paramKey, paramValue) pair
     // by default, search starts at 1 because at params[0] is usually ("", programName) pair
@@ -45,7 +44,7 @@ public:
     static QString getCmdlineUgenePath();
 
 private:
-    static void setCMDLineParams(QList<StrStrPair> &to);
+    static void setCMDLineParams(QList<StrStrPair>& to);
 
 };  // CMDLineRegistryUtils
 
@@ -56,5 +55,3 @@ public:
 };  // CMDLineUtils
 
 }  // namespace U2
-
-#endif  // _U2_CMDLINE_UTILS_H_
