@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATION_DATA_H_
-#define _U2_ANNOTATION_DATA_H_
+#pragma once
 
 #include <QDataStream>
 #include <QSharedData>
@@ -37,15 +36,15 @@ class U2CORE_EXPORT AnnotationData : public QSharedData {
 public:
     AnnotationData();
 
-    AnnotationData &operator=(const AnnotationData &a);
+    AnnotationData(const AnnotationData&) = default;
 
-    bool operator==(const AnnotationData &other) const;
-    bool operator!=(const AnnotationData &other) const;
-    bool operator<(const AnnotationData &other) const;
+    bool operator==(const AnnotationData& other) const;
+    bool operator!=(const AnnotationData& other) const;
+    bool operator<(const AnnotationData& other) const;
 
-    void findQualifiers(const QString &name, QVector<U2Qualifier> &res) const;
-    QString findFirstQualifierValue(const QString &name) const;
-    void removeAllQualifiers(const QString &name, QStringList &values);
+    void findQualifiers(const QString& name, QVector<U2Qualifier>& res) const;
+    QString findFirstQualifierValue(const QString& name) const;
+    void removeAllQualifiers(const QString& name, QStringList& values);
 
     bool isJoin() const;
     bool isOrder() const;
@@ -57,7 +56,7 @@ public:
     U2LocationOperator getLocationOperator() const;
     void setLocationOperator(U2LocationOperator o);
 
-    const QVector<U2Region> &getRegions() const;
+    const QVector<U2Region>& getRegions() const;
 
     QString name;
     U2Location location;
@@ -68,17 +67,15 @@ public:
 
 typedef QSharedDataPointer<AnnotationData> SharedAnnotationData;
 
-U2CORE_EXPORT QDataStream &operator>>(QDataStream &dataStream, TriState &state);
-U2CORE_EXPORT QDataStream &operator<<(QDataStream &dataStream, const TriState &state);
-U2CORE_EXPORT QDataStream &operator>>(QDataStream &dataStream, U2Qualifier &q);
-U2CORE_EXPORT QDataStream &operator<<(QDataStream &dataStream, const U2Qualifier &q);
-U2CORE_EXPORT QDataStream &operator>>(QDataStream &dataStream, AnnotationData &data);
-U2CORE_EXPORT QDataStream &operator<<(QDataStream &dataStream, const AnnotationData &data);
+U2CORE_EXPORT QDataStream& operator>>(QDataStream& dataStream, TriState& state);
+U2CORE_EXPORT QDataStream& operator<<(QDataStream& dataStream, const TriState& state);
+U2CORE_EXPORT QDataStream& operator>>(QDataStream& dataStream, U2Qualifier& q);
+U2CORE_EXPORT QDataStream& operator<<(QDataStream& dataStream, const U2Qualifier& q);
+U2CORE_EXPORT QDataStream& operator>>(QDataStream& dataStream, AnnotationData& data);
+U2CORE_EXPORT QDataStream& operator<<(QDataStream& dataStream, const AnnotationData& data);
 
 }  // namespace U2
 
 Q_DECLARE_METATYPE(U2::AnnotationData)
 Q_DECLARE_METATYPE(U2::SharedAnnotationData)
 Q_DECLARE_METATYPE(QList<U2::SharedAnnotationData>)
-
-#endif
