@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,19 +29,15 @@ enum AnnotationModificationType {
     AnnotationModification_QualifierAdded,
     AnnotationModification_QualifierRemoved,
     AnnotationModification_LocationChanged,
-    AnnotationModification_AddedToGroup,  // Emitted when annotation is added to a group.
-    // Note that first time annotation added to the object it automatically
-    // has a group assigned and this signal is not emitted
-    AnnotationModification_RemovedFromGroup,
     AnnotationModification_TypeChanged
 };
 
 class U2CORE_EXPORT AnnotationModification {
 public:
-    AnnotationModification(AnnotationModificationType type, Annotation *a);
+    AnnotationModification(AnnotationModificationType type, Annotation* a);
 
     AnnotationModificationType type;
-    Annotation *annotation;
+    Annotation* annotation;
 
 protected:
     QVariant additionalData;
@@ -49,16 +45,16 @@ protected:
 
 class U2CORE_EXPORT QualifierModification : public AnnotationModification {
 public:
-    QualifierModification(AnnotationModificationType type, Annotation *a, const U2Qualifier &q);
+    QualifierModification(AnnotationModificationType type, Annotation* a, const U2Qualifier& q);
 
     U2Qualifier getQualifier() const;
 };
 
 class U2CORE_EXPORT AnnotationGroupModification : public AnnotationModification {
 public:
-    AnnotationGroupModification(AnnotationModificationType type, Annotation *a, AnnotationGroup *g);
+    AnnotationGroupModification(AnnotationModificationType type, Annotation* a, AnnotationGroup* g);
 
-    AnnotationGroup *getGroup() const;
+    AnnotationGroup* getGroup() const;
 };
 
 }  // namespace U2
