@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATION_SETTINGS_H_
-#define _U2_ANNOTATION_SETTINGS_H_
+#pragma once
 
 #include <QColor>
 #include <QHash>
@@ -34,12 +33,12 @@ class Settings;
 class U2CORE_EXPORT AnnotationSettings {
 public:
     AnnotationSettings();
-    AnnotationSettings(const QString &name, bool amino, const QColor &color, bool visible);
+    AnnotationSettings(const QString& name, bool amino, const QColor& color, bool visible);
 
-    bool operator==(const AnnotationSettings *as) const {
+    bool operator==(const AnnotationSettings* as) const {
         return equals(as);
     }
-    bool equals(const AnnotationSettings *as) const;
+    bool equals(const AnnotationSettings* as) const;
 
     QString name;
     QColor color;
@@ -54,27 +53,25 @@ public:
 class U2CORE_EXPORT AnnotationSettingsRegistry : public QObject {
     Q_OBJECT
 public:
-    AnnotationSettingsRegistry(const QList<AnnotationSettings *> &predefined);
+    AnnotationSettingsRegistry(const QList<AnnotationSettings*>& predefined);
     ~AnnotationSettingsRegistry();
 
     QStringList getAllSettings() const;
-    AnnotationSettings *getAnnotationSettings(const QString &name);
-    AnnotationSettings *getAnnotationSettings(const SharedAnnotationData &a);
+    AnnotationSettings* getAnnotationSettings(const QString& name);
+    AnnotationSettings* getAnnotationSettings(const SharedAnnotationData& a);
 
     // persistent==true -> save settings to file, ==false -> this session only
-    void changeSettings(const QList<AnnotationSettings *> &settings, bool saveAsPersistent);
+    void changeSettings(const QList<AnnotationSettings*>& settings, bool saveAsPersistent);
 
 signals:
-    void si_annotationSettingsChanged(const QStringList &changedSettings);
+    void si_annotationSettingsChanged(const QStringList& changedSettings);
 
 private:
     void read();
     void save();
 
-    QHash<QString, AnnotationSettings *> persistentMap;
-    QHash<QString, AnnotationSettings *> transientMap;
+    QHash<QString, AnnotationSettings*> persistentMap;
+    QHash<QString, AnnotationSettings*> transientMap;
 };
 
 }  // namespace U2
-
-#endif
