@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATION_TABLE_OBJECT_CONSTRAINTS_H_
-#define _U2_ANNOTATION_TABLE_OBJECT_CONSTRAINTS_H_
+#pragma once
 
 #include <U2Core/GObject.h>
 #include <U2Core/global.h>
@@ -30,13 +29,11 @@ namespace U2 {
 class U2CORE_EXPORT AnnotationTableObjectConstraints : public GObjectConstraints {
     Q_OBJECT
 public:
-    AnnotationTableObjectConstraints(QObject *p = nullptr);
-    AnnotationTableObjectConstraints(const AnnotationTableObjectConstraints &c,
-                                     QObject *p = nullptr);
+    AnnotationTableObjectConstraints(QObject* p = nullptr);
+    AnnotationTableObjectConstraints(const AnnotationTableObjectConstraints& c,
+                                     QObject* p = nullptr);
 
     qint64 sequenceSizeToFit;
 };
 
 }  // namespace U2
-
-#endif  // _U2_ANNOTATION_TABLE_OBJECT_CONSTRAINTS_H_
