@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -47,29 +47,20 @@ BioStruct3D::BioStruct3D()
     transform.loadIdentity();
 }
 
-BioStruct3D::BioStruct3D(const BioStruct3D &other)
-    : moleculeMap(other.moleculeMap), modelMap(other.modelMap),
-      secondaryStructures(other.secondaryStructures),
-      interMolecularBonds(other.interMolecularBonds),
-      descr(other.descr), pdbId(other.pdbId),
-      radius(other.radius), rotationCenter(other.rotationCenter),
-      transform(other.transform) {
-}
-
 void BioStruct3D::calcCenterAndMaxDistance() {
     Vector3D siteSum;
     Vector3D center;
     double dist;
     radius = 0.0;
     int numberOfAtoms = 0;
-    // loop trough all atoms twice - once to get average center, then once to
+    // loop through all atoms twice - once to get average center, then once to
     // find max distance from this center
     for (int i = 0; i < 2; ++i) {
-        for (const SharedMolecule &molecule : qAsConst(moleculeMap)) {
+        for (const SharedMolecule& molecule : qAsConst(moleculeMap)) {
             QList<Molecule3DModel> models = molecule->models.values();
-            for (const Molecule3DModel &model3d : qAsConst(models)) {
-                for (const AtomData *atom : qAsConst(model3d.atoms)) {
-                    const Vector3D &site = atom->coord3d;
+            for (const Molecule3DModel& model3d : qAsConst(models)) {
+                for (const AtomData* atom : qAsConst(model3d.atoms)) {
+                    const Vector3D& site = atom->coord3d;
                     if (i == 0) {
                         siteSum += atom->coord3d;
                         numberOfAtoms++;
@@ -97,14 +88,11 @@ void BioStruct3D::calcCenterAndMaxDistance() {
 }
 
 int BioStruct3D::getNumberOfAtoms() const {
-    // get first coordinates set
-    const AtomCoordSet &coordSet = modelMap.begin().value();
-    return coordSet.count();
+    return modelMap.first().count();
 }
 
 QList<SharedAtom> BioStruct3D::getAllAtoms() const {
-    const AtomCoordSet &coordSet = modelMap.begin().value();
-    return coordSet.values();
+    return modelMap.first().values();
 }
 
 QMap<int, QList<SharedAnnotationData>> BioStruct3D::generateAnnotations() const {
@@ -115,7 +103,7 @@ QMap<int, QList<SharedAnnotationData>> BioStruct3D::generateAnnotations() const
 
 QMap<int, QList<SharedAnnotationData>> BioStruct3D::generateChainAnnotations() const {
     QMap<int, QList<SharedAnnotationData>> result;
-    const char *molNameQualifier = "molecule_name";
+    const char* molNameQualifier = "molecule_name";
     // const char* pdbChainIdQualifier = "pdb_id";
 
     QMap<int, SharedMolecule>::ConstIterator iter = moleculeMap.constBegin();
@@ -147,9 +135,9 @@ int BioStruct3D::getNumberOfResidues() const {
     return numResidues;
 }
 
-const SharedAtom BioStruct3D::getAtomById(int atomIndex, int modelIndex) const {
+SharedAtom BioStruct3D::getAtomById(int atomIndex, int modelIndex) const {
     if (modelMap.contains(modelIndex)) {
-        const AtomCoordSet &coordSet = modelMap.value(modelIndex);
+        const AtomCoordSet& coordSet = modelMap.value(modelIndex);
         if (coordSet.contains(atomIndex)) {
             return coordSet.value(atomIndex);
         }
@@ -158,9 +146,9 @@ const SharedAtom BioStruct3D::getAtomById(int atomIndex, int modelIndex) const {
     return SharedAtom(nullptr);
 }
 
-const SharedResidue BioStruct3D::getResidueById(int chainIndex, ResidueIndex residueIndex) const {
+SharedResidue BioStruct3D::getResidueById(int chainIndex, ResidueIndex residueIndex) const {
     const SharedMolecule mol = moleculeMap.value(chainIndex);
-    foreach (const ResidueIndex &id, mol->residueMap.keys()) {
+    foreach (const ResidueIndex& id, mol->residueMap.keys()) {
         if (id.toInt() == residueIndex.toInt()) {
             return mol->residueMap.value(id);
         }
@@ -169,7 +157,7 @@ const SharedResidue BioStruct3D::getResidueById(int chainIndex, ResidueIndex res
     return SharedResidue(nullptr);
 }
 
-const QString BioStruct3D::getSecStructTypeName(SecondaryStructure::Type type) {
+QString BioStruct3D::getSecStructTypeName(SecondaryStructure::Type type) {
     switch (type) {
         case SecondaryStructure::Type_AlphaHelix:
             return BioStruct3D::AlphaHelixAnnotationTag;
@@ -190,26 +178,26 @@ const QString BioStruct3D::getSecStructTypeName(SecondaryStructure::Type type) {
     }
 }
 
-void BioStruct3D::generateSecStructureAnnotations(QMap<int, QList<SharedAnnotationData>> &result) const {
+void BioStruct3D::generateSecStructureAnnotations(QMap<int, QList<SharedAnnotationData>>& result) const {
     // TODO: issue 0000637
     if (moleculeMap.isEmpty())
         return;
 
-    foreach (const SharedSecondaryStructure &struc, secondaryStructures) {
+    foreach (const SharedSecondaryStructure& secondaryStructure, secondaryStructures) {
         SharedAnnotationData sd(nullptr);
-        int chainId = struc->chainIndex;
+        int chainId = secondaryStructure->chainIndex;
         assert(chainId != 0);
         int initResidueId = moleculeMap.value(chainId)->residueMap.constBegin().key().toInt();
         sd = new AnnotationData;
         sd->name = BioStruct3D::SecStructAnnotationTag;
-        U2Qualifier qual(SecStructTypeQualifierName, getSecStructTypeName(struc->type));
-        sd->qualifiers.append(qual);
-        int numResidues = struc->endSequenceNumber - struc->startSequenceNumber + 1;
+        U2Qualifier qualifier(SecStructTypeQualifierName, getSecStructTypeName(secondaryStructure->type));
+        sd->qualifiers.append(qualifier);
+        int numResidues = secondaryStructure->endSequenceNumber - secondaryStructure->startSequenceNumber + 1;
         // TODO: determine why can it happen and fix if it's a bug
         if (numResidues < 0) {
             continue;
         }
-        int startIndex = struc->startSequenceNumber - initResidueId;
+        int startIndex = secondaryStructure->startSequenceNumber - initResidueId;
         U2Region chainRegion(startIndex, numResidues);
         sd->location->regions << chainRegion;
         Q_ASSERT(moleculeMap.contains(chainId));
@@ -245,43 +233,33 @@ int BioStruct3D::getIndexByChainId(char chainId) const {
     return -1;
 }
 
-const QList<int> BioStruct3D::getModelsNames() const {
+QList<int> BioStruct3D::getModelsIds() const {
     return modelMap.keys();
 }
 
-const Molecule3DModel BioStruct3D::getModelByName(int moleculeId, int name) const {
-    int index = modelMap.keys().indexOf(name);
-    assert(index != -1 && "invalid model id");
-    return getModelByIndex(moleculeId, index);
-}
-
-const Molecule3DModel BioStruct3D::getModelByIndex(int moleculeId, int index) const {
-    return moleculeMap[moleculeId]->models[index];
+Molecule3DModel BioStruct3D::getModelById(int moleculeId, int modelId) const {
+    return moleculeMap[moleculeId]->models[modelId];
 }
 
 void BioStruct3D::setRadius(double value) {
     radius = value;
 }
 
-void BioStruct3D::setCenter(const Vector3D &value) {
+void BioStruct3D::setCenter(const Vector3D& value) {
     rotationCenter = value;
 }
 
 /* class U2CORE_EXPORT BioStruct3DChainSelection */
 
-BioStruct3DChainSelection::BioStruct3DChainSelection(const BioStruct3D &biostruct_)
+BioStruct3DChainSelection::BioStruct3DChainSelection(const BioStruct3D& biostruct_)
     : biostruct(biostruct_), data(new BioStruct3DChainSelectionData()) {
 }
 
-BioStruct3DChainSelection::BioStruct3DChainSelection(const BioStruct3DChainSelection &other)
-    : biostruct(other.biostruct), data(other.data) {
-}
-
 bool BioStruct3DChainSelection::inSelection(int chainId, int residueId) const {
     return data->selection.contains(chainId, residueId);
 }
 
-void BioStruct3DChainSelection::add(int chain, const U2Region &region) {
+void BioStruct3DChainSelection::add(int chain, const U2Region& region) {
     int start = biostruct.moleculeMap[chain]->residueMap.begin().key().toInt();
     for (int i = region.startPos; i < region.endPos(); ++i) {
         if (!data->selection.contains(chain, start + i)) {
@@ -290,36 +268,36 @@ void BioStruct3DChainSelection::add(int chain, const U2Region &region) {
     }
 }
 
-void BioStruct3DChainSelection::add(int chain, const QVector<U2Region> &regions) {
-    foreach (const U2Region &region, regions) {
+void BioStruct3DChainSelection::add(int chain, const QVector<U2Region>& regions) {
+    foreach (const U2Region& region, regions) {
         add(chain, region);
     }
 }
 
-void BioStruct3DChainSelection::remove(int chain, const U2Region &region) {
+void BioStruct3DChainSelection::remove(int chain, const U2Region& region) {
     int start = biostruct.moleculeMap[chain]->residueMap.begin().key().toInt();
     for (int i = region.startPos; i < region.endPos(); ++i) {
         data->selection.remove(chain, start + i);
     }
 }
 
-void BioStruct3DChainSelection::remove(int chain, const QVector<U2Region> &regions) {
-    foreach (const U2Region &region, regions) {
+void BioStruct3DChainSelection::remove(int chain, const QVector<U2Region>& regions) {
+    foreach (const U2Region& region, regions) {
         remove(chain, region);
     }
 }
 
-void BioStruct3DChainSelection::update(int chain, const U2Region &add, const U2Region &remove) {
+void BioStruct3DChainSelection::update(int chain, const U2Region& add, const U2Region& remove) {
     this->remove(chain, remove);
     this->add(chain, add);
 }
 
-void BioStruct3DChainSelection::update(int chain, const QVector<U2Region> &adds, const QVector<U2Region> &removes) {
+void BioStruct3DChainSelection::update(int chain, const QVector<U2Region>& adds, const QVector<U2Region>& removes) {
     remove(chain, removes);
     add(chain, adds);
 }
 
-bool ResidueIndex::operator<(const ResidueIndex &other) const {
+bool ResidueIndex::operator<(const ResidueIndex& other) const {
     if (order == other.order) {
         if (resId == other.resId) {
             return insCode < other.insCode;
@@ -331,11 +309,11 @@ bool ResidueIndex::operator<(const ResidueIndex &other) const {
     }
 }
 
-bool ResidueIndex::operator==(const ResidueIndex &other) const {
+bool ResidueIndex::operator==(const ResidueIndex& other) const {
     return (other.insCode == insCode) && (other.resId == resId);
 }
 
-bool ResidueIndex::operator!=(const ResidueIndex &other) const {
+bool ResidueIndex::operator!=(const ResidueIndex& other) const {
     return !(*this == other);
 }
 
