@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BIOSTRUCT3D_H_
-#define _U2_BIOSTRUCT3D_H_
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -48,9 +47,9 @@ public:
     ResidueIndex(int residueIdx, char insertionCode)
         : resId(residueIdx), order(0), insCode(insertionCode) {
     }
-    bool operator<(const ResidueIndex &other) const;
-    bool operator==(const ResidueIndex &other) const;
-    bool operator!=(const ResidueIndex &other) const;
+    bool operator<(const ResidueIndex& other) const;
+    bool operator==(const ResidueIndex& other) const;
+    bool operator!=(const ResidueIndex& other) const;
     int toInt() const {
         return resId;
     }
@@ -109,7 +108,7 @@ class Bond {
     SharedAtom atom2;
 
 public:
-    Bond(const SharedAtom &a1, const SharedAtom &a2)
+    Bond(const SharedAtom& a1, const SharedAtom& a2)
         : atom1(a1), atom2(a2) {
     }
     const SharedAtom getAtom1() const {
@@ -172,7 +171,7 @@ public:
     MoleculeData()
         : chainId(0), engineered(false) {
     }
-    MoleculeData(const QString &molName)
+    MoleculeData(const QString& molName)
         : name(molName), chainId(0), engineered(false) {
     }
     QMap<ResidueIndex, SharedResidue> residueMap;
@@ -203,7 +202,7 @@ public:
 public:
     BioStruct3D();
     /** This is not deep copy constructor */
-    BioStruct3D(const BioStruct3D &other);
+    BioStruct3D(const BioStruct3D& other) = default;
 
     QMap<int, SharedMolecule> moleculeMap;
     QMap<int, AtomCoordSet> modelMap;
@@ -216,12 +215,12 @@ public:
     double getRadius() const {
         return radius;
     }
-    const Vector3D &getCenter() const {
+    const Vector3D& getCenter() const {
         return rotationCenter;
     }
 
     void setRadius(double value);
-    void setCenter(const Vector3D &value);
+    void setCenter(const Vector3D& value);
 
     QByteArray getRawSequenceByChainIndex(int id) const;
     char getChainIdByIndex(int id) const;
@@ -229,22 +228,15 @@ public:
     int getNumberOfAtoms() const;
     QList<SharedAtom> getAllAtoms() const;
     int getNumberOfResidues() const;
-    static int residueIndexToInt(const ResidueIndex &idx);
-    const SharedAtom getAtomById(int index, int modelIndex) const;
-    const SharedResidue getResidueById(int chainIndex, ResidueIndex residueIndex) const;
+    static int residueIndexToInt(const ResidueIndex& idx);
+    SharedAtom getAtomById(int index, int modelIndex) const;
+    SharedResidue getResidueById(int chainIndex, ResidueIndex residueIndex) const;
 
-    // Theese three methods need to solve confusion between model ids (same as in PDB)
-    // and internal model indexes, both  are used in UGENE
-    // model ids should be used for user interface, and one fine day may become a strings
-    // model index numbers used by internal UGENE parts, and should be consequent int values from 0
-    /** @returns list of model ids (same as in PDB), that can be not consequent */
-    const QList<int> getModelsNames() const;
+    /** Return list of model ids (same as in PDB). */
+    QList<int> getModelsIds() const;
 
-    /** @returns molecule model by it's model id (same as in PDB) */
-    const Molecule3DModel getModelByName(int moleculeId, int name) const;
-
-    /** @returns model by it's index number in our data structure */
-    const Molecule3DModel getModelByIndex(int moleculeId, int index) const;
+    /** Returns molecule model by it's model id (same as in PDB) */
+    Molecule3DModel getModelById(int moleculeId, int modelId) const;
 
     // Modifier
     void calcCenterAndMaxDistance();
@@ -253,20 +245,20 @@ public:
     QMap<int, QList<SharedAnnotationData>> generateAnnotations() const;
 
     /** Biostruct 3D model should be transforemd with this matrix */
-    void setTransform(const Matrix44 &m) {
+    void setTransform(const Matrix44& m) {
         transform = m;
     }
-    const Matrix44 &getTransform() const {
+    const Matrix44& getTransform() const {
         return transform;
     }
 
 public:
     // Static methods
-    static const QString getSecStructTypeName(SecondaryStructure::Type type);
+    static QString getSecStructTypeName(SecondaryStructure::Type type);
 
 private:
     QMap<int, QList<SharedAnnotationData>> generateChainAnnotations() const;
-    void generateSecStructureAnnotations(QMap<int, QList<SharedAnnotationData>> &result) const;
+    void generateSecStructureAnnotations(QMap<int, QList<SharedAnnotationData>>& result) const;
 
 private:
     double radius;
@@ -280,7 +272,7 @@ public:
     BioStruct3DChainSelectionData()
         : QSharedData() {
     }
-    BioStruct3DChainSelectionData(const BioStruct3DChainSelectionData &other)
+    BioStruct3DChainSelectionData(const BioStruct3DChainSelectionData& other)
         : QSharedData(), selection(other.selection) {
     }
 
@@ -296,10 +288,10 @@ public:
 //! Represents residue chain selection on BioStruct3D.
 class U2CORE_EXPORT BioStruct3DChainSelection {
 public:
-    BioStruct3DChainSelection(const BioStruct3D &biostruct);
-    BioStruct3DChainSelection(const BioStruct3DChainSelection &other);
+    BioStruct3DChainSelection(const BioStruct3D& biostruct);
+    BioStruct3DChainSelection(const BioStruct3DChainSelection& other) = default;
 
-    const BioStruct3D &getBioStruct3D() const {
+    const BioStruct3D& getBioStruct3D() const {
         return biostruct;
     }
 
@@ -308,20 +300,18 @@ public:
         return data->selection.isEmpty();
     }
 
-    void add(int chain, const U2Region &region);
-    void add(int chain, const QVector<U2Region> &regions);
+    void add(int chain, const U2Region& region);
+    void add(int chain, const QVector<U2Region>& regions);
 
-    void remove(int chain, const U2Region &region);
-    void remove(int chain, const QVector<U2Region> &regions);
+    void remove(int chain, const U2Region& region);
+    void remove(int chain, const QVector<U2Region>& regions);
 
-    void update(int chain, const U2Region &add, const U2Region &remove);
-    void update(int chain, const QVector<U2Region> &adds, const QVector<U2Region> &removes);
+    void update(int chain, const U2Region& add, const U2Region& remove);
+    void update(int chain, const QVector<U2Region>& adds, const QVector<U2Region>& removes);
 
 private:
-    const BioStruct3D &biostruct;
+    const BioStruct3D& biostruct;
     QSharedDataPointer<BioStruct3DChainSelectionData> data;
-};  // class U2CORE_EXPORT BioStruct3DChainSelection
+};
 
 }  // namespace U2
-
-#endif  // _U2_BIOSTRUCT3D_H_
