@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_CHROMATOGRAM_H_
-#define _U2_DNA_CHROMATOGRAM_H_
+#pragma once
 
 #include <QVector>
 
@@ -67,7 +66,7 @@ public:
 
     ushort getValue(Trace trace, qint64 position) const;
 
-    bool operator==(const DNAChromatogram &otherChromatogram) const;
+    bool operator==(const DNAChromatogram& otherChromatogram) const;
 
     static const ushort INVALID_VALUE;
     static const char DEFAULT_PROBABILITY;
@@ -76,5 +75,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
