@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_INFO_H_
-#define _U2_DNA_INFO_H_
+#pragma once
 
 #include <QPair>
 #include <QString>
@@ -132,10 +131,10 @@ keyword/exactly one record.
     static const QString GENBANK_HEADER;
     static const QString FASTQ_COMMENT;
 
-    static QString getPrimaryAccession(const QVariantMap &);
-    static QString getContig(const QVariantMap &);
-    static QString getName(const QVariantMap &);
-    static QString getFastqComment(const QVariantMap &);
+    static QString getPrimaryAccession(const QVariantMap&);
+    static QString getContig(const QVariantMap&);
+    static QString getName(const QVariantMap&);
+    static QString getFastqComment(const QVariantMap&);
 };
 
 class U2CORE_EXPORT DNALocusInfo {
@@ -171,5 +170,3 @@ public:
 Q_DECLARE_METATYPE(U2::DNALocusInfo)
 Q_DECLARE_METATYPE(U2::DNASourceInfo)
 Q_DECLARE_METATYPE(U2::DNAReferenceInfo)
-
-#endif
