@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_SEQUENCE_H_
-#define _U2_DNA_SEQUENCE_H_
+#pragma once
 
 #include <QVariantMap>
 
@@ -33,19 +32,19 @@ class DNAAlphabet;
 
 class U2CORE_EXPORT DNASequence {
 public:
-    DNASequence(const QString &name, const QByteArray &s = QByteArray(), const DNAAlphabet *a = nullptr);
-    DNASequence(const QByteArray &s = QByteArray(), const DNAAlphabet *a = nullptr);
+    DNASequence(const QString& name, const QByteArray& s = QByteArray(), const DNAAlphabet* a = nullptr);
+    DNASequence(const QByteArray& s = QByteArray(), const DNAAlphabet* a = nullptr);
 
     QVariantMap info;
     QByteArray seq;
-    const DNAAlphabet *alphabet;
+    const DNAAlphabet* alphabet;
     bool circular;
     DNAQuality quality;
 
     QString getName() const {
         return DNAInfo::getName(info);
     }
-    void setName(const QString &name);
+    void setName(const QString& name);
     bool isNull() const {
         return !alphabet && seq.length() == 0;
     }
@@ -55,10 +54,10 @@ public:
     bool hasQualityScores() const {
         return (!quality.isEmpty());
     }
-    const char *constData() const {
+    const char* constData() const {
         return seq.constData();
     }
-    const QByteArray &constSequence() const {
+    const QByteArray& constSequence() const {
         return seq;
     }
 };
@@ -67,5 +66,3 @@ public:
 
 Q_DECLARE_METATYPE(U2::DNASequence)
 Q_DECLARE_METATYPE(QList<U2::DNASequence>)
-
-#endif
