@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FEATURE_COLORS_H_
-#define _U2_FEATURE_COLORS_H_
+#pragma once
 
 #include <QColor>
 
@@ -30,9 +29,7 @@ namespace U2 {
 
 class U2CORE_EXPORT FeatureColors {
 public:
-    static QColor genLightColor(const QString &name);
+    static QColor genLightColor(const QString& name);
 };
 
 }  // namespace U2
-
-#endif
