@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MATRIX_44_H_
-#define _U2_MATRIX_44_H_
+#pragma once
 
 #include <QVector>
 
@@ -31,23 +30,20 @@ namespace U2 {
 class U2CORE_EXPORT Matrix44 {
 public:
     Matrix44();
-    Matrix44(const float *data);
-    Matrix44(const Matrix44 &other);
+    Matrix44(const float* data);
+    Matrix44(const Matrix44&) = default;
 
-    Matrix44 &operator=(const Matrix44 &other);
-
-    void loadZero();
     void loadIdentity();
 
     void transpose();
 
-    float *data();
-    const float *data() const;
+    float* data();
+    const float* data() const;
 
-    float &operator[](unsigned int i);
+    float& operator[](unsigned int i);
     float operator[](unsigned int i) const;
 
-    void load(const QVariantList &values);
+    void load(const QVariantList& values);
     QVariantList store();
 
 private:
@@ -55,5 +51,3 @@ private:
 };  // class Matrix44
 
 }  // namespace U2
-
-#endif  // #ifndef _U2_MATRIX_44_H_
