@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_POSITION_WEIGHT_MATRIX_H_
-#define _U2_POSITION_WEIGHT_MATRIX_H_
+#pragma once
 
 #include <QMap>
 #include <QVarLengthArray>
@@ -40,16 +39,16 @@ public:
     UniprobeInfo();
 
     // constructor from parsed data
-    UniprobeInfo(const QMap<QString, QString> &properties);
+    UniprobeInfo(const QMap<QString, QString>& properties);
 
     // constructor from raw data
-    UniprobeInfo(const QString &data);
+    UniprobeInfo(const QString& data);
 
-    QString getProperty(const QString &name) const;
+    QString getProperty(const QString& name) const;
 
     QMap<QString, QString> getProperties() const;
 
-    bool operator==(const UniprobeInfo &i1) const {
+    bool operator==(const UniprobeInfo& i1) const {
         return i1.properties == properties;
     }
 
@@ -67,7 +66,7 @@ public:
     PWMatrix();
 
     // create matrix from pre-counted data
-    PWMatrix(const QVarLengthArray<float> &matrix, const PWMatrixType &type);
+    PWMatrix(const QVarLengthArray<float>& matrix, const PWMatrixType& type);
 
     // get internal index of position in 1-dimensional array
     int index(int row, int column) const;
@@ -88,15 +87,15 @@ public:
     float getMaxSum() const;
 
     // set UniPROBE info for matrix
-    void setInfo(const UniprobeInfo &info);
+    void setInfo(const UniprobeInfo& info);
 
     // get specified UniPROBE property
-    QString getProperty(const QString &propertyName) const;
+    QString getProperty(const QString& propertyName) const;
 
     // get all UniPROBE properties
     QMap<QString, QString> getProperties() const;
 
-    bool operator==(const PWMatrix &m1) const {
+    bool operator==(const PWMatrix& m1) const {
         // FIXME: for some reasons QT == operator didn't work for gcc compiler
         if (m1.data.size() != data.size())
             return false;
@@ -121,5 +120,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
