@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SUBST_MATRIX_H
-#define _U2_SUBST_MATRIX_H
+#pragma once
 
 #include <QVarLengthArray>
 
@@ -43,7 +42,7 @@ public:
 // Example: Blosum70, PAM200, VTML200
 class U2CORE_EXPORT SMatrix {
 public:
-    SMatrix(const QString &name, const DNAAlphabet *alphabet, const QList<SScore> &rawMatrix, const QString &description = QString());
+    SMatrix(const QString& name, const DNAAlphabet* alphabet, const QList<SScore>& rawMatrix, const QString& description = QString());
 
     // constructs empty anonymous matrix
     SMatrix() {
@@ -60,15 +59,15 @@ public:
 
     void setScore(char c1, char c2, float score);
 
-    const QString &getName() const {
+    const QString& getName() const {
         return name;
     }
 
-    const QString &getDescription() const {
+    const QString& getDescription() const {
         return description;
     }
 
-    const DNAAlphabet *getAlphabet() const {
+    const DNAAlphabet* getAlphabet() const {
         return alphabet;
     }
 
@@ -83,7 +82,7 @@ public:
     // TODO: make this class serializable
     QVariant toQVariant() const;
 
-    static SMatrix fromQVariant(const QVariant &v);
+    static SMatrix fromQVariant(const QVariant& v);
 
 private:
     int getScoreIdx(char c1, char c2) const;
@@ -92,7 +91,7 @@ private:
     QString name;
     QString description;
 
-    const DNAAlphabet *alphabet;
+    const DNAAlphabet* alphabet;
     QVarLengthArray<float> scores;  // TODO: make scores integer ?
     char minChar;  // used for optimization of scores size. Minimal character in the alphabet.
     char maxChar;  // used for optimization of scores size. Maximum character in the alphabet.
@@ -122,5 +121,3 @@ inline int SMatrix::getScoreIdx(char c1, char c2) const {
 }
 
 }  // namespace U2
-
-#endif
