@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ALPHABET_H_
-#define _U2_ALPHABET_H_
+#pragma once
 
 #include <U2Core/U2Identity.h>
 #include <U2Core/global.h>
@@ -33,11 +32,9 @@ namespace U2 {
 */
 class U2CORE_EXPORT U2AlphabetId : public AbstractStringId {
 public:
-    U2AlphabetId(const QString &id = QString())
+    U2AlphabetId(const QString& id = QString())
         : AbstractStringId(id) {
     }
 };
 
 }  // namespace U2
-
-#endif
