@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_H_
-#define _U2_ASSEMBLY_H_
+#pragma once
 
 #include <QSharedData>
 
@@ -33,59 +32,82 @@ namespace U2 {
  * CIGAR string operation.
  * CIGAR string represents complex ins/del model for short-reads.
  *
- * Meanings of the operations are the following:
- *
- * - M - 'alignment match'
- *   Either match or mismatch to reference.
- *
- * - I - 'insertion'
- *   Insertion to the reference. Residues marked as 'I' must be skipped when
- *   counting 'real' read length and must be skipped when read is aligned to
- *   reference.
- *
- * - D - 'deletion'
- *   Deletion from the reference. Gaps must be inserted to the read when read
- *   is aligned to reference. Deleted regions must be added to the 'real'
- *   read length.
- *
- * - N - 'skip'
- *   Skipped region from the reference. Skips behave exactly as deletions,
- *   however have different biological meaning: they make sense _only_ in
- *   mRNA-to-genome alignment where represent an intron.
- *
- * - S - 'soft clipping'
- *   Regions which do not match to the reference, behave exactly as insertions.
- *   Must be located at the start or the end of the read (see
- *   SAM spec and CigarValidator)
- *
- * - H - 'hard clipping'
- *   Regions which do not match to the reference, skipped by hardware (not
- *   present in read sequence). Hard clipping does not affects read length or
- *   visualization
- *
- * - P - 'padding' (TODO)
- *   Silent Deletion from padded reference. Someday we should find out how to
- *   handle this. Padding does not affect read length.
- *
- * - = - 'sequence match'
- *   Exact match to reference.
- *
- * - X - 'sequence mismatch'
- *   Mismatch to reference.
- *
  * See also: U2AssemblyUtils::getCigarExtraLength(), ShortReadIterator.
  */
 enum U2CigarOp {
     U2CigarOp_Invalid = 0,
-    U2CigarOp_D = 1,  // deleted
-    U2CigarOp_I = 2,  // inserted
-    U2CigarOp_H = 3,  // hard-clipped
-    U2CigarOp_M = 4,  // alignment match
-    U2CigarOp_N = 5,  // skipped
-    U2CigarOp_P = 6,  // padded
-    U2CigarOp_S = 7,  // soft-clipped
-    U2CigarOp_EQ = 8,  // sequence match
-    U2CigarOp_X = 9  // sequence mismatch
+
+    /**
+     * D - 'deletion'.
+     * Deletion from the reference. Gaps must be inserted to the read when read is aligned to reference.
+     * Deleted regions must be added to the 'real' read length.
+     * Consumes query: no. Consumes reference: yes.
+     */
+    U2CigarOp_D = 1,
+
+    /**
+     * I - 'insertion'.
+     * Insertion to the reference. Residues marked as 'I' must be skipped when
+     * counting 'real' read length and must be skipped when read is aligned to reference.
+     * Consumes query: yes. Consumes reference: no.
+     */
+    U2CigarOp_I = 2,
+
+    /**
+     * H - 'hard clipping'.
+     * Regions which do not match to the reference, skipped by hardware (not present in read sequence).
+     * Hard clipping does not affects read length or visualization.
+     * Consumes query: no. Consumes reference: no.
+     */
+    U2CigarOp_H = 3,
+
+    /**
+     * M - 'alignment match'.
+     * Either match or mismatch to reference.
+     * Consumes query: yes. Consumes reference: yes.
+     */
+    U2CigarOp_M = 4,
+
+    /**
+     * N - 'skip'.
+     *  Skipped region from the reference. Skips behave exactly as deletions,
+     *  however have different biological meaning: they make sense _only_ in
+     *  mRNA-to-genome alignment where represent an intron.
+     *  Consumes query: no. Consumes reference: yes.
+     */
+    U2CigarOp_N = 5,
+
+    /**
+     * - P - 'padding'.
+     *  Silent Deletion from padded reference.
+     *  Someday we should find out how to handle this.
+     *  Padding does not affect read length.
+     *  Consumes query: no. Consumes reference: no.
+     */
+    U2CigarOp_P = 6,
+
+    /**
+     * S - 'soft clipping'.
+     * Regions which do not match to the reference, behave exactly as insertions.
+     * Must be located at the start or the end of the read (see SAM spec and CigarValidator).
+     * Consumes query: yes. Consumes reference: no.
+     */
+    U2CigarOp_S = 7,
+
+    /*
+     *  = - 'sequence match'.
+     * Exact match to reference.
+     * Consumes query: yes. Consumes reference: yes.
+     *
+     */
+    U2CigarOp_EQ = 8,
+
+    /*
+     * X - 'sequence mismatch'.
+     * Mismatch to reference.
+     *  Consumes query: yes. Consumes reference: yes.
+     */
+    U2CigarOp_X = 9
 };
 
 /**
@@ -104,40 +126,48 @@ public:
     int count;
 };
 
-/**
-    assembly read flags
-*/
+/** BAM read flags. */
 enum ReadFlag {
     None = 0,
-    Fragmented = 1 << 0,
-    FragmentsAligned = 1 << 1,
+    /** Read is paired in sequencing, no matter whether it is mapped in a pair . */
+    Paired = 1 << 0,
+    /** Read is mapped in a proper pair. */
+    ProperPair = 1 << 1,
+    /** Read itself is unmapped; Exclusive with ProperPair. */
     Unmapped = 1 << 2,
-    NextUnmapped = 1 << 3,
+    /** Next segment (mate) in the template unmapped. */
+    MateUnmapped = 1 << 3,
+    /** Read is mapped to the reverse strand: SEQ being reverse complemented.*/
     Reverse = 1 << 4,
-    NextReverse = 1 << 5,
+    /** Mate is mapped to the reverse strand : SEQ of the next segment in the template being reversed. */
+    MateReverse = 1 << 5,
+    /** The first segment in the template (read1). */
     FirstInTemplate = 1 << 6,
+    /** The last segment in the template (read2, mate). */
     LastInTemplate = 1 << 7,
-    SecondaryAlignment = 1 << 8,
-    FailsChecks = 1 << 9,
+    /** Not a primary, but a secondary alignment. */
+    Secondary = 1 << 8,
+    /** Not passing quality controls. */
+    QcFail = 1 << 9,
+    /** Optical or PCR duplicate. */
     Duplicate = 1 << 10,
-    DnaExtAlphabet = 1 << 16
+    /** Supplementary alignment */
+    Supplementary = 1 << 11,
 };
 
+Q_DECLARE_FLAGS(ReadFlags, ReadFlag)
+
 /**
     Utility class to work with flags
  */
 class ReadFlagsUtils {
 public:
-    static bool isExtendedAlphabet(qint64 flags) {
-        return flags & DnaExtAlphabet;
-    }
-
     static bool isComplementaryRead(qint64 flags) {
         return flags & Reverse;
     }
 
     static bool isPairedRead(qint64 flags) {
-        return flags & Fragmented;
+        return flags & Paired;
     }
 
     static bool isUnmappedRead(qint64 flags) {
@@ -255,5 +285,3 @@ public:
 typedef QVector<qint32> U2AssemblyCoverageStat;
 
 }  // namespace U2
-
-#endif
