@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FEATURE_KEYS_H_
-#define _U2_FEATURE_KEYS_H_
+#pragma once
 
 #include <QtCore/QString>
 
@@ -52,5 +51,3 @@ const QString U2FeatureKeyOperationBond = "#~ob";
 const QString U2FeatureKeyCase = "#~c";
 
 }  // namespace U2
-
-#endif  //_U2_FEATURE_KEYS_H_
