@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_QUALIFIER_H_
-#define _U2_QUALIFIER_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -41,23 +40,21 @@ public:
     U2Qualifier();
 
     /** Constructs new qualifier instance with name and value set */
-    U2Qualifier(const QString &name, const QString &value);
+    U2Qualifier(const QString& name, const QString& value);
 
     /** U2Qualifier is valid if  its name is not empty */
     bool isValid() const;
 
     /** Any two qualifiers are equal if their names & values are equal */
-    bool operator==(const U2Qualifier &q) const;
+    bool operator==(const U2Qualifier& q) const;
 
     /** Any two qualifiers are not equal if either their names or values are  not equal */
-    bool operator!=(const U2Qualifier &q) const;
+    bool operator!=(const U2Qualifier& q) const;
 
-    static bool isValidQualifierName(const QString &name);
-    static bool isValidQualifierValue(const QString &value);
+    static bool isValidQualifierName(const QString& name);
+    static bool isValidQualifierValue(const QString& value);
 };
 
 }  // namespace U2
 
 Q_DECLARE_METATYPE(U2::U2Qualifier)
-
-#endif
