@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_REGION_H_
-#define _U2_REGION_H_
+#pragma once
 
 #include <QObject>
 #include <QRect>
@@ -74,27 +73,27 @@ public:
     }
 
     /** Checks whether the specified region fits inside this region or is equal. */
-    bool contains(const U2Region &r) const {
+    bool contains(const U2Region& r) const {
         return r.startPos >= startPos && r.endPos() <= endPos();
     }
 
     /** Checks whether the specified region has common points with this region. */
-    bool intersects(const U2Region &r) const;
+    bool intersects(const U2Region& r) const;
 
     /** Returns the intersection between 2 regions, or empty value if regions do not intersect. */
-    U2Region intersect(const U2Region &r) const;
+    U2Region intersect(const U2Region& r) const;
 
     /**
         Checks whether this region has common points with any region in the specified list.
         Returns the index of the first region found or -1 if no matches found
     */
-    int findIntersectedRegion(const QVector<U2Region> &rs) const;
+    int findIntersectedRegion(const QVector<U2Region>& rs) const;
 
     /**
         Checks whether this region has common points with any region in the specified list.
         Returns the index of the first region found or -1 if no matches found
     */
-    bool intersects(const QVector<U2Region> &rs) const {
+    bool intersects(const QVector<U2Region>& rs) const {
         return findIntersectedRegion(rs) != -1;
     }
 
@@ -102,27 +101,27 @@ public:
         Checks whether this region is located inside of any region in the specified list.
         Returns the index of the first region found or -1 if no matches found
     */
-    int findOverlappingRegion(const QVector<U2Region> &regions) const;
+    int findOverlappingRegion(const QVector<U2Region>& regions) const;
 
     /** Checks if the specified region is equal to this region. */
-    bool operator==(const U2Region &r) const {
+    bool operator==(const U2Region& r) const {
         return r.startPos == startPos && r.length == length;
     }
 
     /** Checks whether the specified region is not equal to this region. */
-    bool operator!=(const U2Region &r) const {
+    bool operator!=(const U2Region& r) const {
         return r.startPos != startPos || r.length != length;
     }
 
     /** Compares 2 regions by start position.
     Returns true if this region starts strictly earlier than the specified one. */
-    bool operator<(const U2Region &r) const {
+    bool operator<(const U2Region& r) const {
         return startPos < r.startPos;
     }
 
     /** Compares 2 regions by start position.
     Returns true if this region starts strictly later than the specified one. */
-    bool operator>(const U2Region &r) const {
+    bool operator>(const U2Region& r) const {
         return startPos > r.startPos;
     }
 
@@ -146,51 +145,65 @@ public:
     ///////////////////////// Class functions /////////////////////////////////
 
     /** Returns least common region which contains both of the 2 specified regions. */
-    static U2Region containingRegion(const U2Region &r1, const U2Region &r2);
+    static U2Region containingRegion(const U2Region& r1, const U2Region& r2);
 
     /** Returns least common region which contains all of the specified regions. */
-    static U2Region containingRegion(const QVector<U2Region> &regions);
+    static U2Region containingRegion(const QVector<U2Region>& regions);
 
     /** Returns least coverage of the regions. Sequence is considered to be circular. */
-    static QVector<U2Region> circularContainingRegion(QVector<U2Region> &regions, int seqLen);
+    static QVector<U2Region> circularContainingRegion(QVector<U2Region>& regions, int seqLen);
 
     /** Normalizes the specified list by joining overlapping regions.
     This function sorts regions by starting position then
     iterates through them and replaces all groups of intersecting regions by containing regions.
     */
-    static QVector<U2Region> join(QVector<U2Region> &regions);
+    static QVector<U2Region> join(QVector<U2Region>& regions);
 
     /** Fixes start & len for all regions to ensure that the result region
         has startPos >= minPos & endPos <= maxPos
      */
-    static void bound(qint64 minPos, qint64 maxPos, QVector<U2Region> &regions);
+    static void bound(qint64 minPos, qint64 maxPos, QVector<U2Region>& regions);
 
     /** mirrors regions by mirror pos: startPos = mirrorPos - startPos */
-    static void mirror(qint64 mirrorPos, QVector<U2Region> &regions);
+    static void mirror(qint64 mirrorPos, QVector<U2Region>& regions);
 
     /** divides regions by  div : startPos = startPos / div */
-    static void divide(qint64 div, QVector<U2Region> &regions);
+    static void divide(qint64 div, QVector<U2Region>& regions);
 
     /** multiplies regions by  mult : startPos = startPos * mult */
-    static void multiply(qint64 mult, QVector<U2Region> &regions);
+    static void multiply(qint64 mult, QVector<U2Region>& regions);
 
     /** Reverses order of regions in the list */
-    static void reverse(QVector<U2Region> &regions);
+    static void reverse(QVector<U2Region>& regions);
 
     /** shifts regions by offset pos: startPos = startPos + offset */
-    static void shift(qint64 offset, QVector<U2Region> &regions);
+    static void shift(qint64 offset, QVector<U2Region>& regions);
 
     /** Splits region into the set of regions of the given block size. */
-    static QList<U2Region> split(const U2Region &region, qint64 blockSize);
+    static QList<U2Region> split(const U2Region& region, qint64 blockSize);
+
+    /**
+     * Returns a sub-list of regions with a total length of 'headLength'.
+     * Starts with the first region in the list.
+     * The last returned region may be trimmed in order to satisfy the 'headLength' constraint.
+     */
+    static QVector<U2Region> headOf(const QVector<U2Region>& regions, qint64 headLength);
+
+    /**
+     * Returns a sub-list of regions with a total length of 'tailLength'.
+     * Starts with the last region in the list.
+     * The first returned region in the resulted list may be trimmed on the startPos side in order to satisfy the 'tailLength' constraint.
+     */
+    static QVector<U2Region> tailOf(const QVector<U2Region>& regions, qint64 tailLength);
 
     /** Returns sum of region lengths. */
-    static qint64 sumLength(const QVector<U2Region> &regions);
+    static qint64 sumLength(const QVector<U2Region>& regions);
 
     /** Creates a region constructed from the X range of the rect: U2Region(rect.x(), rect.width()). */
-    static U2Region fromXRange(const QRect &rect);
+    static U2Region fromXRange(const QRect& rect);
 
     /** Creates a new region constructed from the Y range of the rect: U2Region(rect.y(), rect.height()). */
-    static U2Region fromYRange(const QRect &rect);
+    static U2Region fromYRange(const QRect& rect);
 
     /** Creates a new region with startPos & endPos() set to the specified values. */
     static U2Region fromStartAndEnd(qint64 startPos, qint64 endPos);
@@ -201,12 +214,12 @@ private:
 
 //////////////////// inline implementations ///////////////////////////
 
-inline bool U2Region::intersects(const U2Region &r) const {
+inline bool U2Region::intersects(const U2Region& r) const {
     qint64 sd = startPos - r.startPos;
     return (sd >= 0) ? (sd < r.length) : (-sd < length);
 }
 
-inline U2Region U2Region::intersect(const U2Region &r) const {
+inline U2Region U2Region::intersect(const U2Region& r) const {
     qint64 newStart = qMax(startPos, r.startPos);
     qint64 newEnd = qMin(endPos(), r.endPos());
     if (newStart > newEnd) {
@@ -215,29 +228,27 @@ inline U2Region U2Region::intersect(const U2Region &r) const {
     return U2Region(newStart, newEnd - newStart);
 }
 
-inline U2Region U2Region::containingRegion(const U2Region &r1, const U2Region &r2) {
+inline U2Region U2Region::containingRegion(const U2Region& r1, const U2Region& r2) {
     qint64 newStart = qMin(r1.startPos, r2.startPos);
     qint64 newEnd = qMax(r1.endPos(), r2.endPos());
     return U2Region(newStart, newEnd - newStart);
 }
 
-inline U2Region U2Region::containingRegion(const QVector<U2Region> &regions) {
+inline U2Region U2Region::containingRegion(const QVector<U2Region>& regions) {
     assert(!regions.isEmpty());
 
     U2Region res = regions.first();
-    foreach (const U2Region &r, regions) {
+    foreach (const U2Region& r, regions) {
         res = containingRegion(res, r);
     }
     return res;
 }
 
-U2CORE_EXPORT QDataStream &operator<<(QDataStream &out, const U2Region &myObj);
-U2CORE_EXPORT QDataStream &operator>>(QDataStream &in, U2Region &myObj);
+U2CORE_EXPORT QDataStream& operator<<(QDataStream& out, const U2Region& myObj);
+U2CORE_EXPORT QDataStream& operator>>(QDataStream& in, U2Region& myObj);
 
 }  // namespace U2
 
 Q_DECLARE_TYPEINFO(U2::U2Region, Q_PRIMITIVE_TYPE);
 Q_DECLARE_METATYPE(U2::U2Region)
 Q_DECLARE_METATYPE(QVector<U2::U2Region>)
-
-#endif
