@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_H_
-#define _U2_SEQUENCE_H_
+#pragma once
 
 #include <U2Core/U2Alphabet.h>
 #include <U2Core/U2Type.h>
@@ -36,7 +35,7 @@ public:
     U2Sequence()
         : length(0), circular(false) {
     }
-    U2Sequence(const U2DataId &id, const QString &dbId, qint64 version)
+    U2Sequence(const U2DataId& id, const QString& dbId, qint64 version)
         : U2Object(id, dbId, version), length(0) {
     }
 
@@ -55,5 +54,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
