@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TYPE_H_
-#define _U2_TYPE_H_
+#pragma once
 
 #include <QObject>
 
@@ -36,14 +35,14 @@ class U2Dbi;
 
     U2DataType - data types supported by U2Dbi
     U2DataId - object ids associated with Data by U2Dbi.
-    Note that U2DataId == empty check must be suppoted by DBI to check empty fields.
+    Note that U2DataId == empty check must be supported by DBI to check empty fields.
 */
 typedef quint16 U2DataType;
 typedef QByteArray U2DataId;
 
 /**
     ID of the DBI Factory. Defines type of the DBI driver.
-    Examples: 'sqlite', 'mysql', 'fasta'....
+    Examples: 'sqlite', 'fasta'....
 */
 typedef QString U2DbiFactoryId;
 
@@ -62,54 +61,52 @@ typedef QString U2DbiId;
 class U2CORE_EXPORT U2Type {
 public:
     /** Type is unknown. Default value. */
-    static const U2DataType Unknown = 0;
+    static constexpr U2DataType Unknown = 0;
 
     /** Object types */
-    static const U2DataType Sequence = 1;
-    static const U2DataType Msa = 2;
-    static const U2DataType Assembly = 4;
-    static const U2DataType VariantTrack = 5;
-    static const U2DataType VariantType = 6;
-    static const U2DataType FilterTableType = 7;
-    static const U2DataType KnownMutationsTrackType = 8;
-    static const U2DataType AnnotationTable = 10;
-    static const U2DataType Mca = 11;
+    static constexpr U2DataType Sequence = 1;
+    static constexpr U2DataType Msa = 2;
+    static constexpr U2DataType Assembly = 4;
+    static constexpr U2DataType VariantTrack = 5;
+    static constexpr U2DataType VariantType = 6;
+    static constexpr U2DataType AnnotationTable = 10;
+    static constexpr U2DataType Mca = 11;
     /** UDR object types 101..199 */
-    static const U2DataType Text = 101;
-    static const U2DataType PhyTree = 102;
-    static const U2DataType Chromatogram = 103;
-    static const U2DataType BioStruct3D = 104;
-    static const U2DataType PFMatrix = 105;
-    static const U2DataType PWMatrix = 106;
+    static constexpr U2DataType Text = 101;
+    static constexpr U2DataType PhyTree = 102;
+    static constexpr U2DataType Chromatogram = 103;
+    static constexpr U2DataType BioStruct3D = 104;
+    static constexpr U2DataType PFMatrix = 105;
+    static constexpr U2DataType PWMatrix = 106;
 
-    static const U2DataType CrossDatabaseReference = 999;
+    static constexpr U2DataType CrossDatabaseReference = 999;
 
     /** SCO (non-object, non-root) types */
-    static const U2DataType Annotation = 1000;
-    static const U2DataType AnnotationGroup = 1001;
+    static constexpr U2DataType Annotation = 1000;
+    static constexpr U2DataType AnnotationGroup = 1001;
 
     /**  Assembly read */
-    static const U2DataType AssemblyRead = 1100;
+    static constexpr U2DataType AssemblyRead = 1100;
 
     /** Sequence feature */
-    static const U2DataType Feature = 1300;
+    static constexpr U2DataType Feature = 1300;
 
-    static const U2DataType UdrRecord = 1400;
+    static constexpr U2DataType UdrRecord = 1400;
 
     /**  Attribute types */
-    static const U2DataType AttributeInteger = 2001;
-    static const U2DataType AttributeReal = 2002;
-    static const U2DataType AttributeString = 2003;
-    static const U2DataType AttributeByteArray = 2004;
+    static constexpr U2DataType AttributeInteger = 2001;
+    static constexpr U2DataType AttributeReal = 2002;
+    static constexpr U2DataType AttributeString = 2003;
+    static constexpr U2DataType AttributeByteArray = 2004;
 
-    static bool isObjectType(U2DataType type) {
+    static bool isObjectType(const U2DataType& type) {
         return type > 0 && type <= 999;
     }
-    static bool isUdrObjectType(U2DataType type) {
+    static bool isUdrObjectType(const U2DataType& type) {
         return type > 100 && type < 200;
     }
 
-    static bool isAttributeType(U2DataType type) {
+    static bool isAttributeType(const U2DataType& type) {
         return type >= 2000 && type < 2100;
     }
 };
@@ -123,13 +120,13 @@ enum U2TrackModType {
 /** Dbi reference: dbiURL & DBI type */
 class U2CORE_EXPORT U2DbiRef {
 public:
-    U2DbiRef(const U2DbiFactoryId &dbiFactoryId = U2DbiFactoryId(), const U2DbiId &dbiId = U2DbiId());
+    U2DbiRef(const U2DbiFactoryId& dbiFactoryId = U2DbiFactoryId(), const U2DbiId& dbiId = U2DbiId());
 
     bool isValid() const;
 
-    bool operator!=(const U2DbiRef &r2) const;
-    bool operator==(const U2DbiRef &r2) const;
-    bool operator<(const U2DbiRef &r2) const;
+    bool operator!=(const U2DbiRef& r2) const;
+    bool operator==(const U2DbiRef& r2) const;
+    bool operator<(const U2DbiRef& r2) const;
 
     U2DbiFactoryId dbiFactoryId;
     U2DbiId dbiId;
@@ -138,8 +135,8 @@ private:
     static bool metaInfoRegistered;
 };
 
-QDataStream &operator<<(QDataStream &out, const U2DbiRef &dbiRef);
-QDataStream &operator>>(QDataStream &in, U2DbiRef &dbiRef);
+QDataStream& operator<<(QDataStream& out, const U2DbiRef& dbiRef);
+QDataStream& operator>>(QDataStream& in, U2DbiRef& dbiRef);
 
 /**
     Cross database data reference
@@ -147,12 +144,12 @@ QDataStream &operator>>(QDataStream &in, U2DbiRef &dbiRef);
 class U2CORE_EXPORT U2EntityRef {
 public:
     U2EntityRef();
-    U2EntityRef(const U2DbiRef &dbiRef, const U2DataId &entityId);
+    U2EntityRef(const U2DbiRef& dbiRef, const U2DataId& entityId);
     bool isValid() const;
 
-    bool operator==(const U2EntityRef &other) const;
-    bool operator!=(const U2EntityRef &other) const;
-    bool operator<(const U2EntityRef &other) const;
+    bool operator==(const U2EntityRef& other) const;
+    bool operator!=(const U2EntityRef& other) const;
+    bool operator<(const U2EntityRef& other) const;
 
     /** database  id */
     U2DbiRef dbiRef;
@@ -169,18 +166,16 @@ public:
 */
 class U2CORE_EXPORT U2Entity {
 public:
-    U2Entity(const U2DataId &id = U2DataId());
-    U2Entity(const U2Entity &other);
+    U2Entity(const U2DataId& id = U2DataId());
+    U2Entity(const U2Entity&) = default;
 
-    virtual ~U2Entity();
+    virtual ~U2Entity() = default;
 
     bool hasValidId() const;
 
-    U2Entity operator=(const U2Entity &other);
-
-    bool operator==(const U2Entity &other) const;
-    bool operator!=(const U2Entity &other) const;
-    bool operator<(const U2Entity &other) const;
+    bool operator==(const U2Entity& other) const;
+    bool operator!=(const U2Entity& other) const;
+    bool operator<(const U2Entity& other) const;
 
     U2DataId id;
 };
@@ -193,7 +188,7 @@ public:
     U2Object()
         : version(0), trackModType(NoTrack) {
     }
-    U2Object(U2DataId id, const U2DbiId &_dbId, qint64 v)
+    U2Object(U2DataId id, const U2DbiId& _dbId, qint64 v)
         : U2Entity(id), dbiId(_dbId), version(v), trackModType(NoTrack) {
     }
 
@@ -215,7 +210,7 @@ public:
     }
 };
 
-inline uint qHash(const U2Object &obj) {
+inline uint qHash(const U2Object& obj) {
     return qHash(QPair<U2DataId, U2DbiId>(obj.id, obj.dbiId));
 }
 
@@ -274,15 +269,15 @@ public:
         return value == Direct;
     }
 
-    bool isCompementary() const {
+    bool isComplementary() const {
         return value == Complementary;
     }
 
-    bool operator==(const U2Strand &s) const {
+    bool operator==(const U2Strand& s) const {
         return value == s.value;
     }
 
-    bool operator!=(const U2Strand &s) const {
+    bool operator!=(const U2Strand& s) const {
         return value != s.value;
     }
 
@@ -302,5 +297,3 @@ private:
 
 Q_DECLARE_METATYPE(QList<U2::U2DataId>)
 Q_DECLARE_METATYPE(U2::U2DbiRef)
-
-#endif
