@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_VARIANT_H_
-#define _U2_VARIANT_H_
+#pragma once
 
 #include <U2Core/StrPackUtils.h>
 #include <U2Core/U2Type.h>
@@ -45,7 +44,7 @@ enum VariantTrackType {
 class U2CORE_EXPORT U2VariantTrack : public U2Object {
 public:
     U2VariantTrack();
-    U2VariantTrack(const U2DataId &id, const QString &dbId, VariantTrackType trackType, qint64 version);
+    U2VariantTrack(const U2DataId& id, const QString& dbId, VariantTrackType trackType, qint64 version);
 
     /** Sequence id */
     U2DataId sequence;
@@ -83,5 +82,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // _U2_VARIANT_H_
