@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_UDRSCHEMA_H_
-#define _U2_UDRSCHEMA_H_
+#pragma once
 
 #include <U2Core/U2OpStatus.h>
 
@@ -59,7 +58,7 @@ public:
      */
     class U2CORE_EXPORT FieldDesc {
     public:
-        FieldDesc(const QByteArray &name, DataType dataType, IndexType indexType = NOT_INDEXED);
+        FieldDesc(const QByteArray& name, DataType dataType, IndexType indexType = NOT_INDEXED);
 
         /**
          * The name of the field.
@@ -89,30 +88,30 @@ public:
      * @useObjectReference parameter.
      * If it's 'true' the additional field "object" is created. Its fieldNum is 0 (OBJECT_FIELD_NUM).
      */
-    UdrSchema(const UdrSchemaId &id, bool useObjectReference = false);
+    UdrSchema(const UdrSchemaId& id, bool useObjectReference = false);
 
     /**
      * The name of a new field must be unique within the schema.
      * The number of a field in the order of adding is the field identifier (fieldNum).
      */
-    void addField(const FieldDesc &desc, U2OpStatus &os);
+    void addField(const FieldDesc& desc, U2OpStatus& os);
 
     /**
      * A multi index is a unique list of fieldNums.
      * The index for fields with these fieldNums will be created
      * for optimized access to the data.
      */
-    void addMultiIndex(const QList<int> &multiIndex, U2OpStatus &os);
+    void addMultiIndex(const QList<int>& multiIndex, U2OpStatus& os);
 
     /**
      * Returns the list of multi indexes.
      */
-    const QList<QList<int>> &getMultiIndexes() const;
+    const QList<QList<int>>& getMultiIndexes() const;
 
     /**
      * Returns the schema identifier.
      */
-    const UdrSchemaId &getId() const;
+    const UdrSchemaId& getId() const;
 
     /**
      * Return the count of fields.
@@ -122,16 +121,16 @@ public:
     /**
      * Returns the field description of the specified number.
      */
-    FieldDesc getField(int fieldNum, U2OpStatus &os) const;
+    FieldDesc getField(int fieldNum, U2OpStatus& os) const;
 
     /**
      * Returns true if the schema is created for describing data of some object type.
      */
     bool hasObjectReference() const;
 
-    static QStringList fieldNames(const UdrSchema *schema, U2OpStatus &os, const QList<int> &nums = QList<int>());
-    static QList<int> notBinary(const UdrSchema *schema, U2OpStatus &os);
-    static FieldDesc getBlobField(const UdrSchema *schema, int fieldNum, U2OpStatus &os);
+    static QStringList fieldNames(const UdrSchema* schema, U2OpStatus& os, const QList<int>& nums = QList<int>());
+    static QList<int> notBinary(const UdrSchema* schema, U2OpStatus& os);
+    static FieldDesc getBlobField(const UdrSchema* schema, int fieldNum, U2OpStatus& os);
 
     /**
      * Reserved name of the field for record identifier.
@@ -155,9 +154,7 @@ private:
     QList<FieldDesc> fields;
 
 private:
-    bool contains(const QByteArray &name) const;
+    bool contains(const QByteArray& name) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_UDRSCHEMA_H_
