@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_VECTOR_MATH_H_
-#define _U2_VECTOR_MATH_H_
+#pragma once
 
 #include <QtGlobal>
 
@@ -35,32 +34,28 @@ public:
     double x, y, z;
 
     explicit Vector3D(double xi = 0.0, double yi = 0.0, double zi = 0.0);
-    Vector3D(const Vector3D &v);
-    Vector3D &operator=(const Vector3D &v);
-    bool operator==(const Vector3D &other) const;
-    bool operator!=(const Vector3D &other) const;
-    double &operator[](unsigned int i);
+
+    bool operator==(const Vector3D& other) const;
+    bool operator!=(const Vector3D& other) const;
+    double& operator[](unsigned int i);
     double operator[](unsigned int i) const;
-    Vector3D &operator+=(const Vector3D &v);
-    Vector3D &operator-=(const Vector3D &v);
-    Vector3D &operator*=(double f);
-    Vector3D &operator/=(double f);
-    Vector3D &dot(const Matrix44 &m);
+    Vector3D& operator+=(const Vector3D& v);
+    Vector3D& operator-=(const Vector3D& v);
+    Vector3D& operator*=(double f);
+    Vector3D& operator/=(double f);
+    Vector3D& dot(const Matrix44& m);
     void set(double xs, double ys, double zs);
     double length(void) const;
-    double lengthSquared(void) const;
     void normalize(void);
 };
 
-U2CORE_EXPORT Vector3D operator-(const Vector3D &a);
-U2CORE_EXPORT Vector3D operator+(const Vector3D &a, const Vector3D &b);
-U2CORE_EXPORT Vector3D operator-(const Vector3D &a, const Vector3D &b);
-U2CORE_EXPORT double vector_dot(const Vector3D &a, const Vector3D &b);
-U2CORE_EXPORT Vector3D vector_cross(const Vector3D &a, const Vector3D &b);
-U2CORE_EXPORT Vector3D operator*(const Vector3D &v, double f);
-U2CORE_EXPORT Vector3D operator*(double f, const Vector3D &v);
-U2CORE_EXPORT Vector3D operator/(const Vector3D &v, double f);
+U2CORE_EXPORT Vector3D operator-(const Vector3D& a);
+U2CORE_EXPORT Vector3D operator+(const Vector3D& a, const Vector3D& b);
+U2CORE_EXPORT Vector3D operator-(const Vector3D& a, const Vector3D& b);
+U2CORE_EXPORT double vector_dot(const Vector3D& a, const Vector3D& b);
+U2CORE_EXPORT Vector3D vector_cross(const Vector3D& a, const Vector3D& b);
+U2CORE_EXPORT Vector3D operator*(const Vector3D& v, double f);
+U2CORE_EXPORT Vector3D operator*(double f, const Vector3D& v);
+U2CORE_EXPORT Vector3D operator/(const Vector3D& v, double f);
 
 }  // namespace U2
-
-#endif  //_U2_VECTOR_MATH_H_
