@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MA_STATE_CHECK_H_
-#define _U2_MA_STATE_CHECK_H_
+#pragma once
 
 namespace U2 {
 
@@ -28,13 +27,11 @@ class MultipleAlignmentData;
 
 class MaStateCheck {
 public:
-    MaStateCheck(const MultipleAlignmentData *maData);
+    MaStateCheck(const MultipleAlignmentData* maData);
     ~MaStateCheck();
 
 private:
-    const MultipleAlignmentData *maData;
+    const MultipleAlignmentData* maData;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MA_STATE_CHECK_H_
