@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MULTIPLE_ALIGNMENT_ROW_INFO_H_
-#define _U2_MULTIPLE_ALIGNMENT_ROW_INFO_H_
+#pragma once
 
 #include <QVariantMap>
 
@@ -30,16 +29,14 @@ namespace U2 {
 
 class U2CORE_EXPORT MultipleAlignmentRowInfo {
 public:
-    static void setReversed(QVariantMap &info, bool reversed);
-    static bool getReversed(const QVariantMap &info);
+    static void setReversed(QVariantMap& info, bool reversed);
+    static bool getReversed(const QVariantMap& info);
 
-    static void setComplemented(QVariantMap &info, bool complemented);
-    static bool getComplemented(const QVariantMap &info);
+    static void setComplemented(QVariantMap& info, bool complemented);
+    static bool getComplemented(const QVariantMap& info);
 
     static const QString REVERSED;
     static const QString COMPLEMENTED;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MULTIPLE_ALIGNMENT_ROW_INFO_H_
