@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,7 +28,6 @@
 #include <U2Core/U2SafePoints.h>
 
 #include "MaStateCheck.h"
-#include "MultipleAlignmentInfo.h"
 #include "MultipleChromatogramAlignment.h"
 
 namespace U2 {
@@ -37,36 +36,36 @@ MultipleChromatogramAlignment::MultipleChromatogramAlignment()
     : MultipleAlignment(new MultipleChromatogramAlignmentData()) {
 }
 
-MultipleChromatogramAlignment::MultipleChromatogramAlignment(const MultipleAlignment &ma)
+MultipleChromatogramAlignment::MultipleChromatogramAlignment(const MultipleAlignment& ma)
     : MultipleAlignment(ma) {
-    SAFE_POINT(nullptr != maData.dynamicCast<MultipleChromatogramAlignmentData>(), "Can't cast MultipleAlignment to MultipleChromatogramAlignment", );
+    SAFE_POINT(maData.dynamicCast<MultipleChromatogramAlignmentData>() != nullptr, "Can't cast MultipleAlignment to MultipleChromatogramAlignment", );
 }
 
-MultipleChromatogramAlignment::MultipleChromatogramAlignment(MultipleChromatogramAlignmentData *mcaData)
+MultipleChromatogramAlignment::MultipleChromatogramAlignment(MultipleChromatogramAlignmentData* mcaData)
     : MultipleAlignment(mcaData) {
 }
 
-MultipleChromatogramAlignment::MultipleChromatogramAlignment(const QString &name, const DNAAlphabet *alphabet, const QList<MultipleChromatogramAlignmentRow> &rows)
+MultipleChromatogramAlignment::MultipleChromatogramAlignment(const QString& name, const DNAAlphabet* alphabet, const QList<MultipleChromatogramAlignmentRow>& rows)
     : MultipleAlignment(new MultipleChromatogramAlignmentData(name, alphabet, rows)) {
 }
 
-MultipleChromatogramAlignmentData *MultipleChromatogramAlignment::data() const {
+MultipleChromatogramAlignmentData* MultipleChromatogramAlignment::data() const {
     return getMcaData().data();
 }
 
-MultipleChromatogramAlignmentData &MultipleChromatogramAlignment::operator*() {
+MultipleChromatogramAlignmentData& MultipleChromatogramAlignment::operator*() {
     return *getMcaData();
 }
 
-const MultipleChromatogramAlignmentData &MultipleChromatogramAlignment::operator*() const {
+const MultipleChromatogramAlignmentData& MultipleChromatogramAlignment::operator*() const {
     return *getMcaData();
 }
 
-MultipleChromatogramAlignmentData *MultipleChromatogramAlignment::operator->() {
+MultipleChromatogramAlignmentData* MultipleChromatogramAlignment::operator->() {
     return getMcaData().data();
 }
 
-const MultipleChromatogramAlignmentData *MultipleChromatogramAlignment::operator->() const {
+const MultipleChromatogramAlignmentData* MultipleChromatogramAlignment::operator->() const {
     return getMcaData().data();
 }
 
@@ -80,9 +79,9 @@ QSharedPointer<MultipleChromatogramAlignmentData> MultipleChromatogramAlignment:
 
 namespace {
 
-QList<MultipleAlignmentRow> convertToMaRows(const QList<MultipleChromatogramAlignmentRow> &mcaRows) {
+QList<MultipleAlignmentRow> convertToMaRows(const QList<MultipleChromatogramAlignmentRow>& mcaRows) {
     QList<MultipleAlignmentRow> maRows;
-    foreach (const MultipleChromatogramAlignmentRow &mcaRow, mcaRows) {
+    foreach (const MultipleChromatogramAlignmentRow& mcaRow, mcaRows) {
         maRows << mcaRow;
     }
     return maRows;
@@ -90,24 +89,15 @@ QList<MultipleAlignmentRow> convertToMaRows(const QList<MultipleChromatogramAlig
 
 }  // namespace
 
-MultipleChromatogramAlignmentData::MultipleChromatogramAlignmentData(const QString &name, const DNAAlphabet *alphabet, const QList<MultipleChromatogramAlignmentRow> &rows)
-    : MultipleAlignmentData(name, alphabet, convertToMaRows(rows)) {
+MultipleChromatogramAlignmentData::MultipleChromatogramAlignmentData(const QString& name, const DNAAlphabet* alphabet, const QList<MultipleChromatogramAlignmentRow>& rows)
+    : MultipleAlignmentData(MultipleAlignmentDataType::MCA, name, alphabet, convertToMaRows(rows)) {
 }
 
-MultipleChromatogramAlignmentData::MultipleChromatogramAlignmentData(const MultipleChromatogramAlignmentData &mcaData)
-    : MultipleAlignmentData() {
+MultipleChromatogramAlignmentData::MultipleChromatogramAlignmentData(const MultipleChromatogramAlignmentData& mcaData)
+    : MultipleAlignmentData(MultipleAlignmentDataType::MCA) {
     copy(mcaData);
 }
 
-MultipleChromatogramAlignmentData &MultipleChromatogramAlignmentData::operator=(const MultipleChromatogramAlignment &mca) {
-    return *this = *mca;
-}
-
-MultipleChromatogramAlignmentData &MultipleChromatogramAlignmentData::operator=(const MultipleChromatogramAlignmentData &mcaData) {
-    copy(mcaData);
-    return *this;
-}
-
 bool MultipleChromatogramAlignmentData::trim(bool removeLeadingGaps) {
     MaStateCheck check(this);
     Q_UNUSED(check);
@@ -117,18 +107,18 @@ bool MultipleChromatogramAlignmentData::trim(bool removeLeadingGaps) {
     if (removeLeadingGaps) {
         // Verify if there are leading columns of gaps
         // by checking the first gap in each row
-        qint64 leadingGapColumnsNum = 0;
-        foreach (const MultipleChromatogramAlignmentRow &row, rows) {
-            if (row->getGapModel().count() > 0) {
-                const U2MsaGap firstGap = row->getGapModel().first();
-                if (firstGap.offset > 0) {
+        int leadingGapColumnsNum = 0;
+        for (const auto& row : qAsConst(rows)) {
+            if (!row->getGaps().isEmpty()) {
+                const U2MsaGap& firstGap = row->getGaps().first();
+                if (firstGap.startPos > 0) {
                     leadingGapColumnsNum = 0;
                     break;
                 } else {
                     if (leadingGapColumnsNum == 0) {
-                        leadingGapColumnsNum = firstGap.gap;
+                        leadingGapColumnsNum = firstGap.length;
                     } else {
-                        leadingGapColumnsNum = qMin(leadingGapColumnsNum, firstGap.gap);
+                        leadingGapColumnsNum = qMin(leadingGapColumnsNum, firstGap.length);
                     }
                 }
             } else {
@@ -140,7 +130,7 @@ bool MultipleChromatogramAlignmentData::trim(bool removeLeadingGaps) {
         // If there are leading gap columns, remove them
         U2OpStatus2Log os;
         if (leadingGapColumnsNum > 0) {
-            for (int i = 0; i < getNumRows(); ++i) {
+            for (int i = 0; i < getRowCount(); ++i) {
                 getMcaRow(i)->removeChars(0, leadingGapColumnsNum, os);
                 CHECK_OP(os, true);
                 result = true;
@@ -150,7 +140,7 @@ bool MultipleChromatogramAlignmentData::trim(bool removeLeadingGaps) {
 
     // Verify right side of the alignment (trailing gaps and rows' lengths)
     qint64 newLength = 0;
-    foreach (const MultipleChromatogramAlignmentRow &row, rows) {
+    foreach (const MultipleChromatogramAlignmentRow& row, rows) {
         if (newLength == 0) {
             newLength = row->getRowLengthWithoutTrailing();
         } else {
@@ -172,7 +162,7 @@ bool MultipleChromatogramAlignmentData::simplify() {
 
     int newLen = 0;
     bool changed = false;
-    for (int i = 0, n = getNumRows(); i < n; i++) {
+    for (int i = 0, n = getRowCount(); i < n; i++) {
         changed |= getMcaRow(i)->simplify();
         newLen = qMax(newLen, getMcaRow(i)->getCoreEnd());
     }
@@ -186,8 +176,8 @@ bool MultipleChromatogramAlignmentData::simplify() {
 }
 
 bool MultipleChromatogramAlignmentData::hasEmptyGapModel() const {
-    foreach (const MultipleChromatogramAlignmentRow &row, rows) {
-        if (!row->getGapModel().isEmpty()) {
+    foreach (const MultipleChromatogramAlignmentRow& row, rows) {
+        if (!row->getGaps().isEmpty()) {
             return false;
         }
     }
@@ -221,7 +211,7 @@ MultipleChromatogramAlignment MultipleChromatogramAlignmentData::mid(int start,
     Q_UNUSED(check);
 
     U2OpStatus2Log os;
-    foreach (const MultipleChromatogramAlignmentRow &row, rows) {
+    foreach (const MultipleChromatogramAlignmentRow& row, rows) {
         MultipleChromatogramAlignmentRow mRow = row->mid(start, len, os);
         mRow->setParentAlignment(res);
         res->rows << mRow;
@@ -230,15 +220,15 @@ MultipleChromatogramAlignment MultipleChromatogramAlignmentData::mid(int start,
     return res;
 }
 
-MultipleChromatogramAlignmentData &MultipleChromatogramAlignmentData::operator+=(const MultipleChromatogramAlignmentData &mcaData) {
+MultipleChromatogramAlignmentData& MultipleChromatogramAlignmentData::operator+=(const MultipleChromatogramAlignmentData& mcaData) {
     // TODO: it is used in MUSCLE alignment and it should be something like this. But this emthod is incorrect for the MCA
     MaStateCheck check(this);
     Q_UNUSED(check);
 
     SAFE_POINT(mcaData.alphabet == alphabet, "Different alphabets in MultipleChromatogramAlignmentData::operator+=", *this);
 
-    int nSeq = getNumRows();
-    SAFE_POINT(mcaData.getNumRows() == nSeq, "Different number of rows in MultipleChromatogramAlignmentData::operator+=", *this);
+    int nSeq = getRowCount();
+    SAFE_POINT(mcaData.getRowCount() == nSeq, "Different number of rows in MultipleChromatogramAlignmentData::operator+=", *this);
 
     U2OpStatus2Log os;
     for (int i = 0; i < nSeq; i++) {
@@ -249,18 +239,15 @@ MultipleChromatogramAlignmentData &MultipleChromatogramAlignmentData::operator+=
     return *this;
 }
 
-bool MultipleChromatogramAlignmentData::operator==(const MultipleChromatogramAlignmentData &other) const {
-    bool lengthsAreEqual = (length == other.length);
-    bool alphabetsAreEqual = (alphabet == other.alphabet);
-    bool rowsAreEqual = (rows == other.rows);
-    return lengthsAreEqual && alphabetsAreEqual && rowsAreEqual;
+bool MultipleChromatogramAlignmentData::operator==(const MultipleChromatogramAlignmentData& other) const {
+    return isEqual(other);
 }
 
-bool MultipleChromatogramAlignmentData::operator!=(const MultipleChromatogramAlignmentData &other) const {
-    return !operator==(other);
+bool MultipleChromatogramAlignmentData::operator!=(const MultipleChromatogramAlignmentData& other) const {
+    return !isEqual(other);
 }
 
-bool MultipleChromatogramAlignmentData::crop(const U2Region &region, const QSet<QString> &rowNames, U2OpStatus &os) {
+bool MultipleChromatogramAlignmentData::crop(const U2Region& region, const QSet<QString>& rowNames, U2OpStatus& os) {
     if (!(region.startPos >= 0 && region.length > 0 && region.length < length && region.startPos < length)) {
         os.setError(QString("Incorrect region was passed to MultipleChromatogramAlignmentData::crop, "
                             "startPos '%1', length '%2'")
@@ -293,17 +280,17 @@ bool MultipleChromatogramAlignmentData::crop(const U2Region &region, const QSet<
     return true;
 }
 
-bool MultipleChromatogramAlignmentData::crop(const U2Region &region, U2OpStatus &os) {
+bool MultipleChromatogramAlignmentData::crop(const U2Region& region, U2OpStatus& os) {
     return crop(region, getRowNames().toSet(), os);
 }
 
-bool MultipleChromatogramAlignmentData::crop(int start, int count, U2OpStatus &os) {
+bool MultipleChromatogramAlignmentData::crop(int start, int count, U2OpStatus& os) {
     return crop(U2Region(start, count), os);
 }
 
-MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::createRow(const QString &name, const DNAChromatogram &chromatogram, const QByteArray &bytes) {
+MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::createRow(const QString& name, const DNAChromatogram& chromatogram, const QByteArray& bytes) {
     QByteArray newSequenceBytes;
-    QList<U2MsaGap> newGapsModel;
+    QVector<U2MsaGap> newGapsModel;
 
     MultipleChromatogramAlignmentRowData::splitBytesToCharsAndGaps(bytes, newSequenceBytes, newGapsModel);
     DNASequence newSequence(name, newSequenceBytes);
@@ -312,75 +299,75 @@ MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::createRow(co
     return MultipleChromatogramAlignmentRow(row, chromatogram, newSequence, newGapsModel, this);
 }
 
-MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::createRow(const U2MsaRow &rowInDb, const DNAChromatogram &chromatogram, const DNASequence &sequence, const U2MsaRowGapModel &gaps, U2OpStatus &os) {
+MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::createRow(const U2MsaRow& rowInDb, const DNAChromatogram& chromatogram, const DNASequence& sequence, const QVector<U2MsaGap>& gaps, U2OpStatus& os) {
     QString errorDescr = "Failed to create a multiple alignment row";
-    if (-1 != sequence.constSequence().indexOf(U2Msa::GAP_CHAR)) {
+    if (sequence.constSequence().indexOf(U2Msa::GAP_CHAR) != -1) {
         coreLog.trace("Attempted to create an alignment row from a sequence with gaps");
         os.setError(errorDescr);
         return MultipleChromatogramAlignmentRow();
     }
 
     int length = sequence.length();
-    foreach (const U2MsaGap &gap, gaps) {
-        if (gap.offset > length || !gap.isValid()) {
+    foreach (const U2MsaGap& gap, gaps) {
+        if (gap.startPos > length || !gap.isValid()) {
             coreLog.trace("Incorrect gap model was passed to MultipleChromatogramAlignmentData::createRow");
             os.setError(errorDescr);
             return MultipleChromatogramAlignmentRow();
         }
-        length += gap.gap;
+        length += gap.length;
     }
 
     return MultipleChromatogramAlignmentRow(rowInDb, chromatogram, sequence, gaps, this);
 }
 
-MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::createRow(const MultipleChromatogramAlignmentRow &row) {
+MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::createRow(const MultipleChromatogramAlignmentRow& row) {
     return MultipleChromatogramAlignmentRow(row, this);
 }
 
-void MultipleChromatogramAlignmentData::setRows(const QList<MultipleChromatogramAlignmentRow> &mcaRows) {
+void MultipleChromatogramAlignmentData::setRows(const QList<MultipleChromatogramAlignmentRow>& mcaRows) {
     rows = convertToMaRows(mcaRows);
 }
 
-void MultipleChromatogramAlignmentData::addRow(const QString &name, const DNAChromatogram &chromatogram, const QByteArray &bytes) {
+void MultipleChromatogramAlignmentData::addRow(const QString& name, const DNAChromatogram& chromatogram, const QByteArray& bytes) {
     MultipleChromatogramAlignmentRow newRow = createRow(name, chromatogram, bytes);
     addRowPrivate(newRow, bytes.size(), -1);
 }
 
-void MultipleChromatogramAlignmentData::addRow(const QString &name, const DNAChromatogram &chromatogram, const QByteArray &bytes, int rowIndex) {
+void MultipleChromatogramAlignmentData::addRow(const QString& name, const DNAChromatogram& chromatogram, const QByteArray& bytes, int rowIndex) {
     MultipleChromatogramAlignmentRow newRow = createRow(name, chromatogram, bytes);
     addRowPrivate(newRow, bytes.size(), rowIndex);
 }
 
-void MultipleChromatogramAlignmentData::addRow(const U2MsaRow &rowInDb, const DNAChromatogram &chromatogram, const DNASequence &sequence, U2OpStatus &os) {
+void MultipleChromatogramAlignmentData::addRow(const U2MsaRow& rowInDb, const DNAChromatogram& chromatogram, const DNASequence& sequence, U2OpStatus& os) {
     MultipleChromatogramAlignmentRow newRow = createRow(rowInDb, chromatogram, sequence, rowInDb.gaps, os);
     CHECK_OP(os, );
     addRowPrivate(newRow, rowInDb.length, -1);
 }
 
-void MultipleChromatogramAlignmentData::addRow(const QString &name, const DNAChromatogram &chromatogram, const DNASequence &sequence, const U2MsaRowGapModel &gaps, U2OpStatus &os) {
+void MultipleChromatogramAlignmentData::addRow(const QString& name, const DNAChromatogram& chromatogram, const DNASequence& sequence, const QVector<U2MsaGap>& gaps, U2OpStatus& os) {
     U2MsaRow row;
     MultipleChromatogramAlignmentRow newRow = createRow(row, chromatogram, sequence, gaps, os);
     CHECK_OP(os, );
 
     int len = sequence.length();
-    foreach (const U2MsaGap &gap, gaps) {
-        len += gap.gap;
+    foreach (const U2MsaGap& gap, gaps) {
+        len += gap.length;
     }
 
     newRow->setName(name);
     addRowPrivate(newRow, len, -1);
 }
 
-void MultipleChromatogramAlignmentData::addRow(const U2MsaRow &rowInDb, const McaRowMemoryData &mcaRowMemoryData, U2OpStatus &os) {
+void MultipleChromatogramAlignmentData::addRow(const U2MsaRow& rowInDb, const McaRowMemoryData& mcaRowMemoryData, U2OpStatus& os) {
     addRow(rowInDb, mcaRowMemoryData.chromatogram, mcaRowMemoryData.sequence, os);
 }
 
-void MultipleChromatogramAlignmentData::insertGaps(int row, int pos, int count, U2OpStatus &os) {
+void MultipleChromatogramAlignmentData::insertGaps(int row, int pos, int count, U2OpStatus& os) {
     if (pos > length) {
         length = pos + count;
         return;
     }
-    if (row >= getNumRows() || row < 0 || pos < 0 || count < 0) {
+    if (row >= getRowCount() || row < 0 || pos < 0 || count < 0) {
         coreLog.trace(QString("Internal error: incorrect parameters were passed "
                               "to MultipleChromatogramAlignmentData::insertGaps: row index '%1', pos '%2', count '%3'")
                           .arg(row)
@@ -409,8 +396,8 @@ void MultipleChromatogramAlignmentData::insertGaps(int row, int pos, int count,
     length = qMax(length, rowLength);
 }
 
-void MultipleChromatogramAlignmentData::appendChars(int row, const char *str, int len) {
-    SAFE_POINT(0 <= row && row < getNumRows(),
+void MultipleChromatogramAlignmentData::appendChars(int row, const char* str, int len) {
+    SAFE_POINT(0 <= row && row < getRowCount(),
                QString("Incorrect row index '%1' in MultipleChromatogramAlignmentData::appendChars").arg(row), );
 
     MultipleChromatogramAlignmentRow appendedRow = createRow("", DNAChromatogram(), QByteArray(str, len));
@@ -424,8 +411,8 @@ void MultipleChromatogramAlignmentData::appendChars(int row, const char *str, in
     length = qMax(length, rowLength + len);
 }
 
-void MultipleChromatogramAlignmentData::appendChars(int row, qint64 afterPos, const char *str, int len) {
-    SAFE_POINT(0 <= row && row < getNumRows(),
+void MultipleChromatogramAlignmentData::appendChars(int row, qint64 afterPos, const char* str, int len) {
+    SAFE_POINT(0 <= row && row < getRowCount(),
                QString("Incorrect row index '%1' in MultipleChromatogramAlignmentData::appendChars").arg(row), );
 
     MultipleChromatogramAlignmentRow appendedRow = createRow("", DNAChromatogram(), QByteArray(str, len));
@@ -444,12 +431,12 @@ void MultipleChromatogramAlignmentData::removeRegion(int startPos, int startRow,
                    .arg(startPos)
                    .arg(nBases)
                    .arg(length), );
-    SAFE_POINT(startRow >= 0 && startRow + nRows <= getNumRows() && nRows > 0,
+    SAFE_POINT(startRow >= 0 && startRow + nRows <= getRowCount() && nRows > 0,
                QString("Incorrect parameters were passed to MultipleChromatogramAlignmentData::removeRegion: startRow '%1', "
                        "nRows '%2', the number of rows is '%3'")
                    .arg(startRow)
                    .arg(nRows)
-                   .arg(getNumRows()), );
+                   .arg(getRowCount()), );
 
     MaStateCheck check(this);
     Q_UNUSED(check);
@@ -473,16 +460,16 @@ void MultipleChromatogramAlignmentData::removeRegion(int startPos, int startRow,
     }
 }
 
-int MultipleChromatogramAlignmentData::getNumRows() const {
+int MultipleChromatogramAlignmentData::getRowCount() const {
     return rows.size();
 }
 
-void MultipleChromatogramAlignmentData::renameRow(int row, const QString &name) {
-    SAFE_POINT(row >= 0 && row < getNumRows(),
+void MultipleChromatogramAlignmentData::renameRow(int row, const QString& name) {
+    SAFE_POINT(row >= 0 && row < getRowCount(),
                QString("Incorrect row index '%1' was passed to MultipleChromatogramAlignmentData::renameRow: "
                        "the number of rows is '%2'")
                    .arg(row)
-                   .arg(getNumRows()), );
+                   .arg(getRowCount()), );
     SAFE_POINT(!name.isEmpty(),
                "Incorrect parameter 'name' was passed to MultipleChromatogramAlignmentData::renameRow: "
                "Can't set the name of a row to an empty string", );
@@ -490,7 +477,7 @@ void MultipleChromatogramAlignmentData::renameRow(int row, const QString &name)
 }
 
 void MultipleChromatogramAlignmentData::replaceChars(int row, char origChar, char resultChar) {
-    SAFE_POINT(row >= 0 && row < getNumRows(), QString("Incorrect row index '%1' in MultipleChromatogramAlignmentData::replaceChars").arg(row), );
+    SAFE_POINT(row >= 0 && row < getRowCount(), QString("Incorrect row index '%1' in MultipleChromatogramAlignmentData::replaceChars").arg(row), );
 
     if (origChar == resultChar) {
         return;
@@ -500,12 +487,12 @@ void MultipleChromatogramAlignmentData::replaceChars(int row, char origChar, cha
     getMcaRow(row)->replaceChars(origChar, resultChar, os);
 }
 
-void MultipleChromatogramAlignmentData::setRowContent(int rowNumber, const DNAChromatogram &chromatogram, const DNASequence &sequence, const U2MsaRowGapModel &gapModel) {
-    SAFE_POINT(rowNumber >= 0 && rowNumber < getNumRows(),
+void MultipleChromatogramAlignmentData::setRowContent(int rowNumber, const DNAChromatogram& chromatogram, const DNASequence& sequence, const QVector<U2MsaGap>& gapModel) {
+    SAFE_POINT(rowNumber >= 0 && rowNumber < getRowCount(),
                QString("Incorrect row index '%1' was passed to MultipleChromatogramAlignmentData::setRowContent: "
                        "the number of rows is '%2'")
                    .arg(rowNumber)
-                   .arg(getNumRows()), );
+                   .arg(getRowCount()), );
     MaStateCheck check(this);
     Q_UNUSED(check);
 
@@ -516,17 +503,17 @@ void MultipleChromatogramAlignmentData::setRowContent(int rowNumber, const DNACh
     length = qMax(length, (qint64)MsaRowUtils::getRowLength(sequence.seq, gapModel));
 }
 
-void MultipleChromatogramAlignmentData::setRowContent(int rowNumber, const McaRowMemoryData &mcaRowMemoryData) {
+void MultipleChromatogramAlignmentData::setRowContent(int rowNumber, const McaRowMemoryData& mcaRowMemoryData) {
     setRowContent(rowNumber, mcaRowMemoryData.chromatogram, mcaRowMemoryData.sequence, mcaRowMemoryData.gapModel);
 }
 
 void MultipleChromatogramAlignmentData::toUpperCase() {
-    for (int i = 0, n = getNumRows(); i < n; i++) {
+    for (int i = 0, n = getRowCount(); i < n; i++) {
         getMcaRow(i)->toUpperCase();
     }
 }
 
-bool MultipleChromatogramAlignmentData::sortRowsBySimilarity(QVector<U2Region> &united) {
+bool MultipleChromatogramAlignmentData::sortRowsBySimilarity(QVector<U2Region>& united) {
     QList<MultipleChromatogramAlignmentRow> oldRows = getMcaRows();
     QList<MultipleChromatogramAlignmentRow> sortedRows;
     while (!oldRows.isEmpty()) {
@@ -536,8 +523,8 @@ bool MultipleChromatogramAlignmentData::sortRowsBySimilarity(QVector<U2Region> &
         int len = 1;
         QMutableListIterator<MultipleChromatogramAlignmentRow> iter(oldRows);
         while (iter.hasNext()) {
-            const MultipleChromatogramAlignmentRow &next = iter.next();
-            if (next->isRowContentEqual(row)) {
+            const MultipleChromatogramAlignmentRow& next = iter.next();
+            if (next->isEqualCore(*row)) {
                 sortedRows << next;
                 iter.remove();
                 ++len;
@@ -556,13 +543,13 @@ bool MultipleChromatogramAlignmentData::sortRowsBySimilarity(QVector<U2Region> &
 
 const QList<MultipleChromatogramAlignmentRow> MultipleChromatogramAlignmentData::getMcaRows() const {
     QList<MultipleChromatogramAlignmentRow> mcaRows;
-    foreach (const MultipleAlignmentRow &maRow, rows) {
+    foreach (const MultipleAlignmentRow& maRow, rows) {
         mcaRows << maRow.dynamicCast<MultipleChromatogramAlignmentRow>();
     }
     return mcaRows;
 }
 
-MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::getMcaRowByRowId(qint64 rowId, U2OpStatus &os) const {
+MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::getMcaRowByRowId(qint64 rowId, U2OpStatus& os) const {
     return getRowByRowId(rowId, os).dynamicCast<MultipleChromatogramAlignmentRow>(os);
 }
 
@@ -578,18 +565,18 @@ bool MultipleChromatogramAlignmentData::isTrailingOrLeadingGap(int rowNumber, in
     return getMcaRow(rowNumber)->isTrailingOrLeadingGap(pos);
 }
 
-void MultipleChromatogramAlignmentData::setRowGapModel(int rowNumber, const QList<U2MsaGap> &gapModel) {
-    SAFE_POINT(rowNumber >= 0 && rowNumber < getNumRows(), "Invalid row index", );
+void MultipleChromatogramAlignmentData::setRowGapModel(int rowNumber, const QVector<U2MsaGap>& gapModel) {
+    SAFE_POINT(rowNumber >= 0 && rowNumber < getRowCount(), "Invalid row index", );
     length = qMax(length, (qint64)MsaRowUtils::getGapsLength(gapModel) + getMcaRow(rowNumber)->sequence.length());
     getMcaRow(rowNumber)->setGapModel(gapModel);
 }
 
-void MultipleChromatogramAlignmentData::setSequenceId(int rowIndex, const U2DataId &sequenceId) {
-    SAFE_POINT(rowIndex >= 0 && rowIndex < getNumRows(), "Invalid row index", );
+void MultipleChromatogramAlignmentData::setSequenceId(int rowIndex, const U2DataId& sequenceId) {
+    SAFE_POINT(rowIndex >= 0 && rowIndex < getRowCount(), "Invalid row index", );
     getMcaRow(rowIndex)->setSequenceId(sequenceId);
 }
 
-const MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::getMcaRow(const QString &name) const {
+const MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentData::getMcaRow(const QString& name) const {
     return getRow(name).dynamicCast<const MultipleChromatogramAlignmentRow>();
 }
 
@@ -601,15 +588,15 @@ MultipleChromatogramAlignment MultipleChromatogramAlignmentData::getExplicitCopy
     return MultipleChromatogramAlignment(new MultipleChromatogramAlignmentData(*this));
 }
 
-void MultipleChromatogramAlignmentData::copy(const MultipleAlignmentData &other) {
+void MultipleChromatogramAlignmentData::copy(const MultipleAlignmentData& other) {
     try {
-        copy(dynamic_cast<const MultipleChromatogramAlignmentData &>(other));
-    } catch (std::bad_cast &) {
+        copy(dynamic_cast<const MultipleChromatogramAlignmentData&>(other));
+    } catch (std::bad_cast&) {
         FAIL("Can't cast MultipleAlignmentData to MultipleChromatogramAlignmentData", );
     }
 }
 
-void MultipleChromatogramAlignmentData::copy(const MultipleChromatogramAlignmentData &other) {
+void MultipleChromatogramAlignmentData::copy(const MultipleChromatogramAlignmentData& other) {
     clear();
 
     alphabet = other.alphabet;
