@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +26,7 @@
 #include <U2Core/ChromatogramUtils.h>
 #include <U2Core/DNAChromatogram.h>
 #include <U2Core/DNASequenceUtils.h>
+#include <U2Core/Log.h>
 #include <U2Core/MsaDbiUtils.h>
 #include <U2Core/MultipleAlignmentRowInfo.h>
 #include <U2Core/U2OpStatus.h>
@@ -40,56 +41,56 @@ MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow()
     : MultipleAlignmentRow(new MultipleChromatogramAlignmentRowData) {
 }
 
-MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(const MultipleAlignmentRow &maRow)
+MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(const MultipleAlignmentRow& maRow)
     : MultipleAlignmentRow(maRow) {
-    SAFE_POINT(nullptr != maRowData.dynamicCast<MultipleChromatogramAlignmentRowData>(), "Can't cast MultipleAlignmentRow to MultipleChromatogramAlignmentRow", );
+    SAFE_POINT(maRowData.dynamicCast<MultipleChromatogramAlignmentRowData>() != nullptr, "Can't cast MultipleAlignmentRow to MultipleChromatogramAlignmentRow", );
 }
 
-MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(MultipleChromatogramAlignmentData *mcaData)
+MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(MultipleChromatogramAlignmentData* mcaData)
     : MultipleAlignmentRow(new MultipleChromatogramAlignmentRowData(mcaData)) {
 }
 
-MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(MultipleChromatogramAlignmentRowData *mcaRowData)
+MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(MultipleChromatogramAlignmentRowData* mcaRowData)
     : MultipleAlignmentRow(mcaRowData) {
 }
 
-MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(const U2McaRow &rowInDb,
-                                                                   const DNAChromatogram &chromatogram,
-                                                                   const DNASequence &sequence,
-                                                                   const U2MsaRowGapModel &gaps,
-                                                                   MultipleChromatogramAlignmentData *mcaData)
+MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(const U2McaRow& rowInDb,
+                                                                   const DNAChromatogram& chromatogram,
+                                                                   const DNASequence& sequence,
+                                                                   const QVector<U2MsaGap>& gaps,
+                                                                   MultipleChromatogramAlignmentData* mcaData)
     : MultipleAlignmentRow(new MultipleChromatogramAlignmentRowData(rowInDb, chromatogram, sequence, gaps, mcaData)) {
 }
 
-MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(const U2McaRow &rowInDb,
-                                                                   const QString &rowName,
-                                                                   const DNAChromatogram &chromatogram,
-                                                                   const QByteArray &rawData,
-                                                                   MultipleChromatogramAlignmentData *mcaData)
+MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(const U2McaRow& rowInDb,
+                                                                   const QString& rowName,
+                                                                   const DNAChromatogram& chromatogram,
+                                                                   const QByteArray& rawData,
+                                                                   MultipleChromatogramAlignmentData* mcaData)
     : MultipleAlignmentRow(new MultipleChromatogramAlignmentRowData(rowInDb, rowName, chromatogram, rawData, mcaData)) {
 }
 
-MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(const MultipleChromatogramAlignmentRow &row, MultipleChromatogramAlignmentData *mcaData)
+MultipleChromatogramAlignmentRow::MultipleChromatogramAlignmentRow(const MultipleChromatogramAlignmentRow& row, MultipleChromatogramAlignmentData* mcaData)
     : MultipleAlignmentRow(new MultipleChromatogramAlignmentRowData(row, mcaData)) {
 }
 
-MultipleChromatogramAlignmentRowData *MultipleChromatogramAlignmentRow::data() const {
+MultipleChromatogramAlignmentRowData* MultipleChromatogramAlignmentRow::data() const {
     return getMcaRowData().data();
 }
 
-MultipleChromatogramAlignmentRowData &MultipleChromatogramAlignmentRow::operator*() {
+MultipleChromatogramAlignmentRowData& MultipleChromatogramAlignmentRow::operator*() {
     return *getMcaRowData();
 }
 
-const MultipleChromatogramAlignmentRowData &MultipleChromatogramAlignmentRow::operator*() const {
+const MultipleChromatogramAlignmentRowData& MultipleChromatogramAlignmentRow::operator*() const {
     return *getMcaRowData();
 }
 
-MultipleChromatogramAlignmentRowData *MultipleChromatogramAlignmentRow::operator->() {
+MultipleChromatogramAlignmentRowData* MultipleChromatogramAlignmentRow::operator->() {
     return getMcaRowData().data();
 }
 
-const MultipleChromatogramAlignmentRowData *MultipleChromatogramAlignmentRow::operator->() const {
+const MultipleChromatogramAlignmentRowData* MultipleChromatogramAlignmentRow::operator->() const {
     return getMcaRowData().data();
 }
 
@@ -101,18 +102,18 @@ QSharedPointer<MultipleChromatogramAlignmentRowData> MultipleChromatogramAlignme
     return maRowData.dynamicCast<MultipleChromatogramAlignmentRowData>();
 }
 
-MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(MultipleChromatogramAlignmentData *mcaData)
-    : MultipleAlignmentRowData(),
+MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(MultipleChromatogramAlignmentData* mcaData)
+    : MultipleAlignmentRowData(MultipleAlignmentDataType::MCA),
       alignment(mcaData) {
     removeTrailingGaps();
 }
 
-MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(const U2McaRow &rowInDb,
-                                                                           const DNAChromatogram &chromatogram,
-                                                                           const DNASequence &sequence,
-                                                                           const QList<U2MsaGap> &gaps,
-                                                                           MultipleChromatogramAlignmentData *mcaData)
-    : MultipleAlignmentRowData(sequence, gaps),
+MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(const U2McaRow& rowInDb,
+                                                                           const DNAChromatogram& chromatogram,
+                                                                           const DNASequence& sequence,
+                                                                           const QVector<U2MsaGap>& gaps,
+                                                                           MultipleChromatogramAlignmentData* mcaData)
+    : MultipleAlignmentRowData(MultipleAlignmentDataType::MCA, sequence, gaps),
       alignment(mcaData),
       chromatogram(chromatogram),
       initialRowInDb(rowInDb) {
@@ -120,24 +121,24 @@ MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(const
     removeTrailingGaps();
 }
 
-MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(const U2McaRow &rowInDb,
-                                                                           const QString &rowName,
-                                                                           const DNAChromatogram &chromatogram,
-                                                                           const QByteArray &rawData,
-                                                                           MultipleChromatogramAlignmentData *mcaData)
-    : MultipleAlignmentRowData(),
+MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(const U2McaRow& rowInDb,
+                                                                           const QString& rowName,
+                                                                           const DNAChromatogram& chromatogram,
+                                                                           const QByteArray& rawData,
+                                                                           MultipleChromatogramAlignmentData* mcaData)
+    : MultipleAlignmentRowData(MultipleAlignmentDataType::MCA),
       alignment(mcaData),
       chromatogram(chromatogram),
       initialRowInDb(rowInDb) {
     QByteArray sequenceData;
-    U2MsaRowGapModel gapModel;
+    QVector<U2MsaGap> gapModel;
     MaDbiUtils::splitBytesToCharsAndGaps(rawData, sequenceData, gapModel);
     sequence = DNASequence(rowName, sequenceData);
     setGapModel(gapModel);
 }
 
-MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(const MultipleChromatogramAlignmentRow &row, MultipleChromatogramAlignmentData *mcaData)
-    : MultipleAlignmentRowData(row->sequence, row->gaps),
+MultipleChromatogramAlignmentRowData::MultipleChromatogramAlignmentRowData(const MultipleChromatogramAlignmentRow& row, MultipleChromatogramAlignmentData* mcaData)
+    : MultipleAlignmentRowData(MultipleAlignmentDataType::MCA, row->sequence, row->gaps),
       alignment(mcaData),
       chromatogram(row->chromatogram),
       initialRowInDb(row->initialRowInDb),
@@ -149,16 +150,16 @@ QString MultipleChromatogramAlignmentRowData::getName() const {
     return sequence.getName();
 }
 
-void MultipleChromatogramAlignmentRowData::setName(const QString &name) {
+void MultipleChromatogramAlignmentRowData::setName(const QString& name) {
     sequence.setName(name);
 }
 
-void MultipleChromatogramAlignmentRowData::setGapModel(const QList<U2MsaGap> &newGapModel) {
+void MultipleChromatogramAlignmentRowData::setGapModel(const QVector<U2MsaGap>& newGapModel) {
     gaps = newGapModel;
     removeTrailingGaps();
 }
 
-const DNAChromatogram &MultipleChromatogramAlignmentRowData::getChromatogram() const {
+const DNAChromatogram& MultipleChromatogramAlignmentRowData::getChromatogram() const {
     return chromatogram;
 }
 
@@ -178,7 +179,7 @@ void MultipleChromatogramAlignmentRowData::setRowId(qint64 rowId) {
     initialRowInDb.rowId = rowId;
 }
 
-void MultipleChromatogramAlignmentRowData::setSequenceId(const U2DataId &sequenceId) {
+void MultipleChromatogramAlignmentRowData::setSequenceId(const U2DataId& sequenceId) {
     initialRowInDb.sequenceId = sequenceId;
 }
 
@@ -194,11 +195,11 @@ U2McaRow MultipleChromatogramAlignmentRowData::getRowDbInfo() const {
     return row;
 }
 
-void MultipleChromatogramAlignmentRowData::setRowDbInfo(const U2McaRow &dbRow) {
+void MultipleChromatogramAlignmentRowData::setRowDbInfo(const U2McaRow& dbRow) {
     initialRowInDb = dbRow;
 }
 
-QByteArray MultipleChromatogramAlignmentRowData::toByteArray(U2OpStatus &os, qint64 length) const {
+QByteArray MultipleChromatogramAlignmentRowData::toByteArray(U2OpStatus& os, qint64 length) const {
     if (length < getCoreEnd()) {
         coreLog.trace("Incorrect length was passed to MultipleChromatogramAlignmentRowData::toByteArray");
         os.setError("Failed to get row data");
@@ -246,12 +247,12 @@ qint64 MultipleChromatogramAlignmentRowData::getCoreLength() const {
     return length;
 }
 
-void MultipleChromatogramAlignmentRowData::append(const MultipleChromatogramAlignmentRow &anotherRow, int lengthBefore, U2OpStatus &os) {
+void MultipleChromatogramAlignmentRowData::append(const MultipleChromatogramAlignmentRow& anotherRow, int lengthBefore, U2OpStatus& os) {
     // TODO: remove
     append(*anotherRow, lengthBefore, os);
 }
 
-void MultipleChromatogramAlignmentRowData::append(const MultipleChromatogramAlignmentRowData &anotherRow, int lengthBefore, U2OpStatus &os) {
+void MultipleChromatogramAlignmentRowData::append(const MultipleChromatogramAlignmentRowData& anotherRow, int lengthBefore, U2OpStatus& os) {
     int rowLength = getRowLengthWithoutTrailing();
 
     if (lengthBefore < rowLength) {
@@ -269,9 +270,9 @@ void MultipleChromatogramAlignmentRowData::append(const MultipleChromatogramAlig
     }
 
     // Merge gaps
-    QList<U2MsaGap> anotherRowGaps = anotherRow.getGapModel();
+    QVector<U2MsaGap> anotherRowGaps = anotherRow.getGaps();
     for (int i = 0; i < anotherRowGaps.count(); ++i) {
-        anotherRowGaps[i].offset += lengthBefore;
+        anotherRowGaps[i].startPos += lengthBefore;
     }
     gaps.append(anotherRowGaps);
     mergeConsecutiveGaps();
@@ -283,7 +284,7 @@ void MultipleChromatogramAlignmentRowData::append(const MultipleChromatogramAlig
     ChromatogramUtils::append(chromatogram, anotherRow.chromatogram);
 }
 
-void MultipleChromatogramAlignmentRowData::setRowContent(const DNAChromatogram &newChromatogram, const DNASequence &newSequence, const U2MsaRowGapModel &newGapModel, U2OpStatus &os) {
+void MultipleChromatogramAlignmentRowData::setRowContent(const DNAChromatogram& newChromatogram, const DNASequence& newSequence, const QVector<U2MsaGap>& newGapModel, U2OpStatus& os) {
     // TODO: this method is strange. It is hard to synchronize a chromatogram with a sequence. I think, it should be removed.
     SAFE_POINT_EXT(!newSequence.constSequence().contains(U2Msa::GAP_CHAR), os.setError("The sequence must be without gaps"), );
     chromatogram = newChromatogram;
@@ -292,11 +293,11 @@ void MultipleChromatogramAlignmentRowData::setRowContent(const DNAChromatogram &
     syncLengths();
 }
 
-void MultipleChromatogramAlignmentRowData::insertGaps(int position, int count, U2OpStatus &os) {
+void MultipleChromatogramAlignmentRowData::insertGaps(int position, int count, U2OpStatus& os) {
     MsaRowUtils::insertGaps(os, gaps, getRowLengthWithoutTrailing(), position, count);
 }
 
-void MultipleChromatogramAlignmentRowData::removeChars(int pos, int count, U2OpStatus &os) {
+void MultipleChromatogramAlignmentRowData::removeChars(int pos, int count, U2OpStatus& os) {
     if (pos < 0 || count < 0) {
         coreLog.trace(QString("Internal error: incorrect parameters were passed to MultipleChromatogramAlignmentRowData::removeChars, "
                               "pos '%1', count '%2'")
@@ -359,7 +360,7 @@ const QMap<DNAChromatogram::Trace, QVector<ushort> DNAChromatogram::*> PEAKS =
      {DNAChromatogram::Trace::Trace_T, &DNAChromatogram::T}};
 
 QPair<DNAChromatogram::ChromatogramTraceAndValue, DNAChromatogram::ChromatogramTraceAndValue>
-    MultipleChromatogramAlignmentRowData::getTwoHighestPeaks(qint64 position, bool &hasTwoPeaks) const {
+    MultipleChromatogramAlignmentRowData::getTwoHighestPeaks(qint64 position, bool& hasTwoPeaks) const {
     hasTwoPeaks = true;
     int previousBaseCall = chromatogram.baseCalls[position != 0 ? position - 1 : position];
     int baseCall = chromatogram.baseCalls[position];
@@ -368,7 +369,7 @@ QPair<DNAChromatogram::ChromatogramTraceAndValue, DNAChromatogram::ChromatogramT
 
     auto peaksKeys = PEAKS.keys();
     for (auto peak : qAsConst(peaksKeys)) {
-        const QVector<ushort> &chromatogramBaseCallVector = chromatogram.*PEAKS.value(peak);
+        const QVector<ushort>& chromatogramBaseCallVector = chromatogram.*PEAKS.value(peak);
         auto peakValue = chromatogramBaseCallVector[baseCall];
         int startOfCharacterBaseCall = baseCall - ((baseCall - previousBaseCall) / 2);
         int startValue = chromatogramBaseCallVector[startOfCharacterBaseCall];
@@ -393,65 +394,40 @@ QPair<DNAChromatogram::ChromatogramTraceAndValue, DNAChromatogram::ChromatogramT
 
     std::sort(peaks.begin(),
               peaks.end(),
-              [](const auto &first, const auto &second) {
+              [](const auto& first, const auto& second) {
                   return first.value > second.value;
               });
     return {peaks[0], peaks[1]};
 }
 
-bool MultipleChromatogramAlignmentRowData::isRowContentEqual(const MultipleChromatogramAlignmentRow &row) const {
-    return isRowContentEqual(*row);
+bool MultipleChromatogramAlignmentRowData::isEqual(const MultipleAlignmentRowData& other) const {
+    CHECK(other.type == MultipleAlignmentDataType::MCA, false);
+    auto mcaRow = dynamic_cast<const MultipleChromatogramAlignmentRowData*>(&other);
+    SAFE_POINT(mcaRow != nullptr, "Not an MCA row!", false);
+    return isEqual(*mcaRow);
 }
 
-bool MultipleChromatogramAlignmentRowData::isRowContentEqual(const MultipleChromatogramAlignmentRowData &row) const {
-    if (MatchExactly == DNASequenceUtils::compare(sequence, row.getSequence()) && ChromatogramUtils::areEqual(chromatogram, row.chromatogram)) {
-        if (sequence.length() == 0) {
-            return true;
-        } else {
-            U2MsaRowGapModel firstRowGaps = gaps;
-            if (!firstRowGaps.isEmpty() && (U2Msa::GAP_CHAR == charAt(0))) {
-                firstRowGaps.removeFirst();
-            }
+bool MultipleChromatogramAlignmentRowData::isEqual(const MultipleChromatogramAlignmentRowData& other) const {
+    CHECK(this != &other, true);
+    CHECK(getName() == other.getName(), false);
+    return isEqualCore(other);
+}
 
-            U2MsaRowGapModel secondRowGaps = row.getGapModel();
-            if (!secondRowGaps.isEmpty() && (U2Msa::GAP_CHAR == row.charAt(0))) {
-                secondRowGaps.removeFirst();
-            }
-
-            if (firstRowGaps == secondRowGaps) {
-                return true;
-            }
-        }
+bool MultipleChromatogramAlignmentRowData::isEqualCore(const MultipleAlignmentRowData& other) const {
+    if (other.type == MultipleAlignmentDataType::MCA) {
+        auto mcaRow = dynamic_cast<const MultipleChromatogramAlignmentRowData*>(&other);
+        SAFE_POINT(mcaRow != nullptr, "Not an MCA row!", false);
+        CHECK(ChromatogramUtils::areEqual(chromatogram, mcaRow->chromatogram), false);
     }
-
-    return false;
+    return MultipleAlignmentRowData::isEqualCore(other);
 }
 
 bool MultipleChromatogramAlignmentRowData::isDefault() const {
-    return *this == MultipleChromatogramAlignmentRowData();
+    static const MultipleChromatogramAlignmentRowData defaultRow;
+    return isEqual(defaultRow);
 }
 
-bool MultipleChromatogramAlignmentRowData::operator!=(const MultipleChromatogramAlignmentRowData &mcaRowData) const {
-    return !(*this == mcaRowData);
-}
-
-bool MultipleChromatogramAlignmentRowData::operator!=(const MultipleAlignmentRowData &maRowData) const {
-    return !(*this == maRowData);
-}
-
-bool MultipleChromatogramAlignmentRowData::operator==(const MultipleChromatogramAlignmentRowData &mcaRowData) const {
-    return isRowContentEqual(mcaRowData);
-}
-
-bool MultipleChromatogramAlignmentRowData::operator==(const MultipleAlignmentRowData &maRowData) const {
-    try {
-        return (*this == dynamic_cast<const MultipleChromatogramAlignmentRowData &>(maRowData));
-    } catch (std::bad_cast &) {
-        FAIL("Can't cast MultipleAlignmentRowData to MultipleChromatogramAlignmentRowData", true);
-    }
-}
-
-void MultipleChromatogramAlignmentRowData::crop(U2OpStatus &os, qint64 startPosition, qint64 count) {
+void MultipleChromatogramAlignmentRowData::crop(U2OpStatus& os, qint64 startPosition, qint64 count) {
     if (startPosition < 0 || count < 0) {
         coreLog.trace(QString("Internal error: incorrect parameters were passed to MultipleChromatogramAlignmentRowData::crop, "
                               "startPos '%1', length '%2', row length '%3'")
@@ -499,7 +475,7 @@ void MultipleChromatogramAlignmentRowData::crop(U2OpStatus &os, qint64 startPosi
     removeTrailingGaps();
 }
 
-MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentRowData::mid(int pos, int count, U2OpStatus &os) const {
+MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentRowData::mid(int pos, int count, U2OpStatus& os) const {
     MultipleChromatogramAlignmentRow row = getExplicitCopy();
     row->crop(os, pos, count);
     return row;
@@ -509,7 +485,7 @@ void MultipleChromatogramAlignmentRowData::toUpperCase() {
     DNASequenceUtils::toUpperCase(sequence);
 }
 
-void MultipleChromatogramAlignmentRowData::replaceChars(char origChar, char resultChar, U2OpStatus &os) {
+void MultipleChromatogramAlignmentRowData::replaceChars(char origChar, char resultChar, U2OpStatus& os) {
     if (U2Msa::GAP_CHAR == origChar) {
         coreLog.trace("The original char can't be a gap in MultipleChromatogramAlignmentRowData::replaceChars");
         os.setError("Failed to replace chars in an alignment row");
@@ -533,7 +509,7 @@ void MultipleChromatogramAlignmentRowData::replaceChars(char origChar, char resu
         sequence.seq.replace(origChar, "");
 
         // Re-calculate the gaps model
-        QList<U2MsaGap> newGapsModel = gaps;
+        QVector<U2MsaGap> newGapsModel = gaps;
         for (int i = 0; i < gapsIndexes.size(); ++i) {
             int index = gapsIndexes[i];
             U2MsaGap gap(index, 1);
@@ -559,7 +535,7 @@ MultipleChromatogramAlignmentRow MultipleChromatogramAlignmentRowData::getExplic
     return MultipleChromatogramAlignmentRow(new MultipleChromatogramAlignmentRowData(*this));
 }
 
-void MultipleChromatogramAlignmentRowData::setAdditionalInfo(const QVariantMap &newAdditionalInfo) {
+void MultipleChromatogramAlignmentRowData::setAdditionalInfo(const QVariantMap& newAdditionalInfo) {
     additionalInfo = newAdditionalInfo;
 }
 
@@ -603,19 +579,19 @@ bool MultipleChromatogramAlignmentRowData::isComplemented() const {
     return MultipleAlignmentRowInfo::getComplemented(additionalInfo);
 }
 
-void MultipleChromatogramAlignmentRowData::splitBytesToCharsAndGaps(const QByteArray &input, QByteArray &seqBytes, QList<U2MsaGap> &gapsModel) {
+void MultipleChromatogramAlignmentRowData::splitBytesToCharsAndGaps(const QByteArray& input, QByteArray& seqBytes, QVector<U2MsaGap>& gapsModel) {
     MaDbiUtils::splitBytesToCharsAndGaps(input, seqBytes, gapsModel);
 }
 
-void MultipleChromatogramAlignmentRowData::addOffsetToGapModel(QList<U2MsaGap> &gapModel, int offset) {
+void MultipleChromatogramAlignmentRowData::addOffsetToGapModel(QVector<U2MsaGap>& gapModel, int offset) {
     if (0 == offset) {
         return;
     }
 
     if (!gapModel.isEmpty()) {
-        U2MsaGap &firstGap = gapModel[0];
-        if (0 == firstGap.offset) {
-            firstGap.gap += offset;
+        U2MsaGap& firstGap = gapModel[0];
+        if (0 == firstGap.startPos) {
+            firstGap.length += offset;
         } else {
             SAFE_POINT(offset >= 0, "Negative gap offset", );
             U2MsaGap beginningGap(0, offset);
@@ -625,9 +601,9 @@ void MultipleChromatogramAlignmentRowData::addOffsetToGapModel(QList<U2MsaGap> &
         // Shift other gaps
         if (gapModel.count() > 1) {
             for (int i = 1; i < gapModel.count(); ++i) {
-                qint64 newOffset = gapModel[i].offset + offset;
+                qint64 newOffset = gapModel[i].startPos + offset;
                 SAFE_POINT(newOffset >= 0, "Negative gap offset", );
-                gapModel[i].offset = newOffset;
+                gapModel[i].startPos = newOffset;
             }
         }
     } else {
@@ -659,7 +635,7 @@ void MultipleChromatogramAlignmentRowData::syncLengths() {
     }
 }
 
-void MultipleChromatogramAlignmentRowData::getStartAndEndSequencePositions(int pos, int count, int &startPosInSeq, int &endPosInSeq) {
+void MultipleChromatogramAlignmentRowData::getStartAndEndSequencePositions(int pos, int count, int& startPosInSeq, int& endPosInSeq) {
     int rowLengthWithoutTrailingGap = getRowLengthWithoutTrailing();
     SAFE_POINT(pos < rowLengthWithoutTrailingGap,
                QString("Incorrect position '%1' in MultipleChromatogramAlignmentRowData::getStartAndEndSequencePosition, "
@@ -707,15 +683,15 @@ void MultipleChromatogramAlignmentRowData::getStartAndEndSequencePositions(int p
     }
 }
 
-void MultipleChromatogramAlignmentRowData::removeGapsFromGapModel(U2OpStatus &os, int pos, int count) {
+void MultipleChromatogramAlignmentRowData::removeGapsFromGapModel(U2OpStatus& os, int pos, int count) {
     MsaRowUtils::removeGaps(os, gaps, getRowLengthWithoutTrailing(), pos, count);
 }
 
-void MultipleChromatogramAlignmentRowData::setParentAlignment(const MultipleChromatogramAlignment &msa) {
+void MultipleChromatogramAlignmentRowData::setParentAlignment(const MultipleChromatogramAlignment& msa) {
     setParentAlignment(msa.data());
 }
 
-void MultipleChromatogramAlignmentRowData::setParentAlignment(MultipleChromatogramAlignmentData *mcaData) {
+void MultipleChromatogramAlignmentRowData::setParentAlignment(MultipleChromatogramAlignmentData* mcaData) {
     alignment = mcaData;
 }
 
@@ -723,7 +699,7 @@ int MultipleChromatogramAlignmentRowData::getCoreStart() const {
     return MsaRowUtils::getCoreStart(gaps);
 }
 
-MultipleAlignmentData *MultipleChromatogramAlignmentRowData::getMultipleAlignmentData() const {
+MultipleAlignmentData* MultipleChromatogramAlignmentRowData::getMultipleAlignmentData() const {
     return alignment;
 }
 
