@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -38,20 +38,18 @@
 #include <U2Core/U2SafePoints.h>
 #include <U2Core/UserApplicationsSettings.h>
 
-#include <U2Formats/MysqlDbiUtils.h>
-
 namespace U2 {
 
 static const QString SESSION_TMP_DBI_ALIAS("session");
 
-U2DbiRegistry::U2DbiRegistry(QObject *parent)
+U2DbiRegistry::U2DbiRegistry(QObject* parent)
     : QObject(parent), lock(QMutex::Recursive) {
     pool = new U2DbiPool(this);
     sessionDbiConnection = nullptr;
     sessionDbiInitDone = false;
 }
 
-void U2DbiRegistry::initSessionDbi(TmpDbiRef &tmpDbiRef) {
+void U2DbiRegistry::initSessionDbi(TmpDbiRef& tmpDbiRef) {
     sessionDbiInitDone = true;
 
     U2OpStatus2Log os;
@@ -70,11 +68,11 @@ U2DbiRegistry::~U2DbiRegistry() {
 
     coreLog.trace("Deallocating U2DbiRegistry");
     for (int i = 0; i < tmpDbis.size(); i++) {
-        TmpDbiRef &ref = tmpDbis[i];
+        TmpDbiRef& ref = tmpDbis[i];
         coreLog.trace(QString("BUG: tmp DBI was not deallocated: %1 %2 [%3]").arg(ref.alias).arg(ref.dbiRef.dbiId).arg(ref.nUsers));
         ref.nUsers = 1;
     }
-    foreach (const TmpDbiRef &ref, tmpDbis) {
+    foreach (const TmpDbiRef& ref, tmpDbis) {
         U2OpStatus2Log os;
         detachTmpDbi(ref.alias, os);
     }
@@ -83,17 +81,17 @@ U2DbiRegistry::~U2DbiRegistry() {
 
 QList<U2DbiRef> U2DbiRegistry::listTmpDbis() const {
     QList<U2DbiRef> res;
-    foreach (const TmpDbiRef &ref, tmpDbis) {
+    foreach (const TmpDbiRef& ref, tmpDbis) {
         res << ref.dbiRef;
     }
     return res;
 }
 
-U2DbiRef U2DbiRegistry::attachTmpDbi(const QString &alias, U2OpStatus &os, const U2DbiFactoryId &factoryId) {
+U2DbiRef U2DbiRegistry::attachTmpDbi(const QString& alias, U2OpStatus& os, const U2DbiFactoryId& factoryId) {
     QMutexLocker m(&lock);
 
     for (int i = 0; i < tmpDbis.size(); i++) {
-        TmpDbiRef &ref = tmpDbis[i];
+        TmpDbiRef& ref = tmpDbis[i];
         if (ref.alias == alias) {
             ref.nUsers++;
             return ref.dbiRef;
@@ -116,13 +114,13 @@ U2DbiRef U2DbiRegistry::attachTmpDbi(const QString &alias, U2OpStatus &os, const
     return dbiRef;
 }
 
-void U2DbiRegistry::detachTmpDbi(const QString &alias, U2OpStatus &os) {
+void U2DbiRegistry::detachTmpDbi(const QString& alias, U2OpStatus& os) {
     QMutexLocker l(&lock);
 
     int i = 0;
     bool found = false;
     for (; i < tmpDbis.size(); i++) {
-        TmpDbiRef &ref = tmpDbis[i];
+        TmpDbiRef& ref = tmpDbis[i];
         if (ref.alias == alias) {
             found = true;
             ref.nUsers--;
@@ -137,7 +135,7 @@ void U2DbiRegistry::detachTmpDbi(const QString &alias, U2OpStatus &os) {
         return;
     }
 
-    const TmpDbiRef &tmpDbiRef = tmpDbis.at(i);
+    const TmpDbiRef& tmpDbiRef = tmpDbis.at(i);
 
     coreLog.trace("Deallocating a tmp dbi " + tmpDbiRef.dbiRef.dbiId + " with alias: " + tmpDbiRef.alias);
     deallocateTmpDbi(tmpDbiRef, os);
@@ -145,18 +143,18 @@ void U2DbiRegistry::detachTmpDbi(const QString &alias, U2OpStatus &os) {
     tmpDbis.removeAt(i);
 }
 
-U2DbiRef U2DbiRegistry::getSessionTmpDbiRef(U2OpStatus &os) {
+U2DbiRef U2DbiRegistry::getSessionTmpDbiRef(U2OpStatus& os) {
     TmpDbiHandle dh(SESSION_TMP_DBI_ALIAS, os);
     CHECK_OP(os, U2DbiRef());
 
     return dh.getDbiRef();
 }
 
-QString U2DbiRegistry::shutdownSessionDbi(U2OpStatus &os) {
+QString U2DbiRegistry::shutdownSessionDbi(U2OpStatus& os) {
     QMutexLocker l(&lock);
     CHECK_EXT(sessionDbiInitDone, os.setError("Session dbi is not initialized"), "");
-    CHECK_EXT(nullptr != sessionDbiConnection, os.setError("No session dbi connection"), "");
-    CHECK_EXT(nullptr != sessionDbiConnection->dbi, os.setError("No opened dbi"), "");
+    CHECK_EXT(sessionDbiConnection != nullptr, os.setError("No session dbi connection"), "");
+    CHECK_EXT(sessionDbiConnection->dbi != nullptr, os.setError("No opened dbi"), "");
 
     QString url = sessionDbiConnection->dbi->getDbiRef().dbiId;
     delete sessionDbiConnection;
@@ -164,7 +162,7 @@ QString U2DbiRegistry::shutdownSessionDbi(U2OpStatus &os) {
     return url;
 }
 
-void U2DbiRegistry::deallocateTmpDbi(const TmpDbiRef &ref, U2OpStatus &os) {
+void U2DbiRegistry::deallocateTmpDbi(const TmpDbiRef& ref, U2OpStatus& os) {
     QMutexLocker l(&lock);
 
     pool->closeAllConnections(ref.dbiRef, os);
@@ -174,14 +172,14 @@ void U2DbiRegistry::deallocateTmpDbi(const TmpDbiRef &ref, U2OpStatus &os) {
 }
 
 namespace {
-QString createNewDatabase(const QString &alias, U2OpStatus &os) {
+QString createNewDatabase(const QString& alias, U2OpStatus& os) {
     QString tmpDirPath = AppContext::getAppSettings()->getUserAppsSettings()->getCurrentProcessTemporaryDirPath();
     return GUrlUtils::prepareTmpFileLocation(tmpDirPath, alias, "ugenedb", os);
 }
 
-QString getDatabaseFromCMDLine(U2OpStatus &os) {
-    CMDLineRegistry *cmdlineReg = AppContext::getCMDLineRegistry();
-    SAFE_POINT_EXT(nullptr != cmdlineReg, os.setError("NULL cmdline registry"), "");
+QString getDatabaseFromCMDLine(U2OpStatus& os) {
+    CMDLineRegistry* cmdlineReg = AppContext::getCMDLineRegistry();
+    SAFE_POINT_EXT(cmdlineReg != nullptr, os.setError("NULL cmdline registry"), "");
     if (!cmdlineReg->hasParameter(CMDLineCoreOptions::SESSION_DB)) {
         os.setError("The session database path is not supplied through the cmd line argument");
         return "";
@@ -193,13 +191,13 @@ QString getDatabaseFromCMDLine(U2OpStatus &os) {
  * Returns true if the path to the correct (openable) session database is
  * supplied with the cmdline argument
  */
-bool useDatabaseFromCMDLine(const QString &alias) {
+bool useDatabaseFromCMDLine(const QString& alias) {
     if (SESSION_TMP_DBI_ALIAS != alias) {
         return false;
     }
 
-    CMDLineRegistry *cmdlineReg = AppContext::getCMDLineRegistry();
-    SAFE_POINT(nullptr != cmdlineReg, "NULL cmdline registry", false);
+    CMDLineRegistry* cmdlineReg = AppContext::getCMDLineRegistry();
+    SAFE_POINT(cmdlineReg != nullptr, "NULL cmdline registry", false);
     if (!cmdlineReg->hasParameter(CMDLineCoreOptions::SESSION_DB)) {
         return false;
     }
@@ -214,7 +212,7 @@ bool useDatabaseFromCMDLine(const QString &alias) {
     return !os.hasError();
 }
 
-U2DbiRef getDbiRef(const QString &alias, U2OpStatus &os, const U2DbiFactoryId &factoryId) {
+U2DbiRef getDbiRef(const QString& alias, U2OpStatus& os, const U2DbiFactoryId& factoryId) {
     U2DbiRef res;
     res.dbiFactoryId = factoryId;
     if (useDatabaseFromCMDLine(alias)) {
@@ -226,7 +224,7 @@ U2DbiRef getDbiRef(const QString &alias, U2OpStatus &os, const U2DbiFactoryId &f
 }
 }  // namespace
 
-U2DbiRef U2DbiRegistry::allocateTmpDbi(const QString &alias, U2OpStatus &os, const U2DbiFactoryId &factoryId) {
+U2DbiRef U2DbiRegistry::allocateTmpDbi(const QString& alias, U2OpStatus& os, const U2DbiFactoryId& factoryId) {
     QMutexLocker m(&lock);
 
     U2DbiRef res = getDbiRef(alias, os, factoryId);
@@ -241,7 +239,7 @@ U2DbiRef U2DbiRegistry::allocateTmpDbi(const QString &alias, U2OpStatus &os, con
     return res;
 }
 
-bool U2DbiRegistry::registerDbiFactory(U2DbiFactory *factory) {
+bool U2DbiRegistry::registerDbiFactory(U2DbiFactory* factory) {
     if (factories.contains(factory->getId())) {
         return false;
     }
@@ -253,7 +251,7 @@ QList<U2DbiFactoryId> U2DbiRegistry::getRegisteredDbiFactories() const {
     return factories.keys();
 }
 
-U2DbiFactory *U2DbiRegistry::getDbiFactoryById(const U2DbiFactoryId &id) const {
+U2DbiFactory* U2DbiRegistry::getDbiFactoryById(const U2DbiFactoryId& id) const {
     return factories.value(id, nullptr);
 }
 
@@ -263,7 +261,7 @@ U2DbiFactory *U2DbiRegistry::getDbiFactoryById(const U2DbiFactoryId &id) const {
 const int U2DbiPool::DBI_POOL_EXPIRATION_TIME_MSEC = 1800000;
 const int U2DbiPool::MAX_CONNECTIONS_PER_DBI = 10;
 
-U2DbiPool::U2DbiPool(QObject *p)
+U2DbiPool::U2DbiPool(QObject* p)
     : QObject(p) {
     connect(&expirationTimer, SIGNAL(timeout()), SLOT(sl_checkDbiPoolExpiration()));
     expirationTimer.start(DBI_POOL_EXPIRATION_TIME_MSEC);
@@ -271,16 +269,16 @@ U2DbiPool::U2DbiPool(QObject *p)
 
 U2DbiPool::~U2DbiPool() {
     expirationTimer.stop();
-    foreach (U2Dbi *dbi, suspendedDbis.values()) {
+    foreach (U2Dbi* dbi, suspendedDbis.values()) {
         U2OpStatus2Log os;
         deallocateDbi(dbi, os);
     }
 }
 
-U2Dbi *U2DbiPool::createDbi(const U2DbiRef &ref, bool create, U2OpStatus &os, const QHash<QString, QString> &properties) {
-    U2DbiFactory *dbiFactory = AppContext::getDbiRegistry()->getDbiFactoryById(ref.dbiFactoryId);
-    CHECK_EXT(nullptr != dbiFactory, os.setError(tr("Invalid database type: %1").arg(ref.dbiFactoryId)), nullptr);
-    U2Dbi *result = dbiFactory->createDbi();
+U2Dbi* U2DbiPool::createDbi(const U2DbiRef& ref, bool create, U2OpStatus& os, const QHash<QString, QString>& properties) {
+    U2DbiFactory* dbiFactory = AppContext::getDbiRegistry()->getDbiFactoryById(ref.dbiFactoryId);
+    CHECK_EXT(dbiFactory != nullptr, os.setError(tr("Invalid database type: %1").arg(ref.dbiFactoryId)), nullptr);
+    U2Dbi* result = dbiFactory->createDbi();
 
     const QString url = dbiFactory->id2Url(ref.dbiId).getURLString();
 
@@ -291,27 +289,27 @@ U2Dbi *U2DbiPool::createDbi(const U2DbiRef &ref, bool create, U2OpStatus &os, co
     return result;
 }
 
-void U2DbiPool::deallocateDbi(U2Dbi *dbi, U2OpStatus &os) {
-    SAFE_POINT(nullptr != dbi, "Invalid DBI reference detected!", );
+void U2DbiPool::deallocateDbi(U2Dbi* dbi, U2OpStatus& os) {
+    SAFE_POINT(dbi != nullptr, "Invalid DBI reference detected!", );
     dbi->shutdown(os);
     delete dbi;
     SAFE_POINT_OP(os, );
 }
 
-U2Dbi *U2DbiPool::getDbiFromPool(const QString &id) {
-    U2Dbi *dbi = suspendedDbis[id];
+U2Dbi* U2DbiPool::getDbiFromPool(const QString& id) {
+    U2Dbi* dbi = suspendedDbis[id];
     removeDbiRecordFromPool(id);
     return dbi;
 }
 
-U2Dbi *U2DbiPool::openDbi(const U2DbiRef &ref, bool createDatabase, U2OpStatus &os, const QHash<QString, QString> &properties) {
+U2Dbi* U2DbiPool::openDbi(const U2DbiRef& ref, bool createDatabase, U2OpStatus& os, const QHash<QString, QString>& properties) {
     CHECK_EXT(!ref.dbiId.isEmpty(), os.setError(tr("Invalid database id")), nullptr);
     QMutexLocker m(&lock);
     Q_UNUSED(m);
 
     const QString id = getId(ref, os);
     CHECK_OP(os, nullptr);
-    U2Dbi *dbi = nullptr;
+    U2Dbi* dbi = nullptr;
 
     if (dbiById.contains(id)) {
         dbi = dbiById[id];
@@ -326,14 +324,14 @@ U2Dbi *U2DbiPool::openDbi(const U2DbiRef &ref, bool createDatabase, U2OpStatus &
             dbi = createDbi(ref, createDatabase, os, properties);
             CHECK_OP(os, nullptr);
         }
-        SAFE_POINT_EXT(nullptr != dbi, os.setError("Invalid DBI detected"), nullptr);
+        SAFE_POINT_EXT(dbi != nullptr, os.setError("Invalid DBI detected"), nullptr);
         dbiById[id] = dbi;
         dbiCountersById[id] = 1;
     }
     return dbi;
 }
 
-void U2DbiPool::addRef(U2Dbi *dbi, U2OpStatus &os) {
+void U2DbiPool::addRef(U2Dbi* dbi, U2OpStatus& os) {
     QMutexLocker m(&lock);
     Q_UNUSED(m);
 
@@ -348,7 +346,7 @@ void U2DbiPool::addRef(U2Dbi *dbi, U2OpStatus &os) {
     ++dbiCountersById[id];
 }
 
-void U2DbiPool::releaseDbi(U2Dbi *dbi, U2OpStatus &os) {
+void U2DbiPool::releaseDbi(U2Dbi* dbi, U2OpStatus& os) {
     QMutexLocker m(&lock);
     Q_UNUSED(m);
 
@@ -367,22 +365,12 @@ void U2DbiPool::releaseDbi(U2Dbi *dbi, U2OpStatus &os) {
     dbiById.remove(id);
     dbiCountersById.remove(id);
 
-    if (MYSQL_DBI_ID == dbi->getDbiRef().dbiFactoryId) {
-        const QString dbiUrl = id2Url(id);
-        if (MAX_CONNECTIONS_PER_DBI < getCountOfConnectionsInPool(dbiUrl)) {
-            flushPool(dbiUrl);
-        }
-
-        suspendedDbis.insert(id, dbi);
-        dbiSuspendStartTime.insert(dbi, QDateTime::currentMSecsSinceEpoch());
-    } else {
-        deallocateDbi(dbi, os);
-    }
+    deallocateDbi(dbi, os);
 }
 
-int U2DbiPool::getCountOfConnectionsInPool(const QString &url) const {
+int U2DbiPool::getCountOfConnectionsInPool(const QString& url) const {
     int result = 0;
-    foreach (const QString &id, suspendedDbis.keys()) {
+    foreach (const QString& id, suspendedDbis.keys()) {
         if (url == id2Url(id)) {
             ++result;
         }
@@ -390,12 +378,12 @@ int U2DbiPool::getCountOfConnectionsInPool(const QString &url) const {
     return result;
 }
 
-void U2DbiPool::flushPool(const QString &url, bool removeAll) {
+void U2DbiPool::flushPool(const QString& url, bool removeAll) {
     U2OpStatus2Log os;
 
-    foreach (const QString &id, suspendedDbis.keys()) {
+    foreach (const QString& id, suspendedDbis.keys()) {
         if (url == id2Url(id) || url.isEmpty()) {
-            U2Dbi *dbi = suspendedDbis[id];
+            U2Dbi* dbi = suspendedDbis[id];
             if (!isDbiFromMainThread(id) || removeAll) {
                 removeDbiRecordFromPool(id);
                 deallocateDbi(dbi, os);
@@ -404,19 +392,19 @@ void U2DbiPool::flushPool(const QString &url, bool removeAll) {
     }
 }
 
-void U2DbiPool::removeDbiRecordFromPool(const QString &id) {
+void U2DbiPool::removeDbiRecordFromPool(const QString& id) {
     SAFE_POINT(suspendedDbis.contains(id) && dbiSuspendStartTime.contains(suspendedDbis[id]), "Unexpected DBI detected", );
     dbiSuspendStartTime.remove(suspendedDbis[id]);
     suspendedDbis.remove(id);
 }
 
 void U2DbiPool::sl_checkDbiPoolExpiration() {
-    Project *proj = AppContext::getProject();
+    Project* proj = AppContext::getProject();
 
     // collect DBI references from all used documents
     QList<U2DbiRef> dbiRefsInUse;
-    if (nullptr != proj) {
-        foreach (Document *doc, proj->getDocuments()) {
+    if (proj != nullptr) {
+        foreach (Document* doc, proj->getDocuments()) {
             const U2DbiRef ref = doc->getDbiRef();
             if (!dbiRefsInUse.contains(ref)) {
                 dbiRefsInUse.append(ref);
@@ -430,7 +418,7 @@ void U2DbiPool::sl_checkDbiPoolExpiration() {
     U2OpStatus2Log os;
     const qint64 currentTime = QDateTime::currentMSecsSinceEpoch();
     QMap<QString, int> dbUrl2DbiCount;  // count how many connections are in pool that refers to the same DB instance
-    foreach (U2Dbi *dbi, dbiSuspendStartTime.keys()) {
+    foreach (U2Dbi* dbi, dbiSuspendStartTime.keys()) {
         const QString id = suspendedDbis.key(dbi, QString());
         SAFE_POINT(!id.isEmpty(), "Unexpected DBI detected in pool", );
 
@@ -456,7 +444,7 @@ void U2DbiPool::sl_checkDbiPoolExpiration() {
     }
 }
 
-void U2DbiPool::closeAllConnections(const U2DbiRef &ref, U2OpStatus &os) {
+void U2DbiPool::closeAllConnections(const U2DbiRef& ref, U2OpStatus& os) {
     QMutexLocker m(&lock);
     Q_UNUSED(m);
 
@@ -466,8 +454,8 @@ void U2DbiPool::closeAllConnections(const U2DbiRef &ref, U2OpStatus &os) {
     SAFE_POINT_OP(os, );
 
     int nActive = 0;
-    foreach (const QString &id, allConnectionsIds) {
-        U2Dbi *dbi = dbiById[id];
+    foreach (const QString& id, allConnectionsIds) {
+        U2Dbi* dbi = dbiById[id];
         deallocateDbi(dbi, os);
 
         dbiById.remove(id);
@@ -478,7 +466,7 @@ void U2DbiPool::closeAllConnections(const U2DbiRef &ref, U2OpStatus &os) {
     ioLog.trace(QString("DBIPool: closing all connections. Id: %1, active references: %2 ").arg(ref.dbiId).arg(nActive));
 }
 
-QHash<QString, QString> U2DbiPool::getInitProperties(const QString &url, bool create) {
+QHash<QString, QString> U2DbiPool::getInitProperties(const QString& url, bool create) {
     QHash<QString, QString> initProperties;
 
     initProperties[U2DbiOptions::U2_DBI_OPTION_URL] = url;
@@ -495,51 +483,36 @@ namespace {
 
 const QString DBI_ID_DELIMETER = "|";
 
-QString getDbiUrlByRef(const U2DbiRef &ref, U2OpStatus &os) {
-    U2DbiFactory *dbiFactory = AppContext::getDbiRegistry()->getDbiFactoryById(ref.dbiFactoryId);
-    SAFE_POINT_EXT(nullptr != dbiFactory, os.setError(QObject::tr("Invalid database type: %1").arg(ref.dbiFactoryId)), QString());
+QString getDbiUrlByRef(const U2DbiRef& ref, U2OpStatus& os) {
+    U2DbiFactory* dbiFactory = AppContext::getDbiRegistry()->getDbiFactoryById(ref.dbiFactoryId);
+    SAFE_POINT_EXT(dbiFactory != nullptr, os.setError(QString("Invalid database type: %1").arg(ref.dbiFactoryId)), QString());
     return dbiFactory->id2Url(ref.dbiId).getURLString();
 }
 
 }  // namespace
 
-QString U2DbiPool::getId(const U2DbiRef &ref, U2OpStatus &os) {
+QString U2DbiPool::getId(const U2DbiRef& ref, U2OpStatus& os) {
     const QString url = U2DbiUtils::ref2Url(ref);
-    SAFE_POINT_EXT(!url.isEmpty(), os.setError(tr("Invalid dbi reference")), "");
-
-    if (ref.dbiFactoryId == MYSQL_DBI_ID) {
-        return url + DBI_ID_DELIMETER + QString::number((qint64)QThread::currentThread());
-    } else {
-        return url;
-    }
+    SAFE_POINT_EXT(!url.isEmpty(), os.setError(QString("Invalid dbi reference")), "");
+    return url;
 }
 
-bool U2DbiPool::isDbiFromMainThread(const QString &dbiId) {
+bool U2DbiPool::isDbiFromMainThread(const QString& dbiId) {
     const QString mainThreadId = QString::number((qint64)QCoreApplication::instance()->thread());
     return dbiId.right(dbiId.size() - dbiId.indexOf(DBI_ID_DELIMETER) - 1) == mainThreadId;
 }
 
-QStringList U2DbiPool::getIds(const U2DbiRef &ref, U2OpStatus &os) const {
+QStringList U2DbiPool::getIds(const U2DbiRef& ref, U2OpStatus& os) const {
     const QString url = getDbiUrlByRef(ref, os);
     CHECK_OP(os, QStringList());
     QStringList result;
-
-    if (ref.dbiFactoryId == MYSQL_DBI_ID) {
-        foreach (const QString &id, dbiById.keys()) {
-            if (id2Url(id) == url) {
-                result << id;
-            }
-        }
-    } else {
-        if (dbiById.contains(url)) {
-            result << url;
-        }
+    if (dbiById.contains(url)) {
+        result << url;
     }
-
     return result;
 }
 
-QString U2DbiPool::id2Url(const QString &id) {
+QString U2DbiPool::id2Url(const QString& id) {
     return id.left(id.indexOf(DBI_ID_DELIMETER));
 }
 
