@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DBI_UTILS_H_
-#define _U2_DBI_UTILS_H_
+#pragma once
 
 #include <U2Core/StrPackUtils.h>
 #include <U2Core/U2Dbi.h>
@@ -37,11 +36,11 @@ class U2CORE_EXPORT TmpDbiHandle {
 public:
     TmpDbiHandle();
 
-    TmpDbiHandle(const QString &alias, U2OpStatus &os, const U2DbiFactoryId &factoryId = DEFAULT_DBI_ID);
+    TmpDbiHandle(const QString& alias, U2OpStatus& os, const U2DbiFactoryId& factoryId = DEFAULT_DBI_ID);
 
-    TmpDbiHandle(const TmpDbiHandle &dbiHandle);
+    TmpDbiHandle(const TmpDbiHandle& dbiHandle);
 
-    TmpDbiHandle &operator=(const TmpDbiHandle &dbiHandle);
+    TmpDbiHandle& operator=(const TmpDbiHandle& dbiHandle);
 
     ~TmpDbiHandle();
 
@@ -67,14 +66,14 @@ private:
 
 class U2CORE_EXPORT TmpDbiObjects {
 public:
-    TmpDbiObjects(const U2DbiRef &_dbiRef, U2OpStatus &_os)
+    TmpDbiObjects(const U2DbiRef& _dbiRef, U2OpStatus& _os)
         : dbiRef(_dbiRef), os(_os) {
     }
     ~TmpDbiObjects();
 
     U2DbiRef dbiRef;
     QList<U2DataId> objects;
-    U2OpStatus &os;
+    U2OpStatus& os;
 };
 
 /**
@@ -83,7 +82,7 @@ public:
 template<class T>
 class BufferedDbiIterator : public U2DbiIterator<T> {
 public:
-    BufferedDbiIterator(const QList<T> &_buffer, const T &_errValue = T())
+    BufferedDbiIterator(const QList<T>& _buffer, const T& _errValue = T())
         : buffer(_buffer), pos(0), errValue(_errValue) {
     }
 
@@ -97,7 +96,7 @@ public:
         if (!hasNext()) {
             return errValue;
         }
-        const T &res = buffer.at(pos);
+        const T& res = buffer.at(pos);
         pos++;
         return res;
     }
@@ -123,32 +122,32 @@ public:
         Logs that operation called is not supported by DBI
         If U2OpStatus has no error set, sets the error message
     */
-    static void logNotSupported(U2DbiFeature f, U2Dbi *dbi, U2OpStatus &os);
+    static void logNotSupported(U2DbiFeature f, U2Dbi* dbi, U2OpStatus& os);
 
     template<class T>
-    static QList<T> toList(U2DbiIterator<T> *it);
+    static QList<T> toList(U2DbiIterator<T>* it);
 
-    static U2DbiRef toRef(U2Dbi *dbi);
+    static U2DbiRef toRef(U2Dbi* dbi);
 
     /** Adds limit operator to the sql query */
-    static void addLimit(QString &sql, qint64 offset, qint64 count);
+    static void addLimit(QString& sql, qint64 offset, qint64 count);
 
     /** Converts internal database id to U2DataId*/
-    static U2DataId toU2DataId(qint64 id, U2DataType type, const QByteArray &dbExtra = QByteArray());
+    static U2DataId toU2DataId(qint64 id, U2DataType type, const QByteArray& dbExtra = QByteArray());
 
     /** Converts U2DataId to internal database id*/
-    static quint64 toDbiId(const U2DataId &id);
+    static quint64 toDbiId(const U2DataId& id);
 
     /** Extracts type info from U2DataId */
-    static U2DataType toType(const U2DataId &id);
+    static U2DataType toType(const U2DataId& id);
 
     /** Extracts table info from U2DataId */
-    static QByteArray toDbExtra(const U2DataId &id);
+    static QByteArray toDbExtra(const U2DataId& id);
 
     /** Return textual representation of the id */
-    static QString text(const U2DataId &id);
+    static QString text(const U2DataId& id);
 
-    static QString ref2Url(const U2DbiRef &dbiRef);
+    static QString ref2Url(const U2DbiRef& dbiRef);
 
     /**
      * Dbi url (short dbi url) looks like "host:port/database_name"
@@ -156,23 +155,21 @@ public:
      * Short dbi url is used where user name is not defined. It should be converted
      * to the full url before using.
      */
-    static QString createDbiUrl(const QString &host, int port, const QString &dbName);
-    static QString createFullDbiUrl(const QString &userName, const QString &host, int port, const QString &dbName);
-    static QString createFullDbiUrl(const QString &userName, const QString &dbiUrl);
+    static QString createDbiUrl(const QString& host, int port, const QString& dbName);
+    static QString createFullDbiUrl(const QString& userName, const QString& host, int port, const QString& dbName);
+    static QString createFullDbiUrl(const QString& userName, const QString& dbiUrl);
 
-    static bool parseDbiUrl(const QString &dbiUrl, QString &host, int &port, QString &dbName);
-    static bool parseFullDbiUrl(const QString &dbiUrl, QString &userName, QString &host, int &port, QString &dbName);
+    static bool parseDbiUrl(const QString& dbiUrl, QString& host, int& port, QString& dbName);
+    static bool parseFullDbiUrl(const QString& dbiUrl, QString& userName, QString& host, int& port, QString& dbName);
 
-    static QString full2shortDbiUrl(const QString &fullDbiUrl);
-    static QString full2shortDbiUrl(const QString &fullDbiUrl, QString &userName);
-    static bool isFullDbiUrl(const QString &dbiUrl);
+    static QString full2shortDbiUrl(const QString& fullDbiUrl, QString& userName);
 
-    static QString makeFolderCanonical(const QString &folder);
+    static QString makeFolderCanonical(const QString& folder);
 
-    static bool isDbiReadOnly(const U2DbiRef &dbiRef);
-    static Version getDbMinRequiredVersion(const U2DbiRef &dbiRef, U2OpStatus &os);
-    static bool isDatabaseTooNew(const U2DbiRef &dbiRef, const Version &ugeneVersion, QString &minRequiredVersionString, U2OpStatus &os);
-    static bool isDatabaseTooOld(const U2DbiRef &dbiRef, const Version &ugeneVersion, U2OpStatus &os);
+    static bool isDbiReadOnly(const U2DbiRef& dbiRef);
+    static Version getDbMinRequiredVersion(const U2DbiRef& dbiRef, U2OpStatus& os);
+    static bool isDatabaseTooNew(const U2DbiRef& dbiRef, const Version& ugeneVersion, QString& minRequiredVersionString, U2OpStatus& os);
+    static bool isDatabaseTooOld(const U2DbiRef& dbiRef, const Version& ugeneVersion, U2OpStatus& os);
 
     static const QString PUBLIC_DATABASE_NAME;
     static const QString PUBLIC_DATABASE_URL;
@@ -185,17 +182,17 @@ public:
 */
 class U2CORE_EXPORT DbiOperationsBlock {
 public:
-    DbiOperationsBlock(const U2DbiRef &dbiRef, U2OpStatus &os);
+    DbiOperationsBlock(const U2DbiRef& dbiRef, U2OpStatus& os);
     ~DbiOperationsBlock();
 
 private:
     U2DbiRef dbiRef;
-    DbiConnection *connection;
-    U2OpStatus &os;
+    DbiConnection* connection;
+    U2OpStatus& os;
 };
 
 template<class T>
-QList<T> U2DbiUtils::toList(U2DbiIterator<T> *it) {
+QList<T> U2DbiUtils::toList(U2DbiIterator<T>* it) {
     QList<T> result;
     while (it->hasNext()) {
         result << it->next();
@@ -204,5 +201,3 @@ QList<T> U2DbiUtils::toList(U2DbiIterator<T> *it) {
 }
 
 }  // namespace U2
-
-#endif
