@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_QSLITE_TRIPLESTORE_
-#define _U2_QSLITE_TRIPLESTORE_
+#pragma once
 
 #include <U2Core/U2Dbi.h>
 #include <U2Core/U2OpStatus.h>
@@ -35,8 +34,7 @@ class U2CORE_EXPORT U2Triplet {
     friend class U2SQLiteTripleStore;
 
 public:
-    U2Triplet(const QString &key, const QString &role, const QString &value);
-    U2Triplet(const U2Triplet &other);
+    U2Triplet(const QString& key, const QString& role, const QString& value);
     QString getKey() const;
     QString getRole() const;
     QString getValue() const;
@@ -53,8 +51,8 @@ class U2CORE_EXPORT Owner {
     friend class U2SQLiteTripleStore;
 
 public:
-    Owner(const QString &name);
-    Owner(const Owner &owner);
+    Owner(const QString& name);
+    Owner(const Owner& owner);
     QString getName() const;
 
 private:
@@ -68,29 +66,29 @@ public:
     U2SQLiteTripleStore();
     virtual ~U2SQLiteTripleStore();
 
-    void init(const QString &url, U2OpStatus &os);
-    void shutdown(U2OpStatus &os);
+    void init(const QString& url, U2OpStatus& os);
+    void shutdown(U2OpStatus& os);
 
-    void addValue(const U2Triplet &value, U2OpStatus &os);
-    bool contains(const U2Triplet &value, U2OpStatus &os) const;
-    void removeValue(const U2Triplet &value, U2OpStatus &os);
+    void addValue(const U2Triplet& value, U2OpStatus& os);
+    bool contains(const U2Triplet& value, U2OpStatus& os) const;
+    void removeValue(const U2Triplet& value, U2OpStatus& os);
 
-    bool contains(const QString &key, const QString &role, U2OpStatus &os) const;
-    QString getValue(const QString &key, const QString &role, U2OpStatus &os) const;
+    bool contains(const QString& key, const QString& role, U2OpStatus& os) const;
+    QString getValue(const QString& key, const QString& role, U2OpStatus& os) const;
 
-    QList<U2Triplet> getTriplets(U2OpStatus &os) const;
+    QList<U2Triplet> getTriplets(U2OpStatus& os) const;
 
 private:
     U2DbiState state;
-    DbRef *db;
+    DbRef* db;
 
-    bool isEmpty(U2OpStatus &os) const;
-    void createTables(U2OpStatus &os);
+    bool isEmpty(U2OpStatus& os) const;
+    void createTables(U2OpStatus& os);
 
-    qint64 getTripletId(const U2Triplet &value, bool &found, U2OpStatus &os) const;
+    qint64 getTripletId(const U2Triplet& value, bool& found, U2OpStatus& os) const;
     /** Returns triplet id */
-    qint64 insertTriplet(const U2Triplet &value, U2OpStatus &os);
-    void removeTriplet(qint64 tripletId, U2OpStatus &os);
+    qint64 insertTriplet(const U2Triplet& value, U2OpStatus& os);
+    void removeTriplet(qint64 tripletId, U2OpStatus& os);
 };
 
 class TripleStoreL10N : public QObject {
@@ -98,5 +96,3 @@ class TripleStoreL10N : public QObject {
 };
 
 }  // namespace U2
-
-#endif  // _U2_QSLITE_TRIPLESTORE_
