@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_APPSETTINGS_H_
-#define _U2_APPSETTINGS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -32,44 +31,39 @@ class UserAppsSettings;
 class AppResourcePool;
 class TestRunnerSettings;
 
-/** A collection for all settings used in app that have C++ model description */
-
+/** Global application settings used bu UGENE. */
 class U2CORE_EXPORT AppSettings {
 public:
-    AppSettings()
-        : nc(nullptr), userAppsSettings(nullptr), ri(nullptr), trs(nullptr), formatSettings(nullptr) {
-    }
+    AppSettings() = default;
 
-    virtual ~AppSettings() {
-    }
+    virtual ~AppSettings() = default;
 
-    NetworkConfiguration *getNetworkConfiguration() const {
+    NetworkConfiguration* getNetworkConfiguration() const {
         return nc;
     }
 
-    UserAppsSettings *getUserAppsSettings() const {
+    UserAppsSettings* getUserAppsSettings() const {
         return userAppsSettings;
     }
 
-    AppResourcePool *getAppResourcePool() const {
+    AppResourcePool* getAppResourcePool() const {
         return ri;
     }
 
-    TestRunnerSettings *getTestRunnerSettings() const {
+    TestRunnerSettings* getTestRunnerSettings() const {
         return trs;
     }
 
-    FormatAppsSettings *getFormatAppsSettings() const {
+    FormatAppsSettings* getFormatAppsSettings() const {
         return formatSettings;
     }
 
 protected:
-    NetworkConfiguration *nc;
-    UserAppsSettings *userAppsSettings;
-    AppResourcePool *ri;
-    TestRunnerSettings *trs;
-    FormatAppsSettings *formatSettings;
+    NetworkConfiguration* nc = nullptr;
+    UserAppsSettings* userAppsSettings = nullptr;
+    AppResourcePool* ri = nullptr;
+    TestRunnerSettings* trs = nullptr;
+    FormatAppsSettings* formatSettings = nullptr;
 };
 
 }  // namespace U2
-#endif
