@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,7 +32,6 @@ const DocumentFormatId BaseDocumentFormats::ACE("ace");
 const DocumentFormatId BaseDocumentFormats::BAM("bam");
 const DocumentFormatId BaseDocumentFormats::BED("bed");
 const DocumentFormatId BaseDocumentFormats::CLUSTAL_ALN("clustal");
-const DocumentFormatId BaseDocumentFormats::DATABASE_CONNECTION("database_connection");
 const DocumentFormatId BaseDocumentFormats::DIFF("diff");
 const DocumentFormatId BaseDocumentFormats::FASTA("fasta");
 const DocumentFormatId BaseDocumentFormats::FASTQ("fastq");
@@ -64,7 +63,7 @@ const DocumentFormatId BaseDocumentFormats::VCF4("vcf");
 const DocumentFormatId BaseDocumentFormats::VECTOR_NTI_ALIGNX("Vector_nti_alignx");
 const DocumentFormatId BaseDocumentFormats::VECTOR_NTI_SEQUENCE("vector_nti_sequence");
 
-DocumentFormat *BaseDocumentFormats::get(const DocumentFormatId &formatId) {
+DocumentFormat* BaseDocumentFormats::get(const DocumentFormatId& formatId) {
     return AppContext::getDocumentFormatRegistry()->getFormatById(formatId);
 }
 
@@ -79,7 +78,6 @@ StrStrMap initInvalidFormatIdsMap() {
     invalidIds2trueIds.insert("BAM", BaseDocumentFormats::BAM);
     invalidIds2trueIds.insert("BED", BaseDocumentFormats::BED);
     invalidIds2trueIds.insert("CLUSTAL", BaseDocumentFormats::CLUSTAL_ALN);
-    invalidIds2trueIds.insert("database_connection", BaseDocumentFormats::DATABASE_CONNECTION);
     invalidIds2trueIds.insert("Diff", BaseDocumentFormats::DIFF);
     invalidIds2trueIds.insert("FASTA", BaseDocumentFormats::FASTA);
     invalidIds2trueIds.insert("FASTQ", BaseDocumentFormats::FASTQ);
@@ -124,7 +122,6 @@ StrStrMap initFormatIdsMap() {
     anyIds2trueIds.insert(BaseDocumentFormats::BAM, BaseDocumentFormats::BAM);
     anyIds2trueIds.insert(BaseDocumentFormats::BED, BaseDocumentFormats::BED);
     anyIds2trueIds.insert(BaseDocumentFormats::CLUSTAL_ALN, BaseDocumentFormats::CLUSTAL_ALN);
-    anyIds2trueIds.insert(BaseDocumentFormats::DATABASE_CONNECTION, BaseDocumentFormats::DATABASE_CONNECTION);
     anyIds2trueIds.insert(BaseDocumentFormats::DIFF, BaseDocumentFormats::DIFF);
     anyIds2trueIds.insert(BaseDocumentFormats::FASTA, BaseDocumentFormats::FASTA);
     anyIds2trueIds.insert(BaseDocumentFormats::FASTQ, BaseDocumentFormats::FASTQ);
@@ -164,19 +161,19 @@ StrStrMap initFormatIdsMap() {
 
 }  // namespace
 
-bool BaseDocumentFormats::equal(const DocumentFormatId &first, const DocumentFormatId &second) {
+bool BaseDocumentFormats::equal(const DocumentFormatId& first, const DocumentFormatId& second) {
     // After UGENE-5719 fix format IDs were occasionally changed
     // Case insensitive comparison grants a correct comparison result
     static const StrStrMap formatIds = initFormatIdsMap();
     return formatIds.value(first, first) == formatIds.value(second, second);
 }
 
-bool BaseDocumentFormats::isInvalidId(const DocumentFormatId &formatId) {
+bool BaseDocumentFormats::isInvalidId(const DocumentFormatId& formatId) {
     static const QStringList invalidIdsList = initInvalidFormatIdsMap().keys();
     return invalidIdsList.contains(formatId);
 }
 
-DocumentFormatId BaseDocumentFormats::toValidId(const DocumentFormatId &invalidFormatId) {
+DocumentFormatId BaseDocumentFormats::toValidId(const DocumentFormatId& invalidFormatId) {
     static const StrStrMap invalidIds = initInvalidFormatIdsMap();
     return invalidIds.value(invalidFormatId, invalidFormatId);
 }
