@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOCUMENT_FORMATS_H_
-#define _U2_DOCUMENT_FORMATS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -38,7 +37,6 @@ public:
     static const DocumentFormatId BAM;
     static const DocumentFormatId BED;
     static const DocumentFormatId CLUSTAL_ALN;
-    static const DocumentFormatId DATABASE_CONNECTION;
     static const DocumentFormatId DIFF;
     static const DocumentFormatId FASTA;
     static const DocumentFormatId FASTQ;
@@ -70,12 +68,10 @@ public:
     static const DocumentFormatId VECTOR_NTI_ALIGNX;
     static const DocumentFormatId VECTOR_NTI_SEQUENCE;
 
-    static DocumentFormat *get(const DocumentFormatId &formatId);
-    static bool equal(const DocumentFormatId &first, const DocumentFormatId &second);  // a workaround for UGENE-5521, use this method to compare format IDs
-    static bool isInvalidId(const DocumentFormatId &formatId);
-    static DocumentFormatId toValidId(const DocumentFormatId &invalidFormatId);
+    static DocumentFormat* get(const DocumentFormatId& formatId);
+    static bool equal(const DocumentFormatId& first, const DocumentFormatId& second);  // a workaround for UGENE-5521, use this method to compare format IDs
+    static bool isInvalidId(const DocumentFormatId& formatId);
+    static DocumentFormatId toValidId(const DocumentFormatId& invalidFormatId);
 };
 
 }  // namespace U2
-
-#endif
