@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CLIPBOARD_CONTROLLER_H_
-#define _U2_CLIPBOARD_CONTROLLER_H_
+#pragma once
 
 #include <QClipboard>
 
@@ -48,27 +47,25 @@ public:
     PasteTask(TaskFlags flags = TaskFlag_None);
 
     virtual QList<GUrl> getUrls() const = 0;
-    virtual QList<Document *> getDocuments() const = 0;
+    virtual QList<Document*> getDocuments() const = 0;
 
 protected:
-    virtual void processDocument(Document *doc);
+    virtual void processDocument(Document* doc);
 };
 
 class U2CORE_EXPORT PasteFactory : public QObject {
     Q_OBJECT
 public:
-    PasteFactory(QObject *parent = 0);
+    PasteFactory(QObject* parent = 0);
 
     /** Creates task using current clipboard state. May return NULL if clipboard state is invalid/unsupported. */
-    virtual PasteTask *createPasteTask(bool isAddToProject) = 0;
+    virtual PasteTask* createPasteTask(bool isAddToProject) = 0;
 };
 
 class U2CORE_EXPORT PasteUtils : public QObject {
     Q_OBJECT
 public:
-    static QList<DNASequence> getSequences(const QList<Document *> &docs, U2OpStatus &os);
+    static QList<DNASequence> getSequences(const QList<Document*>& docs, U2OpStatus& os);
 };
 
 }  // namespace U2
-
-#endif  // _U2_CLIPBOARD_CONTROLLER_H_
