@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,9 +30,9 @@ namespace U2 {
 CredentialsAsker::~CredentialsAsker() {
 }
 
-void CredentialsAsker::saveCredentials(const QString &resourceUrl, const QString &password, bool remember) {
-    PasswordStorage *storage = AppContext::getPasswordStorage();
-    CHECK(nullptr != storage, );
+void CredentialsAsker::saveCredentials(const QString& resourceUrl, const QString& password, bool remember) {
+    PasswordStorage* storage = AppContext::getPasswordStorage();
+    CHECK(storage != nullptr, );
 
     storage->addEntry(resourceUrl, password, remember);
 }
