@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CREDENTIALS_ASKER_H_
-#define _U2_CREDENTIALS_ASKER_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -30,13 +29,11 @@ class U2CORE_EXPORT CredentialsAsker {
 public:
     virtual ~CredentialsAsker();
 
-    virtual bool askWithFixedLogin(const QString &resourceUrl) const = 0;
-    virtual bool askWithModifiableLogin(QString &resourceUrl) const = 0;
+    virtual bool askWithFixedLogin(const QString& resourceUrl) const = 0;
+    virtual bool askWithModifiableLogin(QString& resourceUrl) const = 0;
 
 protected:
-    static void saveCredentials(const QString &resourceUrl, const QString &password, bool remember);
+    static void saveCredentials(const QString& resourceUrl, const QString& password, bool remember);
 };
 
 }  // namespace U2
-
-#endif  // _U2_CREDENTIALS_ASKER_H_
