@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DBXREF_H_
-#define _U2_DBXREF_H_
+#pragma once
 
 #include <QMap>
 #include <QObject>
@@ -35,7 +34,7 @@ class U2CORE_EXPORT DBXRefInfo {
 public:
     DBXRefInfo() {
     }
-    DBXRefInfo(const QString &_name, const QString &_url, const QString &_fileUrl, const QString &_comment)
+    DBXRefInfo(const QString& _name, const QString& _url, const QString& _fileUrl, const QString& _comment)
         : name(_name), url(_url), fileUrl(_fileUrl), comment(_comment) {
     }
 
@@ -44,35 +43,37 @@ public:
     QString fileUrl;
     QString comment;
 
-    static void setupToEngine(QScriptEngine *engine);
+    static void setupToEngine(QScriptEngine* engine);
 
 private:
-    static QScriptValue toScriptValue(QScriptEngine *engine, DBXRefInfo const &in);
-    static void fromScriptValue(const QScriptValue &object, DBXRefInfo &out);
+    static QScriptValue toScriptValue(QScriptEngine* engine, DBXRefInfo const& in);
+    static void fromScriptValue(const QScriptValue& object, DBXRefInfo& out);
 };
 
 class U2CORE_EXPORT DBXRefRegistry : public QObject {
     Q_OBJECT
 public:
-    DBXRefRegistry(QObject *p = nullptr);
+    DBXRefRegistry(QObject* p = nullptr);
 
-    Q_INVOKABLE DBXRefInfo getRefByKey(const QString &dbxrefKey) const {
+    Q_INVOKABLE DBXRefInfo getRefByKey(const QString& dbxrefKey) const {
         return refsByKey.value(dbxrefKey);
     }
 
-    static void setupToEngine(QScriptEngine *engine);
-    const QMap<QString, DBXRefInfo> &getEntries() {
+    static void setupToEngine(QScriptEngine* engine);
+    const QMap<QString, DBXRefInfo>& getEntries() {
         return refsByKey;
     }
 
+    // Finds a database and accession, which have been used when @url was created
+    // Return pair, where database name is the first, accession number is the second
+    QPair<QString, QString> getDbAndAccessionBytUrl(const QString& url) const;
+
 private:
-    static QScriptValue toScriptValue(QScriptEngine *engine, DBXRefRegistry *const &in);
-    static void fromScriptValue(const QScriptValue &object, DBXRefRegistry *&out);
+    static QScriptValue toScriptValue(QScriptEngine* engine, DBXRefRegistry* const& in);
+    static void fromScriptValue(const QScriptValue& object, DBXRefRegistry*& out);
 
     QMap<QString, DBXRefInfo> refsByKey;
 };
 }  // namespace U2
-Q_DECLARE_METATYPE(U2::DBXRefRegistry *)
+Q_DECLARE_METATYPE(U2::DBXRefRegistry*)
 Q_DECLARE_METATYPE(U2::DBXRefInfo)
-
-#endif
