@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _DATABASE_REGISTRY_
-#define _DATABASE_REGISTRY_
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -34,7 +33,7 @@ namespace U2 {
 
 class HttpRequest {
 public:
-    virtual void sendRequest(const QString &program, const QString &query) = 0;
+    virtual void sendRequest(const QString& program, const QString& query) = 0;
     virtual QList<SharedAnnotationData> getAnnotations() {
         return result;
     }
@@ -47,33 +46,31 @@ public:
     virtual ~HttpRequest() {};
 
 protected:
-    HttpRequest(Task *_task)
+    HttpRequest(Task* _task)
         : error(""), task(_task) {};
     QString error;
     QList<SharedAnnotationData> result;
-    Task *task;
+    Task* task;
 };
 
 class DataBaseFactory {
 public:
     virtual ~DataBaseFactory() {
     }
-    virtual HttpRequest *getRequest(Task *t) = 0;
+    virtual HttpRequest* getRequest(Task* t) = 0;
 };
 
 class U2CORE_EXPORT DataBaseRegistry : public QObject {
     Q_OBJECT
 public:
-    DataBaseRegistry(QObject *o = nullptr);
+    DataBaseRegistry(QObject* o = nullptr);
     ~DataBaseRegistry();
-    bool registerDataBase(DataBaseFactory *f, const QString &id);
-    DataBaseFactory *getFactoryById(const QString &id);
-    bool isRegistered(const QString &id);
+    bool registerDataBase(DataBaseFactory* f, const QString& id);
+    DataBaseFactory* getFactoryById(const QString& id);
+    bool isRegistered(const QString& id);
 
 private:
-    QMap<QString, DataBaseFactory *> factories;
+    QMap<QString, DataBaseFactory*> factories;
 };
 
 }  // namespace U2
-
-#endif
