@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,7 +32,7 @@
 
 namespace U2 {
 
-static QString makeFilePathCanonical(const QString &originalUrl) {
+static QString makeFilePathCanonical(const QString& originalUrl) {
     // ensure that name is canonical
     QString result = originalUrl.trimmed();
 
@@ -58,29 +58,32 @@ static QString makeFilePathCanonical(const QString &originalUrl) {
         prefix = ":";
         result = result.mid(1);
     } else {
+        // https://learn.microsoft.com/en-us/dotnet/standard/io/file-path-formats#:~:text=%5C%5C.%5CC%3A%5CTest%5CFoo.txt%20%5C%5C%3F%5CC%3A%5CTest%5CFoo.txt
+        // Paths starting with "\\.\" and "\\?\" appear to be the same, but Qt treats them differently.
+        if (result.startsWith("\\\\?\\")) {
+            result[2] = '.';
+        }
         result = QFileInfo(result).absoluteFilePath();
     }
 
-#ifdef Q_OS_WIN
     bool isSambaPath = false;
-    if (result.startsWith("//") && prefix.isEmpty()) {
+    if (isOsWindows() && result.startsWith("//") && prefix.isEmpty()) {
         // keep Samba share designation
         prefix = "//";
         isSambaPath = true;
     }
-#endif
 
     QStringList parts = result.split('/', QString::SkipEmptyParts);
-    if (parts.size() > 0) {
+    if (!parts.empty()) {
         QStringList canonicalParts;
-#ifdef Q_OS_WIN
-        // append drive spec letter or Samba server name to the prefix
-        if (isSambaPath) {
-            prefix += parts.takeFirst();
-        } else if (parts.at(0).endsWith(':') && parts.at(0).length() == 2 && prefix.isEmpty()) {  // Windows drive letter designation
-            prefix = parts.takeFirst();
+        if (isOsWindows()) {
+            // append drive spec letter or Samba server name to the prefix
+            if (isSambaPath) {
+                prefix += parts.takeFirst();
+            } else if (parts.at(0).endsWith(':') && parts.at(0).length() == 2 && prefix.isEmpty()) {  // Windows drive letter designation
+                prefix = parts.takeFirst();
+            }
         }
-#endif
         // get rid of redundant '.' and '..' now
         QStringListIterator it(parts);
         while (it.hasNext()) {
@@ -101,7 +104,7 @@ static QString makeFilePathCanonical(const QString &originalUrl) {
     return result;
 }
 
-GUrlType GUrl::getURLType(const QString &rawUrl) {
+GUrlType GUrl::getURLType(const QString& rawUrl) {
     GUrlType result = GUrl_File;
     if (rawUrl.startsWith("http://") || rawUrl.startsWith("https://")) {
         result = GUrl_Http;
@@ -116,7 +119,7 @@ GUrlType GUrl::getURLType(const QString &rawUrl) {
 }
 
 // constructs url specified by string. The type is parsed
-GUrl::GUrl(const QString &_urlString) {
+GUrl::GUrl(const QString& _urlString) {
     urlString = _urlString;
     type = getURLType(urlString);
     if (type == GUrl_File) {
@@ -125,7 +128,7 @@ GUrl::GUrl(const QString &_urlString) {
 }
 
 // constructs url specified by string. The type provided as param
-GUrl::GUrl(const QString &_urlString, const GUrlType _type) {
+GUrl::GUrl(const QString& _urlString, const GUrlType& _type) {
     urlString = _urlString;
     type = _type;
     if (type == GUrl_File) {
@@ -133,44 +136,15 @@ GUrl::GUrl(const QString &_urlString, const GUrlType _type) {
     }
 }
 
-GUrl::GUrl(const GUrl &anotherUrl) {
-    urlString = anotherUrl.getURLString();
-    type = anotherUrl.getType();
-}
-
-bool GUrl::operator==(const GUrl &url) const {
+bool GUrl::operator==(const GUrl& url) const {
     return urlString == url.getURLString();
 }
 
-bool GUrl::operator!=(const GUrl &url) const {
+bool GUrl::operator!=(const GUrl& url) const {
     return !(*this == url);
 }
 
-QByteArray GUrl::getURLStringAnsi(int codePage) const {
-#ifdef Q_OS_WIN
-    std::wstring wPath = getURLString().toStdWString();
-    codePage = codePage < 0 ? CP_THREAD_ACP : codePage;
-
-    DWORD buffSize = WideCharToMultiByte(codePage, 0, wPath.c_str(), -1, nullptr, 0, nullptr, nullptr);
-    if (!buffSize) {
-        return QByteArray();
-    }
-
-    char *buffer = new char[buffSize + 1];
-    if (!WideCharToMultiByte(codePage, 0, wPath.c_str(), -1, buffer, buffSize, nullptr, nullptr)) {
-        delete[] buffer;
-        return QByteArray();
-    }
-    QByteArray bytes = QByteArray(buffer, buffSize + 1);
-    delete[] buffer;
-    return bytes;
-#else
-    Q_UNUSED(codePage);
-    return getURLString().toLocal8Bit();
-#endif  // Q_OS_WIN
-}
-
-static QString path(const GUrl *url) {
+static QString path(const GUrl* url) {
     // TODO: parse HTTP and other formats for path part
     QString result;
     if (url->isVFSFile()) {
@@ -252,12 +226,12 @@ static bool registerMetas() {
     return true;
 }
 
-QDataStream &operator<<(QDataStream &out, const GUrl &myObj) {
+QDataStream& operator<<(QDataStream& out, const GUrl& myObj) {
     out << myObj.getURLString() << myObj.getType();
     return out;
 }
 
-QDataStream &operator>>(QDataStream &in, GUrl &myObj) {
+QDataStream& operator>>(QDataStream& in, GUrl& myObj) {
     QString urlString;
     in >> urlString;
     int t;
