@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GURL_H_
-#define _U2_GURL_H_
+#pragma once
 
 #include <QMetaType>
 
@@ -60,27 +59,23 @@ public:
     }
 
     // constructs url specified by string. The type is parsed
-    GUrl(const QString &urlString);
+    GUrl(const QString& urlString);
 
     // constructs url specified by string. The type provided as param
-    GUrl(const QString &urlString, const GUrlType type);
+    GUrl(const QString& urlString, const GUrlType& type);
 
-    GUrl(const GUrl &anotherUrl);
+    GUrl(const GUrl& url) = default;
 
-    bool operator==(const GUrl &url) const;
+    bool operator==(const GUrl& url) const;
 
-    bool operator!=(const GUrl &url) const;
+    bool operator!=(const GUrl& url) const;
 
-    const QString &getURLString() const {
+    GUrl& operator=(const GUrl& url) = default;
+
+    const QString& getURLString() const {
         return urlString;
     }
 
-    /**
-     * The function converts url string to multibyte form for Windows (default code page is CP_THREAD_ACP)
-     * And calls to getURLString().toLocal8Bit() on Linux & Mac platforms.
-     */
-    QByteArray getURLStringAnsi(int codePage = -1) const;
-
     GUrlType getType() const {
         return type;
     }
@@ -115,7 +110,7 @@ public:
 
     QString completeFileSuffix() const;
 
-    static GUrlType getURLType(const QString &rawUrl);
+    static GUrlType getURLType(const QString& rawUrl);
 
 private:
     static bool registerMeta;
@@ -123,11 +118,9 @@ private:
     GUrlType type;
 };
 
-QDataStream &operator<<(QDataStream &out, const GUrl &myObj);
-QDataStream &operator>>(QDataStream &in, GUrl &myObj);
+QDataStream& operator<<(QDataStream& out, const GUrl& myObj);
+QDataStream& operator>>(QDataStream& in, GUrl& myObj);
 
 }  // namespace U2
 
 Q_DECLARE_METATYPE(U2::GUrl);
-
-#endif
