@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_COREAPI_ID_REGISTRY_H_
-#define _U2_COREAPI_ID_REGISTRY_H_
+#pragma once
 
 #include <QMap>
 
@@ -32,10 +31,10 @@ namespace U2 {
 template<class T>
 class IdRegistry {
 public:
-    virtual T *getById(const QString &id) {
+    virtual T* getById(const QString& id) const {
         return registry.value(id, nullptr);
     }
-    virtual bool registerEntry(T *t) {
+    virtual bool registerEntry(T* t) {
         if (registry.contains(t->getId())) {
             return false;
         } else {
@@ -43,14 +42,14 @@ public:
             return true;
         }
     }
-    virtual T *unregisterEntry(const QString &id) {
+    virtual T* unregisterEntry(const QString& id) {
         return registry.contains(id) ? registry.take(id) : nullptr;
     }
     virtual ~IdRegistry() {
         qDeleteAll(registry.values());
     }
 
-    virtual QList<T *> getAllEntries() const {
+    virtual QList<T*> getAllEntries() const {
         return registry.values();
     }
     virtual QList<QString> getAllIds() const {
@@ -58,10 +57,8 @@ public:
     }
 
 protected:
-    QMap<QString, T *> registry;
+    QMap<QString, T*> registry;
 
 };  // IdRegistry
 
 }  // namespace U2
-
-#endif  // _U2_COREAPI_ID_REGISTRY_H_
