@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,6 +21,8 @@
 
 #include "LogCache.h"
 
+#include <QDateTime>
+
 #ifdef Q_OS_WIN32
 #    include "windows.h"
 #endif
@@ -29,16 +31,16 @@
 
 namespace U2 {
 
-LogCache *LogCache::appGlobalCache = nullptr;
+LogCache* LogCache::appGlobalCache = nullptr;
 
-LogFilterItem::LogFilterItem(const QString &_category, LogLevel _minLevel) {
+LogFilterItem::LogFilterItem(const QString& _category, LogLevel _minLevel) {
     category = _category;
     minLevel = _minLevel;
 }
 
-QString LogFilter::selectEffectiveCategory(const LogMessage &msg) const {
+QString LogFilter::selectEffectiveCategory(const LogMessage& msg) const {
     QString result;
-    foreach (const LogFilterItem &f, filters) {
+    foreach (const LogFilterItem& f, filters) {
         if (msg.level >= f.minLevel && msg.categories.contains(f.category)) {
             result = f.category;
             break;
@@ -47,7 +49,7 @@ QString LogFilter::selectEffectiveCategory(const LogMessage &msg) const {
     return result;
 }
 
-bool LogFilter::matches(const LogMessage &msg) const {
+bool LogFilter::matches(const LogMessage& msg) const {
     return !selectEffectiveCategory(msg).isEmpty();
 }
 
@@ -62,12 +64,12 @@ LogCache::LogCache(int maxLogMessages)
 LogCache::~LogCache() {
     LogServer::getInstance()->removeListener(this);
     while (!messages.empty()) {
-        LogMessage *m = messages.takeFirst();
+        LogMessage* m = messages.takeFirst();
         delete m;
     }
 }
 
-void LogCache::onMessage(const LogMessage &msg) {
+void LogCache::onMessage(const LogMessage& msg) {
     lock.lockForWrite();
     if (!filter.isEmpty() && !filter.matches(msg)) {
         lock.unlock();
@@ -81,12 +83,12 @@ void LogCache::onMessage(const LogMessage &msg) {
 
 void LogCache::updateSize() {
     while (messages.size() > maxLogMessages) {
-        LogMessage *m = messages.takeFirst();
+        LogMessage* m = messages.takeFirst();
         delete m;
     }
 }
 
-void LogCache::setAppGlobalInstance(LogCache *cache) {
+void LogCache::setAppGlobalInstance(LogCache* cache) {
     assert(appGlobalCache == nullptr);
     appGlobalCache = cache;
 }
@@ -101,7 +103,7 @@ QList<LogMessage> LogCache::getLastMessages(int count) {
 
     QList<LogMessage> lastMessages;
     for (int i = cacheSize; --i >= lastToAdd;) {
-        LogMessage *m = messages.at(i);
+        LogMessage* m = messages.at(i);
         if (m->categories.contains(ULOG_CAT_USER_ACTIONS))
             continue;
         lastMessages.prepend(*m);
@@ -119,7 +121,7 @@ LogCacheExt::LogCacheExt() {
     fileEnabled = false;
 }
 
-bool LogCacheExt::setFileOutputEnabled(const QString &fileName) {
+bool LogCacheExt::setFileOutputEnabled(const QString& fileName) {
     if (fileName.isEmpty()) {
         file.close();
         fileEnabled = false;
@@ -139,13 +141,17 @@ bool LogCacheExt::setFileOutputEnabled(const QString &fileName) {
     return true;
 }
 
-void LogCacheExt::onMessage(const LogMessage &msg) {
+void LogCacheExt::onMessage(const LogMessage& msg) {
     if (!filter.isEmpty() && !filter.matches(msg)) {
         return;
     }
     if (consoleEnabled) {
-        QByteArray ba = msg.text.toLocal8Bit();
-        char *buf = ba.data();
+        QByteArray message = msg.text.toLocal8Bit();
+        if (!message.startsWith("[")) {
+            QByteArray time = QDateTime::fromMSecsSinceEpoch(msg.time / 1000).toString("hh:mm:ss.zzz").toLocal8Bit();
+            printf("[%s] ", time.constData());
+        }
+        char* buf = message.data();
 #ifdef Q_OS_WIN32
         // a bit of magic to workaround Windows console encoding issues
         CharToOemA(buf, buf);
@@ -155,7 +161,7 @@ void LogCacheExt::onMessage(const LogMessage &msg) {
 
     if (fileEnabled) {
         QByteArray ba = msg.text.toLocal8Bit();
-        char *buf = ba.data();
+        char* buf = ba.data();
         file.write(buf, ba.length());
         file.write("\n", 1);
         file.flush();
