@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,19 +34,22 @@ ProjectFilterTaskRegistry::~ProjectFilterTaskRegistry() {
     qDeleteAll(factories);
 }
 
-QList<AbstractProjectFilterTask *> ProjectFilterTaskRegistry::createFilterTasks(const ProjectTreeControllerModeSettings &settings,
-                                                                                const QList<QPointer<Document>> &docs) {
+QList<AbstractProjectFilterTask*> ProjectFilterTaskRegistry::createFilterTasks(const ProjectTreeControllerModeSettings& settings,
+                                                                               const QList<QPointer<Document>>& docs) {
     QMutexLocker guard(&lock);
 
-    QList<AbstractProjectFilterTask *> result;
-    foreach (ProjectFilterTaskFactory *factory, factories) {
-        result.append(factory->registerNewTask(settings, docs));
+    QList<AbstractProjectFilterTask*> result;
+    foreach (ProjectFilterTaskFactory* factory, factories) {
+        AbstractProjectFilterTask* filterTask = factory->registerNewTask(settings, docs);
+        if (filterTask != nullptr) {
+            result.append(filterTask);
+        }
     }
     return result;
 }
 
-void ProjectFilterTaskRegistry::registerTaskFactory(ProjectFilterTaskFactory *factory) {
-    SAFE_POINT(nullptr != factory, L10N::nullPointerError("Project filter task factory"), );
+void ProjectFilterTaskRegistry::registerTaskFactory(ProjectFilterTaskFactory* factory) {
+    SAFE_POINT_NN(factory, );
     SAFE_POINT(!factories.contains(factory), "Attempting to register a factory twice", );
 
     QMutexLocker guard(&lock);
