@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PROJECT_FILTER_TASK_REGISTRY_H_
-#define _U2_PROJECT_FILTER_TASK_REGISTRY_H_
+#pragma once
 
 #include <QMutex>
 
@@ -36,15 +35,13 @@ class U2CORE_EXPORT ProjectFilterTaskRegistry {
 public:
     virtual ~ProjectFilterTaskRegistry();
 
-    QList<AbstractProjectFilterTask *> createFilterTasks(const ProjectTreeControllerModeSettings &settings,
-                                                         const QList<QPointer<Document>> &docs);
-    void registerTaskFactory(ProjectFilterTaskFactory *factory);
+    QList<AbstractProjectFilterTask*> createFilterTasks(const ProjectTreeControllerModeSettings& settings,
+                                                        const QList<QPointer<Document>>& docs);
+    void registerTaskFactory(ProjectFilterTaskFactory* factory);
 
 private:
     QMutex lock;
-    QList<ProjectFilterTaskFactory *> factories;
+    QList<ProjectFilterTaskFactory*> factories;
 };
 
 }  // namespace U2
-
-#endif  // _U2_PROJECT_FILTER_TASK_REGISTRY_H_
