@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_RESOURCE_TRACKER_H_
-#define _U2_RESOURCE_TRACKER_H_
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -39,21 +38,20 @@ public:
     }
     ~ResourceTracker();
 
-    void registerResourceUser(const QString &resourceName, Task *t);
-    void unregisterResourceUser(const QString &resourceName, Task *t);
+    void registerResourceUser(const QString& resourceName, Task* t);
+    void unregisterResourceUser(const QString& resourceName, Task* t);
 
-    QList<Task *> getResourceUsers(const QString &resourceName);
+    QList<Task*> getResourceUsers(const QString& resourceName);
 
 signals:
-    void si_resourceUserRegistered(const QString &rName, Task *t);
-    void si_resourceUserUnregistered(const QString &rName, Task *t);
+    void si_resourceUserRegistered(const QString& rName, Task* t);
+    void si_resourceUserUnregistered(const QString& rName, Task* t);
 
 private:
-    typedef QList<Task *> TList;
+    typedef QList<Task*> TList;
     typedef QMap<QString, TList> RMap;
 
     RMap resMap;
 };
 
 }  // namespace U2
-#endif
