@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SCRIPTING_TOOL_REGISTRY_H
-#define _U2_SCRIPTING_TOOL_REGISTRY_H
+#pragma once
 
 #include <QMap>
 #include <QStringList>
@@ -34,7 +33,7 @@ class ExternalTool;
 class U2CORE_EXPORT ScriptingTool : public QObject {
     Q_OBJECT
 public:
-    ScriptingTool(const QString &id, const QString &name, const QString &path, const QStringList &runParams = QStringList());
+    ScriptingTool(const QString& id, const QString& name, const QString& path, const QStringList& runParams = QStringList());
 
     const QString getId() const {
         return id;
@@ -49,7 +48,7 @@ public:
         return runParams;
     }
 
-    static void onPathChanged(ExternalTool *tool, const QStringList &runParams = QStringList());
+    static void onPathChanged(ExternalTool* tool, const QStringList& runParams = QStringList());
 
 protected:
     QString id;
@@ -63,17 +62,16 @@ class U2CORE_EXPORT ScriptingToolRegistry : public QObject {
 public:
     ~ScriptingToolRegistry();
 
-    ScriptingTool *getById(const QString &id);
+    ScriptingTool* getById(const QString& id);
 
-    bool registerEntry(ScriptingTool *t);
-    void unregisterEntry(const QString &id);
+    bool registerEntry(ScriptingTool* t);
+    void unregisterEntry(const QString& id);
 
-    QList<ScriptingTool *> getAllEntries() const;
+    QList<ScriptingTool*> getAllEntries() const;
     QStringList getAllNames() const;
 
 protected:
-    QMap<QString, ScriptingTool *> registry;
+    QMap<QString, ScriptingTool*> registry;
 };
 
 }  // namespace U2
-#endif  // _U2_SCRIPTING_TOOL_REGISTRY_H
