@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SERVICE_TYPE_H_
-#define _U2_SERVICE_TYPE_H_
+#pragma once
 
 #include "ServiceModel.h"
 
@@ -45,5 +44,3 @@ const ServiceType Service_MinCoreServiceId = 500;
 const ServiceType Service_MaxCoreServiceId = 1000;
 
 }  // namespace U2
-
-#endif
