@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,14 +19,13 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TASK_H_
-#define _U2_TASK_H_
+#pragma once
 
 #include <QDateTime>
 #include <QPointer>
 #include <QReadWriteLock>
 #include <QStringList>
-#include <QVarLengthArray>
+#include <QVector>
 
 #include <U2Core/Log.h>
 #include <U2Core/U2OpStatus.h>
@@ -34,24 +33,25 @@
 
 namespace U2 {
 
+/** Constants to describe resource locking stage. */
+enum class U2CORE_EXPORT TaskResourceStage {
+    /** Resource must be locked before task->prepare() & released after successful task->report(). */
+    Prepare = 1,
+    /** Resource must be locked before task->run() & released after task->run(). */
+    Run = 2,
+};
+
 struct U2CORE_EXPORT TaskResourceUsage {
-    TaskResourceUsage(int id = 0, int use = 0, bool prepareStage = false)
-        : resourceId(id), resourceUse(use), prepareStageLock(prepareStage), locked(false) {
-    }
+    TaskResourceUsage(const QString& resourceId, int usage, const TaskResourceStage& stage);
+    TaskResourceUsage(const TaskResourceUsage& r) = default;
+    TaskResourceUsage& operator=(const TaskResourceUsage& r) = default;
 
-    enum UseType {
-        Read,
-        Write
-    };
+    QString resourceId;
+    int resourceUse = 0;
+    TaskResourceStage stage = TaskResourceStage::Prepare;
 
-    TaskResourceUsage(int id, UseType use, bool prepareStage = false)
-        : resourceId(id), resourceUse(use), prepareStageLock(prepareStage), locked(false) {
-    }
+    bool locked = false;
 
-    int resourceId;
-    int resourceUse;
-    bool prepareStageLock;
-    bool locked;
     /* Leave it empty for default message */
     QString errorMessage;
 };
@@ -72,55 +72,55 @@ public:
     int progress;
     int cancelFlag;
 
-    virtual bool hasError() const {
+    bool hasError() const override {
         return hasErr;
     }
-    virtual QString getError() const {
+    QString getError() const override {
         QReadLocker r(&lock);
         return error;
     }
-    virtual void setError(const QString &err) {
+    void setError(const QString& err) override {
         QWriteLocker w(&lock);
         error = err;
         hasErr = !error.isEmpty();
     }
 
-    virtual bool isCanceled() const {
+    bool isCanceled() const override {
         return cancelFlag;
     }
-    virtual void setCanceled(bool v) {
+    void setCanceled(bool v) override {
         cancelFlag = v;
     }
 
-    virtual int getProgress() const {
+    int getProgress() const override {
         return progress;
     }
-    virtual void setProgress(int v) {
+    void setProgress(int v) override {
         progress = v;
     }
 
-    virtual QString getDescription() const {
+    QString getDescription() const override {
         QReadLocker r(&lock);
         return desc;
     }
-    virtual void setDescription(const QString &_desc) {
+    void setDescription(const QString& _desc) override {
         QWriteLocker w(&lock);
         desc = _desc;
     }
 
-    virtual bool hasWarnings() const {
+    bool hasWarnings() const override {
         QReadLocker r(&lock);
         return !warnings.isEmpty();
     }
-    virtual QStringList getWarnings() const {
+    QStringList getWarnings() const override {
         QReadLocker r(&lock);
         return warnings;
     }
-    virtual void addWarning(const QString &warning);
-    virtual void addWarnings(const QStringList &wList);
+    void addWarning(const QString& warning) override;
+    void addWarnings(const QStringList& wList) override;
 
     /* The same as addWarnings() but it does not write to log. Used by TaskScheduler. */
-    void insertWarnings(const QStringList &wList);
+    void insertWarnings(const QStringList& wList);
 
 private:
     bool hasErr;
@@ -229,7 +229,12 @@ enum TaskFlag {
      * When set the global shutdown task will not ask user if to cancel the task or not.
      * The flag should be used for background service tasks.
      */
-    TaskFlag_SilentCancelOnShutdown = 1 << 29
+    TaskFlag_SilentCancelOnShutdown = 1 << 29,
+
+    /**
+     * Shutdown console application with error code in case of task error.
+     */
+    TaskFlag_FailCommandLineRunOnTaskError = 1 << 30
 };
 
 #define TaskFlags_FOSCOE (U2::TaskFlags(U2::TaskFlag_FailOnSubtaskError) | U2::TaskFlag_FailOnSubtaskCancel)
@@ -239,10 +244,8 @@ enum TaskFlag {
 // TODO: use this new alternative to FOSCOE, more logical: fail on error, cancel on cancel
 #define TaskFlags_FOSE_COSC (TaskFlags(TaskFlag_FailOnSubtaskError) | TaskFlag_CancelOnSubtaskCancel)
 #define TaskFlags_NR_FOSE_COSC (TaskFlags_FOSE_COSC | TaskFlag_NoRun)
-#define TaskFlags_RBSF_FOSE_COSC (TaskFlags_FOSE_COSC | TaskFlag_RunBeforeSubtasksFinished)
 
 Q_DECLARE_FLAGS(TaskFlags, TaskFlag)
-typedef QVarLengthArray<TaskResourceUsage, 1> TaskResources;
 
 class U2CORE_EXPORT Task : public QObject {
     Q_OBJECT
@@ -267,7 +270,7 @@ public:
     };
 
     // Creates new task with State_New state
-    Task(const QString &_name, TaskFlags f);
+    Task(const QString& _name, TaskFlags f);
 
     // Prepares Task to run
     // Task must request/prepare all resources it needs, create subtasks and define progress management type
@@ -297,8 +300,8 @@ public:
     }
 
     // Returns subtasks of the task. Task must prepare it's subtask on prepare() call and can't change them latter.
-    const QList<QPointer<Task>> &getSubtasks() const;
-    QList<Task *> getPureSubtasks() const;
+    const QList<QPointer<Task>>& getSubtasks() const;
+    QList<Task*> getPureSubtasks() const;
 
     QString getTaskName() const {
         return taskName;
@@ -308,11 +311,11 @@ public:
         return state;
     }
 
-    const TaskStateInfo &getStateInfo() const {
+    const TaskStateInfo& getStateInfo() const {
         return stateInfo;
     }
 
-    const TaskTimeInfo &getTimeInfo() const {
+    const TaskTimeInfo& getTimeInfo() const {
         return timeInfo;
     }
 
@@ -332,7 +335,7 @@ public:
         return flags & f;
     }
 
-    void addSubTask(Task *sub);
+    void addSubTask(Task* sub);
 
     bool hasError() const {
         return stateInfo.hasError();
@@ -379,21 +382,21 @@ public:
 
     virtual bool propagateSubtaskError();
 
-    virtual Task *getSubtaskWithErrors() const;
+    virtual Task* getSubtaskWithErrors() const;
 
     virtual qint64 getTaskId() const {
         return taskId;
     }
 
     virtual bool isTopLevelTask() const {
-        return getParentTask() == 0;
+        return getParentTask() == nullptr;
     }
 
-    virtual Task *getParentTask() const {
+    virtual Task* getParentTask() const {
         return parentTask;
     }
 
-    virtual Task *getTopLevelParentTask() {
+    virtual Task* getTopLevelParentTask() {
         return isTopLevelTask() ? this : parentTask->getTopLevelParentTask();
     }
 
@@ -482,7 +485,7 @@ public:
         setFlag(TaskFlag_ConcatenateChildrenErrors, v);
     }
 
-    const TaskResources &getTaskResources() {
+    const QVector<TaskResourceUsage>& getTaskResources() const {
         return taskResources;
     }
 
@@ -497,7 +500,7 @@ public:
 
     void setMaxParallelSubtasks(int n);
 
-    void setError(const QString &err) {
+    void setError(const QString& err) {
         stateInfo.setError(err);
     }
 
@@ -513,7 +516,7 @@ public:
         return timeInfo.timeOut;
     }
 
-    void addTaskResource(const TaskResourceUsage &r);
+    void addTaskResource(const TaskResourceUsage& r);
 
     bool isMinimizeSubtaskErrorText() const;
 
@@ -522,7 +525,7 @@ public slots:
     void cancel();
 
 signals:
-    void si_subtaskAdded(Task *sub);
+    void si_subtaskAdded(Task* sub);
 
     void si_progressChanged();
     void si_descriptionChanged();
@@ -530,13 +533,13 @@ signals:
 
 protected:
     /// Called by scheduler when subtask is finished.
-    virtual QList<Task *> onSubTaskFinished(Task *subTask);
-    void setRunResources(const TaskResources &taskR) {
+    virtual QList<Task*> onSubTaskFinished(Task* subTask);
+    void setRunResources(const QVector<TaskResourceUsage>& taskR) {
         assert(state <= State_Prepared);
         taskResources = taskR;
     }
 
-    void setTaskName(const QString &taskName);
+    void setTaskName(const QString& taskName);
 
     void setFlag(TaskFlag f, bool v) {
         flags = v ? (flags | f) : flags & (~f);
@@ -553,87 +556,81 @@ private:
     TaskFlags flags;
     QString taskName;
     State state;
-    Task *parentTask;
+    Task* parentTask;
     QList<QPointer<Task>> subtasks;
     qint64 taskId;
-    TaskResources taskResources;
+    QVector<TaskResourceUsage> taskResources;
     bool insidePrepare;
 };
 
 class U2CORE_EXPORT TaskScheduler : public QObject {
     Q_OBJECT
 public:
-    virtual void registerTopLevelTask(Task *t) = 0;
+    virtual void registerTopLevelTask(Task* t) = 0;
 
-    virtual void unregisterTopLevelTask(Task *t) = 0;
+    virtual void unregisterTopLevelTask(Task* t) = 0;
 
-    virtual const QList<Task *> &getTopLevelTasks() const = 0;
-
-    virtual Task *getTopLevelTaskById(qint64 id) const = 0;
-
-    virtual QDateTime estimatedFinishTime(Task *) const = 0;
+    virtual const QList<Task*>& getTopLevelTasks() const = 0;
 
     virtual void cancelAllTasks() = 0;
 
-    virtual QString getStateName(Task *t) const = 0;
+    virtual QString getStateName(Task* t) const = 0;
 
     virtual void addThreadId(qint64 taskId, Qt::HANDLE id) = 0;
 
     virtual void removeThreadId(qint64 taskId) = 0;
 
-    virtual qint64 getNameByThreadId(Qt::HANDLE id) const = 0;
+    virtual void pauseThreadWithTask(const Task* task) = 0;
 
-    virtual void pauseThreadWithTask(const Task *task) = 0;
+    virtual void resumeThreadWithTask(const Task* task) = 0;
 
-    virtual void resumeThreadWithTask(const Task *task) = 0;
+    /**
+     * Returns true if the caller method is inside task processing callback (signal).
+     * This method is used to check if it is safe to run a message loop (or a modal dialog) with no side-effects for tasks.
+     */
+    virtual bool isCallerInsideTaskSchedulerCallback() const = 0;
 
 signals:
-    void si_noTasksInScheduler();
-    void si_ugeneIsReadyToWork();
+    void si_topLevelTaskRegistered(Task*);
+
+    void si_topLevelTaskUnregistered(Task*);
+
+    void si_stateChanged(Task* task);
 
 protected:
-    TaskResources &getTaskResources(Task *t) {
+    QVector<TaskResourceUsage>& getTaskResources(Task* t) {
         return t->taskResources;
     }
 
-    TaskStateInfo &getTaskStateInfo(Task *t) {
+    TaskStateInfo& getTaskStateInfo(Task* t) {
         return t->stateInfo;
     }
 
-    TaskTimeInfo &getTaskTimeInfo(Task *t) {
+    TaskTimeInfo& getTaskTimeInfo(Task* t) {
         return t->timeInfo;
     }
 
-    void emit_taskProgressChanged(Task *t) {
+    void emit_taskProgressChanged(Task* t) {
         emit t->si_progressChanged();
     }
 
-    void emit_taskDescriptionChanged(Task *t) {
+    void emit_taskDescriptionChanged(Task* t) {
         emit t->si_descriptionChanged();
     }
 
-    QList<Task *> onSubTaskFinished(Task *parentTask, Task *subTask) {
+    QList<Task*> onSubTaskFinished(Task* parentTask, Task* subTask) {
         return parentTask->onSubTaskFinished(subTask);
     }
 
-    void addSubTask(Task *t, Task *sub);
+    void addSubTask(Task* t, Task* sub);
 
-    void setTaskState(Task *t, Task::State newState);
+    void setTaskState(Task* task, Task::State newState);
 
-    void setTaskStateDesc(Task *t, const QString &desc);
+    void setTaskStateDesc(Task* t, const QString& desc);
 
-    void setTaskInsidePrepare(Task *t, bool val);
-
-signals:
-    void si_topLevelTaskRegistered(Task *);
-
-    void si_topLevelTaskUnregistered(Task *);
-
-    void si_stateChanged(Task *task);
+    void setTaskInsidePrepare(Task* t, bool val);
 };
 
 }  // namespace U2
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(U2::TaskFlags)
-
-#endif
