@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_THEME_H_
-#define _U2_THEME_H_
+#pragma once
 
 #include <QColor>
 
@@ -79,5 +78,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
