@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OPSTATUS_H_
-#define _U2_OPSTATUS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -36,7 +35,7 @@ public:
     virtual ~U2OpStatus() {
     }
 
-    virtual void setError(const QString &err) = 0;
+    virtual void setError(const QString& err) = 0;
     virtual QString getError() const = 0;
     virtual bool hasError() const = 0;
 
@@ -52,14 +51,12 @@ public:
     virtual void setProgress(int v) = 0;
 
     virtual QString getDescription() const = 0;
-    virtual void setDescription(const QString &desc) = 0;
+    virtual void setDescription(const QString& desc) = 0;
 
     virtual bool hasWarnings() const = 0;
     virtual QStringList getWarnings() const = 0;
-    virtual void addWarning(const QString &w) = 0;
-    virtual void addWarnings(const QStringList &wList) = 0;
+    virtual void addWarning(const QString& w) = 0;
+    virtual void addWarnings(const QStringList& wList) = 0;
 };
 
 }  // namespace U2
-
-#endif
