@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,12 +27,25 @@
 
     NOTE: all checks below work in release mode. Be careful not to make code slow!
 */
-#ifndef _U2_SAFE_POINTS_
-#define _U2_SAFE_POINTS_
+#pragma once
 
 #include <assert.h>
 
-#include <U2Core/Log.h>
+#include <U2Core/global.h>
+
+namespace U2 {
+/** Safe points related utility methods. */
+class U2CORE_EXPORT U2SafePoints {
+public:
+    /**
+     * Prints error message into the core-log & calls 'assert(false)'.
+     * If UGENE runs in release mode with asserts disabled this function will not stop the control flow,
+     * but if GUI or XML tests mode is enabled the function will make UGENE to stop (call std::abort)
+     * after printing the message.
+     */
+    static void fail(const QString& message);
+};
+}  // namespace U2
 
 /**
     Recover utility. Must be used when code tries to recover from invalid internal state
@@ -44,8 +57,7 @@
 */
 #define SAFE_POINT(condition, message, result) \
     if (Q_UNLIKELY(!(condition))) { \
-        U2::coreLog.error(QString("Trying to recover from error: %1 at %2:%3").arg(message).arg(__FILE__).arg(__LINE__)); \
-        assert(condition); \
+        U2::U2SafePoints::fail(QString("Trying to recover from error: %1 at %2:%3").arg(message).arg(__FILE__).arg(__LINE__)); \
         return result; \
     }
 
@@ -60,8 +72,7 @@
 */
 #define SAFE_POINT_OP(os, result) \
     if (Q_UNLIKELY(os.hasError())) { \
-        U2::coreLog.error(QString("Trying to recover from error: %1 at %2:%3").arg(os.getError()).arg(__FILE__).arg(__LINE__)); \
-        assert(0); \
+        U2::U2SafePoints::fail(QString("Trying to recover from error: %1 at %2:%3").arg(os.getError()).arg(__FILE__).arg(__LINE__)); \
         return result; \
     }
 
@@ -75,94 +86,70 @@
 */
 #define SAFE_POINT_EXT(condition, extraOp, result) \
     if (Q_UNLIKELY(!(condition))) { \
-        assert(condition); \
+        QString message = U2_TOSTRING(condition); \
+        U2::U2SafePoints::fail(QString("Trying to recover from error: %1 at %2:%3").arg(message).arg(__FILE__).arg(__LINE__)); \
         extraOp; \
         return result; \
     }
 
+/** Asserts that the passed statement is not nullptr. */
+#define SAFE_POINT_NN(statement, result) \
+    if (Q_UNLIKELY((statement) == nullptr)) { \
+        QString message = U2_TOSTRING(statement); \
+        U2::U2SafePoints::fail(QString("Trying to recover from nullptr error: %1 at %2:%3").arg(message).arg(__FILE__).arg(__LINE__)); \
+        return result; \
+    }
+
 /**
     FAIL utility. Same as SAFE_POINT but uses unconditional fail.
     Can be used in code that must be unreachable
 */
 #define FAIL(message, result) \
-    U2::coreLog.error(QString("Trying to recover from error: %1 at %2:%3").arg(message).arg(__FILE__).arg(__LINE__)); \
-    assert(0); \
+    U2::U2SafePoints::fail(QString("Trying to recover from error: %1 at %2:%3").arg(message).arg(__FILE__).arg(__LINE__)); \
     return result;
 
 /**
-    Checks condition is false and returns the result if it is
-
-    Code style hint: use CHECK macro only to make error processing more compact but not all if {return;} patterns !
-*/
-#define CHECK(condition, result) \
+ * Checks condition and runs the extra op if the condition is falsy.
+ * Do not use directly: designed to be used as a low level implementation for other utilities.
+ */
+#define RUN_IF_FALTHY_1(condition, extraOp) \
     if (!(condition)) { \
-        return result; \
+        extraOp; \
     }
 
 /**
-    Checks condition is false and performs a sequence of operations if it is.
-
-    Code style hint: use CHECK macro only to make error processing more compact but not all if {operation1; operation2;} patterns !
-*/
-#define CHECK_OPERATIONS(condition, extraOp1, extraOp2) \
+ * Checks condition and runs 2 extra ops if the condition is falsy.
+ * Do not use directly: designed to be used as a low level implementation for other utilities.
+ */
+#define RUN_IF_FALTHY_2(condition, extraOp1, extraOp2) \
     if (!(condition)) { \
         extraOp1; \
         extraOp2; \
     }
 
-/**
-    Checks condition is false and performs an operation if it is.
+/** Checks 'condition' and returns if result is 'false'. */
+#define CHECK(condition, result) RUN_IF_FALTHY_1(condition, return result)
 
-    Code style hint: use CHECK macro only to make error processing more compact but not all if {operation;} patterns !
-*/
-#define CHECK_OPERATION(condition, extraOp) CHECK_OPERATIONS(condition, extraOp, )
+/** Checks 'condition' and calls 'break' if 'condition' is 'false'. */
+#define CHECK_BREAK(condition) RUN_IF_FALTHY_1(condition, break)
 
-/**
-    Checks condition is false and breaks if it is.
+/** Checks 'condition' and calls 'continue' if 'condition' is 'false'. */
+#define CHECK_CONTINUE(condition) RUN_IF_FALTHY_1(condition, continue)
 
-    Code style hint: use CHECK macro only to make error processing more compact but not all if {break;} patterns !
-*/
-#define CHECK_BREAK(condition) CHECK_OPERATION(condition, break)
+/** Checks 'condition' and executes 'extraOp' and returns 'result' if 'condition' is 'false'. */
+#define CHECK_EXT(condition, extraOp, result) RUN_IF_FALTHY_2(condition, extraOp, return result)
 
-/**
-    Checks condition is false and continue the cycle if it is.
-*/
-#define CHECK_CONTINUE(condition) CHECK_OPERATION(condition, continue)
+/** Checks 'condition' and executes 'extraOp' and calls 'break' if 'condition' is 'false'. */
+#define CHECK_EXT_BREAK(condition, extraOp) RUN_IF_FALTHY_2(condition, extraOp, break)
 
-/**
-    Checks condition is false and breaks if it is.
-    Before breaking the 'extraOp' operation is performed (for example logging)
+/** Checks 'condition' and calls 'extraOp' and 'continue' if 'condition' is 'false'. */
+#define CHECK_EXT_CONTINUE(condition, extraOp) RUN_IF_FALTHY_2(condition, extraOp, continue)
 
-    Code style hint: use CHECK macro only to make error processing more compact but not all if {operation; break;} patterns !
-*/
-#define CHECK_EXT_BREAK(condition, extraOp) CHECK_OPERATIONS(condition, extraOp, break)
-
-/**
-    Checks condition is false and returns the result if it is.
-    Before the result is returned the 'extraOp' operation is performed (for example logging)
-
-    Code style hint: use CHECK macro only to make error processing more compact but not all if {return;} patterns !
-*/
-#define CHECK_EXT(condition, extraOp, result) \
-    if (!(condition)) { \
-        extraOp; \
-        return result; \
-    }
-
-/**
-    Checks that operation is neither not failed nor canceled and returns the result if it does
-*/
+/** Checks if 'os' has error or is cancelled and returns 'result' if it does. */
 #define CHECK_OP(os, result) CHECK(!os.isCoR(), result)
 
-/**
-    Checks that operation is neither not failed nor canceled and breaks if it does
-*/
+/** Checks if 'os' has error or is cancelled and calls 'break' if it does. */
 #define CHECK_OP_BREAK(os) CHECK_BREAK(!os.isCoR())
 
-/**
-    Checks that operation is neither failed nor canceled and returns the result if it does.
-    Before the result is returned the 'extraOp' operation is performed (for example logging)
-*/
+/** Checks if 'os' has error or is cancelled and executes 'extraOp' and returns 'result' if it does. */
 #define CHECK_OP_EXT(os, extraOp, result) CHECK_EXT(!(os.isCoR()), extraOp, result)
-
-#endif
