@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_COREAPI_H_
-#define _U2_COREAPI_H_
+#pragma once
 
 #include <assert.h>
 
@@ -107,6 +106,7 @@
 #define ENV_USE_CRASH_HANDLER "UGENE_USE_CRASH_HANDLER"
 #define ENV_TEST_CRASH_HANDLER "UGENE_TEST_CRASH_HANDLER"
 #define ENV_SEND_CRASH_REPORTS "UGENE_SEND_CRASH_REPORTS"
+#define ENV_TEST_NOTIFICATIONS "UGENE_TEST_NOTIFICATIONS"
 #define ENV_UGENE_DEV "UGENE_DEV"
 #define ENV_GUI_TEST "UGENE_GUI_TEST"
 #define ENV_USE_NATIVE_DIALOGS "UGENE_USE_NATIVE_DIALOGS"
@@ -120,6 +120,9 @@
 #define PATH_PREFIX_DATA "data"
 #define PATH_PREFIX_SCRIPTS "scripts"
 
+#define U2_STRINGIFY(x) #x
+#define U2_TOSTRING(x) U2_STRINGIFY(x)
+
 namespace U2 {
 
 enum TriState {
@@ -200,15 +203,3 @@ inline bool isOsUnix() {
     return false;
 #endif
 }
-
-/** Backport of qAsConst for QT < 5.7.0. */
-#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0))
-template<typename T>
-Q_DECL_CONSTEXPR typename std::add_const<T>::type &qAsConst(T &t) noexcept {
-    return t;
-}
-template<typename T>
-void qAsConst(const T &&) = delete;
-#endif
-
-#endif
