@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BIOSTRUCT3D_OBJECT_H_
-#define _U2_BIOSTRUCT3D_OBJECT_H_
+#pragma once
 
 #include <U2Core/BioStruct3D.h>
 #include <U2Core/GObject.h>
@@ -31,7 +30,7 @@ namespace U2 {
 class U2CORE_EXPORT U2BioStruct3D : public U2RawData {
 public:
     U2BioStruct3D();
-    U2BioStruct3D(const U2DbiRef &dbiRef);
+    U2BioStruct3D(const U2DbiRef& dbiRef);
 
     U2DataType getType() const;
 };
@@ -39,21 +38,19 @@ public:
 class U2CORE_EXPORT BioStruct3DObject : public GObject {
     Q_OBJECT
 public:
-    static BioStruct3DObject *createInstance(const BioStruct3D &bioStruct3D, const QString &objectName, const U2DbiRef &dbiRef, U2OpStatus &os, const QVariantMap &hintsMap = QVariantMap());
-    BioStruct3DObject(const QString &objectName, const U2EntityRef &structRef, const QVariantMap &hintsMap = QVariantMap());
+    static BioStruct3DObject* createInstance(const BioStruct3D& bioStruct3D, const QString& objectName, const U2DbiRef& dbiRef, U2OpStatus& os, const QVariantMap& hintsMap = QVariantMap());
+    BioStruct3DObject(const QString& objectName, const U2EntityRef& structRef, const QVariantMap& hintsMap = QVariantMap());
 
-    const BioStruct3D &getBioStruct3D() const;
-    GObject *clone(const U2DbiRef &dstDbiRef, U2OpStatus &os, const QVariantMap &hints = QVariantMap()) const;
+    const BioStruct3D& getBioStruct3D() const;
+    GObject* clone(const U2DbiRef& dstDbiRef, U2OpStatus& os, const QVariantMap& hints = QVariantMap()) const;
 
 protected:
-    void loadDataCore(U2OpStatus &os);
+    void loadDataCore(U2OpStatus& os);
 
 private:
-    BioStruct3DObject(const BioStruct3D &bioStruct3D, const QString &objectName, const U2EntityRef &structRef, const QVariantMap &hintsMap);
+    BioStruct3DObject(const BioStruct3D& bioStruct3D, const QString& objectName, const U2EntityRef& structRef, const QVariantMap& hintsMap);
 
     BioStruct3D bioStruct3D;
 };
 
 }  // namespace U2
-
-#endif  //_U2_BIOSTRUCT3D_OBJECT_H_
