@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +24,6 @@
 #include <QApplication>
 
 #include <U2Core/AppContext.h>
-#include <U2Core/AppResources.h>
 #include <U2Core/DocumentModel.h>
 #include <U2Core/GHints.h>
 #include <U2Core/U2AlphabetUtils.h>
@@ -41,20 +40,20 @@
 namespace U2 {
 
 #define NO_LENGTH_CONSTRAINT -1
-U2SequenceObjectConstraints::U2SequenceObjectConstraints(QObject *p)
+U2SequenceObjectConstraints::U2SequenceObjectConstraints(QObject* p)
     : GObjectConstraints(GObjectTypes::SEQUENCE, p), sequenceSize(NO_LENGTH_CONSTRAINT) {
 }
 
 //////////////////////////////////////////////////////////////////////////
 // U2SequenceObject
 
-U2SequenceObject::U2SequenceObject(const QString &name, const U2EntityRef &seqRef, const QVariantMap &hintsMap)
+U2SequenceObject::U2SequenceObject(const QString& name, const U2EntityRef& seqRef, const QVariantMap& hintsMap)
     : GObject(GObjectTypes::SEQUENCE, name, hintsMap), cachedAlphabet(nullptr), cachedLength(-1), cachedCircular(TriState_Unknown) {
     entityRef = seqRef;
 }
 
-bool U2SequenceObject::checkConstraints(const GObjectConstraints *c) const {
-    const U2SequenceObjectConstraints *dnac = qobject_cast<const U2SequenceObjectConstraints *>(c);
+bool U2SequenceObject::checkConstraints(const GObjectConstraints* c) const {
+    auto dnac = qobject_cast<const U2SequenceObjectConstraints*>(c);
     SAFE_POINT(dnac != nullptr, "Not a U2SequenceObjectConstraints!", false);
 
     if (dnac->sequenceSize != NO_LENGTH_CONSTRAINT) {
@@ -64,7 +63,7 @@ bool U2SequenceObject::checkConstraints(const GObjectConstraints *c) const {
         }
     }
     if (dnac->alphabetType != DNAAlphabet_RAW) {
-        const DNAAlphabet *dalphabet = getAlphabet();
+        const DNAAlphabet* dalphabet = getAlphabet();
         SAFE_POINT(dalphabet != nullptr, "U2SequenceObject::no alphabet", false);
         DNAAlphabetType aType = dalphabet->getType();
         if (dnac->alphabetType != aType) {
@@ -97,14 +96,16 @@ QString U2SequenceObject::getSequenceName() const {
         seqGet = true; \
     }
 
-DNASequence U2SequenceObject::getSequence(const U2Region &region, U2OpStatus &os) const {
+DNASequence U2SequenceObject::getSequence(const U2Region& region, U2OpStatus& os) const {
     U2Sequence seq;
     bool seqGet = false;
 
-    const DNAAlphabet *alpha = cachedAlphabet;
+    const DNAAlphabet* alpha = cachedAlphabet;
     if (!cachedAlphabet) {
         FETCH_SEQUENCE(seqGet, seq, entityRef);
-        cachedAlphabet = alpha = U2AlphabetUtils::getById(seq.alphabet);
+        alpha = U2AlphabetUtils::getById(seq.alphabet);
+        cachedAlphabet = alpha;
+        CHECK_EXT(alpha != nullptr, os.setError(tr("Failed to derive sequence alphabet: ") + getGObjectName()), {});
     }
     QString seqName = cachedName;
     if (cachedName.isEmpty()) {
@@ -125,11 +126,11 @@ DNASequence U2SequenceObject::getSequence(const U2Region &region, U2OpStatus &os
     return res;
 }
 
-DNASequence U2SequenceObject::getWholeSequence(U2OpStatus &os) const {
+DNASequence U2SequenceObject::getWholeSequence(U2OpStatus& os) const {
     return getSequence(U2_REGION_MAX, os);
 }
 
-QByteArray U2SequenceObject::getWholeSequenceData(U2OpStatus &os) const {
+QByteArray U2SequenceObject::getWholeSequenceData(U2OpStatus& os) const {
     return getSequenceData(U2_REGION_MAX, os);
 }
 
@@ -140,14 +141,14 @@ bool U2SequenceObject::isCircular() const {
     return cachedCircular == TriState_Yes;
 }
 
-const DNAAlphabet *U2SequenceObject::getAlphabet() const {
+const DNAAlphabet* U2SequenceObject::getAlphabet() const {
     if (cachedAlphabet == nullptr) {
         updateCachedValues();
     }
     return cachedAlphabet;
 }
 
-void U2SequenceObject::setWholeSequence(const DNASequence &seq) {
+void U2SequenceObject::setWholeSequence(const DNASequence& seq) {
     U2OpStatus2Log os;
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, );
@@ -163,14 +164,14 @@ void U2SequenceObject::setWholeSequence(const DNASequence &seq) {
     emit si_sequenceChanged();
 }
 
-QByteArray U2SequenceObject::getSequenceData(const U2Region &r) const {
+QByteArray U2SequenceObject::getSequenceData(const U2Region& r) const {
     U2OpStatus2Log os;
     const QByteArray res = getSequenceData(r, os);
     SAFE_POINT_OP(os, QByteArray());
     return res;
 }
 
-QByteArray U2SequenceObject::getSequenceData(const U2Region &r, U2OpStatus &os) const {
+QByteArray U2SequenceObject::getSequenceData(const U2Region& r, U2OpStatus& os) const {
     if (!cachedLastAccessedRegion.first.contains(r)) {
         DbiConnection con(entityRef.dbiRef, os);
         CHECK_OP(os, QByteArray());
@@ -186,7 +187,7 @@ QByteArray U2SequenceObject::getSequenceData(const U2Region &r, U2OpStatus &os)
     return cachedLastAccessedRegion.second.mid(r.startPos - cachedLastAccessedRegion.first.startPos, r.length);
 }
 
-bool U2SequenceObject::isValidDbiObject(U2OpStatus &os) {
+bool U2SequenceObject::isValidDbiObject(U2OpStatus& os) {
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, false);
     U2Sequence s = con.dbi->getSequenceDbi()->getSequenceObject(entityRef.entityId, os);
@@ -198,11 +199,11 @@ bool U2SequenceObject::isValidDbiObject(U2OpStatus &os) {
     return true;
 }
 
-void U2SequenceObject::replaceRegion(const U2Region &region, const DNASequence &seq, U2OpStatus &os) {
+void U2SequenceObject::replaceRegion(const U2Region& region, const DNASequence& seq, U2OpStatus& os) {
     replaceRegion(entityRef.entityId, region, seq, os);
 }
 
-void U2SequenceObject::replaceRegion(const U2DataId &masterId, const U2Region &region, const DNASequence &seq, U2OpStatus &os) {
+void U2SequenceObject::replaceRegion(const U2DataId& masterId, const U2Region& region, const DNASequence& seq, U2OpStatus& os) {
     // seq.alphabet == NULL - for tests.
     CHECK_EXT(seq.alphabet == getAlphabet() || seq.seq.isEmpty() || seq.alphabet == nullptr,
               os.setError(tr("Modified sequence & region have different alphabet")), );
@@ -219,11 +220,11 @@ void U2SequenceObject::replaceRegion(const U2DataId &masterId, const U2Region &r
     emit si_sequenceChanged();
 }
 
-void U2SequenceObject::removeRegion(U2OpStatus &os, const U2Region &region) {
+void U2SequenceObject::removeRegion(U2OpStatus& os, const U2Region& region) {
     replaceRegion(region, DNASequence(), os);
 }
 
-GObject *U2SequenceObject::clone(const U2DbiRef &dbiRef, U2OpStatus &os, const QVariantMap &hints) const {
+GObject* U2SequenceObject::clone(const U2DbiRef& dbiRef, U2OpStatus& os, const QVariantMap& hints) const {
     DbiOperationsBlock opBlock(dbiRef, os);
     CHECK_OP(os, nullptr);
 
@@ -234,12 +235,12 @@ GObject *U2SequenceObject::clone(const U2DbiRef &dbiRef, U2OpStatus &os, const Q
 
     GHintsDefaultImpl gHints(getGHintsMap());
     gHints.setAll(hints);
-    const QString &dstFolder = gHints.get(DocumentFormat::DBI_FOLDER_HINT, U2ObjectDbi::ROOT_FOLDER).toString();
+    const QString& dstFolder = gHints.get(DocumentFormat::DBI_FOLDER_HINT, U2ObjectDbi::ROOT_FOLDER).toString();
 
     U2Sequence seq = U2SequenceUtils::copySequence(entityRef, dbiRef, dstFolder, os);
     CHECK_OP(os, nullptr);
 
-    U2SequenceObject *res = new U2SequenceObject(seq.visualName, U2EntityRef(dbiRef, seq.id), gHints.getMap());
+    U2SequenceObject* res = new U2SequenceObject(seq.visualName, U2EntityRef(dbiRef, seq.id), gHints.getMap());
 
     U2AttributeUtils::copyObjectAttributes(entityRef.entityId, seq.id, srcCon.dbi->getAttributeDbi(), dstCon.dbi->getAttributeDbi(), os);
     CHECK_OP(os, nullptr);
@@ -265,7 +266,7 @@ void U2SequenceObject::setCircular(bool isCircular) {
     emit si_sequenceCircularStateChanged();
 }
 
-void U2SequenceObject::setQuality(const DNAQuality &q) {
+void U2SequenceObject::setQuality(const DNAQuality& q) {
     U2SequenceUtils::setQuality(entityRef, q);
 }
 
@@ -287,7 +288,7 @@ DNAQuality U2SequenceObject::getQuality() const {
     return res;
 }
 
-void U2SequenceObject::setSequenceInfo(const QVariantMap &info) {
+void U2SequenceObject::setSequenceInfo(const QVariantMap& info) {
     U2OpStatus2Log os;
     U2SequenceUtils::setSequenceInfo(os, entityRef, info);
     CHECK_OP(os, );
@@ -301,12 +302,12 @@ QVariantMap U2SequenceObject::getSequenceInfo() const {
     return variantMap;
 }
 
-QString U2SequenceObject::getStringAttribute(const QString &name) const {
+QString U2SequenceObject::getStringAttribute(const QString& name) const {
     // TODO: Re-check all usages and start using real attributes from DBI!
     return getSequenceInfo().value(name).toString();
 }
 
-void U2SequenceObject::setStringAttribute(const QString &name, const QString &value) {
+void U2SequenceObject::setStringAttribute(const QString& name, const QString& value) {
     U2OpStatus2Log os;
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, );
@@ -321,12 +322,12 @@ void U2SequenceObject::setStringAttribute(const QString &name, const QString &va
     CHECK_OP(os, );
 }
 
-qint64 U2SequenceObject::getIntegerAttribute(const QString &name) const {
+qint64 U2SequenceObject::getIntegerAttribute(const QString& name) const {
     U2OpStatus2Log os;
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, 0);
 
-    U2AttributeDbi *attributeDbi = con.dbi->getAttributeDbi();
+    U2AttributeDbi* attributeDbi = con.dbi->getAttributeDbi();
     QList<U2DataId> attributeList = attributeDbi->getObjectAttributes(entityRef.entityId, name, os);
     CHECK_OP(os, 0);
     CHECK(!attributeList.isEmpty(), 0);
@@ -336,7 +337,7 @@ qint64 U2SequenceObject::getIntegerAttribute(const QString &name) const {
     return attribute.value;
 }
 
-void U2SequenceObject::setIntegerAttribute(const QString &name, int value) {
+void U2SequenceObject::setIntegerAttribute(const QString& name, int value) {
     U2OpStatus2Log os;
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, );
@@ -351,12 +352,12 @@ void U2SequenceObject::setIntegerAttribute(const QString &name, int value) {
     CHECK_OP(os, );
 }
 
-double U2SequenceObject::getRealAttribute(const QString &name) const {
+double U2SequenceObject::getRealAttribute(const QString& name) const {
     // TODO: Re-check all usages and start using real attributes from DBI!
     return getSequenceInfo().value(name).toReal();
 }
 
-void U2SequenceObject::setRealAttribute(const QString &name, double value) {
+void U2SequenceObject::setRealAttribute(const QString& name, double value) {
     U2OpStatus2Log os;
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, );
@@ -371,12 +372,12 @@ void U2SequenceObject::setRealAttribute(const QString &name, double value) {
     CHECK_OP(os, );
 }
 
-QByteArray U2SequenceObject::getByteArrayAttribute(const QString &name) const {
+QByteArray U2SequenceObject::getByteArrayAttribute(const QString& name) const {
     // TODO: Re-check all usages and start using real attributes from DBI!
     return getSequenceInfo().value(name).toByteArray();
 }
 
-void U2SequenceObject::setByteArrayAttribute(const QString &name, const QByteArray &value) {
+void U2SequenceObject::setByteArrayAttribute(const QString& name, const QByteArray& value) {
     U2OpStatus2Log os;
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, );
@@ -411,7 +412,7 @@ void U2SequenceObject::sl_resetDataCaches() {
     cachedLength = -1;
 }
 
-void U2SequenceObject::setGObjectName(const QString &newName) {
+void U2SequenceObject::setGObjectName(const QString& newName) {
     CHECK(cachedName != newName, );
 
     GObject::setGObjectName(newName);
