@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GOBJECT_RELATION_ROLES_H_
-#define _U2_GOBJECT_RELATION_ROLES_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -39,9 +38,7 @@ enum GObjectRelationRole {
 class GObjectRelationRoleCompatibility {
 public:
     static QString toString(GObjectRelationRole role);
-    static GObjectRelationRole fromString(const QString &str);
+    static GObjectRelationRole fromString(const QString& str);
 };
 
 }  // namespace U2
-
-#endif
