@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MULTIPLE_ALIGNMENT_OBJECT_H_
-#define _U2_MULTIPLE_ALIGNMENT_OBJECT_H_
+#pragma once
 
 #include <U2Core/GObject.h>
 #include <U2Core/MaModificationInfo.h>
@@ -35,79 +34,79 @@ public:
 
     bool hasState() const;
     const MultipleAlignment takeState();
-    void setState(const MultipleAlignment &ma);
+    void setState(const MultipleAlignment& ma);
 
 private:
-    MultipleAlignment *lastState;
+    MultipleAlignment* lastState;
 };
 
 class U2CORE_EXPORT MultipleAlignmentObject : public GObject {
     Q_OBJECT
 public:
-    MultipleAlignmentObject(const QString &gobjectType,
-                            const QString &name,
-                            const U2EntityRef &maRef,
-                            const QVariantMap &hintsMap,
-                            const MultipleAlignment &alignment);
+    MultipleAlignmentObject(const QString& gobjectType,
+                            const QString& name,
+                            const U2EntityRef& maRef,
+                            const QVariantMap& hintsMap,
+                            const MultipleAlignment& alignment);
     ~MultipleAlignmentObject();
 
     /** Sets type of modifications tracking for the alignment */
-    void setTrackMod(U2OpStatus &os, U2TrackModType trackMod);
+    void setTrackMod(U2OpStatus& os, U2TrackModType trackMod);
 
-    const MultipleAlignment &getMultipleAlignment() const;
-    void setMultipleAlignment(const MultipleAlignment &ma, MaModificationInfo mi = MaModificationInfo(), const QVariantMap &hints = QVariantMap());
+    const MultipleAlignment& getMultipleAlignment() const;
+    void setMultipleAlignment(const MultipleAlignment& ma, MaModificationInfo mi = MaModificationInfo(), const QVariantMap& hints = QVariantMap());
 
     const MultipleAlignment getMultipleAlignmentCopy() const;
 
     /** GObject methods */
-    void setGObjectName(const QString &newName);
+    void setGObjectName(const QString& newName);
 
     /** Const getters */
-    const DNAAlphabet *getAlphabet() const;
+    const DNAAlphabet* getAlphabet() const;
     qint64 getLength() const;
-    qint64 getNumRows() const;
-    const QList<MultipleAlignmentRow> &getRows() const;
+    qint64 getRowCount() const;
+    const QList<MultipleAlignmentRow>& getRows() const;
     const MultipleAlignmentRow getRow(int row) const;
     int getRowPosById(qint64 rowId) const;
     virtual char charAt(int seqNum, qint64 position) const = 0;
 
-    U2MsaListGapModel getGapModel() const;
+    QList<QVector<U2MsaGap>> getGapModel() const;
 
     /**
      * Converts MA indexes into ids.
      * If index is out of range and 'excludeErrors' is false appends '-1' to the result list.
      */
-    QList<qint64> convertMaRowIndexesToMaRowIds(const QList<int> &maRowIndexes, bool excludeErrors = true);
+    QList<qint64> convertMaRowIndexesToMaRowIds(const QList<int>& maRowIndexes, bool excludeErrors = true);
 
     /**
      * Converts MA ids into indexes.
      * If id is invalid and 'excludeErrors' is false appends '-1' to the result list.
      */
-    QList<int> convertMaRowIdsToMaRowIndexes(const QList<qint64> &maRowIds, bool excludeErrors = true);
+    QList<int> convertMaRowIdsToMaRowIndexes(const QList<qint64>& maRowIds, bool excludeErrors = true);
 
     /** Removes single row from the alignment by row index. */
     void removeRow(int rowIdx);
 
     /** Removes all rows from the list from the alignment by row indexes. */
-    void removeRows(const QList<int> &rowIndexes);
+    void removeRows(const QList<int>& rowIndexes);
 
     /** Removes all rows with the given ids from the alignment. */
-    void removeRowsById(const QList<qint64> &rowIds);
+    void removeRowsById(const QList<qint64>& rowIds);
 
     /** Removes columns region from all rows in the list. */
-    void removeRegion(const QList<int> &rowIndexes, int x, int width, bool removeEmptyRows);
+    void removeRegion(const QList<int>& rowIndexes, int x, int width, bool removeEmptyRows);
 
     /** Method that affect the whole alignment, including sequences */
     void removeRegion(int startPos, int startRow, int nBases, int nRows, bool removeEmptyRows, bool track = true);
 
     /** Renames row with a given index. */
-    void renameRow(int rowIdx, const QString &newName);
+    void renameRow(int rowIdx, const QString& newName);
 
     void moveRowsBlock(int firstRow, int numRows, int delta);
 
     bool isRegionEmpty(int x, int y, int width, int height) const;
 
-    bool isRegionEmpty(const QList<int> &rowIndexes, int x, int width) const;
+    bool isRegionEmpty(const QList<int>& rowIndexes, int x, int width) const;
 
     /** Returns list of ordered row ids. */
     QList<qint64> getRowIds() const;
@@ -116,31 +115,31 @@ public:
      * Returns list of row ids for the given row indexes.
      * Returns empty list if some row index is out of range.
      */
-    QList<qint64> getRowIdsByRowIndexes(const QList<int> &rowIndexes) const;
+    QList<qint64> getRowIdsByRowIndexes(const QList<int>& rowIndexes) const;
 
     /**
      * Updates the rows order.
      * There must be one-to-one correspondence between the specified rows IDs
      * and rows IDs of the alignment.
      */
-    void updateRowsOrder(U2OpStatus &os, const QList<qint64> &rowIds);
+    void updateRowsOrder(U2OpStatus& os, const QList<qint64>& rowIds);
 
-    void changeLength(U2OpStatus &os, qint64 newLength);
+    void changeLength(U2OpStatus& os, qint64 newLength);
 
-    void updateCachedMultipleAlignment(const MaModificationInfo &mi = MaModificationInfo(), const QList<qint64> &removedRowIds = QList<qint64>());
-    void sortRowsByList(const QStringList &order);
+    void updateCachedMultipleAlignment(const MaModificationInfo& mi = MaModificationInfo(), const QList<qint64>& removedRowIds = QList<qint64>());
+    void sortRowsByList(const QStringList& order);
 
     /** Replaces character in the row and changes the alphabet, if the current one does not contain the character. */
     virtual void replaceCharacter(int startPos, int rowIndex, char newChar);
 
     /** Replaces sequence of characters from startPos with the new char. Updates alignment alphabet if needed*/
-    virtual void replaceCharacters(const U2Region &columnRange, int rowIndex, char newChar);
+    virtual void replaceCharacters(const U2Region& columnRange, int rowIndex, char newChar);
 
     /** Inserts gap into 'pos' for the given rows. */
-    virtual void insertGap(const U2Region &rows, int pos, int nGaps) = 0;
+    virtual void insertGap(const U2Region& rows, int pos, int nGaps) = 0;
 
     /** Inserts gap into 'pos' for the given rows. */
-    virtual void insertGapByRowIndexList(const QList<int> &rowIndexes, int pos, int nGaps) = 0;
+    virtual void insertGapByRowIndexList(const QList<int>& rowIndexes, int pos, int nGaps) = 0;
 
     /**
      * Removes gap region that extends from the @pos column and is no longer than @maxGaps.
@@ -149,9 +148,9 @@ public:
      *
      * If the given region is a subset of a trailing gaps area then nothing happens.
      */
-    int deleteGap(U2OpStatus &os, const U2Region &rows, int pos, int maxGaps);
+    int deleteGap(U2OpStatus& os, const U2Region& rows, int pos, int maxGaps);
 
-    int deleteGapByRowIndexList(U2OpStatus &os, const QList<int> &rowIndexes, int pos, int maxGaps);
+    int deleteGapByRowIndexList(U2OpStatus& os, const QList<int>& rowIndexes, int pos, int maxGaps);
 
     /**
      * Performs shift of the region specified by parameters @startPos (leftmost column number),
@@ -173,32 +172,36 @@ public:
 
     void saveState();
     void releaseState();
+    /**
+     * Returns true if there are any gaps except trailing.
+     */
+    bool hasNonTrailingGap() const;
 
 signals:
     void si_startMaUpdating();
-    void si_alignmentChanged(const MultipleAlignment &maBefore, const MaModificationInfo &modInfo);
+    void si_alignmentChanged(const MultipleAlignment& maBefore, const MaModificationInfo& modInfo);
     void si_alignmentBecomesEmpty(bool isEmpty);
     void si_completeStateChanged(bool complete);
-    void si_rowsRemoved(const QList<qint64> &rowIds);
+    void si_rowsRemoved(const QList<qint64>& rowIds);
     void si_invalidateAlignmentObject();
-    void si_alphabetChanged(const MaModificationInfo &mi, const DNAAlphabet *prevAlphabet);
+    void si_alphabetChanged(const MaModificationInfo& mi, const DNAAlphabet* prevAlphabet);
 
 protected:
-    virtual void loadAlignment(U2OpStatus &os) = 0;
-    virtual void updateCachedRows(U2OpStatus &os, const QList<qint64> &rowIds) = 0;
-    virtual void updateDatabase(U2OpStatus &os, const MultipleAlignment &ma) = 0;
-    virtual void removeRowPrivate(U2OpStatus &os, const U2EntityRef &maRef, qint64 rowId) = 0;
-    virtual void removeRegionPrivate(U2OpStatus &os, const U2EntityRef &maRef, const QList<qint64> &rows, int startPos, int nBases) = 0;
-    void insertGap(const U2Region &rows, int pos, int nGaps, bool collapseTrailingGaps);
+    virtual void loadAlignment(U2OpStatus& os) = 0;
+    virtual void updateCachedRows(U2OpStatus& os, const QList<qint64>& rowIds) = 0;
+    virtual void updateDatabase(U2OpStatus& os, const MultipleAlignment& ma) = 0;
+    virtual void removeRowPrivate(U2OpStatus& os, const U2EntityRef& maRef, qint64 rowId) = 0;
+    virtual void removeRegionPrivate(U2OpStatus& os, const U2EntityRef& maRef, const QList<qint64>& rows, int startPos, int nBases) = 0;
+    void insertGap(const U2Region& rows, int pos, int nGaps, bool collapseTrailingGaps);
 
-    void insertGapByRowIndexList(const QList<int> &rowIndexes, int pos, int nGaps, bool collapseTrailingGaps);
+    void insertGapByRowIndexList(const QList<int>& rowIndexes, int pos, int nGaps, bool collapseTrailingGaps);
 
-    void insertGapByRowIdList(const QList<qint64> &rowIds, int pos, int nGaps, bool collapseTrailingGaps);
+    void insertGapByRowIdList(const QList<qint64>& rowIds, int pos, int nGaps, bool collapseTrailingGaps);
 
     MultipleAlignment cachedMa;
 
 private:
-    void loadDataCore(U2OpStatus &os);
+    void loadDataCore(U2OpStatus& os);
 
     /**
      * Returns maximum count of subsequent gap columns in the region that starts from column
@@ -207,11 +210,9 @@ private:
      * having @pos + @maxGaps number, otherwise 0 is returned. If the region is located
      * in the MSA trailing gaps area, then 0 is returned.
      */
-    int getMaxWidthOfGapRegion(U2OpStatus &os, const QList<int> &rowIndexes, int pos, int maxGaps);
+    int getMaxWidthOfGapRegion(U2OpStatus& os, const QList<int>& rowIndexes, int pos, int maxGaps);
 
     MaSavedState savedState;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MULTIPLE_ALIGNMENT_OBJECT_H_
