@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -35,22 +35,22 @@
 
 namespace U2 {
 
-MultipleSequenceAlignmentObject::MultipleSequenceAlignmentObject(const QString &name,
-                                                                 const U2EntityRef &msaRef,
-                                                                 const QVariantMap &hintsMap,
-                                                                 const MultipleSequenceAlignment &alnData)
+MultipleSequenceAlignmentObject::MultipleSequenceAlignmentObject(const QString& name,
+                                                                 const U2EntityRef& msaRef,
+                                                                 const QVariantMap& hintsMap,
+                                                                 const MultipleSequenceAlignment& alnData)
     : MultipleAlignmentObject(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT, name, msaRef, hintsMap, alnData) {
 }
 
-const MultipleSequenceAlignment &MultipleSequenceAlignmentObject::getMsa() const {
-    return getMultipleAlignment().dynamicCast<const MultipleSequenceAlignment &>();
+const MultipleSequenceAlignment& MultipleSequenceAlignmentObject::getMsa() const {
+    return getMultipleAlignment().dynamicCast<const MultipleSequenceAlignment&>();
 }
 
 const MultipleSequenceAlignment MultipleSequenceAlignmentObject::getMsaCopy() const {
     return getMsa()->getExplicitCopy();
 }
 
-MultipleSequenceAlignmentObject *MultipleSequenceAlignmentObject::clone(const U2DbiRef &dstDbiRef, U2OpStatus &os, const QVariantMap &hints) const {
+MultipleSequenceAlignmentObject* MultipleSequenceAlignmentObject::clone(const U2DbiRef& dstDbiRef, U2OpStatus& os, const QVariantMap& hints) const {
     DbiOperationsBlock opBlock(dstDbiRef, os);
     CHECK_OP(os, nullptr);
 
@@ -59,7 +59,7 @@ MultipleSequenceAlignmentObject *MultipleSequenceAlignmentObject::clone(const U2
     const QString dstFolder = gHints->get(DocumentFormat::DBI_FOLDER_HINT, U2ObjectDbi::ROOT_FOLDER).toString();
 
     MultipleSequenceAlignment msa = getMsa()->getExplicitCopy();
-    MultipleSequenceAlignmentObject *clonedObj = MultipleSequenceAlignmentImporter::createAlignment(dstDbiRef, dstFolder, msa, os);
+    MultipleSequenceAlignmentObject* clonedObj = MultipleSequenceAlignmentImporter::createAlignment(dstDbiRef, dstFolder, msa, os);
     CHECK_OP(os, nullptr);
 
     clonedObj->setGHints(gHints.take());
@@ -75,12 +75,12 @@ const MultipleSequenceAlignmentRow MultipleSequenceAlignmentObject::getMsaRow(in
     return getRow(row).dynamicCast<MultipleSequenceAlignmentRow>();
 }
 
-void MultipleSequenceAlignmentObject::updateGapModel(U2OpStatus &os, const U2MsaMapGapModel &rowsGapModel) {
+void MultipleSequenceAlignmentObject::updateGapModel(U2OpStatus& os, const QMap<qint64, QVector<U2MsaGap>>& rowsGapModel) {
     SAFE_POINT(!isStateLocked(), "Alignment state is locked", );
 
     const MultipleSequenceAlignment msa = getMultipleAlignment();
 
-    const QList<qint64> rowIds = msa->getRowsIds();
+    QList<qint64> rowIds = msa->getRowsIds();
     QList<qint64> modifiedRowIds;
     foreach (qint64 rowId, rowsGapModel.keys()) {
         if (!rowIds.contains(rowId)) {
@@ -99,31 +99,31 @@ void MultipleSequenceAlignmentObject::updateGapModel(U2OpStatus &os, const U2Msa
     updateCachedMultipleAlignment(mi);
 }
 
-void MultipleSequenceAlignmentObject::updateGapModel(const QList<MultipleSequenceAlignmentRow> &sourceRows) {
+void MultipleSequenceAlignmentObject::updateGapModel(const QList<MultipleSequenceAlignmentRow>& sourceRows) {
     const QList<MultipleSequenceAlignmentRow> oldRows = getMsa()->getMsaRows();
 
     SAFE_POINT(oldRows.count() == sourceRows.count(), "Different rows count", );
 
-    U2MsaMapGapModel newGapModel;
+    QMap<qint64, QVector<U2MsaGap>> newGapModel;
     QList<MultipleSequenceAlignmentRow>::ConstIterator oldRowsIterator = oldRows.begin();
     QList<MultipleSequenceAlignmentRow>::ConstIterator sourceRowsIterator = sourceRows.begin();
     for (; oldRowsIterator != oldRows.end(); oldRowsIterator++, sourceRowsIterator++) {
-        newGapModel[(*oldRowsIterator)->getRowId()] = (*sourceRowsIterator)->getGapModel();
+        newGapModel[(*oldRowsIterator)->getRowId()] = (*sourceRowsIterator)->getGaps();
     }
 
     U2OpStatus2Log os;
     updateGapModel(os, newGapModel);
 }
 
-void MultipleSequenceAlignmentObject::insertGap(const U2Region &rows, int pos, int nGaps) {
+void MultipleSequenceAlignmentObject::insertGap(const U2Region& rows, int pos, int nGaps) {
     MultipleAlignmentObject::insertGap(rows, pos, nGaps, false);
 }
 
-void MultipleSequenceAlignmentObject::insertGapByRowIndexList(const QList<int> &rowIndexes, int pos, int nGaps) {
+void MultipleSequenceAlignmentObject::insertGapByRowIndexList(const QList<int>& rowIndexes, int pos, int nGaps) {
     MultipleAlignmentObject::insertGapByRowIndexList(rowIndexes, pos, nGaps, false);
 }
 
-void MultipleSequenceAlignmentObject::crop(const QList<qint64> &rowIds, const U2Region &columnRange) {
+void MultipleSequenceAlignmentObject::crop(const QList<qint64>& rowIds, const U2Region& columnRange) {
     SAFE_POINT(!isStateLocked(), "Alignment state is locked", );
     U2OpStatus2Log os;
     MsaDbiUtils::crop(entityRef, rowIds, columnRange, os);
@@ -132,15 +132,15 @@ void MultipleSequenceAlignmentObject::crop(const QList<qint64> &rowIds, const U2
     updateCachedMultipleAlignment();
 }
 
-void MultipleSequenceAlignmentObject::crop(const U2Region &columnRange) {
+void MultipleSequenceAlignmentObject::crop(const U2Region& columnRange) {
     crop(getRowIds(), columnRange);
 }
 
-void MultipleSequenceAlignmentObject::updateRow(U2OpStatus &os, int rowIdx, const QString &name, const QByteArray &seqBytes, const U2MsaRowGapModel &gapModel) {
+void MultipleSequenceAlignmentObject::updateRow(U2OpStatus& os, int rowIdx, const QString& name, const QByteArray& seqBytes, const QVector<U2MsaGap>& gapModel) {
     SAFE_POINT(!isStateLocked(), "Alignment state is locked", );
 
     const MultipleSequenceAlignment msa = getMultipleAlignment();
-    SAFE_POINT(rowIdx >= 0 && rowIdx < msa->getNumRows(), "Invalid row index", );
+    SAFE_POINT(rowIdx >= 0 && rowIdx < msa->getRowCount(), "Invalid row index", );
     qint64 rowId = msa->getRow(rowIdx)->getRowId();
 
     MsaDbiUtils::updateRowContent(entityRef, rowId, seqBytes, gapModel, os);
@@ -150,7 +150,7 @@ void MultipleSequenceAlignmentObject::updateRow(U2OpStatus &os, int rowIdx, cons
     CHECK_OP(os, );
 }
 
-void MultipleSequenceAlignmentObject::replaceAllCharacters(char oldChar, char newChar, const DNAAlphabet *newAlphabet) {
+void MultipleSequenceAlignmentObject::replaceAllCharacters(char oldChar, char newChar, const DNAAlphabet* newAlphabet) {
     SAFE_POINT(!isStateLocked(), "Alignment state is locked", );
     SAFE_POINT(oldChar != U2Msa::GAP_CHAR && newChar != U2Msa::GAP_CHAR, "Gap characters replacement is not supported", );
     if (oldChar == newChar) {
@@ -181,7 +181,7 @@ void MultipleSequenceAlignmentObject::replaceAllCharacters(char oldChar, char ne
     updateCachedMultipleAlignment(mi);
 }
 
-void MultipleSequenceAlignmentObject::morphAlphabet(const DNAAlphabet *newAlphabet, const QByteArray &replacementMap) {
+void MultipleSequenceAlignmentObject::morphAlphabet(const DNAAlphabet* newAlphabet, const QByteArray& replacementMap) {
     SAFE_POINT(!isStateLocked(), "Alignment state is locked", );
     SAFE_POINT(newAlphabet != nullptr, "newAlphabet is null!", );
     U2OpStatus2Log os;
@@ -208,30 +208,30 @@ void MultipleSequenceAlignmentObject::morphAlphabet(const DNAAlphabet *newAlphab
     updateCachedMultipleAlignment(mi);
 }
 
-void MultipleSequenceAlignmentObject::deleteColumnsWithGaps(U2OpStatus &os, int requiredGapsCount) {
-    const QList<U2Region> regionsToDelete = MSAUtils::getColumnsWithGaps(getGapModel(), getLength(), requiredGapsCount);
+void MultipleSequenceAlignmentObject::deleteColumnsWithGaps(U2OpStatus& os, int requiredGapsCount) {
+    const QList<U2Region> regionsToDelete = MSAUtils::getColumnsWithGaps(getGapModel(), getRows(), getLength(), requiredGapsCount);
     CHECK(!regionsToDelete.isEmpty(), );
     CHECK(regionsToDelete.first().length != getLength(), );
 
     for (int n = regionsToDelete.size(), i = n - 1; i >= 0; i--) {
-        removeRegion(regionsToDelete[i].startPos, 0, regionsToDelete[i].length, getNumRows(), true, false);
+        removeRegion(regionsToDelete[i].startPos, 0, regionsToDelete[i].length, getRowCount(), true, false);
         os.setProgress(100 * (n - i) / n);
     }
     updateCachedMultipleAlignment();
 }
 
-void MultipleSequenceAlignmentObject::loadAlignment(U2OpStatus &os) {
+void MultipleSequenceAlignmentObject::loadAlignment(U2OpStatus& os) {
     MultipleSequenceAlignmentExporter msaExporter;
     cachedMa = msaExporter.getAlignment(entityRef.dbiRef, entityRef.entityId, os);
 }
 
-void MultipleSequenceAlignmentObject::updateCachedRows(U2OpStatus &os, const QList<qint64> &rowIds) {
+void MultipleSequenceAlignmentObject::updateCachedRows(U2OpStatus& os, const QList<qint64>& rowIds) {
     MultipleSequenceAlignment cachedMsa = cachedMa.dynamicCast<MultipleSequenceAlignment>();
 
     MultipleSequenceAlignmentExporter msaExporter;
     QList<MsaRowReplacementData> rowsAndSeqs = msaExporter.getAlignmentRows(entityRef.dbiRef, entityRef.entityId, rowIds, os);
     SAFE_POINT_OP(os, );
-    foreach (const MsaRowReplacementData &data, rowsAndSeqs) {
+    foreach (const MsaRowReplacementData& data, rowsAndSeqs) {
         const int rowIndex = cachedMsa->getRowIndexByRowId(data.row.rowId, os);
         SAFE_POINT_OP(os, );
         cachedMsa->setRowContent(rowIndex, data.sequence.seq);
@@ -240,16 +240,16 @@ void MultipleSequenceAlignmentObject::updateCachedRows(U2OpStatus &os, const QLi
     }
 }
 
-void MultipleSequenceAlignmentObject::updateDatabase(U2OpStatus &os, const MultipleAlignment &ma) {
+void MultipleSequenceAlignmentObject::updateDatabase(U2OpStatus& os, const MultipleAlignment& ma) {
     const MultipleSequenceAlignment msa = ma.dynamicCast<MultipleSequenceAlignment>();
     MsaDbiUtils::updateMsa(entityRef, msa, os);
 }
 
-void MultipleSequenceAlignmentObject::removeRowPrivate(U2OpStatus &os, const U2EntityRef &msaRef, qint64 rowId) {
+void MultipleSequenceAlignmentObject::removeRowPrivate(U2OpStatus& os, const U2EntityRef& msaRef, qint64 rowId) {
     MsaDbiUtils::removeRow(msaRef, rowId, os);
 }
 
-void MultipleSequenceAlignmentObject::removeRegionPrivate(U2OpStatus &os, const U2EntityRef &maRef, const QList<qint64> &rows, int startPos, int nBases) {
+void MultipleSequenceAlignmentObject::removeRegionPrivate(U2OpStatus& os, const U2EntityRef& maRef, const QList<qint64>& rows, int startPos, int nBases) {
     MsaDbiUtils::removeRegion(maRef, rows, startPos, nBases, os);
 }
 
