@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PW_MATRIX_OBJECT_H_
-#define _U2_PW_MATRIX_OBJECT_H_
+#pragma once
 
 #include <U2Core/GObject.h>
 #include <U2Core/PWMatrix.h>
@@ -31,7 +30,7 @@ namespace U2 {
 class U2CORE_EXPORT U2PWMatrix : public U2RawData {
 public:
     U2PWMatrix();
-    U2PWMatrix(const U2DbiRef &dbiRef);
+    U2PWMatrix(const U2DbiRef& dbiRef);
 
     U2DataType getType() const;
 };
@@ -41,24 +40,22 @@ class U2CORE_EXPORT PWMatrixObject : public GObject {
 public:
     static const GObjectType TYPE;
 
-    PWMatrixObject(const QString &objectName,
-                   const U2EntityRef &matrixRef,
-                   const QVariantMap &hintsMap = QVariantMap());
+    PWMatrixObject(const QString& objectName,
+                   const U2EntityRef& matrixRef,
+                   const QVariantMap& hintsMap = QVariantMap());
 
-    static PWMatrixObject *createInstance(const PWMatrix &matrix, const QString &objectName, const U2DbiRef &dbiRef, U2OpStatus &os, const QVariantMap &hintsMap = QVariantMap());
+    static PWMatrixObject* createInstance(const PWMatrix& matrix, const QString& objectName, const U2DbiRef& dbiRef, U2OpStatus& os, const QVariantMap& hintsMap = QVariantMap());
 
-    const PWMatrix &getMatrix() const;
-    GObject *clone(const U2DbiRef &dstDbiRef, U2OpStatus &os, const QVariantMap &hints = QVariantMap()) const;
+    const PWMatrix& getMatrix() const;
+    GObject* clone(const U2DbiRef& dstDbiRef, U2OpStatus& os, const QVariantMap& hints = QVariantMap()) const;
 
 protected:
-    void loadDataCore(U2OpStatus &os);
+    void loadDataCore(U2OpStatus& os);
 
 private:
-    PWMatrixObject(const PWMatrix &matrix, const QString &objectName, const U2EntityRef &matrixRef, const QVariantMap &hintsMap);
+    PWMatrixObject(const PWMatrix& matrix, const QString& objectName, const U2EntityRef& matrixRef, const QVariantMap& hintsMap);
 
     PWMatrix m;
 };
 
 }  // namespace U2
-
-#endif  // _U2_PW_MATRIX_OBJECT_H_
