@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PHYTREE_OBJECT_H_
-#define _U2_PHYTREE_OBJECT_H_
+#pragma once
 
 #include <U2Core/GObject.h>
 #include <U2Core/PhyTree.h>
@@ -31,52 +30,49 @@ namespace U2 {
 class U2CORE_EXPORT U2PhyTree : public U2RawData {
 public:
     U2PhyTree();
-    U2PhyTree(const U2DbiRef &dbiRef);
+    U2PhyTree(const U2DbiRef& dbiRef);
 
-    U2DataType getType() const;
+    U2DataType getType() const override;
 };
 
 class U2CORE_EXPORT PhyTreeObject : public GObject {
     Q_OBJECT
 public:
-    static PhyTreeObject *createInstance(const PhyTree &tree, const QString &objectName, const U2DbiRef &dbiRef, U2OpStatus &os, const QVariantMap &hintsMap = QVariantMap());
+    static PhyTreeObject* createInstance(const PhyTree& tree, const QString& objectName, const U2DbiRef& dbiRef, U2OpStatus& os, const QVariantMap& hintsMap = QVariantMap());
 
-    PhyTreeObject(const QString &objectName, const U2EntityRef &treeRef, const QVariantMap &hintsMap = QVariantMap());
+    PhyTreeObject(const QString& objectName, const U2EntityRef& treeRef, const QVariantMap& hintsMap = QVariantMap());
 
-    virtual const PhyTree &getTree() const;
-    void setTree(const PhyTree &_tree);
+    virtual const PhyTree& getTree() const;
+    void setTree(const PhyTree& _tree);
 
     void onTreeChanged();
 
-    void rerootPhyTree(PhyNode *node);
+    void rerootPhyTree(PhyNode* node);
     // Warning!
     // PhyBranches can be accessed and modified!
     // TODO: move branches to private data, add getters and setters
-    const PhyNode *findPhyNodeByName(const QString &name);
+    const PhyNode* findPhyNodeByName(const QString& name);
 
-    virtual GObject *clone(const U2DbiRef &dstDbiRef, U2OpStatus &os, const QVariantMap &hints = QVariantMap()) const;
+    GObject* clone(const U2DbiRef& dstDbiRef, U2OpStatus& os, const QVariantMap& hints = QVariantMap()) const override;
 
     // Utility functions
     // Compares number of nodes and nodes with names (how many nodes etc.)
-    static bool treesAreAlike(const PhyTree &tree1, const PhyTree &tree2);
-
-    bool haveNodeLabels() const;
+    // TODO: document the algorithm and usage.
+    static bool treesAreAlike(const PhyTree& tree1, const PhyTree& tree2);
 
 signals:
     void si_phyTreeChanged();
 
 protected:
-    void loadDataCore(U2OpStatus &os);
+    void loadDataCore(U2OpStatus& os) override;
 
 private:
-    PhyTreeObject(const PhyTree &tree, const QString &objectName, const U2EntityRef &treeRef, const QVariantMap &hintsMap);
+    PhyTreeObject(const PhyTree& tree, const QString& objectName, const U2EntityRef& treeRef, const QVariantMap& hintsMap);
     void commit();
-    static void commit(const PhyTree &tree, const U2EntityRef &treeRef, U2OpStatus &os);
-    static void commit(const PhyTree &tree, const U2EntityRef &treeRef);
+    static void commit(const PhyTree& tree, const U2EntityRef& treeRef, U2OpStatus& os);
+    static void commit(const PhyTree& tree, const U2EntityRef& treeRef);
 
     PhyTree tree;
 };
 
 }  // namespace U2
-
-#endif
