@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_VARIANT_TRACK_OBJECT_H_
-#define _U2_VARIANT_TRACK_OBJECT_H_
+#pragma once
 
 #include <U2Core/GObject.h>
 #include <U2Core/U2Region.h>
@@ -33,20 +32,18 @@ class U2CORE_EXPORT VariantTrackObject : public GObject {
     Q_OBJECT
 
 public:
-    VariantTrackObject(const QString &objectName, const U2EntityRef &trackRef, const QVariantMap &hintsMap = QVariantMap());
+    VariantTrackObject(const QString& objectName, const U2EntityRef& trackRef, const QVariantMap& hintsMap = QVariantMap());
     ~VariantTrackObject();
 
-    GObject *clone(const U2DbiRef &dbiRef, U2OpStatus &os, const QVariantMap &hints = QVariantMap()) const;
+    GObject* clone(const U2DbiRef& dbiRef, U2OpStatus& os, const QVariantMap& hints = QVariantMap()) const;
 
     /**U2_REGION_MAX to get all variants*/
-    U2DbiIterator<U2Variant> *getVariants(const U2Region &reg, U2OpStatus &os) const;
-    int getVariantCount(U2OpStatus &os) const;
+    U2DbiIterator<U2Variant>* getVariants(const U2Region& reg, U2OpStatus& os) const;
+    int getVariantCount(U2OpStatus& os) const;
 
-    void addVariants(const QList<U2Variant> &variants, U2OpStatus &os);
+    void addVariants(const QList<U2Variant>& variants, U2OpStatus& os);
 
-    U2VariantTrack getVariantTrack(U2OpStatus &os) const;
+    U2VariantTrack getVariantTrack(U2OpStatus& os) const;
 };
 
 }  // namespace U2
-
-#endif  //_U2_VARIANT_TRACK_OBJECT_H_
