@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,7 +26,6 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QUrl>
-#include <QWaitCondition>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/AppSettings.h>
@@ -40,30 +39,30 @@ namespace U2 {
 
 #define MAX_GET_LENGTH 3000
 
-HttpFileAdapterFactory::HttpFileAdapterFactory(QObject *o)
+HttpFileAdapterFactory::HttpFileAdapterFactory(QObject* o)
     : IOAdapterFactory(o) {
     name = tr("HTTP file");
 }
 
-IOAdapter *HttpFileAdapterFactory::createIOAdapter() {
+IOAdapter* HttpFileAdapterFactory::createIOAdapter() {
     return new HttpFileAdapter(this);
 }
 
-GzippedHttpFileAdapterFactory::GzippedHttpFileAdapterFactory(QObject *obj /* = 0 */)
+GzippedHttpFileAdapterFactory::GzippedHttpFileAdapterFactory(QObject* obj /* = 0 */)
     : HttpFileAdapterFactory(obj) {
     name = tr("HTTP GZIP adaptor");
 }
 
-IOAdapter *GzippedHttpFileAdapterFactory::createIOAdapter() {
+IOAdapter* GzippedHttpFileAdapterFactory::createIOAdapter() {
     return new ZlibAdapter(new HttpFileAdapter(this));
 }
 
-QNetworkProxy HttpFileAdapterFactory::getProxyByUrl(const QUrl &url) const {
-    NetworkConfiguration *nc = AppContext::getAppSettings()->getNetworkConfiguration();
+QNetworkProxy HttpFileAdapterFactory::getProxyByUrl(const QUrl& url) const {
+    NetworkConfiguration* nc = AppContext::getAppSettings()->getNetworkConfiguration();
     return nc->getProxyByUrl(url);
 }
 
-HttpFileAdapter::HttpFileAdapter(HttpFileAdapterFactory *factory, QObject *o)
+HttpFileAdapter::HttpFileAdapter(HttpFileAdapterFactory* factory, QObject* o)
     : IOAdapter(factory, o), is_cached(false), begin_ptr(-1), end_ptr(0),
       reply(nullptr), badstate(false), is_downloaded(false), downloaded(0), total(0) {
     chunk_list.push_back(QByteArray(CHUNKSIZE, char(0)));
@@ -75,7 +74,7 @@ HttpFileAdapter::~HttpFileAdapter() {
     delete netManager;
     netManager = nullptr;
 }
-bool HttpFileAdapter::open(const GUrl &url_, IOAdapterMode m) {
+bool HttpFileAdapter::open(const GUrl& url_, IOAdapterMode m) {
     SAFE_POINT(m == IOAdapterMode_Read, QString("Illegal IO mode: %1").arg(m), false);
 
     QUrl url(url_.getURLString().trimmed());
@@ -89,26 +88,27 @@ bool HttpFileAdapter::open(const GUrl &url_, IOAdapterMode m) {
     gurl = url_;
     init();
 
-    HttpFileAdapterFactory *f = qobject_cast<HttpFileAdapterFactory *>(getFactory());
-    QNetworkProxy proxy = f->getProxyByUrl(url);
+    auto httpFileAdapterFactory = qobject_cast<HttpFileAdapterFactory*>(getFactory());
+    QNetworkProxy proxy = httpFileAdapterFactory->getProxyByUrl(url);
     return open(url, proxy);
 }
 
-bool HttpFileAdapter::open(const QUrl &url, const QNetworkProxy &p) {
+bool HttpFileAdapter::open(const QUrl& url, const QNetworkProxy& p) {
     SAFE_POINT(!isOpen(), "Adapter is already opened!", false);
 
     if (reply) {
         close();
     }
     netManager->setProxy(p);
-    connect(netManager, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)), this, SLOT(onProxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)));
+    connect(netManager, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)), this, SLOT(onProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
     if (url.toString().length() > MAX_GET_LENGTH) {
         QStringList splittedStrings = url.toString().split(RemoteRequestConfig::HTTP_BODY_SEPARATOR);
         if (splittedStrings.count() > 1) {
-            SAFE_POINT(2 == splittedStrings.count(), tr("Incorrect url string has been passed to HttpFileAdapter::open()"), false);
-            QString headerString = splittedStrings.at(0);
+            SAFE_POINT(splittedStrings.count() == 2, tr("Incorrect url string has been passed to HttpFileAdapter::open()"), false);
+            const QString& headerString = splittedStrings.at(0);
             postData = splittedStrings.at(1).toLatin1();
             QNetworkRequest netRequest(headerString);
+            netRequest.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
             reply = netManager->post(netRequest, postData);
         } else {
             QNetworkRequest netRequest(url);
@@ -120,7 +120,7 @@ bool HttpFileAdapter::open(const QUrl &url, const QNetworkProxy &p) {
         QNetworkRequest netRequest(urlString);
         reply = netManager->get(netRequest);
     }
-    coreLog.details(tr("Downloading from %1").arg(reply->url().toString()));
+    coreLog.details(tr("GET %1").arg(reply->url().toString()));
     connect(reply, SIGNAL(readyRead()), this, SLOT(add_data()), Qt::DirectConnection);
     connect(reply, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(progress(qint64, qint64)), Qt::DirectConnection);  //+
     connect(reply, SIGNAL(finished()), this, SLOT(done()), Qt::DirectConnection);
@@ -141,7 +141,7 @@ void HttpFileAdapter::close() {
     init();
 }
 
-qint64 HttpFileAdapter::readBlock(char *data, qint64 size) {
+qint64 HttpFileAdapter::readBlock(char* data, qint64 size) {
     SAFE_POINT(isOpen(), "Adapter is not opened!", 0);
     if (badstate) {
         return -1;
@@ -159,10 +159,6 @@ qint64 HttpFileAdapter::readBlock(char *data, qint64 size) {
     while (write_offs < size) {
         qint64 howmuch = qMin(size - write_offs, (qint64)firstChunkContains());
         readFromChunk(data + write_offs, howmuch);
-        if (formatMode == TextMode) {
-            cutByteOrderMarks(data, errorMessage, howmuch);
-            CHECK(errorMessage.isEmpty(), -1);
-        }
         write_offs += howmuch;
     }
 
@@ -170,9 +166,8 @@ qint64 HttpFileAdapter::readBlock(char *data, qint64 size) {
     return size;
 }
 
-qint64 HttpFileAdapter::writeBlock(const char *, qint64) {
-    SAFE_POINT(0, "Operation is not supported!", 0);
-    return 0;
+qint64 HttpFileAdapter::writeBlock(const char*, qint64) {
+    FAIL("Operation is not supported!", 0);
 }
 
 bool HttpFileAdapter::skip(qint64 nBytes) {
@@ -251,7 +246,7 @@ qint64 HttpFileAdapter::stored() const {
     return (singleChunk() ? firstChunkContains() : firstChunkContains() + end_ptr + (chunk_list.size() - 2) * CHUNKSIZE);
 }
 
-void HttpFileAdapter::readFromChunk(char *data, int size) {
+void HttpFileAdapter::readFromChunk(char* data, int size) {
     assert(size <= firstChunkContains());
     assert(!isEmpty());
 
@@ -319,8 +314,7 @@ void HttpFileAdapter::done() {
         return;
     }
     is_downloaded = true;
-    badstate = (reply->error() != QNetworkReply::NoError);
-
+    badstate = reply->error() != QNetworkReply::NoError;
     loop.exit();
 }
 
@@ -334,19 +328,17 @@ void HttpFileAdapter::progress(qint64 done_, qint64 total_) {
 }
 
 QString HttpFileAdapter::errorString() const {
-    QString result;
-    if (reply) {
-        result = reply->errorString();
-    } else {
-        result = errorMessage;
+    CHECK(errorMessage.isEmpty(), errorMessage);
+    if (reply && reply->error() != QNetworkReply::NoError) {
+        return reply->errorString();
     }
-    return result;
+    return "";
 }
 
-void HttpFileAdapter::onProxyAuthenticationRequired(const QNetworkProxy &proxy, QAuthenticator *auth) {
+void HttpFileAdapter::onProxyAuthenticationRequired(const QNetworkProxy& proxy, QAuthenticator* auth) {
     auth->setUser(proxy.user());
     auth->setPassword(proxy.password());
-    disconnect(this, SLOT(onProxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)));
+    disconnect(this, SLOT(onProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
 }
 
 }  // namespace U2
