@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_INPUTSTREAM_H_
-#define _U2_INPUTSTREAM_H_
+#pragma once
 
 #include <U2Core/U2OpStatus.h>
 
@@ -49,14 +48,12 @@ public:
      * Returns the total number of bytes read into the buffer,
      * or -1 if there is no more data because the end of the stream has been reached.
      */
-    virtual int read(char *buffer, int length, U2OpStatus &os) = 0;
+    virtual int read(char* buffer, int length, U2OpStatus& os) = 0;
     /**
      * Skips over and discards n bytes of data from this input stream.
      * Returns the actual number of bytes skipped.
      */
-    virtual qint64 skip(qint64 n, U2OpStatus &os) = 0;
+    virtual qint64 skip(qint64 n, U2OpStatus& os) = 0;
 };
 
 }  // namespace U2
-
-#endif  // _U2_INPUTSTREAM_H_
