@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OUTPUTSTREAM_H_
-#define _U2_OUTPUTSTREAM_H_
+#pragma once
 
 #include <U2Core/U2OpStatus.h>
 
@@ -43,9 +42,7 @@ public:
     /**
      * Writes @length bytes from the specified byte array starting to this output stream.
      */
-    virtual void write(const char *buffer, int length, U2OpStatus &os) = 0;
+    virtual void write(const char* buffer, int length, U2OpStatus& os) = 0;
 };
 
 }  // namespace U2
-
-#endif  // _U2_OUTPUTSTREAM_H_
