@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,33 +19,32 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_RING_BUF_H_
-#define _U2_RING_BUF_H_
+#pragma once
 
 namespace U2 {
 
 class RingBuffer {
 public:
-    RingBuffer(char *buf, int size)
+    RingBuffer(char* buf, int size)
         : data(buf), size(size), len(0), start(0) {
     }
-    inline int read(char *dest, int n, int index = 0) const;
-    inline void append(const char *src, int n);
+    inline int read(char* dest, int n, int index = 0) const;
+    inline void append(const char* src, int n);
     int length() const {
         return len;
     }
-    char *rawData() const {
+    char* rawData() const {
         return data;
     }
 
 private:
-    char *data;  // buffer area
+    char* data;  // buffer area
     int size;  // buffer size
     int len;  // length of buffered data
     int start;  // start offset
 };
 
-int RingBuffer::read(char *dest, int n, int index) const {
+int RingBuffer::read(char* dest, int n, int index) const {
     assert(index < len);
     if (n > len - index) {
         n = len - index;
@@ -65,7 +64,7 @@ int RingBuffer::read(char *dest, int n, int index) const {
     return n;
 }
 
-void RingBuffer::append(const char *src, int n) {
+void RingBuffer::append(const char* src, int n) {
     if (n >= size) {
         start = 0;
         len = size;
@@ -93,5 +92,3 @@ void RingBuffer::append(const char *src, int n) {
 }
 
 }  // namespace U2
-
-#endif
