@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_STRING_ADAPTER_H_
-#define _U2_STRING_ADAPTER_H_
+#pragma once
 
 #include <U2Core/IOAdapter.h>
 
@@ -29,15 +28,15 @@ namespace U2 {
 class U2CORE_EXPORT StringAdapterFactory : public IOAdapterFactory {
     Q_OBJECT
 public:
-    StringAdapterFactory(QObject *p = nullptr);
+    StringAdapterFactory(QObject* p = nullptr);
 
-    virtual IOAdapter *createIOAdapter();
+    virtual IOAdapter* createIOAdapter();
 
     virtual IOAdapterId getAdapterId() const {
         return BaseIOAdapters::STRING;
     }
 
-    virtual const QString &getAdapterName() const {
+    virtual const QString& getAdapterName() const {
         return name;
     }
 
@@ -46,7 +45,7 @@ public:
         return true;
     }  // data can be read and be written
 
-    virtual TriState isResourceAvailable(const GUrl &url) const {
+    virtual TriState isResourceAvailable(const GUrl& url) const {
         Q_UNUSED(url);
         return TriState_Yes;
     }
@@ -58,9 +57,9 @@ protected:
 class U2CORE_EXPORT StringAdapterFactoryWithStringData : public StringAdapterFactory {
     Q_OBJECT
 public:
-    StringAdapterFactoryWithStringData(const QString &data, QObject *parent = nullptr);
+    StringAdapterFactoryWithStringData(const QString& data, QObject* parent = nullptr);
 
-    virtual IOAdapter *createIOAdapter();
+    virtual IOAdapter* createIOAdapter();
 
 private:
     const QString data;
@@ -69,16 +68,16 @@ private:
 class U2CORE_EXPORT StringAdapter : public IOAdapter {
     Q_OBJECT
 public:
-    StringAdapter(StringAdapterFactory *f, QObject *o = nullptr);
+    StringAdapter(StringAdapterFactory* f, QObject* o = nullptr);
     ~StringAdapter() {
         if (isOpen())
             close();
     }
 
     /** Creates opened adapter */
-    StringAdapter(const QByteArray &data, StringAdapterFactory *f);
+    StringAdapter(const QByteArray& data, StringAdapterFactory* f);
 
-    virtual bool open(const GUrl &url, IOAdapterMode m);
+    virtual bool open(const GUrl& url, IOAdapterMode m);
 
     virtual bool isOpen() const {
         return opened;
@@ -86,9 +85,9 @@ public:
 
     virtual void close();
 
-    virtual qint64 readBlock(char *data, qint64 maxSize);
+    virtual qint64 readBlock(char* data, qint64 maxSize);
 
-    virtual qint64 writeBlock(const char *data, qint64 size);
+    virtual qint64 writeBlock(const char* data, qint64 size);
 
     virtual bool skip(qint64 nBytes);
 
@@ -100,7 +99,7 @@ public:
 
     virtual GUrl getURL() const;
 
-    const QByteArray &getBuffer() {
+    const QByteArray& getBuffer() {
         return buffer;
     }
 
@@ -114,5 +113,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_STRING_ADAPTER_H_
