@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ZLIB_ADAPTER_H_
-#define _U2_ZLIB_ADAPTER_H_
+#pragma once
 
 #include <U2Core/IOAdapter.h>
 
@@ -35,18 +34,18 @@ struct GZipIndexAccessPoint;
 class U2CORE_EXPORT ZlibAdapter : public IOAdapter {
     Q_OBJECT
 public:
-    ZlibAdapter(IOAdapter *io);
+    ZlibAdapter(IOAdapter* io);
     ~ZlibAdapter();
 
-    virtual bool open(const GUrl &url, IOAdapterMode m_);
+    virtual bool open(const GUrl& url, IOAdapterMode m_);
 
     virtual bool isOpen() const;
 
     virtual void close();
 
-    virtual qint64 readBlock(char *data, qint64 maxSize);
+    virtual qint64 readBlock(char* data, qint64 maxSize);
 
-    virtual qint64 writeBlock(const char *data, qint64 size);
+    virtual qint64 writeBlock(const char* data, qint64 size);
 
     virtual bool skip(qint64 nBytes);
 
@@ -61,20 +60,20 @@ public:
     /**
      * should be invoked after open() ( needs z not null )
      */
-    bool skip(const GZipIndexAccessPoint &point, qint64 offset);
+    bool skip(const GZipIndexAccessPoint& point, qint64 offset);
 
     /**
      * returns -1 if a file is failed to open
      */
-    static qint64 getUncompressedFileSizeInBytes(const GUrl &url);
+    static qint64 getUncompressedFileSizeInBytes(const GUrl& url);
 
     virtual QString errorString() const;
 
 private:
     static const int BUFLEN = 32768;
-    IOAdapter *io;
-    GzipUtil *z;
-    RingBuffer *buf;  // seek buffer
+    IOAdapter* io;
+    GzipUtil* z;
+    RingBuffer* buf;  // seek buffer
     int rewinded;  // how much should read from seek buffer
 };
 
@@ -94,5 +93,3 @@ struct U2CORE_EXPORT GZipIndex {
 };  // GZipIndex
 
 };  // namespace U2
-
-#endif
