@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BUNCHMIMEDATA_H_
-#define _U2_BUNCHMIMEDATA_H_
+#pragma once
 
 #include <U2Core/Folder.h>
 #include <U2Core/GObject.h>
@@ -35,7 +34,7 @@ public:
     BunchMimeData();
 
     // QMimeData
-    bool hasFormat(const QString &mimeType) const;
+    bool hasFormat(const QString& mimeType) const;
     QStringList formats() const;
 
     QList<QPointer<Document>> docs;
@@ -44,5 +43,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // _U2_BUNCHMIMEDATA_H_
