@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOCUMENT_IMPORT_H_
-#define _U2_DOCUMENT_IMPORT_H_
+#pragma once
 
 #include <QDialog>
 
@@ -36,11 +35,11 @@ class ImportWidget;
 class U2CORE_EXPORT ImportDialog : public QDialog {
     Q_OBJECT
 public:
-    ImportDialog(const QVariantMap &_settings)
+    ImportDialog(const QVariantMap& _settings)
         : settings(_settings) {
     }
 
-    const QVariantMap &getSettings() const {
+    const QVariantMap& getSettings() const {
         return settings;
     }
 
@@ -61,7 +60,7 @@ public:
     virtual ~ImportWidgetFactory() {
     }
 
-    virtual ImportWidget *getWidget(const GUrl &url, const QVariantMap &settings) const = 0;
+    virtual ImportWidget* getWidget(const GUrl& url, const QVariantMap& settings) const = 0;
 };
 
 /** Registry for all DocumentImportHandlers */
@@ -69,30 +68,30 @@ class U2CORE_EXPORT DocumentImportersRegistry : public QObject {
     Q_OBJECT
     Q_DISABLE_COPY(DocumentImportersRegistry)
 public:
-    DocumentImportersRegistry(QObject *p = nullptr)
+    DocumentImportersRegistry(QObject* p = nullptr)
         : QObject(p) {
     }
     ~DocumentImportersRegistry();
 
     /** returns handler by its id */
-    DocumentImporter *getDocumentImporter(const QString &importerId) const;
+    DocumentImporter* getDocumentImporter(const QString& importerId) const;
 
     /** registers new document import handler */
-    void addDocumentImporter(DocumentImporter *i);
+    void addDocumentImporter(DocumentImporter* i);
 
-    const QList<DocumentImporter *> &getImporters() const {
+    const QList<DocumentImporter*>& getImporters() const {
         return importers;
     }
 
 private:
-    QList<DocumentImporter *> importers;
+    QList<DocumentImporter*> importers;
 };
 
 class U2CORE_EXPORT DocumentImporter : public QObject {
     Q_OBJECT
     Q_DISABLE_COPY(DocumentImporter)
 public:
-    DocumentImporter(const QString &_id, const QString &_name, QObject *o = nullptr)
+    DocumentImporter(const QString& _id, const QString& _name, QObject* o = nullptr)
         : QObject(o), id(_id), name(_name), widgetFactory(nullptr) {
     }
 
@@ -100,37 +99,37 @@ public:
         delete widgetFactory;
     }
 
-    virtual FormatCheckResult checkRawData(const QByteArray &rawData, const GUrl &url) = 0;
+    virtual FormatCheckResult checkRawData(const QByteArray& rawData, const GUrl& url) = 0;
 
-    virtual DocumentProviderTask *createImportTask(const FormatDetectionResult &res, bool showGui, const QVariantMap &hints) = 0;
+    virtual DocumentProviderTask* createImportTask(const FormatDetectionResult& res, bool showGui, const QVariantMap& hints) = 0;
 
     virtual QString getRadioButtonText() const;
 
-    virtual ImportWidget *createImportWidget(const GUrl &url, const QVariantMap &settings) const;
+    virtual ImportWidget* createImportWidget(const GUrl& url, const QVariantMap& settings) const;
 
     virtual QString getImporterDescription() const {
         return importerDescription;
     }
 
-    const QString &getImporterName() const {
+    const QString& getImporterName() const {
         return name;
     }
 
-    const QString &getId() const {
+    const QString& getId() const {
         return id;
     }
 
-    const QStringList &getFormatIds() const {
+    const QStringList& getFormatIds() const {
         return formatIds;
     }
 
-    const QList<QString> &getSupportedFileExtensions() const {
+    const QList<QString>& getSupportedFileExtensions() const {
         return extensions;
     }
 
-    void setWidgetFactory(ImportWidgetFactory *factory);
+    void setWidgetFactory(ImportWidgetFactory* factory);
 
-    const QSet<GObjectType> &getSupportedObjectTypes() const;
+    const QSet<GObjectType>& getSupportedObjectTypes() const;
 
     // NOTE: it is hint, it should be true by default
     static const QString LOAD_RESULT_DOCUMENT;
@@ -141,10 +140,8 @@ protected:
     QStringList formatIds;
     QList<QString> extensions;
     QString importerDescription;
-    ImportWidgetFactory *widgetFactory;
+    ImportWidgetFactory* widgetFactory;
     QSet<GObjectType> supportedObjectTypes;
 };
 
 }  // namespace U2
-
-#endif
