@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -53,40 +53,40 @@ const QString DocumentMimeData::MIME_TYPE("application/x-ugene-document-mime");
 
 const int DocumentFormat::READ_BUFF_SIZE = 4194304;  // 4Mb optimal buffer size for reading from network drives
 
-DocumentFormat::DocumentFormat(QObject *p, const DocumentFormatId &_id, DocumentFormatFlags _flags, const QStringList &fileExts)
+DocumentFormat::DocumentFormat(QObject* p, const DocumentFormatId& _id, DocumentFormatFlags _flags, const QStringList& fileExts)
     : QObject(p),
       id(_id),
       formatFlags(_flags),
       fileExtensions(fileExts) {
 }
 
-Document *DocumentFormat::createNewLoadedDocument(IOAdapterFactory *iof, const GUrl &url, U2OpStatus &os, const QVariantMap &hints) {
+Document* DocumentFormat::createNewLoadedDocument(IOAdapterFactory* iof, const GUrl& url, U2OpStatus& os, const QVariantMap& hints) {
     U2DbiRef tmpDbiRef = fetchDbiRef(hints, os);
     CHECK_OP(os, nullptr);
 
-    Document *doc = new Document(this, iof, url, tmpDbiRef, QList<UnloadedObjectInfo>(), hints, QString());
+    Document* doc = new Document(this, iof, url, tmpDbiRef, QList<UnloadedObjectInfo>(), hints, QString());
     doc->setLoaded(true);
     doc->setDocumentOwnsDbiResources(true);
     doc->setModificationTrack(!checkFlags(DocumentFormatFlag_DirectWriteOperations));
     return doc;
 }
 
-Document *DocumentFormat::createNewUnloadedDocument(IOAdapterFactory *iof, const GUrl &url, U2OpStatus &os, const QVariantMap &hints, const QList<UnloadedObjectInfo> &info, const QString &instanceModLockDesc) {
+Document* DocumentFormat::createNewUnloadedDocument(IOAdapterFactory* iof, const GUrl& url, U2OpStatus& os, const QVariantMap& hints, const QList<UnloadedObjectInfo>& info, const QString& instanceModLockDesc) {
     Q_UNUSED(os);
     U2DbiRef dbiRef = (hints[DocumentFormat::DBI_REF_HINT]).value<U2DbiRef>();
-    Document *doc = new Document(this, iof, url, dbiRef, info, hints, instanceModLockDesc);
+    Document* doc = new Document(this, iof, url, dbiRef, info, hints, instanceModLockDesc);
     doc->setModificationTrack(!checkFlags(DocumentFormatFlag_DirectWriteOperations));
     return doc;
 }
 
-Document *DocumentFormat::loadDocument(IOAdapterFactory *iof, const GUrl &url, const QVariantMap &hints, U2OpStatus &os) {
+Document* DocumentFormat::loadDocument(IOAdapterFactory* iof, const GUrl& url, const QVariantMap& hints, U2OpStatus& os) {
     QScopedPointer<IOAdapter> io(iof->createIOAdapter());
     if (!io->open(url, IOAdapterMode_Read)) {
         os.setError(L10N::errorOpeningFileRead(url));
         return nullptr;
     }
 
-    Document *res = nullptr;
+    Document* res = nullptr;
 
     U2DbiRef dbiRef = fetchDbiRef(hints, os);
     CHECK_OP(os, nullptr);
@@ -103,7 +103,7 @@ Document *DocumentFormat::loadDocument(IOAdapterFactory *iof, const GUrl &url, c
     return res;
 }
 
-U2DbiRef DocumentFormat::fetchDbiRef(const QVariantMap &hints, U2OpStatus &os) const {
+U2DbiRef DocumentFormat::fetchDbiRef(const QVariantMap& hints, U2OpStatus& os) const {
     if (hints.contains(DBI_REF_HINT)) {
         return hints.value(DBI_REF_HINT).value<U2DbiRef>();
     } else {
@@ -111,17 +111,17 @@ U2DbiRef DocumentFormat::fetchDbiRef(const QVariantMap &hints, U2OpStatus &os) c
     }
 }
 
-DNASequence *DocumentFormat::loadSequence(IOAdapter *, U2OpStatus &os) {
+DNASequence* DocumentFormat::loadSequence(IOAdapter*, U2OpStatus& os) {
     os.setError("This document format does not support streaming reading mode");
     return nullptr;
 }
 
-void DocumentFormat::storeDocument(Document *, IOAdapter *, U2OpStatus &os) {
+void DocumentFormat::storeDocument(Document*, IOAdapter*, U2OpStatus& os) {
     assert(0);
     os.setError(tr("Writing is not supported for this format (%1). Feel free to send a feature request though.").arg(formatName));
 }
 
-void DocumentFormat::storeDocument(Document *doc, U2OpStatus &os, IOAdapterFactory *iof, const GUrl &newDocURL) {
+void DocumentFormat::storeDocument(Document* doc, U2OpStatus& os, IOAdapterFactory* iof, const GUrl& newDocURL) {
     SAFE_POINT_EXT(formatFlags.testFlag(DocumentFormatFlag_SupportWriting),
                    os.setError(tr("Writing is not supported for this format (%1). Feel free to send a feature request though.").arg(formatName)), );
 
@@ -149,7 +149,7 @@ void DocumentFormat::storeDocument(Document *doc, U2OpStatus &os, IOAdapterFacto
     storeDocument(doc, io.data(), os);
 }
 
-bool DocumentFormat::checkConstraints(const DocumentFormatConstraints &c) const {
+bool DocumentFormat::checkConstraints(const DocumentFormatConstraints& c) const {
     assert(!supportedObjectTypes.isEmpty());  // extra check for DF state validation
 
     if (!checkFlags(c.flagsToSupport)) {
@@ -169,7 +169,7 @@ bool DocumentFormat::checkConstraints(const DocumentFormatConstraints &c) const
     }
 
     bool areTypesSatisfied = !c.allowPartialTypeMapping;
-    foreach (const GObjectType &objType, c.supportedObjectTypes) {
+    foreach (const GObjectType& objType, c.supportedObjectTypes) {
         if (c.allowPartialTypeMapping && supportedObjectTypes.contains(objType)) {  // at least one type is supported
             areTypesSatisfied = true;
             break;
@@ -182,7 +182,7 @@ bool DocumentFormat::checkConstraints(const DocumentFormatConstraints &c) const
     return areTypesSatisfied;
 }
 
-void DocumentFormat::storeEntry(IOAdapter *, const QMap<GObjectType, QList<GObject *>> &, U2OpStatus &os) {
+void DocumentFormat::storeEntry(IOAdapter*, const QMap<GObjectType, QList<GObject*>>&, U2OpStatus& os) {
     os.setError("This document format does not support streaming mode");
 }
 
@@ -190,7 +190,7 @@ QString DocumentFormat::getRadioButtonText() const {
     return QString();
 }
 
-bool DocumentFormat::isObjectOpSupported(const Document *d, DocObjectOp op, GObjectType t) const {
+bool DocumentFormat::isObjectOpSupported(const Document* d, DocObjectOp op, GObjectType t) const {
     assert(d->getDocumentFormat() == this);
 
     if (!supportedObjectTypes.contains(t)) {
@@ -214,14 +214,14 @@ bool DocumentFormat::isObjectOpSupported(const Document *d, DocObjectOp op, GObj
 /// Document
 const QString Document::UNLOAD_LOCK_NAME = "unload_document_lock";
 
-Document::Document(DocumentFormat *_df, IOAdapterFactory *_io, const GUrl &_url, const U2DbiRef &_dbiRef, const QList<UnloadedObjectInfo> &unloadedObjects, const QVariantMap &hints, const QString &instanceModLockDesc)
+Document::Document(DocumentFormat* _df, IOAdapterFactory* _io, const GUrl& _url, const U2DbiRef& _dbiRef, const QList<UnloadedObjectInfo>& unloadedObjects, const QVariantMap& hints, const QString& instanceModLockDesc)
     : StateLockableTreeItem(), df(_df), io(_io), url(_url), dbiRef(_dbiRef) {
     documentOwnsDbiResources = false;
 
     ctxState = new GHintsDefaultImpl(hints);
     name = url.fileName();
 
-    std::fill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock *)nullptr);
+    std::fill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)nullptr);
 
     loadStateChangeMode = true;
     addUnloadedObjects(unloadedObjects);
@@ -232,7 +232,7 @@ Document::Document(DocumentFormat *_df, IOAdapterFactory *_io, const GUrl &_url,
     //    assert(!isModified());
 }
 
-Document::Document(DocumentFormat *_df, IOAdapterFactory *_io, const GUrl &_url, const U2DbiRef &_dbiRef, const QList<GObject *> &_objects, const QVariantMap &hints, const QString &instanceModLockDesc)
+Document::Document(DocumentFormat* _df, IOAdapterFactory* _io, const GUrl& _url, const U2DbiRef& _dbiRef, const QList<GObject*>& _objects, const QVariantMap& hints, const QString& instanceModLockDesc)
     : StateLockableTreeItem(), df(_df), io(_io), url(_url), dbiRef(_dbiRef) {
     documentOwnsDbiResources = true;
 
@@ -240,8 +240,8 @@ Document::Document(DocumentFormat *_df, IOAdapterFactory *_io, const GUrl &_url,
     name = url.fileName();
 
     loadStateChangeMode = true;
-    std::fill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock *)nullptr);
-    foreach (GObject *o, _objects) {
+    std::fill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)nullptr);
+    foreach (GObject* o, _objects) {
         _addObject(o);
     }
     loadStateChangeMode = false;
@@ -252,8 +252,8 @@ Document::Document(DocumentFormat *_df, IOAdapterFactory *_io, const GUrl &_url,
     assert(!isModified());
 }
 
-Document *Document::getSimpleCopy(DocumentFormat *df, IOAdapterFactory *io, const GUrl &url) const {
-    Document *result = new Document(df, io, url, this->dbiRef, QList<GObject *>(), this->getGHintsMap());
+Document* Document::getSimpleCopy(DocumentFormat* df, IOAdapterFactory* io, const GUrl& url) const {
+    Document* result = new Document(df, io, url, this->dbiRef, QList<GObject*>(), this->getGHintsMap());
     result->objects = this->objects;
     result->documentOwnsDbiResources = false;
 
@@ -262,7 +262,7 @@ Document *Document::getSimpleCopy(DocumentFormat *df, IOAdapterFactory *io, cons
 
 Document::~Document() {
     for (int i = 0; i < DocumentModLock_NUM_LOCKS; i++) {
-        StateLock *sl = modLocks[i];
+        StateLock* sl = modLocks[i];
         if (sl != nullptr) {
             unlockState(sl);
             delete sl;
@@ -276,15 +276,26 @@ Document::~Document() {
     delete ctxState;
 }
 
-GObject *Document::getObjectById(const U2DataId &id) const {
+GObject* Document::getObjectById(const U2DataId& id) const {
     return id2Object.value(id, nullptr);
 }
 
-void Document::setObjectsInUse(const QSet<U2DataId> &objs) {
+QList<U2DataId> Document::findGObjectIdsByType(const GObjectType& type) const {
+    QList<U2DataId> result;
+    const QList<U2DataId> ids = id2Object.keys();
+    for (const U2DataId& key : qAsConst(ids)) {
+        if (id2Object.value(key)->getGObjectType() == type) {
+            result.append(key);
+        }
+    }
+    return result;
+}
+
+void Document::setObjectsInUse(const QSet<U2DataId>& objs) {
     objectsInUse = objs;
 }
 
-void Document::addObject(GObject *obj) {
+void Document::addObject(GObject* obj) {
     SAFE_POINT(obj != nullptr, "Object is NULL", );
     SAFE_POINT(obj->getDocument() == nullptr, "Object already belongs to some document", );
     SAFE_POINT(df->isObjectOpSupported(this, DocumentFormat::DocObjectOp_Add, obj->getGObjectType()), "Document format doesn't support new objects adding", );
@@ -294,7 +305,7 @@ void Document::addObject(GObject *obj) {
     _addObject(obj);
 }
 
-void Document::_addObjectToHierarchy(GObject *obj) {
+void Document::_addObjectToHierarchy(GObject* obj) {
     SAFE_POINT(obj != nullptr, "Object is NULL", );
     obj->setParentStateLockItem(this);
     obj->setGHints(new ModTrackHints(this, obj->getGHintsMap(), true));
@@ -303,16 +314,42 @@ void Document::_addObjectToHierarchy(GObject *obj) {
     id2Object.insert(obj->getEntityRef().entityId, obj);
 }
 
-void Document::_addObject(GObject *obj) {
+void Document::_addObject(GObject* obj) {
     SAFE_POINT(obj != nullptr, "Object is NULL", );
     _addObjectToHierarchy(obj);
     assert(objects.size() == getChildItems().size());
     emit si_objectAdded(obj);
 }
 
-bool Document::removeObject(GObject *obj, DocumentObjectRemovalMode removalMode) {
+bool Document::removeObject(GObject* obj, DocumentObjectRemovalMode removalMode) {
+    if (removalMode == DocumentObjectRemovalMode::DocumentObjectRemovalMode_Detach) {
+        emit si_beforeObjectRemoved(obj);
+
+        SAFE_POINT(obj->getParentStateLockItem() == this, "Invalid parent document!", false)
+        CHECK(!obj->entityRef.isValid() || !objectsInUse.contains(obj->getEntityRef().entityId), false)
+
+        obj->setModified(false);
+
+        QList<StateLock*> oldLocks = locks;
+        locks.clear();
+        obj->setParentStateLockItem(nullptr);
+        locks = oldLocks;
+
+        objects.removeOne(obj);
+        id2Object.remove(obj->getEntityRef().entityId);
+        obj->setGHints(new GHintsDefaultImpl(obj->getGHintsMap()));
+
+        SAFE_POINT(objects.size() == getChildItems().size(), "Invalid child object count!", false)
+
+        emit si_objectRemoved(obj);
+        delete obj;
+        return true;
+    }
+
     SAFE_POINT(df->isObjectOpSupported(this, DocumentFormat::DocObjectOp_Remove, obj->getGObjectType()), "Unsupported format operation", false);
 
+    emit si_beforeObjectRemoved(obj);
+
     switch (removalMode) {
         case DocumentObjectRemovalMode_Deallocate:
             return _removeObject(obj, true);
@@ -321,12 +358,13 @@ bool Document::removeObject(GObject *obj, DocumentObjectRemovalMode removalMode)
             break;
         case DocumentObjectRemovalMode_Release:
             return _removeObject(obj, false);
+        case DocumentObjectRemovalMode_Detach:
+            break;  // Do nothing.
     }
-
     return true;
 }
 
-bool Document::_removeObject(GObject *obj, bool deleteObjects) {
+bool Document::_removeObject(GObject* obj, bool deleteObjects) {
     SAFE_POINT(obj->getParentStateLockItem() == this, "Invalid parent document!", false);
 
     if (obj->entityRef.isValid() && objectsInUse.contains(obj->getEntityRef().entityId)) {
@@ -345,7 +383,7 @@ bool Document::_removeObject(GObject *obj, bool deleteObjects) {
     emit si_objectRemoved(obj);
 
     if (deleteObjects) {
-        removeObjectsDataFromDbi(QList<GObject *>() << obj);
+        removeObjectsDataFromDbi(QList<GObject*>() << obj);
         delete obj;
     }
     return true;
@@ -356,7 +394,7 @@ void Document::makeClean() {
         return;
     }
     setModified(false);
-    foreach (GObject *obj, objects) {
+    foreach (GObject* obj, objects) {
         obj->setModified(false);
     }
 }
@@ -369,29 +407,29 @@ void Document::setModificationTrack(bool track) {
     }
 }
 
-GObject *Document::findGObjectByNameInDb(const QString &name) const {
+GObject* Document::findGObjectByNameInDb(const QString& name) const {
     U2OpStatusImpl os;
     DbiConnection con(dbiRef, os);
     SAFE_POINT_OP(os, nullptr);
 
-    U2ObjectDbi *oDbi = con.dbi->getObjectDbi();
-    SAFE_POINT(nullptr != oDbi, "Invalid database connection", nullptr);
+    U2ObjectDbi* oDbi = con.dbi->getObjectDbi();
+    SAFE_POINT(oDbi != nullptr, "Invalid database connection", nullptr);
 
     QScopedPointer<U2DbiIterator<U2DataId>> iter(oDbi->getObjectsByVisualName(name, U2Type::Unknown, os));
     SAFE_POINT_OP(os, nullptr);
 
     while (iter->hasNext()) {
         const U2DataId objId = iter->next();
-        GObject *obj = getObjectById(objId);
-        if (nullptr != obj) {
+        GObject* obj = getObjectById(objId);
+        if (obj != nullptr) {
             return obj;
         }
     }
     return nullptr;
 }
 
-GObject *Document::findGObjectByNameInMem(const QString &name) const {
-    foreach (GObject *obj, objects) {
+GObject* Document::findGObjectByNameInMem(const QString& name) const {
+    foreach (GObject* obj, objects) {
         if (obj->getGObjectName() == name) {
             return obj;
         }
@@ -399,11 +437,11 @@ GObject *Document::findGObjectByNameInMem(const QString &name) const {
     return nullptr;
 }
 
-GObject *Document::findGObjectByName(const QString &name) const {
+GObject* Document::findGObjectByName(const QString& name) const {
     return isLoaded() ? findGObjectByNameInDb(name) : findGObjectByNameInMem(name);
 }
 
-QList<GObject *> Document::findGObjectByType(GObjectType t, UnloadedObjectFilter f) const {
+QList<GObject*> Document::findGObjectByType(GObjectType t, UnloadedObjectFilter f) const {
     return GObjectUtils::select(objects, t, f);
 }
 
@@ -426,8 +464,8 @@ void Document::checkUniqueObjectNames() const {
         return;
     }
     QSet<QString> names;
-    foreach (GObject *o, objects) {
-        const QString &name = o->getGObjectName();
+    foreach (GObject* o, objects) {
+        const QString& name = o->getGObjectName();
         assert(!names.contains(name));
         names.insert(name);
     }
@@ -446,24 +484,24 @@ void Document::checkLoadedState() const {
 
 class DocumentChildEventsHelper {
 public:
-    DocumentChildEventsHelper(Document *doc)
+    DocumentChildEventsHelper(Document* doc)
         : doc(doc) {
-        if (nullptr != doc) {
+        if (doc != nullptr) {
             doc->d_ptr->receiveChildEvents = false;
         }
     }
 
     ~DocumentChildEventsHelper() {
-        if (nullptr != doc) {
+        if (doc != nullptr) {
             doc->d_ptr->receiveChildEvents = true;
         }
     }
 
 private:
-    Document *doc;
+    Document* doc;
 };
 
-void Document::loadFrom(Document *sourceDoc) {
+void Document::loadFrom(Document* sourceDoc) {
     SAFE_POINT(!isLoaded(), QString("Document is already loaded: ").arg(getURLString()), )
 
     DocumentChildEventsHelper eventsHelper(this);
@@ -476,7 +514,7 @@ void Document::loadFrom(Document *sourceDoc) {
 
     QMap<QString, UnloadedObjectInfo> unloadedInfo;
 
-    foreach (GObject *obj, objects) {  // remove all unloaded objects but save hints
+    foreach (GObject* obj, objects) {  // remove all unloaded objects but save hints
         unloadedInfo.insert(obj->getGObjectName(), UnloadedObjectInfo(obj));
         _removeObject(obj, documentOwnsDbiResources);
     }
@@ -486,8 +524,8 @@ void Document::loadFrom(Document *sourceDoc) {
     lastUpdateTime = sourceDoc->getLastUpdateTime();
 
     // copy instance mod-locks if any
-    StateLock *mLock = modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
-    StateLock *dLock = sourceDoc->modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
+    StateLock* mLock = modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
+    StateLock* dLock = sourceDoc->modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
     if (mLock != nullptr) {
         if (dLock == nullptr) {
             unlockState(mLock);
@@ -507,14 +545,14 @@ void Document::loadFrom(Document *sourceDoc) {
     sourceDoc->dbiRef = U2DbiRef();
     sourceDoc->setDocumentOwnsDbiResources(false);
 
-    QList<GObject *> sourceObjects = sourceDoc->getObjects();
+    QList<GObject*> sourceObjects = sourceDoc->getObjects();
     sourceDoc->unload(false);
-    for (GObject *obj: qAsConst(sourceObjects)) {
+    for (GObject* obj : qAsConst(sourceObjects)) {
         // TODO: add constrains to ObjectRelations!!
         UnloadedObjectInfo info = unloadedInfo.value(obj->getGObjectName());
         if (info.type == obj->getGObjectType()) {
             QVariantMap mergedHints = obj->getGHintsMap();
-            foreach (const QString &k, info.hints.keys()) {
+            foreach (const QString& k, info.hints.keys()) {
                 if (!mergedHints.contains(k)) {
                     mergedHints.insert(k, info.hints.value(k));
                 } else if (k == GObjectHint_RelatedObjects) {
@@ -538,7 +576,7 @@ void Document::setLoaded(bool v) {
     if (v == isLoaded()) {
         return;
     }
-    StateLock *l = modLocks[DocumentModLock_UNLOADED_STATE];
+    StateLock* l = modLocks[DocumentModLock_UNLOADED_STATE];
     if (v) {
         unlockState(l);
         modLocks[DocumentModLock_UNLOADED_STATE] = nullptr;
@@ -554,7 +592,7 @@ void Document::setLoaded(bool v) {
     emit si_loadedStateChanged();
 }
 
-void Document::initModLocks(const QString &instanceModLockDesc, bool loaded) {
+void Document::initModLocks(const QString& instanceModLockDesc, bool loaded) {
     setLoaded(loaded);
 
     // must be locked for modifications if io-adapter does not support writes
@@ -575,7 +613,7 @@ void Document::initModLocks(const QString &instanceModLockDesc, bool loaded) {
     }
 }
 
-void Document::setName(const QString &newName) {
+void Document::setName(const QString& newName) {
     if (name == newName) {
         return;
     }
@@ -583,7 +621,7 @@ void Document::setName(const QString &newName) {
     emit si_nameChanged();
 }
 
-void Document::setURL(const GUrl &newUrl) {
+void Document::setURL(const GUrl& newUrl) {
     assert(!isLoaded() || !isStateLocked());
     if (url == newUrl) {
         return;
@@ -592,7 +630,7 @@ void Document::setURL(const GUrl &newUrl) {
     emit si_urlChanged();
 }
 
-bool Document::checkConstraints(const Document::Constraints &c) const {
+bool Document::checkConstraints(const Document::Constraints& c) const {
     if (c.stateLocked != TriState_Unknown) {
         if (c.stateLocked == TriState_No && isStateLocked()) {
             return false;
@@ -633,11 +671,11 @@ void Document::setUserModLock(bool v) {
         return;
     }
     if (v) {
-        StateLock *sl = new StateLock(tr("Locked by user"));
+        StateLock* sl = new StateLock(tr("Locked by user"));
         modLocks[DocumentModLock_USER] = sl;
         lockState(sl);
     } else {
-        StateLock *sl = modLocks[DocumentModLock_USER];
+        StateLock* sl = modLocks[DocumentModLock_USER];
         modLocks[DocumentModLock_USER] = nullptr;
         unlockState(sl);
         delete sl;
@@ -654,10 +692,10 @@ bool Document::unload(bool deleteObjects) {
     DocumentChildEventsHelper eventsHelper(this);
     Q_UNUSED(eventsHelper);
 
-    QList<StateLock *> locks = findLocks(StateLockableTreeFlags_ItemAndChildren, StateLockFlag_LiveLock);
+    QList<StateLock*> locks = findLocks(StateLockableTreeFlags_ItemAndChildren, StateLockFlag_LiveLock);
     bool liveLocked = (locks.size() > 1);
     if (locks.size() == 1 && !liveLocked) {
-        SAFE_POINT(locks.first() != nullptr, tr("Lock is NULL"), false);
+        SAFE_POINT(locks.first() != nullptr, "Lock is NULL", false);
         liveLocked &= (locks.first()->getUserDesc() == UNLOAD_LOCK_NAME);
     }
     if (liveLocked) {
@@ -668,8 +706,8 @@ bool Document::unload(bool deleteObjects) {
     loadStateChangeMode = true;
 
     QList<UnloadedObjectInfo> unloadedInfo;
-    QList<GObject *> tmpObjects;
-    foreach (GObject *obj, objects) {
+    QList<GObject*> tmpObjects;
+    foreach (GObject* obj, objects) {
         unloadedInfo.append(UnloadedObjectInfo(obj));
         // exclude objects from the document
         tmpObjects.append(obj);
@@ -685,7 +723,7 @@ bool Document::unload(bool deleteObjects) {
         qDeleteAll(tmpObjects);
     }
 
-    StateLock *fl = modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
+    StateLock* fl = modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
     if (fl != nullptr) {
         unlockState(fl);
         modLocks[DocumentModLock_FORMAT_AS_INSTANCE] = nullptr;
@@ -701,15 +739,11 @@ bool Document::unload(bool deleteObjects) {
     return true;
 }
 
-const U2DbiRef &Document::getDbiRef() const {
+const U2DbiRef& Document::getDbiRef() const {
     return dbiRef;
 }
 
-bool Document::isDatabaseConnection() const {
-    return BaseDocumentFormats::DATABASE_CONNECTION == df->getFormatId();
-}
-
-void Document::setModified(bool modified, const QString &modType) {
+void Document::setModified(bool modified, const QString& modType) {
     CHECK(!df->checkFlags(DocumentFormatFlag_DirectWriteOperations), );
     if (loadStateChangeMode && modified && modType == StateLockModType_AddChild) {  // ignore modification events during loading/unloading
         return;
@@ -717,13 +751,13 @@ void Document::setModified(bool modified, const QString &modType) {
     StateLockableTreeItem::setModified(modified, modType);
 }
 
-bool Document::isModificationAllowed(const QString &modType) {
+bool Document::isModificationAllowed(const QString& modType) {
     bool ok = loadStateChangeMode && modType == StateLockModType_AddChild;
     ok = ok || StateLockableTreeItem::isModificationAllowed(modType);
     return ok;
 }
 
-void Document::setGHints(GHints *newHints) {
+void Document::setGHints(GHints* newHints) {
     assert(newHints != nullptr);
     // gobjects in document keep states in parent document map -> preserve gobject hints
     if (newHints == ctxState) {
@@ -731,7 +765,7 @@ void Document::setGHints(GHints *newHints) {
     }
     QList<QVariantMap> objectHints;
     for (int i = 0; i < objects.size(); i++) {
-        GObject *obj = objects[i];
+        GObject* obj = objects[i];
         objectHints.append(obj->getGHintsMap());
     }
 
@@ -739,15 +773,15 @@ void Document::setGHints(GHints *newHints) {
     ctxState = newHints;
 
     for (int i = 0; i < objects.size(); i++) {
-        const QVariantMap &hints = objectHints[i];
-        GObject *obj = objects[i];
+        const QVariantMap& hints = objectHints[i];
+        GObject* obj = objects[i];
         obj->getGHints()->setMap(hints);
     }
 }
 
-void Document::addUnloadedObjects(const QList<UnloadedObjectInfo> &info) {
-    foreach (const UnloadedObjectInfo &oi, info) {
-        UnloadedObject *obj = new UnloadedObject(oi);
+void Document::addUnloadedObjects(const QList<UnloadedObjectInfo>& info) {
+    foreach (const UnloadedObjectInfo& oi, info) {
+        UnloadedObject* obj = new UnloadedObject(oi);
         obj->moveToThread(thread());
         _addObjectToHierarchy(obj);
         assert(obj->getDocument() == this);
@@ -759,23 +793,23 @@ QVariantMap Document::getGHintsMap() const {
     return ctxState->getMap();
 }
 
-void Document::setupToEngine(QScriptEngine *engine) {
+void Document::setupToEngine(QScriptEngine* engine) {
     qScriptRegisterMetaType(engine, toScriptValue, fromScriptValue);
 }
 
-QScriptValue Document::toScriptValue(QScriptEngine *engine, Document *const &in) {
+QScriptValue Document::toScriptValue(QScriptEngine* engine, Document* const& in) {
     return engine->newQObject(in);
 }
 
-void Document::fromScriptValue(const QScriptValue &object, Document *&out) {
-    out = qobject_cast<Document *>(object.toQObject());
+void Document::fromScriptValue(const QScriptValue& object, Document*& out) {
+    out = qobject_cast<Document*>(object.toQObject());
 }
 
-void Document::removeObjectsDataFromDbi(QList<GObject *> objects) {
+void Document::removeObjectsDataFromDbi(QList<GObject*> objects) {
     const bool removeAsynchronously = AppContext::isGUIMode() && QCoreApplication::instance()->thread() == QThread::currentThread() && !ctxState->getMap().contains(DocumentRemovalMode_Synchronous);
     if (removeAsynchronously) {
         // Do not remove objects in the main thread to prevent GUI hanging
-        DeleteObjectsTask *deleteTask = new DeleteObjectsTask(objects);
+        DeleteObjectsTask* deleteTask = new DeleteObjectsTask(objects);
         AppContext::getTaskScheduler()->registerTopLevelTask(deleteTask);
     } else {
         U2OpStatus2Log os;
@@ -786,7 +820,7 @@ void Document::removeObjectsDataFromDbi(QList<GObject *> objects) {
         CHECK_OP(os, );
         CHECK(con.dbi->getFeatures().contains(U2DbiFeature_RemoveObjects), );
 
-        foreach (GObject *object, objects) {
+        foreach (GObject* object, objects) {
             U2OpStatus2Log osLog;
             SAFE_POINT(object != nullptr, "NULL object was provided", );
             con.dbi->getObjectDbi()->removeObject(object->getEntityRef().entityId, true, osLog);
@@ -801,22 +835,22 @@ void Document::setLastUpdateTime() {
     }
 }
 
-void Document::propagateModLocks(Document *doc) const {
+void Document::propagateModLocks(Document* doc) const {
     for (int i = 0; i < DocumentModLock_NUM_LOCKS; i++) {
-        StateLock *lock = modLocks[i];
+        StateLock* lock = modLocks[i];
         if (lock != nullptr && doc->modLocks[i] != nullptr) {
-            StateLock *newLock = new StateLock(lock->getUserDesc(), lock->getFlags());
+            StateLock* newLock = new StateLock(lock->getUserDesc(), lock->getFlags());
             doc->modLocks[i] = newLock;
             doc->lockState(newLock);
         }
     }
 }
 
-void Document::setIOAdapterFactory(IOAdapterFactory *iof) {
+void Document::setIOAdapterFactory(IOAdapterFactory* iof) {
     io = iof;
 }
 
-DocumentMimeData::DocumentMimeData(Document *obj)
+DocumentMimeData::DocumentMimeData(Document* obj)
     : objPtr(obj) {
     setUrls(QList<QUrl>() << QUrl(GUrlUtils::gUrl2qUrl(obj->getURL())));
 }
