@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOCUMENT_MODEL_H_
-#define _U2_DOCUMENT_MODEL_H_
+#pragma once
 
 #include <QDateTime>
 #include <QMimeData>
@@ -116,6 +115,12 @@ typedef QFlags<DocumentFormatFlag> DocumentFormatFlags;
 #define DocumentReadingMode_DontMakeUniqueNames "no-unique-names"
 #define DocumentReadingMode_LoadAsModified "load-as-modified"
 
+/**
+ * By default document format parsers treat empty files as error.
+ * This flag makes empty files valid. Supported by a limited set of formats only (FASTA).
+ */
+#define DocumentReadingMode_AllowEmptyFile "allow-empty-file"
+
 /** Set of hints that can be processed during document storing */
 #define DocumentWritingMode_SimpleNames "simple-names"
 
@@ -128,6 +133,9 @@ typedef QFlags<DocumentFormatFlag> DocumentFormatFlags;
 /** Set of hints that can be processed during objects conversion */
 #define ObjectConvertion_UseGenbankHeader "use-genbank-header"
 
+/** Set of hints for formats with importers */
+#define ImportHint_DestinationUrl "import-hint-destination-url"
+
 class U2CORE_EXPORT DocumentFormat : public QObject {
     Q_OBJECT
 public:
@@ -143,20 +151,20 @@ public:
         DocObjectOp_Remove
     };
 
-    DocumentFormat(QObject *p, const DocumentFormatId &id, DocumentFormatFlags _flags, const QStringList &fileExts = QStringList());
+    DocumentFormat(QObject* p, const DocumentFormatId& id, DocumentFormatFlags _flags, const QStringList& fileExts = QStringList());
 
     /* returns unique document format id */
-    const DocumentFormatId &getFormatId() const {
+    const DocumentFormatId& getFormatId() const {
         return id;
     }
 
     /* Returns localized format name. */
-    const QString &getFormatName() const {
+    const QString& getFormatName() const {
         return formatName;
     }
 
     /* Returns localized format description. */
-    const QString &getFormatDescription() const {
+    const QString& getFormatDescription() const {
         return formatDescription;
     }
 
@@ -172,45 +180,45 @@ public:
      * Hints contain additional information for document loading Common hints:
      * 1) DBI_ALIAS_HINT is used for keeping special DBI-alias
      */
-    virtual Document *createNewLoadedDocument(IOAdapterFactory *io, const GUrl &url, U2OpStatus &os, const QVariantMap &hints = QVariantMap());
+    virtual Document* createNewLoadedDocument(IOAdapterFactory* io, const GUrl& url, U2OpStatus& os, const QVariantMap& hints = QVariantMap());
 
     /** Creates new document in unloaded state. Assigns DBI if needed */
-    virtual Document *createNewUnloadedDocument(IOAdapterFactory *iof, const GUrl &url, U2OpStatus &os, const QVariantMap &hints = QVariantMap(), const QList<UnloadedObjectInfo> &info = QList<UnloadedObjectInfo>(), const QString &instanceModLockDesc = QString());
+    virtual Document* createNewUnloadedDocument(IOAdapterFactory* iof, const GUrl& url, U2OpStatus& os, const QVariantMap& hints = QVariantMap(), const QList<UnloadedObjectInfo>& info = QList<UnloadedObjectInfo>(), const QString& instanceModLockDesc = QString());
 
     /** A method for compatibility with old code : creates IO adapter and loads document in DocumentLoadMode_Whole
      * Hints contain additional information for document loading. Common hints:
      * 1) DBI_ALIAS_HINT is used for keeping special DBI-alias
      */
-    virtual Document *loadDocument(IOAdapterFactory *iof, const GUrl &url, const QVariantMap &hints, U2OpStatus &os);
+    virtual Document* loadDocument(IOAdapterFactory* iof, const GUrl& url, const QVariantMap& hints, U2OpStatus& os);
 
     /**
         Loads single dna sequence in streaming mode.
         Note! this function is available only if format supports streaming mode and sequences as an stored data type
     */
-    virtual DNASequence *loadSequence(IOAdapter *io, U2OpStatus &ti);
+    virtual DNASequence* loadSequence(IOAdapter* io, U2OpStatus& ti);
 
-    virtual void storeDocument(Document *d, U2OpStatus &os, IOAdapterFactory *io = nullptr, const GUrl &newDocURL = GUrl());
+    virtual void storeDocument(Document* d, U2OpStatus& os, IOAdapterFactory* io = nullptr, const GUrl& newDocURL = GUrl());
 
     /* io - opened IOAdapter
      * so you can store many documents to this file
      */
-    virtual void storeDocument(Document *d, IOAdapter *io, U2OpStatus &os);
+    virtual void storeDocument(Document* d, IOAdapter* io, U2OpStatus& os);
 
     /** Checks if object can be added/removed to the document */
-    virtual bool isObjectOpSupported(const Document *d, DocObjectOp op, GObjectType t) const;
+    virtual bool isObjectOpSupported(const Document* d, DocObjectOp op, GObjectType t) const;
 
     /*
         Returns score rating that indicates that the data supplied is recognized as a valid document format
         Note: Data can contain only first N (~1024) bytes of the file
         The URL value is optional and provided as supplementary option. URL value here can be empty in some special cases.
     */
-    virtual FormatCheckResult checkRawData(const QByteArray &dataPrefix, const GUrl &url = GUrl()) const = 0;
+    virtual FormatCheckResult checkRawData(const QByteArray& dataPrefix, const GUrl& url = GUrl()) const = 0;
 
     /* Checks that document format satisfies given constraints */
-    virtual bool checkConstraints(const DocumentFormatConstraints &c) const;
+    virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
 
     /* Default implementation does nothing */
-    virtual void updateFormatSettings(Document *d) const {
+    virtual void updateFormatSettings(Document* d) const {
         Q_UNUSED(d);
     }
 
@@ -218,7 +226,7 @@ public:
         These object types can be produced by reading documents
         If the format supports write it must support write operation for all the object types it support
     */
-    const QSet<GObjectType> &getSupportedObjectTypes() const {
+    const QSet<GObjectType>& getSupportedObjectTypes() const {
         return supportedObjectTypes;
     }
 
@@ -237,7 +245,7 @@ public:
         return formatFlags.testFlag(DocumentFormatFlag_SupportStreaming);
     }
 
-    virtual void storeEntry(IOAdapter *io, const QMap<GObjectType, QList<GObject *>> &objectsMap, U2OpStatus &os);
+    virtual void storeEntry(IOAdapter* io, const QMap<GObjectType, QList<GObject*>>& objectsMap, U2OpStatus& os);
 
     virtual QString getRadioButtonText() const;
 
@@ -246,7 +254,7 @@ protected:
      * if document format supports streaming reading it must correctly process DocumentLoadMode
      * otherwise, it will load all file from starting position ( default )
      */
-    virtual Document *loadDocument(IOAdapter *io, const U2DbiRef &targetDb, const QVariantMap &hints, U2OpStatus &os) = 0;
+    virtual Document* loadDocument(IOAdapter* io, const U2DbiRef& targetDb, const QVariantMap& hints, U2OpStatus& os) = 0;
 
     DocumentFormatId id;
     DocumentFormatFlags formatFlags;
@@ -256,7 +264,7 @@ protected:
     QString formatDescription;
 
 private:
-    U2DbiRef fetchDbiRef(const QVariantMap &hints, U2OpStatus &os) const;
+    U2DbiRef fetchDbiRef(const QVariantMap& hints, U2OpStatus& os) const;
 };
 
 class DocumentFormatConstraints {
@@ -298,27 +306,27 @@ class DocumentImportersRegistry;
 class U2CORE_EXPORT DocumentFormatRegistry : public QObject {
     Q_OBJECT
 public:
-    DocumentFormatRegistry(QObject *p = nullptr)
+    DocumentFormatRegistry(QObject* p = nullptr)
         : QObject(p) {
     }
 
-    virtual bool registerFormat(DocumentFormat *dfs) = 0;
+    virtual bool registerFormat(DocumentFormat* dfs) = 0;
 
-    virtual bool unregisterFormat(DocumentFormat *dfs) = 0;
+    virtual bool unregisterFormat(DocumentFormat* dfs) = 0;
 
     virtual QList<DocumentFormatId> getRegisteredFormats() const = 0;
 
-    virtual DocumentFormat *getFormatById(DocumentFormatId id) const = 0;
+    virtual DocumentFormat* getFormatById(DocumentFormatId id) const = 0;
 
-    virtual DocumentFormat *selectFormatByFileExtension(const QString &fileExt) const = 0;
+    virtual DocumentFormat* selectFormatByFileExtension(const QString& fileExt) const = 0;
 
-    virtual QList<DocumentFormatId> selectFormats(const DocumentFormatConstraints &c) const = 0;
+    virtual QList<DocumentFormatId> selectFormats(const DocumentFormatConstraints& c) const = 0;
 
-    virtual DocumentImportersRegistry *getImportSupport() = 0;
+    virtual DocumentImportersRegistry* getImportSupport() = 0;
 
 signals:
-    void si_documentFormatRegistered(DocumentFormat *);
-    void si_documentFormatUnregistered(DocumentFormat *);
+    void si_documentFormatRegistered(DocumentFormat*);
+    void si_documentFormatUnregistered(DocumentFormat*);
 };
 
 enum DocumentModLock {
@@ -334,9 +342,10 @@ enum DocumentObjectRemovalMode {
     DocumentObjectRemovalMode_Deallocate,  // ordinary removal: both object and its DB representation are deallocated
     DocumentObjectRemovalMode_OnlyNotify,  // fake removal: neither object nor its DB representation are deallocated.
     // Only signals about removal are emitted. The object itself remains to belong to the document.
-    DocumentObjectRemovalMode_Release  // fake removal: the same as DocumentObjectRemovalMode_OnlyNotify.
+    DocumentObjectRemovalMode_Release,  // fake removal: the same as DocumentObjectRemovalMode_OnlyNotify.
     // Additionally, the object is excluded from the document's child objects list.
     // External code has to handle a proper object deallocation.
+    DocumentObjectRemovalMode_Detach  // sudo removes an object from the doc, removes an object, leaving it in the db.
 };
 
 class DocumentChildEventsHelper;
@@ -362,14 +371,14 @@ public:
     static const QString UNLOAD_LOCK_NAME;
 
     // Creates document in unloaded state. Populates it with unloaded objects
-    Document(DocumentFormat *_df, IOAdapterFactory *_io, const GUrl &_url, const U2DbiRef &_dbiRef, const QList<UnloadedObjectInfo> &unloadedObjects = QList<UnloadedObjectInfo>(), const QVariantMap &hints = QVariantMap(), const QString &instanceModLockDesc = QString());
+    Document(DocumentFormat* _df, IOAdapterFactory* _io, const GUrl& _url, const U2DbiRef& _dbiRef, const QList<UnloadedObjectInfo>& unloadedObjects = QList<UnloadedObjectInfo>(), const QVariantMap& hints = QVariantMap(), const QString& instanceModLockDesc = QString());
 
     // Creates document in loaded state.
-    Document(DocumentFormat *_df, IOAdapterFactory *_io, const GUrl &_url, const U2DbiRef &_dbiRef, const QList<GObject *> &objects, const QVariantMap &hints = QVariantMap(), const QString &instanceModLockDesc = QString());
+    Document(DocumentFormat* _df, IOAdapterFactory* _io, const GUrl& _url, const U2DbiRef& _dbiRef, const QList<GObject*>& objects, const QVariantMap& hints = QVariantMap(), const QString& instanceModLockDesc = QString());
 
     virtual ~Document();
 
-    DocumentFormat *getDocumentFormat() const {
+    DocumentFormat* getDocumentFormat() const {
         return df;
     }
 
@@ -377,39 +386,42 @@ public:
         return df->getFormatId();
     }
 
-    IOAdapterFactory *getIOAdapterFactory() const {
+    IOAdapterFactory* getIOAdapterFactory() const {
         return io;
     }
 
-    void setIOAdapterFactory(IOAdapterFactory *iof);
+    void setIOAdapterFactory(IOAdapterFactory* iof);
 
-    const QList<GObject *> &getObjects() const {
+    const QList<GObject*>& getObjects() const {
         return objects;
     }
 
-    GObject *getObjectById(const U2DataId &id) const;
+    GObject* getObjectById(const U2DataId& id) const;
 
-    void addObject(GObject *ref);
+    //Returns list of Ids for objects with given type
+    QList<U2DataId> findGObjectIdsByType(const GObjectType& type) const;
 
-    bool removeObject(GObject *o, DocumentObjectRemovalMode removalMode = DocumentObjectRemovalMode_Deallocate);
+    void addObject(GObject* ref);
 
-    void setObjectsInUse(const QSet<U2DataId> &objs);
+    bool removeObject(GObject* o, DocumentObjectRemovalMode removalMode = DocumentObjectRemovalMode_Deallocate);
 
-    const QString &getName() const {
+    void setObjectsInUse(const QSet<U2DataId>& objs);
+
+    const QString& getName() const {
         return name;
     }
 
-    void setName(const QString &newName);
+    void setName(const QString& newName);
 
-    const GUrl &getURL() const {
+    const GUrl& getURL() const {
         return url;
     }
 
-    const QString &getURLString() const {
+    const QString& getURLString() const {
         return url.getURLString();
     }
 
-    void setURL(const GUrl &newUrl);
+    void setURL(const GUrl& newUrl);
 
     void makeClean();
 
@@ -418,9 +430,9 @@ public:
     // avoid using this method against shared databases documents,
     // since databases allow many objects with the same name. The method returns
     // first matched GObject. Use `getObjectById` instead.
-    GObject *findGObjectByName(const QString &name) const;
+    GObject* findGObjectByName(const QString& name) const;
 
-    QList<GObject *> findGObjectByType(GObjectType t, UnloadedObjectFilter f = UOF_LoadedOnly) const;
+    QList<GObject*> findGObjectByType(GObjectType t, UnloadedObjectFilter f = UOF_LoadedOnly) const;
 
     bool isLoaded() const {
         return modLocks[DocumentModLock_UNLOADED_STATE] == 0;
@@ -429,26 +441,26 @@ public:
     void setLoaded(bool v);
 
     /** Takes content from sourceDoc. Source doc becomes unloaded after this op is completed! */
-    void loadFrom(Document *sourceDoc);
+    void loadFrom(Document* sourceDoc);
 
     /** If deleteObjects is false -> does not delete objects and leaves them without parent */
     bool unload(bool deleteObjects = true);
 
-    bool checkConstraints(const Constraints &c) const;
+    bool checkConstraints(const Constraints& c) const;
 
-    GHints *getGHints() const {
+    GHints* getGHints() const {
         return ctxState;
     }
 
-    void setGHints(GHints *state);
+    void setGHints(GHints* state);
 
     QVariantMap getGHintsMap() const;
 
-    StateLock *getDocumentModLock(DocumentModLock type) const {
+    StateLock* getDocumentModLock(DocumentModLock type) const {
         return modLocks[type];
     }
 
-    void propagateModLocks(Document *doc) const;
+    void propagateModLocks(Document* doc) const;
 
     bool hasUserModLock() const {
         return modLocks[DocumentModLock_USER] != nullptr;
@@ -456,9 +468,9 @@ public:
 
     void setUserModLock(bool v);
 
-    virtual void setModified(bool modified, const QString &modType = QString());
+    virtual void setModified(bool modified, const QString& modType = QString());
 
-    virtual bool isModificationAllowed(const QString &modType);
+    virtual bool isModificationAllowed(const QString& modType);
 
     bool isModified() const {
         return isTreeItemModified();
@@ -466,11 +478,11 @@ public:
 
     void setLastUpdateTime();
 
-    const QDateTime &getLastUpdateTime() const {
+    const QDateTime& getLastUpdateTime() const {
         return lastUpdateTime;
     }
 
-    const U2DbiRef &getDbiRef() const;
+    const U2DbiRef& getDbiRef() const;
 
     inline bool isDocumentOwnsDbiResources() const {
         return documentOwnsDbiResources;
@@ -480,53 +492,56 @@ public:
         documentOwnsDbiResources = value;
     }
 
-    virtual bool isDatabaseConnection() const;
+    inline QList<U2DataId> getDocObjectsIds() const {
+        return id2Object.keys();
+    }
 
-    static void setupToEngine(QScriptEngine *engine);
+    static void setupToEngine(QScriptEngine* engine);
 
-    Document *getSimpleCopy(DocumentFormat *df, IOAdapterFactory *io, const GUrl &url) const;
+    Document* getSimpleCopy(DocumentFormat* df, IOAdapterFactory* io, const GUrl& url) const;
 
 private:
-    static QScriptValue toScriptValue(QScriptEngine *engine, Document *const &in);
-    static void fromScriptValue(const QScriptValue &object, Document *&out);
+    static QScriptValue toScriptValue(QScriptEngine* engine, Document* const& in);
+    static void fromScriptValue(const QScriptValue& object, Document*& out);
 
 protected:
-    void removeObjectsDataFromDbi(QList<GObject *> objects);
-    bool _removeObject(GObject *o, bool deleteObjects = true);
-    void _addObject(GObject *obj);
-    void _addObjectToHierarchy(GObject *obj);
+    void removeObjectsDataFromDbi(QList<GObject*> objects);
+    bool _removeObject(GObject* o, bool deleteObjects = true);
+    void _addObject(GObject* obj);
+    void _addObjectToHierarchy(GObject* obj);
 
-    void initModLocks(const QString &instanceModLockDesc, bool loaded);
+    void initModLocks(const QString& instanceModLockDesc, bool loaded);
 
     void checkUnloadedState() const;
     void checkLoadedState() const;
     void checkUniqueObjectNames() const;
-    void addUnloadedObjects(const QList<UnloadedObjectInfo> &info);
+    void addUnloadedObjects(const QList<UnloadedObjectInfo>& info);
 
-    GObject *findGObjectByNameInDb(const QString &name) const;
-    GObject *findGObjectByNameInMem(const QString &name) const;
+    GObject* findGObjectByNameInDb(const QString& name) const;
+    GObject* findGObjectByNameInMem(const QString& name) const;
 
-    DocumentFormat *const df;
-    IOAdapterFactory *io;
+    DocumentFormat* const df;
+    IOAdapterFactory* io;
     GUrl url;
     U2DbiRef dbiRef;  // Default dbi ref for the document
 
     QString name; /* display name == short pathname, excluding the path */
-    QList<GObject *> objects;
-    QHash<U2DataId, GObject *> id2Object;
+    QList<GObject*> objects;
+    QHash<U2DataId, GObject*> id2Object;
     QSet<U2DataId> objectsInUse;
-    GHints *ctxState;
+    GHints* ctxState;
     QDateTime lastUpdateTime;
     bool documentOwnsDbiResources;
 
-    StateLock *modLocks[DocumentModLock_NUM_LOCKS];
+    StateLock* modLocks[DocumentModLock_NUM_LOCKS];
     bool loadStateChangeMode;
 
 signals:
     void si_urlChanged();
     void si_nameChanged();
-    void si_objectAdded(GObject *o);
-    void si_objectRemoved(GObject *o);
+    void si_objectAdded(GObject* o);
+    void si_beforeObjectRemoved(GObject* o);
+    void si_objectRemoved(GObject* o);
     void si_loadedStateChanged();
 };
 
@@ -536,16 +551,16 @@ class U2CORE_EXPORT DocumentFilter {
 public:
     virtual ~DocumentFilter() {
     }
-    virtual bool matches(Document *doc) const = 0;
+    virtual bool matches(Document* doc) const = 0;
 };
 
 class U2CORE_EXPORT DocumentConstraintsFilter : public DocumentFilter {
 public:
-    DocumentConstraintsFilter(const Document::Constraints &_c)
+    DocumentConstraintsFilter(const Document::Constraints& _c)
         : constraints(_c) {
     }
 
-    virtual bool matches(Document *doc) const {
+    virtual bool matches(Document* doc) const {
         return doc->checkConstraints(constraints);
     }
 
@@ -557,9 +572,9 @@ class U2CORE_EXPORT DocumentMimeData : public QMimeData {
     Q_OBJECT
 public:
     static const QString MIME_TYPE;
-    DocumentMimeData(Document *obj);
+    DocumentMimeData(Document* obj);
     QPointer<Document> objPtr;
-    bool hasFormat(const QString &mimeType) const {
+    bool hasFormat(const QString& mimeType) const {
         return (mimeType == MIME_TYPE);
     }
     QStringList formats() const {
@@ -569,7 +584,5 @@ public:
 
 }  // namespace U2
 
-Q_DECLARE_METATYPE(U2::Document *)
+Q_DECLARE_METATYPE(U2::Document*)
 Q_DECLARE_OPERATORS_FOR_FLAGS(U2::DocumentFormatFlags)
-
-#endif
