@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOCUMENT_UTILS_H_
-#define _U2_DOCUMENT_UTILS_H_
+#pragma once
 
 #include <QFile>
 
@@ -37,10 +36,10 @@ class DocumentImporter;
 class U2CORE_EXPORT FormatDetectionResult {
 public:
     /** Detected document format. */
-    DocumentFormat *format = nullptr;
+    DocumentFormat* format = nullptr;
 
     /** DocumentImporter that can be used to import the data. */
-    DocumentImporter *importer = nullptr;
+    DocumentImporter* importer = nullptr;
 
     /** Raw binary data from the URL. Present for all formats. For text formats this may be raw unicode bytes. */
     QByteArray rawBinaryData;
@@ -93,7 +92,7 @@ class U2CORE_EXPORT DocumentUtils : public QObject {
     Q_OBJECT
 public:
     /* returns set with document urls */
-    static QSet<QString> getURLs(const QList<Document *> &docs);
+    static QSet<QString> getURLs(const QList<Document*>& docs);
 
     /*  The set of urls that should not be used for new documents
         returns list of loaded urls. Gets them from the active project
@@ -101,19 +100,19 @@ public:
     static QSet<QString> getNewDocFileNameExcludesHint();
 
     /* Detects document format. The best match goes first in the returned list */
-    static QList<FormatDetectionResult> detectFormat(const GUrl &url, const FormatDetectionConfig &conf = FormatDetectionConfig());
+    static QList<FormatDetectionResult> detectFormat(const GUrl& url, const FormatDetectionConfig& conf = FormatDetectionConfig());
 
     /*
         Detects document format. The best match goes first in the returned list
         IOAdapter must be opened
         */
-    static QList<FormatDetectionResult> detectFormat(IOAdapter *io, const FormatDetectionConfig &conf = FormatDetectionConfig());
+    static QList<FormatDetectionResult> detectFormat(IOAdapter* io, const FormatDetectionConfig& conf = FormatDetectionConfig());
 
     /*
         Detects document format. The best match goes first in the returned list
         ext & url can be used here to add extension bonus to the final score
         */
-    static QList<FormatDetectionResult> detectFormat(const QByteArray &rawData, const QString &ext = QString(), const GUrl &url = GUrl(), const FormatDetectionConfig &conf = FormatDetectionConfig());
+    static QList<FormatDetectionResult> detectFormat(const QByteArray& rawData, const QString& ext = QString(), const GUrl& url = GUrl(), const FormatDetectionConfig& conf = FormatDetectionConfig());
 
     /*
         Find the best matching document format and stores it in @resultId.
@@ -123,25 +122,23 @@ public:
         FORMAT,
         IMPORTER
     };
-    static Detection detectFormat(const GUrl &url, QString &resultId);
+    static Detection detectFormat(const GUrl& url, QString& resultId);
 
-    static QList<DocumentFormat *> toFormats(const QList<FormatDetectionResult> &infos);
+    static QList<DocumentFormat*> toFormats(const QList<FormatDetectionResult>& infos);
 
-    static bool canAddGObjectsToDocument(Document *doc, const GObjectType &type);
+    static bool canAddGObjectsToDocument(Document* doc, const GObjectType& type);
 
-    static bool canRemoveGObjectFromDocument(GObject *obj);
+    static bool canRemoveGObjectFromDocument(GObject* obj);
 
-    static void removeDocumentsContainigGObjectFromProject(GObject *obj);
+    static void removeDocumentsContainigGObjectFromProject(GObject* obj);
 
-    static QFile::Permissions getPermissions(Document *doc);
+    static QFile::Permissions getPermissions(Document* doc);
 
     /** Creates new document that contains data from original one restructured to new form according to document hints
         For example: combines all sequences to alignment, merge sequences, etc
         Return NULL if no restructuring was made
         */
-    static Document *createCopyRestructuredWithHints(Document *doc, U2OpStatus &os, bool shallowCopy = false);
+    static Document* createCopyRestructuredWithHints(Document* doc, U2OpStatus& os, bool shallowCopy = false);
 };
 
 }  // namespace U2
-
-#endif
