@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -36,9 +36,9 @@
 
 namespace U2 {
 
-GObject::GObject(QString _type, const QString &_name, const QVariantMap &hintsMap)
-    : dataLoaded(false), type(_type), name(_name), arePermanentRelationsFetched(false) {
-    SAFE_POINT(!name.isEmpty(), "Invalid object name detected", );
+GObject::GObject(QString _type, const QString& _name, const QVariantMap& hintsMap)
+    : dataLoaded(false), type(_type), name(_name) {
+    SAFE_POINT(!name.isEmpty(), "Got an empty object name, type: " + type, );
     setupHints(hintsMap);
 }
 
@@ -51,27 +51,27 @@ QVariantMap GObject::getGHintsMap() const {
     return getGHints()->getMap();
 }
 
-Document *GObject::getDocument() const {
-    StateLockableTreeItem *sl = getParentStateLockItem();
-    Document *doc = qobject_cast<Document *>(sl);
+Document* GObject::getDocument() const {
+    StateLockableTreeItem* sl = getParentStateLockItem();
+    auto doc = qobject_cast<Document*>(sl);
     return doc;
 }
 
-void GObject::setGHints(GHints *s) {
+void GObject::setGHints(GHints* s) {
     delete hints;
     hints = s;
 }
 
-void GObject::setGObjectName(const QString &newName) {
+void GObject::setGObjectName(const QString& newName) {
     CHECK(name != newName, );
 
     if (entityRef.dbiRef.isValid()) {
         U2OpStatus2Log os;
         DbiConnection con(entityRef.dbiRef, os);
         CHECK_OP(os, );
-        CHECK(nullptr != con.dbi, );
-        U2ObjectDbi *oDbi = con.dbi->getObjectDbi();
-        CHECK(nullptr != oDbi, );
+        CHECK(con.dbi != nullptr, );
+        U2ObjectDbi* oDbi = con.dbi->getObjectDbi();
+        CHECK(oDbi != nullptr, );
 
         oDbi->renameObject(entityRef.entityId, newName, os);
         CHECK_OP(os, );
@@ -80,7 +80,7 @@ void GObject::setGObjectName(const QString &newName) {
     setGObjectNameNotDbi(newName);
 }
 
-void GObject::setGObjectNameNotDbi(const QString &newName) {
+void GObject::setGObjectNameNotDbi(const QString& newName) {
     CHECK(name != newName, );
 
     QString oldName = name;
@@ -92,63 +92,10 @@ void GObject::setGObjectNameNotDbi(const QString &newName) {
 
 QList<GObjectRelation> GObject::getObjectRelations() const {
     SAFE_POINT(hints != nullptr, "Object hints is NULL", QList<GObjectRelation>());
-    QList<GObjectRelation> res = hints->get(GObjectHint_RelatedObjects).value<QList<GObjectRelation>>();
-
-    // fetch permanent object relations from DB
-    // only for the first time for objects from shared DBs
-    Document *parentDoc = getDocument();
-    if (!arePermanentRelationsFetched && !isUnloaded() && !(nullptr != parentDoc && !parentDoc->isDatabaseConnection())) {
-        fetchPermanentGObjectRelations(res);
-    }
-
-    return res;
+    return hints->get(GObjectHint_RelatedObjects).value<QList<GObjectRelation>>();
 }
 
-void GObject::fetchPermanentGObjectRelations(QList<GObjectRelation> &res) const {
-    Document *parentDoc = getDocument();
-    // take into account the case when the object was not added to document
-    CHECK(nullptr != parentDoc && entityRef.dbiRef.isValid(), );
-
-    U2OpStatusImpl os;
-    DbiConnection con(entityRef.dbiRef, os);
-    SAFE_POINT_OP(os, );
-
-    U2ObjectRelationsDbi *rDbi = con.dbi->getObjectRelationsDbi();
-    SAFE_POINT(rDbi != nullptr, "Invalid object relations DBI detected!", );
-
-    const QList<U2ObjectRelation> rawDbRelations = rDbi->getObjectRelations(entityRef.entityId, os);
-    SAFE_POINT_OP(os, );
-
-    const QString docUrl = parentDoc->getURLString();
-    QList<GObjectRelation> dbRelations;
-    foreach (const U2ObjectRelation &relation, rawDbRelations) {
-        if (nullptr != parentDoc->findGObjectByName(relation.referencedName)) {
-            GObjectReference reference(docUrl, relation.referencedName, relation.referencedType);
-            reference.entityRef = U2EntityRef(entityRef.dbiRef, relation.referencedObject);
-            const GObjectRelation relationFromDb(reference, relation.relationRole);
-            dbRelations.append(relationFromDb);
-
-            if (!res.contains(relationFromDb)) {
-                res.append(relationFromDb);
-            }
-        }
-    }
-
-    QList<GObjectRelation> relationsMissedFromDb;
-    foreach (const GObjectRelation &relation, res) {
-        if (!dbRelations.contains(relation)) {
-            relationsMissedFromDb.append(relation);
-        }
-    }
-    if (!relationsMissedFromDb.isEmpty()) {
-        const_cast<GObject *>(this)->setRelationsInDb(relationsMissedFromDb);
-    }
-
-    hints->set(GObjectHint_RelatedObjects, QVariant::fromValue<QList<GObjectRelation>>(res));
-    const_cast<GObject *>(this)->arePermanentRelationsFetched = true;
-}
-
-void GObject::setObjectRelations(const QList<GObjectRelation> &list) {
+void GObject::setObjectRelations(const QList<GObjectRelation>& list) {
     QList<GObjectRelation> internalCopy = list;
     QList<GObjectRelation> oldRelations = getObjectRelations();
     setRelationsInDb(internalCopy);
@@ -156,19 +103,19 @@ void GObject::setObjectRelations(const QList<GObjectRelation> &list) {
     emit si_relationChanged(oldRelations);
 }
 
-void GObject::setRelationsInDb(QList<GObjectRelation> &list) const {
+void GObject::setRelationsInDb(QList<GObjectRelation>& list) const {
     U2OpStatus2Log os;
     DbiConnection con(entityRef.dbiRef, os);
-    SAFE_POINT_OP(os, );
-    U2ObjectRelationsDbi *rDbi = con.dbi->getObjectRelationsDbi();
+    CHECK_OP(os, );  // Database is not available for some reason. It is may be deleted.
+    U2ObjectRelationsDbi* rDbi = con.dbi->getObjectRelationsDbi();
     SAFE_POINT(rDbi != nullptr, "Invalid object relations DBI detected!", );
     rDbi->removeReferencesForObject(entityRef.entityId, os);
     SAFE_POINT_OP(os, );
-    U2ObjectDbi *oDbi = con.dbi->getObjectDbi();
+    U2ObjectDbi* oDbi = con.dbi->getObjectDbi();
 
     QList<U2ObjectRelation> dbRelations;
     for (int i = 0, n = list.size(); i < n; ++i) {
-        GObjectRelation &relation = list[i];
+        GObjectRelation& relation = list[i];
         const U2DataType refType = U2ObjectTypeUtils::toDataType(relation.ref.objType);
         const bool relatedObjectDbReferenceValid = relation.ref.entityRef.dbiRef.isValid();
 
@@ -211,10 +158,10 @@ void GObject::setupHints(QVariantMap hintsMap) {
     hints = new GHintsDefaultImpl(hintsMap);
 }
 
-QList<GObjectRelation> GObject::findRelatedObjectsByRole(const GObjectRelationRole &role) const {
+QList<GObjectRelation> GObject::findRelatedObjectsByRole(const GObjectRelationRole& role) const {
     QList<GObjectRelation> res;
     QList<GObjectRelation> relations = getObjectRelations();
-    foreach (const GObjectRelation &ref, relations) {
+    foreach (const GObjectRelation& ref, relations) {
         if (ref.role == role) {
             res.append(ref);
         }
@@ -222,9 +169,9 @@ QList<GObjectRelation> GObject::findRelatedObjectsByRole(const GObjectRelationRo
     return res;
 }
 
-QList<GObjectRelation> GObject::findRelatedObjectsByType(const GObjectType &objType) const {
+QList<GObjectRelation> GObject::findRelatedObjectsByType(const GObjectType& objType) const {
     QList<GObjectRelation> res;
-    foreach (const GObjectRelation &rel, getObjectRelations()) {
+    foreach (const GObjectRelation& rel, getObjectRelations()) {
         if (rel.ref.objType == objType) {
             res.append(rel);
         }
@@ -232,7 +179,7 @@ QList<GObjectRelation> GObject::findRelatedObjectsByType(const GObjectType &objT
     return res;
 }
 
-void GObject::addObjectRelation(const GObjectRelation &rel) {
+void GObject::addObjectRelation(const GObjectRelation& rel) {
     SAFE_POINT(rel.isValid(), "Object relation is not valid!", );
     QList<GObjectRelation> list = getObjectRelations();
     CHECK(!list.contains(rel), );
@@ -240,7 +187,7 @@ void GObject::addObjectRelation(const GObjectRelation &rel) {
     setObjectRelations(list);
 }
 
-void GObject::removeObjectRelation(const GObjectRelation &ref) {
+void GObject::removeObjectRelation(const GObjectRelation& ref) {
     QList<GObjectRelation> list = getObjectRelations();
     bool ok = list.removeOne(ref);
     if (ok) {
@@ -248,24 +195,20 @@ void GObject::removeObjectRelation(const GObjectRelation &ref) {
     }
 }
 
-void GObject::addObjectRelation(const GObject *obj, const GObjectRelationRole &role) {
-    GObjectRelation rel(obj, role);
+void GObject::addObjectRelation(const GObject* obj, const GObjectRelationRole& role) {
+    GObjectRelation rel(obj->getReference(), role);
     addObjectRelation(rel);
 }
 
-namespace {
-
-bool relationsAreEqualExceptDbId(const GObjectRelation &f, const GObjectRelation &s) {
+static bool relationsAreEqualExceptDbId(const GObjectRelation& f, const GObjectRelation& s) {
     return f.role == s.role && f.ref.objName == s.ref.objName && f.getDocURL() == s.getDocURL() && f.ref.objType == s.ref.objType &&
            (!f.ref.entityRef.isValid() || !s.ref.entityRef.isValid() || f.ref.entityRef.dbiRef == s.ref.entityRef.dbiRef);
 }
 
-}  // namespace
-
-bool GObject::hasObjectRelation(const GObjectRelation &r) const {
-    Document *parentDoc = getDocument();
-    if (nullptr != parentDoc && !parentDoc->isDatabaseConnection()) {
-        foreach (const GObjectRelation &rel, getObjectRelations()) {
+bool GObject::hasObjectRelation(const GObjectRelation& r) const {
+    Document* parentDoc = getDocument();
+    if (parentDoc != nullptr) {
+        foreach (const GObjectRelation& rel, getObjectRelations()) {
             if (relationsAreEqualExceptDbId(rel, r)) {
                 return true;
             }
@@ -276,8 +219,8 @@ bool GObject::hasObjectRelation(const GObjectRelation &r) const {
     }
 }
 
-bool GObject::hasObjectRelation(const GObject *obj, const GObjectRelationRole &role) const {
-    GObjectRelation rel(obj, role);
+bool GObject::hasObjectRelation(const GObject* obj, const GObjectRelationRole& role) const {
+    GObjectRelation rel(obj->getReference(), role);
     return hasObjectRelation(rel);
 }
 
@@ -285,23 +228,23 @@ bool GObject::isUnloaded() const {
     return type == GObjectTypes::UNLOADED;
 }
 
-StateLock *GObject::getGObjectModLock(GObjectModLock type) const {
-    return modLocks.value(type, nullptr);
+StateLock* GObject::getGObjectModLock(GObjectModLock lock) const {
+    return modLocks.value(lock, nullptr);
 }
 
 void GObject::relatedObjectRelationChanged() {
     emit si_relatedObjectRelationChanged();
 }
 
-bool GObject::objectLessThan(GObject *first, GObject *second) {
+bool GObject::objectLessThan(GObject* first, GObject* second) {
     return QString::compare(first->getGObjectName(), second->getGObjectName(), Qt::CaseInsensitive) < 0;
 }
 
-void GObject::updateRefInRelations(const GObjectReference &oldRef, const GObjectReference &newRef) {
+void GObject::updateRefInRelations(const GObjectReference& oldRef, const GObjectReference& newRef) {
     QList<GObjectRelation> rels = getObjectRelations();
     bool changed = false;
     for (int i = 0; i < rels.size(); i++) {
-        GObjectRelation &rel = rels[i];
+        GObjectRelation& rel = rels[i];
         if (rel.ref == oldRef) {
             rel.ref = newRef;
             changed = true;
@@ -311,11 +254,11 @@ void GObject::updateRefInRelations(const GObjectReference &oldRef, const GObject
         setObjectRelations(rels);
     }
 }
-void GObject::removeRelations(const QString &removedDocUrl) {
+void GObject::removeRelations(const QString& removedDocUrl) {
     QList<GObjectRelation> rels = getObjectRelations();
     bool changed = false;
     for (int i = 0; i < rels.size(); i++) {
-        GObjectRelation &rel = rels[i];
+        GObjectRelation& rel = rels[i];
         if (rel.ref.docUrl == removedDocUrl) {
             rels.removeAll(rel);
             changed = true;
@@ -326,11 +269,11 @@ void GObject::removeRelations(const QString &removedDocUrl) {
     }
 }
 
-void GObject::updateDocInRelations(const QString &oldDocUrl, const QString &newDocUrl) {
+void GObject::updateDocInRelations(const QString& oldDocUrl, const QString& newDocUrl) {
     QList<GObjectRelation> rels = getObjectRelations();
     bool changed = false;
     for (int i = 0; i < rels.size(); i++) {
-        GObjectRelation &rel = rels[i];
+        GObjectRelation& rel = rels[i];
         if (rel.ref.docUrl == oldDocUrl) {
             rel.ref.docUrl = newDocUrl;
             changed = true;
@@ -346,53 +289,55 @@ void GObject::ensureDataLoaded() const {
     ensureDataLoaded(os);
 }
 
-void GObject::ensureDataLoaded(U2OpStatus &os) const {
+void GObject::ensureDataLoaded(U2OpStatus& os) const {
     QMutexLocker locker(&dataGuard);
     CHECK(!dataLoaded, );
-    const_cast<GObject *>(this)->loadDataCore(os);
+    const_cast<GObject*>(this)->loadDataCore(os);
     CHECK_OP(os, );
     dataLoaded = true;
 }
 
-void GObject::loadDataCore(U2OpStatus & /*os*/) {
+void GObject::loadDataCore(U2OpStatus& /*os*/) {
     FAIL("Not implemented!", );
 }
 
-void GObject::setParentStateLockItem(StateLockableTreeItem *p) {
+void GObject::setParentStateLockItem(StateLockableTreeItem* p) {
     StateLockableTreeItem::setParentStateLockItem(p);
-    checkIfBelongToSharedDatabase(p);
-}
-
-void GObject::checkIfBelongToSharedDatabase(StateLockableTreeItem *parent) {
-    Document *parentDoc = qobject_cast<Document *>(parent);
-    CHECK(nullptr != parentDoc, );
-
-    if (parentDoc->isDatabaseConnection()) {
-        if (!modLocks.contains(GObjectModLock_IO)) {
-            modLocks[GObjectModLock_IO] = new StateLock();
-            lockState(modLocks[GObjectModLock_IO]);
-        }
-    } else if (modLocks.contains(GObjectModLock_IO)) {
-        StateLock *lock = modLocks[GObjectModLock_IO];
-        unlockState(lock);
-        modLocks.remove(GObjectModLock_IO);
-        delete lock;
-    }
 }
 
 void GObject::removeAllLocks() {
-    foreach (StateLock *lock, modLocks.values()) {
+    foreach (StateLock* lock, modLocks.values()) {
         unlockState(lock);
     }
     qDeleteAll(modLocks.values());
     modLocks.clear();
 }
 
+int GObject::getObjectVersion() const {
+    CHECK(entityRef.dbiRef.isValid(), -1);
+
+    U2OpStatus2Log os;
+    DbiConnection con(entityRef.dbiRef, os);
+    CHECK_OP(os, -1);
+    CHECK(con.dbi != nullptr, -1);
+
+    U2ObjectDbi* objectDbi = con.dbi->getObjectDbi();
+    CHECK(objectDbi != nullptr, -1);
+
+    int version = objectDbi->getObjectVersion(entityRef.entityId, os);
+    CHECK_OP(os, -1);
+    return version;
+}
+
+GObjectReference GObject::getReference() const {
+    return GObjectReference(this);
+}
+
 //////////////////////////////////////////////////////////////////////////
 // mime
 const QString GObjectMimeData::MIME_TYPE("application/x-ugene-object-mime");
 
-bool GObjectMimeData::hasFormat(const QString &mimeType) const {
+bool GObjectMimeData::hasFormat(const QString& mimeType) const {
     return mimeType == MIME_TYPE;
 }
 
