@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,25 +30,25 @@ namespace U2 {
 /************************************************************************/
 /* MimeDataIterator */
 /************************************************************************/
-MimeDataIterator::MimeDataIterator(const QMimeData *md)
+MimeDataIterator::MimeDataIterator(const QMimeData* md)
     : docIdx(0), objectIdx(0), folderIdx(0) {
-    const DocumentMimeData *dmd = dynamic_cast<const DocumentMimeData *>(md);
-    if (nullptr != dmd) {
+    auto dmd = dynamic_cast<const DocumentMimeData*>(md);
+    if (dmd != nullptr) {
         docs << dmd->objPtr;
     }
 
-    const GObjectMimeData *gomd = dynamic_cast<const GObjectMimeData *>(md);
-    if (nullptr != gomd) {
+    auto gomd = dynamic_cast<const GObjectMimeData*>(md);
+    if (gomd != nullptr) {
         objects << gomd->objPtr;
     }
 
-    const FolderMimeData *fmd = dynamic_cast<const FolderMimeData *>(md);
-    if (nullptr != fmd) {
+    auto fmd = dynamic_cast<const FolderMimeData*>(md);
+    if (fmd != nullptr) {
         folders << fmd->folder;
     }
 
-    const BunchMimeData *bmd = dynamic_cast<const BunchMimeData *>(md);
-    if (nullptr != bmd) {
+    auto bmd = dynamic_cast<const BunchMimeData*>(md);
+    if (bmd != nullptr) {
         docs << bmd->docs;
         objects << bmd->objects;
         folders << bmd->folders;
@@ -59,7 +59,7 @@ bool MimeDataIterator::hasNextDocument() const {
     return (docIdx < docs.size());
 }
 
-Document *MimeDataIterator::nextDocument() {
+Document* MimeDataIterator::nextDocument() {
     CHECK(hasNextDocument(), nullptr);
     docIdx++;
     return docs[docIdx - 1];
@@ -69,7 +69,7 @@ bool MimeDataIterator::hasNextObject() const {
     return (objectIdx < objects.size());
 }
 
-GObject *MimeDataIterator::nextObject() {
+GObject* MimeDataIterator::nextObject() {
     CHECK(hasNextObject(), nullptr);
     objectIdx++;
     return objects[objectIdx - 1];
