@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MIMEDATAITERATOR_H_
-#define _U2_MIMEDATAITERATOR_H_
+#pragma once
 
 #include <U2Core/Folder.h>
 
@@ -32,13 +31,13 @@ class GObjectMimeData;
 
 class U2CORE_EXPORT MimeDataIterator {
 public:
-    MimeDataIterator(const QMimeData *md);
+    MimeDataIterator(const QMimeData* md);
 
     bool hasNextDocument() const;
-    Document *nextDocument();
+    Document* nextDocument();
 
     bool hasNextObject() const;
-    GObject *nextObject();
+    GObject* nextObject();
 
     bool hasNextFolder() const;
     Folder nextFolder();
@@ -53,5 +52,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_MIMEDATAITERATOR_H_
