@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNASEQUENCE_SELECTION_H_
-#define _U2_DNASEQUENCE_SELECTION_H_
+#pragma once
 
 #include "LRegionsSelection.h"
 #include "SelectionTypes.h"
@@ -33,17 +32,15 @@ class U2CORE_EXPORT DNASequenceSelection : public LRegionsSelection {
     Q_OBJECT
 
 public:
-    DNASequenceSelection(U2SequenceObject *_obj, QObject *p = nullptr)
+    DNASequenceSelection(U2SequenceObject* _obj, QObject* p = nullptr)
         : LRegionsSelection(GSelectionTypes::DNASEQUENCE, p), obj(_obj) {
     }
-    const U2SequenceObject *getSequenceObject() const {
+    const U2SequenceObject* getSequenceObject() const {
         return obj;
     }
 
 private:
-    U2SequenceObject *obj;
+    U2SequenceObject* obj;
 };
 
 }  // namespace U2
-
-#endif
