@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FOLDER_SELECTION_H_
-#define _U2_FOLDER_SELECTION_H_
+#pragma once
 
 #include <U2Core/Folder.h>
 #include <U2Core/SelectionModel.h>
@@ -29,18 +28,16 @@ namespace U2 {
 
 class U2CORE_EXPORT FolderSelection : public GSelection {
 public:
-    FolderSelection(QObject *p = nullptr);
+    FolderSelection(QObject* p = nullptr);
 
     bool isEmpty() const;
     void clear();
 
-    const QList<Folder> &getSelection() const;
-    void setSelection(const QList<Folder> &folders);
+    const QList<Folder>& getSelection() const;
+    void setSelection(const QList<Folder>& folders);
 
 private:
     QList<Folder> selection;
 };
 
 }  // namespace U2
-
-#endif  // _U2_FOLDER_SELECTION_H_
