@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LREGION_SELECTION_H_
-#define _U2_LREGION_SELECTION_H_
+#pragma once
 
 #include <U2Core/SelectionModel.h>
 #include <U2Core/U2Region.h>
@@ -31,25 +30,25 @@ namespace U2 {
 class U2CORE_EXPORT LRegionsSelection : public GSelection {
     Q_OBJECT
 public:
-    explicit LRegionsSelection(const GSelectionType &type, QObject *p = nullptr);
+    explicit LRegionsSelection(const GSelectionType& type, QObject* p = nullptr);
 
     /** Returns currently selected regions. */
-    const QVector<U2Region> &getSelectedRegions() const;
+    const QVector<U2Region>& getSelectedRegions() const;
 
     /**
      * Sets new selection state and emits 'si_selectionChanged'.
      * Dedups call if the new selection is the same as ignored (does nothing in this case).
      */
-    void setSelectedRegions(const QVector<U2Region> &newSelection);
+    void setSelectedRegions(const QVector<U2Region>& newSelection);
 
     /** Adds region to the selection. Does nothing if the region is empty or the region is already in the selection. */
-    void addRegion(const U2Region &r);
+    void addRegion(const U2Region& r);
 
     /** Removes region from the selection. Does nothing if there is no such region in the selection. */
-    void removeRegion(const U2Region &r);
+    void removeRegion(const U2Region& r);
 
     /** Sets the selection to the given region. If the region is empty clears the selection. */
-    void setRegion(const U2Region &r);
+    void setRegion(const U2Region& r);
 
     /** Returns true if there is no selected regions in the selection. */
     bool isEmpty() const override;
@@ -60,16 +59,14 @@ public:
     /** Returns true if selection contains given point. */
     bool contains(qint64 pos) const;
 
-    static QVector<U2Region> cropSelection(qint64 sequenceLength, const QVector<U2Region> &regions);
+    static QVector<U2Region> cropSelection(qint64 sequenceLength, const QVector<U2Region>& regions);
 
 signals:
     /** The signal emitted when selection is changed. */
-    void si_selectionChanged(LRegionsSelection *thiz, const QVector<U2Region> &added, const QVector<U2Region> &removed);
+    void si_selectionChanged(LRegionsSelection* thiz, const QVector<U2Region>& added, const QVector<U2Region>& removed);
 
 public:
     QVector<U2Region> regions;
 };
 
 }  // namespace U2
-
-#endif
