@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SELECTION_MODEL_H_
-#define _U2_SELECTION_MODEL_H_
+#pragma once
 
 #include <QObject>
 
@@ -33,7 +32,7 @@ typedef QString GSelectionType;
 class U2CORE_EXPORT GSelection : public QObject {
     Q_OBJECT
 public:
-    GSelection(GSelectionType _type, QObject *p = nullptr)
+    GSelection(GSelectionType _type, QObject* p = nullptr)
         : QObject(p), type(_type) {
     }
 
@@ -49,13 +48,13 @@ protected slots:
     void sl_selectionChanged();
 
 signals:
-    void si_onSelectionChanged(GSelection *);
+    void si_onSelectionChanged(GSelection*);
 
 private:
     GSelectionType type;
 };
 
-typedef QList<GSelection *> GSelections;
+typedef QList<GSelection*> GSelections;
 
 class U2CORE_EXPORT MultiGSelection {
 public:
@@ -63,23 +62,22 @@ public:
     }
     // TODO: deallocation! -> use shared data
 
-    void addSelection(const GSelection *s);
+    void addSelection(const GSelection* s);
 
-    void removeSelection(const GSelection *s);
+    void removeSelection(const GSelection* s);
 
     bool contains(GSelectionType t) const {
         return findSelectionByType(t) != nullptr;
     }
 
-    const GSelection *findSelectionByType(GSelectionType t) const;
+    const GSelection* findSelectionByType(GSelectionType t) const;
 
-    const QList<const GSelection *> &getSelections() const {
+    const QList<const GSelection*>& getSelections() const {
         return selections;
     }
 
 private:
-    QList<const GSelection *> selections;
+    QList<const GSelection*> selections;
 };
 
 }  // namespace U2
-#endif
