@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SELECTION_UTILS_H_
-#define _U2_SELECTION_UTILS_H_
+#pragma once
 
 #include <QSet>
 
@@ -35,28 +34,26 @@ class GSelection;
 
 class U2CORE_EXPORT SelectionUtils {
 public:
-    static QList<GObject *> findObjects(GObjectType t, const MultiGSelection *s, UnloadedObjectFilter f);
+    static QList<GObject*> findObjects(GObjectType t, const MultiGSelection* s, UnloadedObjectFilter f);
 
-    static QList<GObject *> findObjectsKeepOrder(GObjectType t, const MultiGSelection *s, UnloadedObjectFilter f);
+    static QList<GObject*> findObjectsKeepOrder(GObjectType t, const MultiGSelection* s, UnloadedObjectFilter f);
 
-    static QList<GObject *> findObjects(GObjectType t, const GSelection *s, UnloadedObjectFilter f);
+    static QList<GObject*> findObjects(GObjectType t, const GSelection* s, UnloadedObjectFilter f);
 
-    static QList<GObject *> findObjectsKeepOrder(GObjectType t, const GSelection *s, UnloadedObjectFilter f);
+    static QList<GObject*> findObjectsKeepOrder(GObjectType t, const GSelection* s, UnloadedObjectFilter f);
 
-    static QSet<Document *> findDocumentsWithObjects(GObjectType t, const MultiGSelection *s, UnloadedObjectFilter f, bool deriveDocsFromObjectSelection);
+    static QSet<Document*> findDocumentsWithObjects(GObjectType t, const MultiGSelection* s, UnloadedObjectFilter f, bool deriveDocsFromObjectSelection);
 
-    static QSet<Document *> findDocumentsWithObjects(GObjectType t, const GSelection *s, UnloadedObjectFilter f, bool deriveDocsFromObjectSelection);
+    static QSet<Document*> findDocumentsWithObjects(GObjectType t, const GSelection* s, UnloadedObjectFilter f, bool deriveDocsFromObjectSelection);
 
-    static bool isDocumentInSelection(const Document *doc, const MultiGSelection &ms, bool deriveDocsFromObjectSelection);
+    static bool isDocumentInSelection(const Document* doc, const MultiGSelection& ms, bool deriveDocsFromObjectSelection);
 
-    static QList<Document *> getSelectedDocs(const MultiGSelection &ms);
+    static QList<Document*> getSelectedDocs(const MultiGSelection& ms);
 
-    static QList<GObject *> getSelectedObjects(const MultiGSelection &ms);
+    static QList<GObject*> getSelectedObjects(const MultiGSelection& ms);
 
     // todo: find a better place: like DNAUtils..
     static U2Region normalizeRegionBy3(U2Region reg, int seqLen, bool direct);
 };
 
 }  // namespace U2
-
-#endif
