@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TEXT_SELECTION_H_
-#define _U2_TEXT_SELECTION_H_
+#pragma once
 
 #include "LRegionsSelection.h"
 #include "SelectionTypes.h"
@@ -31,17 +30,15 @@ class TextObject;
 
 class U2CORE_EXPORT TextSelection : public LRegionsSelection {
 public:
-    TextSelection(TextObject *_obj, QObject *p = nullptr)
+    TextSelection(TextObject* _obj, QObject* p = nullptr)
         : LRegionsSelection(GSelectionTypes::TEXT, p), obj(_obj) {
     }
-    TextObject *getObject() const {
+    TextObject* getObject() const {
         return obj;
     }
 
 private:
-    TextObject *obj;
+    TextObject* obj;
 };
 
 }  // namespace U2
-
-#endif
