@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@ namespace U2 {
 /// AbstractProjectFilterTask
 //////////////////////////////////////////////////////////////////////////
 
-AbstractProjectFilterTask::AbstractProjectFilterTask(const ProjectTreeControllerModeSettings &settings, const QString &filterGroupName, const QList<QPointer<Document>> &docs)
+AbstractProjectFilterTask::AbstractProjectFilterTask(const ProjectTreeControllerModeSettings& settings, const QString& filterGroupName, const QList<QPointer<Document>>& docs)
     : Task(tr("Filtering project content by the \"%1\" criterion").arg(filterGroupName), TaskFlag_None), settings(settings), docs(docs),
       filterGroupName(filterGroupName), filteredObjCountPerIteration(10), totalObjectCount(0), processedObjectCount(0) {
     tpm = Task::Progress_Manual;
@@ -39,7 +39,7 @@ AbstractProjectFilterTask::AbstractProjectFilterTask(const ProjectTreeController
     SAFE_POINT(!filterGroupName.isEmpty(), "Project filter has empty name", );
     doStaticInitialization();
 
-    foreach (const QPointer<Document> &doc, docs) {
+    foreach (const QPointer<Document>& doc, docs) {
         if (!doc.isNull()) {
             totalObjectCount += doc->getObjects().size();
         }
@@ -47,7 +47,7 @@ AbstractProjectFilterTask::AbstractProjectFilterTask(const ProjectTreeController
 }
 
 void AbstractProjectFilterTask::run() {
-    foreach (const QPointer<Document> &doc, docs) {
+    foreach (const QPointer<Document>& doc, docs) {
         filterDocument(doc.data());
     }
     const int filteredObjectCount = filteredObjs.size();
@@ -56,15 +56,15 @@ void AbstractProjectFilterTask::run() {
     }
 }
 
-void AbstractProjectFilterTask::filterDocument(const QPointer<Document> &doc) {
+void AbstractProjectFilterTask::filterDocument(const QPointer<Document>& doc) {
     CHECK(!doc.isNull(), );
     CHECK(doc->isLoaded(), );
 
-    foreach (GObject *obj, doc->getObjects()) {
+    foreach (GObject* obj, doc->getObjects()) {
         CHECK(!doc.isNull(), );
         if (filterAcceptsObject(obj)) {
             filteredObjs.append(obj);
-            if (0 == filteredObjs.size() % filteredObjCountPerIteration || 1 == filteredObjCountPerIteration) {
+            if (filteredObjs.size() % filteredObjCountPerIteration == 0 || filteredObjCountPerIteration == 1) {
                 emit si_objectsFiltered(filterGroupName, filteredObjs.mid(filteredObjs.size() - filteredObjCountPerIteration));
             }
         }
@@ -75,7 +75,7 @@ void AbstractProjectFilterTask::filterDocument(const QPointer<Document> &doc) {
     }
 }
 
-bool AbstractProjectFilterTask::filterAcceptsObject(GObject * /*obj*/) {
+bool AbstractProjectFilterTask::filterAcceptsObject(GObject* /*obj*/) {
     FAIL("AbstractProjectFilterTask::filterAcceptsObject is not implemented", false);
 }
 
@@ -94,12 +94,26 @@ void AbstractProjectFilterTask::doStaticInitialization() {
 ProjectFilterTaskFactory::~ProjectFilterTaskFactory() {
 }
 
-AbstractProjectFilterTask *ProjectFilterTaskFactory::registerNewTask(const ProjectTreeControllerModeSettings &settings,
-                                                                     const QList<QPointer<Document>> &docs) const {
-    AbstractProjectFilterTask *task = createNewTask(settings, docs);
-    SAFE_POINT(nullptr != task, L10N::nullPointerError("project filter task"), nullptr);
-    AppContext::getTaskScheduler()->registerTopLevelTask(task);
+AbstractProjectFilterTask* ProjectFilterTaskFactory::registerNewTask(const ProjectTreeControllerModeSettings& settings,
+                                                                     const QList<QPointer<Document>>& docs) const {
+    AbstractProjectFilterTask* task = createNewTask(settings, docs);
+    if (task != nullptr) {
+        AppContext::getTaskScheduler()->registerTopLevelTask(task);
+    }
     return task;
 }
 
+QList<QPointer<Document>> ProjectFilterTaskFactory::getAcceptedDocs(const QList<QPointer<Document>>& docs, const QList<GObjectType>& acceptableObjectTypes) {
+    QList<QPointer<Document>> result;
+    for (const QPointer<Document>& docRef : qAsConst(docs)) {
+        for (const GObjectType& objType : qAsConst(acceptableObjectTypes)) {
+            if (!docRef->findGObjectByType(objType).isEmpty()) {
+                result.append(docRef);
+                break;
+            }
+        }
+    }
+    return result;
+}
+
 }  // namespace U2
