@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,10 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ABSTRACT_PROJECT_FILTER_TASK_H_
-#define _U2_ABSTRACT_PROJECT_FILTER_TASK_H_
+#pragma once
 
 #include <U2Core/DocumentModel.h>
+#include <U2Core/GObjectTypes.h>
 #include <U2Core/ProjectTreeControllerModeSettings.h>
 #include <U2Core/Task.h>
 
@@ -37,15 +37,15 @@ typedef QList<QPointer<GObject>> SafeObjList;
 class U2CORE_EXPORT AbstractProjectFilterTask : public Task {
     Q_OBJECT
 public:
-    void run();
+    void run() override;
 
 signals:
-    void si_objectsFiltered(const QString &filterGroupName, const SafeObjList &objects);
+    void si_objectsFiltered(const QString& filterGroupName, const SafeObjList& objects);
 
 protected:
-    AbstractProjectFilterTask(const ProjectTreeControllerModeSettings &settings, const QString &filterGroupName, const QList<QPointer<Document>> &docs);
+    AbstractProjectFilterTask(const ProjectTreeControllerModeSettings& settings, const QString& filterGroupName, const QList<QPointer<Document>>& docs);
 
-    virtual bool filterAcceptsObject(GObject *obj);
+    virtual bool filterAcceptsObject(GObject* obj);
 
     const ProjectTreeControllerModeSettings settings;
     const QList<QPointer<Document>> docs;
@@ -57,7 +57,7 @@ protected:
     int processedObjectCount;
 
 private:
-    void filterDocument(const QPointer<Document> &doc);
+    void filterDocument(const QPointer<Document>& doc);
 
     static void doStaticInitialization();
 };
@@ -70,13 +70,12 @@ class U2CORE_EXPORT ProjectFilterTaskFactory {
 public:
     virtual ~ProjectFilterTaskFactory();
 
-    AbstractProjectFilterTask *registerNewTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document>> &docs) const;
+    AbstractProjectFilterTask* registerNewTask(const ProjectTreeControllerModeSettings& settings, const QList<QPointer<Document>>& docs) const;
 
 protected:
-    virtual AbstractProjectFilterTask *createNewTask(const ProjectTreeControllerModeSettings &settings,
-                                                     const QList<QPointer<Document>> &docs) const = 0;
+    virtual AbstractProjectFilterTask* createNewTask(const ProjectTreeControllerModeSettings& settings,
+                                                     const QList<QPointer<Document>>& docs) const = 0;
+    static QList<QPointer<Document>> getAcceptedDocs(const QList<QPointer<Document>>& docs, const QList<GObjectType>& acceptableObjectTypes);
 };
 
 }  // namespace U2
-
-#endif  // _U2_ABSTRACT_PROJECT_FILTER_TASK_H_
