@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADD_DOCUMENT_TASK_H_
-#define _U2_ADD_DOCUMENT_TASK_H_
+#pragma once
 
 #include <U2Core/DocumentModel.h>
 #include <U2Core/Task.h>
@@ -43,22 +42,20 @@ public:
 class U2CORE_EXPORT AddDocumentTask : public Task {
     Q_OBJECT
 public:
-    AddDocumentTask(Document *d, const AddDocumentTaskConfig &c = AddDocumentTaskConfig());
-    AddDocumentTask(DocumentProviderTask *dp, const AddDocumentTaskConfig &c = AddDocumentTaskConfig());
+    AddDocumentTask(Document* d, const AddDocumentTaskConfig& c = AddDocumentTaskConfig());
+    AddDocumentTask(DocumentProviderTask* dp, const AddDocumentTaskConfig& c = AddDocumentTaskConfig());
 
     ReportResult report();
 
-    QList<Task *> onSubTaskFinished(Task *subTask);
-    Document *getDocument() {
+    QList<Task*> onSubTaskFinished(Task* subTask);
+    Document* getDocument() {
         return document;
     }
 
 private:
-    Document *document;
-    DocumentProviderTask *dpt;
+    Document* document;
+    DocumentProviderTask* dpt;
     AddDocumentTaskConfig conf;
 };
 
 }  // namespace U2
-
-#endif
