@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADD_OBJECTS_TO_DOCUMENT_TASK_H_
-#define _U2_ADD_OBJECTS_TO_DOCUMENT_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -32,16 +31,14 @@ class GObject;
 class U2CORE_EXPORT AddObjectsToDocumentTask : public Task {
     Q_OBJECT
 public:
-    AddObjectsToDocumentTask(QList<GObject *> &_objects, Document *_doc);
+    AddObjectsToDocumentTask(QList<GObject*>& _objects, Document* _doc);
     void prepare();
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
 
 private:
-    QList<GObject *> objects;
-    Document *doc;
-    QList<GObject *> clones;
+    QList<GObject*> objects;
+    Document* doc;
+    QList<GObject*> clones;
 };
 
 }  // namespace U2
-
-#endif
\ No newline at end of file
