@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,8 +32,8 @@ CleanupFileStorageTask::CleanupFileStorageTask()
 }
 
 void CleanupFileStorageTask::run() {
-    AppFileStorage *fileStorage = AppContext::getAppFileStorage();
-    CHECK_EXT(nullptr != fileStorage, stateInfo.setError("NULL file storage"), );
+    AppFileStorage* fileStorage = AppContext::getAppFileStorage();
+    CHECK_EXT(fileStorage != nullptr, stateInfo.setError("NULL file storage"), );
 
     fileStorage->cleanup(stateInfo);
 }
