@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CMDLINE_IO_OUT_TASK_RUNNER_H_
-#define _U2_CMDLINE_IO_OUT_TASK_RUNNER_H_
+#pragma once
 
 #include <U2Core/CmdlineTaskRunner.h>
 #include <U2Core/U2Type.h>
@@ -33,7 +32,7 @@ class U2CORE_EXPORT CmdlineInOutTaskConfig : public CmdlineTaskConfig {
 public:
     CmdlineInOutTaskConfig();
 
-    QList<GObject *> inputObjects;
+    QList<GObject*> inputObjects;
     U2DbiRef outDbiRef;
     bool emptyOutputPossible;
 };
@@ -41,25 +40,25 @@ public:
 class U2CORE_EXPORT CmdlineInOutTaskRunner : public CmdlineTaskRunner {
     Q_OBJECT
 public:
-    CmdlineInOutTaskRunner(const CmdlineInOutTaskConfig &config);
+    CmdlineInOutTaskRunner(const CmdlineInOutTaskConfig& config);
 
     ReportResult report();
 
-    const QList<U2DataId> &getOutputObjects() const;
+    const QList<U2DataId>& getOutputObjects() const;
 
-    static QString toString(const U2DbiRef &dbiRef);
-    static U2DbiRef parseDbiRef(const QString &string, U2OpStatus &os);
-    static QString toString(const U2DataId &id);
-    static U2DataId parseDataId(const QString &string, const U2DbiRef &dbiRef, U2OpStatus &os);
-    static void logOutputObject(const U2DataId &id);
+    static QString toString(const U2DbiRef& dbiRef);
+    static U2DbiRef parseDbiRef(const QString& string, U2OpStatus& os);
+    static QString toString(const U2DataId& id);
+    static U2DataId parseDataId(const QString& string, const U2DbiRef& dbiRef, U2OpStatus& os);
+    static void logOutputObject(const U2DataId& id);
     static const QString IN_DB_ARG;
     static const QString IN_ID_ARG;
     static const QString OUT_DB_ARG;
 
 private:
     // CmdlineTaskRunner
-    bool isCommandLogLine(const QString &logLine) const;
-    bool parseCommandLogWord(const QString &logWord);
+    bool isCommandLogLine(const QString& logLine) const;
+    bool parseCommandLogWord(const QString& logWord);
 
 private:
     CmdlineInOutTaskConfig config;
@@ -67,5 +66,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_CMDLINE_IO_OUT_TASK_RUNNER_H_
