@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -42,10 +42,6 @@
 
 namespace U2 {
 
-CmdlineTaskConfig::CmdlineTaskConfig()
-    : logLevel(LogLevel_DETAILS), withPluginList(false) {
-}
-
 /************************************************************************/
 /* CmdlineTaskRunner */
 /************************************************************************/
@@ -55,7 +51,7 @@ const QString OUTPUT_PROGRESS_ARG = "ugene-output-progress-state";
 const QString OUTPUT_PROGRESS_TAG = "task-progress=";
 const QString ERROR_KEYWORD = "#%*ugene-finished-with-error#%*";
 
-inline int getLogNameCandidate(const QString &line, QString &nameCandidate) {
+inline int getLogNameCandidate(const QString& line, QString& nameCandidate) {
     if ("" == line) {
         return -1;
     }
@@ -93,8 +89,8 @@ QString getLogLevelName(LogLevel l) {
     return "";
 }
 
-bool containsPrefix(const QStringList &args, const QString &prefix) {
-    foreach (const QString &arg, args) {
+bool containsPrefix(const QStringList& args, const QString& prefix) {
+    foreach (const QString& arg, args) {
         if (arg.startsWith(prefix)) {
             return true;
         }
@@ -109,12 +105,12 @@ QList<long> CmdlineTaskRunner::getChildrenProcesses(qint64 processId, bool fullT
     QList<long> children;
 
 #if defined(Q_OS_LINUX) || defined(Q_OS_DARWIN)
-    char *buff = nullptr;
+    char* buff = nullptr;
     size_t len = 255;
     char command[256] = {0};
 
     sprintf(command, "ps -ef|awk '$3==%u {print $2}'", (unsigned)processId);
-    FILE *fp = (FILE *)popen(command, "r");
+    FILE* fp = (FILE*)popen(command, "r");
     while (getline(&buff, &len, fp) >= 0) {
         int child_process_id = QString(buff).toInt();
         if (child_process_id != 0) {
@@ -122,7 +118,7 @@ QList<long> CmdlineTaskRunner::getChildrenProcesses(qint64 processId, bool fullT
         }
     }
     free(buff);
-    fclose(fp);
+    pclose(fp);
 #elif defined(Q_OS_WIN)
     HANDLE hProcessSnap;
     HANDLE hProcess;
@@ -188,7 +184,7 @@ int CmdlineTaskRunner::killChildrenProcesses(qint64 processId, bool fullTree) {
     return result;
 }
 
-int CmdlineTaskRunner::killProcessTree(QProcess *process) {
+int CmdlineTaskRunner::killProcessTree(QProcess* process) {
     qint64 processId = process->processId();
     return killProcessTree(processId);
 }
@@ -221,7 +217,7 @@ int CmdlineTaskRunner::killProcess(qint64 processId) {
     return result;
 }
 
-CmdlineTaskRunner::CmdlineTaskRunner(const CmdlineTaskConfig &config)
+CmdlineTaskRunner::CmdlineTaskRunner(const CmdlineTaskConfig& config)
     : Task(tr("Run UGENE command line: %1").arg(config.command), TaskFlag_NoRun), config(config), process(nullptr) {
     tpm = Progress_Manual;
 }
@@ -262,7 +258,7 @@ void CmdlineTaskRunner::prepare() {
     coreLog.details("Starting UGENE command line: " + cmdlineUgenePath + " " + args.join(" "));
     process->start(cmdlineUgenePath, args);
 #if (defined(Q_OS_WIN32) || defined(Q_OS_WINCE))
-    QString processId = nullptr != process->pid() ? QString::number(process->pid()->dwProcessId) : "unknown";
+    QString processId = process->pid() != nullptr ? QString::number(process->pid()->dwProcessId) : "unknown";
     processLogPrefix = QString("process:%1>").arg(processId);
 #else
     processLogPrefix = QString("process:%1>").arg(process->pid());
@@ -272,7 +268,7 @@ void CmdlineTaskRunner::prepare() {
 }
 
 Task::ReportResult CmdlineTaskRunner::report() {
-    CHECK(nullptr != process, ReportResult_Finished);
+    CHECK(process != nullptr, ReportResult_Finished);
     if (hasError()) {
         return ReportResult_Finished;
     }
@@ -287,18 +283,22 @@ Task::ReportResult CmdlineTaskRunner::report() {
     return ReportResult_Finished;
 }
 
-bool CmdlineTaskRunner::isCommandLogLine(const QString & /*logLine*/) const {
+QString CmdlineTaskRunner::getProcessErrorsLog() const {
+    return processErrorLog;
+}
+
+bool CmdlineTaskRunner::isCommandLogLine(const QString& /*logLine*/) const {
     return false;
 }
 
-bool CmdlineTaskRunner::parseCommandLogWord(const QString & /*logWord*/) {
+bool CmdlineTaskRunner::parseCommandLogWord(const QString& /*logWord*/) {
     return false;
 }
 
-void CmdlineTaskRunner::writeLog(QStringList &lines) {
-    QStringList::Iterator it = lines.begin();
-    for (; it != lines.end(); it++) {
-        QString &line = *it;
+void CmdlineTaskRunner::writeLog(QStringList& messages) {
+    QStringList::Iterator it = messages.begin();
+    for (; it != messages.end(); it++) {
+        QString& line = *it;
         line = line.trimmed();
         QString nameCandidate;
         int closePos = getLogNameCandidate(line, nameCandidate);
@@ -306,19 +306,24 @@ void CmdlineTaskRunner::writeLog(QStringList &lines) {
             continue;
         }
 
+        QString logMessage = line.mid(closePos + 1);
+        static const QString logLevelErrorName = getLogLevelName(LogLevel_ERROR);
+        if (logLevelErrorName == nameCandidate) {
+            processErrorLog += logMessage + "\n";
+        }
+
         for (int i = config.logLevel; i < LogLevel_NumLevels; i++) {
             QString logLevelName = getLogLevelName((LogLevel)i);
             if (logLevelName != nameCandidate) {
                 continue;
             }
 
-            QString logLine = line.mid(closePos + 1);
-            logLine = logLine.trimmed();
-            bool commandToken = logLine.startsWith(OUTPUT_PROGRESS_TAG) || logLine.startsWith(ERROR_KEYWORD) || isCommandLogLine(logLine);
+            logMessage = logMessage.trimmed();
+            bool commandToken = logMessage.startsWith(OUTPUT_PROGRESS_TAG) || logMessage.startsWith(ERROR_KEYWORD) || isCommandLogLine(logMessage);
             if (commandToken) {
                 continue;
             }
-            taskLog.message((LogLevel)i, processLogPrefix + logLine);
+            taskLog.message((LogLevel)i, processLogPrefix + logMessage);
         }
     }
 }
@@ -330,7 +335,7 @@ QString CmdlineTaskRunner::readStdout() {
 #else
     charSet = "UTF-8";
 #endif
-    QTextCodec *codec = QTextCodec::codecForName(charSet);
+    QTextCodec* codec = QTextCodec::codecForName(charSet);
     return codec->toUnicode(process->readAllStandardOutput());
 }
 
@@ -357,8 +362,16 @@ void CmdlineTaskRunner::sl_onError(QProcess::ProcessError error) {
 
 void CmdlineTaskRunner::sl_onReadStandardOutput() {
     QString data = readStdout();
-    QStringList lines = data.split(QChar('\n'));
-    writeLog(lines);
+    const QStringList lines = data.split(QChar('\n'));
+    QStringList combineMultiLines;
+    for (const QString& line : qAsConst(lines)) {
+        if (line.startsWith("[") || combineMultiLines.isEmpty()) {
+            combineMultiLines.append(line);
+        } else {
+            combineMultiLines.last() += "\n" + line;
+        }
+    }
+    writeLog(combineMultiLines);
 
     int errInd = data.indexOf(ERROR_KEYWORD);
     if (errInd >= 0) {
@@ -371,9 +384,9 @@ void CmdlineTaskRunner::sl_onReadStandardOutput() {
         return;
     }
 
-    for (const QString &line : qAsConst(lines)) {
+    for (const QString& line : qAsConst(lines)) {
         QStringList words = line.split(QRegExp("\\s+"), QString::SkipEmptyParts);
-        for (const QString &word : qAsConst(words)) {
+        for (const QString& word : qAsConst(words)) {
             if (word.startsWith(OUTPUT_PROGRESS_TAG)) {
                 QString numStr = word.mid(OUTPUT_PROGRESS_TAG.size());
                 bool ok = false;
@@ -390,8 +403,6 @@ void CmdlineTaskRunner::sl_onReadStandardOutput() {
 }
 
 void CmdlineTaskRunner::sl_onFinish(int exitCode, QProcess::ExitStatus exitStatus) {
-    CHECK(!hasError(), );  // !do not overwrite previous error!
-
     // On Windows, if the process was terminated with TerminateProcess() from another application,
     // this function will still return NormalExit unless the exit code is less than 0.
     if (exitStatus != QProcess::NormalExit || exitCode != 0) {
@@ -405,15 +416,15 @@ void CmdlineTaskRunner::sl_onFinish(int exitCode, QProcess::ExitStatus exitStatu
 namespace {
 const int UPDATE_PROGRESS_INTERVAL = 500;
 
-void logError(const QString &error) {
+void logError(const QString& error) {
     coreLog.info(QString("%1%2%1").arg(ERROR_KEYWORD).arg(error));
 }
 }  // namespace
 
-CmdlineTask::CmdlineTask(const QString &name, TaskFlags flags)
+CmdlineTask::CmdlineTask(const QString& name, TaskFlags flags)
     : Task(name, flags) {
     if (AppContext::getCMDLineRegistry()->hasParameter(OUTPUT_PROGRESS_ARG)) {
-        QTimer *timer = new QTimer(this);
+        QTimer* timer = new QTimer(this);
         connect(timer, SIGNAL(timeout()), SLOT(sl_outputProgressAndState()));
         timer->start(UPDATE_PROGRESS_INTERVAL);
     }
