@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CMDLINE_TASK_RUNNER_H_
-#define _U2_CMDLINE_TASK_RUNNER_H_
+#pragma once
 
 #include <QProcess>
 
@@ -30,12 +29,10 @@ namespace U2 {
 
 class U2CORE_EXPORT CmdlineTaskConfig {
 public:
-    CmdlineTaskConfig();
-
     QString command;
     QStringList arguments;
-    LogLevel logLevel;
-    bool withPluginList;
+    LogLevel logLevel = LogLevel_DETAILS;
+    bool withPluginList = false;
     QStringList pluginList;
     QString reportFile;
 };
@@ -45,23 +42,28 @@ class U2CORE_EXPORT CmdlineTaskRunner : public Task {
 public:
     static QList<long> getChildrenProcesses(qint64 processId, bool fullTree = true);
     static int killChildrenProcesses(qint64 processId, bool fullTree = true);
-    static int killProcessTree(QProcess *process);
+    static int killProcessTree(QProcess* process);
     static int killProcessTree(qint64 processId);
     static int killProcess(qint64 processId);
 
-    CmdlineTaskRunner(const CmdlineTaskConfig &config);
+    CmdlineTaskRunner(const CmdlineTaskConfig& config);
 
     void prepare();
     ReportResult report();
 
+    /*
+    * Returns QString with [ERROR] level log messages separated by new line.
+    */
+    QString getProcessErrorsLog() const;
+
     static const QString REPORT_FILE_ARG;
 
 protected:
-    virtual bool isCommandLogLine(const QString &logLine) const;
-    virtual bool parseCommandLogWord(const QString &logWord);
+    virtual bool isCommandLogLine(const QString& logLine) const;
+    virtual bool parseCommandLogWord(const QString& logWord);
 
 private:
-    void writeLog(QStringList &lines);
+    void writeLog(QStringList& messages);
     QString readStdout();
 
 private slots:
@@ -71,14 +73,15 @@ private slots:
 
 private:
     CmdlineTaskConfig config;
-    QProcess *process;
+    QProcess* process;
     QString processLogPrefix;
+    QString processErrorLog;
 };
 
 class U2CORE_EXPORT CmdlineTask : public Task {
     Q_OBJECT
 public:
-    CmdlineTask(const QString &name, TaskFlags flags);
+    CmdlineTask(const QString& name, TaskFlags flags);
     ReportResult report();
 
 protected:
@@ -89,5 +92,3 @@ private slots:
 };
 
 }  // namespace U2
-
-#endif  // _U2_CMDLINE_TASK_RUNNER_H_
