@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_COPY_DATA_TASK_H_
-#define _U2_COPY_DATA_TASK_H_
+#pragma once
 
 #include <U2Core/GUrl.h>
 #include <U2Core/Task.h>
@@ -32,18 +31,16 @@ class IOAdapterFactory;
 class U2CORE_EXPORT CopyDataTask : public Task {
     Q_OBJECT
 public:
-    CopyDataTask(IOAdapterFactory *ioFrom, const GUrl &urlFrom, IOAdapterFactory *ioTo, const GUrl &urlTo);
+    CopyDataTask(IOAdapterFactory* ioFrom, const GUrl& urlFrom, IOAdapterFactory* ioTo, const GUrl& urlTo);
 
     virtual void run();
 
 private:
     static const int BUFFSIZE = 32 * 1024;
-    IOAdapterFactory *ioFrom;
-    IOAdapterFactory *ioTo;
+    IOAdapterFactory* ioFrom;
+    IOAdapterFactory* ioTo;
     GUrl urlFrom;
     GUrl urlTo;
 };
 
 }  // namespace U2
-
-#endif
