@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_COPY_FILE_TASK_H_
-#define _U2_COPY_FILE_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -29,7 +28,7 @@ namespace U2 {
 class U2CORE_EXPORT CopyFileTask : public Task {
     Q_OBJECT
 public:
-    CopyFileTask(const QString &sourceFilePath, const QString &targetFilePath);
+    CopyFileTask(const QString& sourceFilePath, const QString& targetFilePath);
 
     QString getSourceFilePath() const;
     QString getTargetFilePath() const;
@@ -42,5 +41,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_COPY_FILE_TASK_H_
