@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CREATE_ANNOTATION_TASK_H_
-#define _U2_CREATE_ANNOTATION_TASK_H_
+#pragma once
 
 #include <U2Core/AnnotationData.h>
 #include <U2Core/AnnotationTableObject.h>
@@ -30,30 +29,36 @@ namespace U2 {
 
 class U2CORE_EXPORT CreateAnnotationsTask : public Task {
     Q_OBJECT
+
+    CreateAnnotationsTask(bool isAnnotationObjectShared);
+
 public:
-    // Adds annotations to the object. Waits object to be unlocked if needed
-    // Works only in a context of active project
-    CreateAnnotationsTask(AnnotationTableObject *o, const QList<SharedAnnotationData> &data, const QString &group = QString());
-    CreateAnnotationsTask(const GObjectReference &ref, const QList<SharedAnnotationData> &data, const QString &group = QString());
-    CreateAnnotationsTask(AnnotationTableObject *annotationTableObject, const QMap<QString, QList<SharedAnnotationData>> &annotationsByGroupMap);
+    /**
+     * Adds annotations to the object.
+     *
+     * 'isAnnotationObjectShared'- for the shared annotation object the task will add all annotations in main UI thread.
+     *   if the annotation object is not 'shared' the annotations can be created in a separate thread, thus reducing the UI thread lock time.
+     */
+    CreateAnnotationsTask(AnnotationTableObject* annotationTableObject,
+                          const QMap<QString, QList<SharedAnnotationData>>& annotationsByGroupMap,
+                          bool isAnnotationObjectShared = true);
+
+    /** Adds annotations to the object. Loads object if needed. Works only in project context. */
+    CreateAnnotationsTask(const GObjectReference& ref, const QList<SharedAnnotationData>& data, const QString& groupName = "");
 
     void run() override;
     ReportResult report() override;
 
-    AnnotationTableObject *getAnnotationTableObject() const;
+    AnnotationTableObject* getAnnotationTableObject() const;
     int getAnnotationCount() const;
-    QList<Annotation *> getResultAnnotations() const;
+    QList<Annotation*> getResultAnnotations() const;
 
 private:
-    void initAnnObjectRef();
-
-    GObjectReference aRef;
+    GObjectReference annotationTableObjectRef;
     QPointer<AnnotationTableObject> annotationTableObjectPointer;
-    QMap<AnnotationGroup *, QList<Annotation *>> annotationsByGroupMap;
+    QMap<AnnotationGroup*, QList<Annotation*>> annotationsByGroupMap;
     QMap<QString, QList<SharedAnnotationData>> annotationDatasByGroupNameMap;
-    QList<Annotation *> resultAnnotations;
+    QList<Annotation*> resultAnnotations;
 };
 
 }  // namespace U2
-
-#endif
