@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DELETE_OBJECTS_H_
-#define _U2_DELETE_OBJECTS_H_
+#pragma once
 
 #include <U2Core/Folder.h>
 #include <U2Core/Task.h>
@@ -33,7 +32,7 @@ class GObject;
 class U2CORE_EXPORT DeleteObjectsTask : public Task {
     Q_OBJECT
 public:
-    DeleteObjectsTask(const QList<GObject *> &objs);
+    DeleteObjectsTask(const QList<GObject*>& objs);
 
     void run();
 
@@ -44,7 +43,7 @@ private:
 class U2CORE_EXPORT DeleteFoldersTask : public Task {
     Q_OBJECT
 public:
-    DeleteFoldersTask(const QList<Folder> &folders);
+    DeleteFoldersTask(const QList<Folder>& folders);
 
     void run();
 
@@ -53,5 +52,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_DELETE_OBJECTS_H_
