@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOCUMENT_PROVIDER_TASK_H_
-#define _U2_DOCUMENT_PROVIDER_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -34,13 +33,13 @@ class Document;
 class U2CORE_EXPORT DocumentProviderTask : public Task {
     Q_OBJECT
 public:
-    DocumentProviderTask(const QString &name, TaskFlags flags);
+    DocumentProviderTask(const QString& name, TaskFlags flags);
     virtual ~DocumentProviderTask() {
         cleanup();
     }
 
-    virtual Document *getDocument(bool mainThread = true);
-    virtual Document *takeDocument(bool mainThread = true);
+    virtual Document* getDocument(bool mainThread = true);
+    virtual Document* takeDocument(bool mainThread = true);
 
     virtual void cleanup();
     virtual QString getDocumentDescription() const {
@@ -48,7 +47,7 @@ public:
     }
 
 protected:
-    Document *resultDocument;
+    Document* resultDocument;
     bool docOwner;
 
     /** provider's document description */
@@ -56,5 +55,3 @@ protected:
 };
 
 }  // namespace U2
-
-#endif
