@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +24,6 @@
 #include <QDir>
 #include <QRegularExpression>
 
-#include <U2Core/AnnotationTableObject.h>
 #include <U2Core/AppContext.h>
 #include <U2Core/AppSettings.h>
 #include <U2Core/CmdlineTaskRunner.h>
@@ -32,47 +31,45 @@
 #include <U2Core/GUrlUtils.h>
 #include <U2Core/Log.h>
 #include <U2Core/ScriptingToolRegistry.h>
+#include <U2Core/Settings.h>
 #include <U2Core/U2SafePoints.h>
 #include <U2Core/UserApplicationsSettings.h>
 
-#ifdef Q_OS_WIN
-#    include <windows.h>
-#endif
-
-#ifdef Q_OS_UNIX
-#    include <signal.h>
-#    include <unistd.h>
-#endif
-
 namespace U2 {
 
+#define SETTINGS_ROOT QString("/genome_aligner_settings/")
+#define INDEX_DIR QString("index_dir")
+
 #define WIN_LAUNCH_CMD_COMMAND "cmd /C "
 #define START_WAIT_MSEC 3000
 
-ExternalToolRunTask::ExternalToolRunTask(const QString &_toolId, const QStringList &_arguments, ExternalToolLogParser *_logParser, const QString &_workingDirectory, const QStringList &_additionalPaths, bool parseOutputFile)
+ExternalToolRunTask::ExternalToolRunTask(const QString& _toolId, const QStringList& _arguments, ExternalToolLogParser* _logParser, const QString& _workingDirectory, const QStringList& _additionalPaths, bool parseOutputFile)
     : Task(AppContext::getExternalToolRegistry()->getToolNameById(_toolId) + tr(" tool"), TaskFlag_None),
       arguments(_arguments),
       logParser(_logParser),
       toolId(_toolId),
       workingDirectory(_workingDirectory),
       additionalPaths(_additionalPaths),
-      externalToolProcess(nullptr),
-      helper(nullptr),
-      listener(nullptr),
       parseOutputFile(parseOutputFile) {
-    CHECK_EXT(AppContext::getExternalToolRegistry()->getById(toolId) != nullptr, stateInfo.setError(tr("External tool is absent")), );
-
-    toolName = AppContext::getExternalToolRegistry()->getToolNameById(toolId);
-    coreLog.trace("Creating run task for: " + toolName);
-    if (logParser != nullptr) {
-        logParser->setParent(this);
-    }
 }
 
 ExternalToolRunTask::~ExternalToolRunTask() {
     delete externalToolProcess;
 }
 
+void ExternalToolRunTask::prepare() {
+    ExternalTool* tool = AppContext::getExternalToolRegistry()->getById(toolId);
+    CHECK_EXT(tool != nullptr, stateInfo.setError(tr("External tool \"%1\" is absent").arg(toolId)), );
+    toolName = tool->getName();
+
+    CHECK_EXT(QFile::exists(tool->getPath()), stateInfo.setError(tr("External tool '%1' doesn't exist").arg(tool->getPath())), )
+    tool->checkArgsAndPaths(arguments, stateInfo);
+
+    if (!stateInfo.hasError() && logParser != nullptr) {
+        logParser->setParent(this);
+    }
+}
+
 void ExternalToolRunTask::run() {
     if (hasError() || isCanceled()) {
         return;
@@ -90,7 +87,7 @@ void ExternalToolRunTask::run() {
     }
     if (!additionalEnvVariables.isEmpty()) {
         QProcessEnvironment processEnvironment = externalToolProcess->processEnvironment();
-        foreach (const QString &envVarName, additionalEnvVariables.keys()) {
+        foreach (const QString& envVarName, additionalEnvVariables.keys()) {
             processEnvironment.insert(envVarName, additionalEnvVariables.value(envVarName));
         }
         externalToolProcess->setProcessEnvironment(processEnvironment);
@@ -105,7 +102,7 @@ void ExternalToolRunTask::run() {
     bool started = externalToolProcess->waitForStarted(START_WAIT_MSEC);
 
     if (!started) {
-        ExternalTool *tool = AppContext::getExternalToolRegistry()->getById(toolId);
+        ExternalTool* tool = AppContext::getExternalToolRegistry()->getById(toolId);
         if (tool->isValid()) {
             stateInfo.setError(tr("Can not run %1 tool.").arg(toolName));
         } else {
@@ -115,10 +112,18 @@ void ExternalToolRunTask::run() {
         }
         return;
     }
+    externalToolProcess->closeWriteChannel();
     while (!externalToolProcess->waitForFinished(1000)) {
         if (isCanceled()) {
             killProcess(externalToolProcess);
-            algoLog.details(tr("Tool %1 is cancelled").arg(toolName));
+            if (!externalToolProcess->waitForFinished(2000)) {  // wait 2 seconds to let OS kill process in previous method
+                externalToolProcess->kill();
+            }
+            if (externalToolProcess->state() != QProcess::NotRunning && !externalToolProcess->waitForFinished(10000)) {
+                algoLog.info(tr("Unable to cancel tool %1 for 10 seconds. Stop \"%2\" process manually by your OS task manager.").arg(toolName).arg(AppContext::getExternalToolRegistry()->getById(toolId)->getExecutableFileName()));
+            } else {
+                algoLog.details(tr("Tool %1 is cancelled").arg(toolName));
+            }
             return;
         }
     }
@@ -127,7 +132,7 @@ void ExternalToolRunTask::run() {
         QProcess::ExitStatus status = externalToolProcess->exitStatus();
         int exitCode = externalToolProcess->exitCode();
         if (status == QProcess::CrashExit && !hasError()) {
-            QString error = parseStandartOutputFile();
+            QString error = parseStandardOutputFile();
             if (error.isEmpty()) {
                 QString intendedError = tr("%1 tool exited with the following error: %2 (Code: %3)")
                                             .arg(toolName)
@@ -139,7 +144,7 @@ void ExternalToolRunTask::run() {
 
             setError(error);
         } else if (status == QProcess::NormalExit && exitCode != EXIT_SUCCESS && !hasError()) {
-            QString error = parseStandartOutputFile();
+            QString error = parseStandardOutputFile();
             setError(error.isEmpty() ? tr("%1 tool exited with code %2").arg(toolName).arg(exitCode) : error);
         } else if (status == QProcess::NormalExit && exitCode == EXIT_SUCCESS && !hasError()) {
             algoLog.details(tr("Tool %1 finished successfully").arg(toolName));
@@ -147,22 +152,18 @@ void ExternalToolRunTask::run() {
     }
 }
 
-void ExternalToolRunTask::killProcess(QProcess *process) {
+void ExternalToolRunTask::killProcess(QProcess* process) {
     CmdlineTaskRunner::killProcessTree(process);
 }
 
-QList<long> ExternalToolRunTask::getChildPidsRecursive(long parentPid) {
-    return CmdlineTaskRunner::getChildrenProcesses(parentPid);
-}
-
-void ExternalToolRunTask::addOutputListener(ExternalToolListener *outputListener) {
+void ExternalToolRunTask::addOutputListener(ExternalToolListener* outputListener) {
     if (helper) {
         helper->addOutputListener(outputListener);
     }
     listener = outputListener;
 }
 
-QString ExternalToolRunTask::parseStandartOutputFile() const {
+QString ExternalToolRunTask::parseStandardOutputFile() const {
     CHECK(parseOutputFile, QString());
 
     QFile f(outputFile);
@@ -178,37 +179,37 @@ QString ExternalToolRunTask::parseStandartOutputFile() const {
     return logParser->getLastError();
 }
 
-void ExternalToolRunTask::parseError(const QString &error) const {
+void ExternalToolRunTask::parseError(const QString& error) const {
     logParser->parseErrOutput(error);
 }
 
 ////////////////////////////////////////
 // ExternalToolSupportTask
-void ExternalToolSupportTask::setListenerForTask(ExternalToolRunTask *runTask, int listenerNumber) {
+void ExternalToolSupportTask::setListenerForTask(ExternalToolRunTask* runTask, int listenerNumber) {
     CHECK(listeners.size() > listenerNumber, );
     runTask->addOutputListener(listeners.at(listenerNumber));
 }
 
-void ExternalToolSupportTask::setListenerForHelper(ExternalToolRunTaskHelper *helper, int listenerNumber) {
+void ExternalToolSupportTask::setListenerForHelper(ExternalToolRunTaskHelper* helper, int listenerNumber) {
     CHECK(listeners.size() > listenerNumber, );
     helper->addOutputListener(listeners.at(listenerNumber));
 }
 
-ExternalToolListener *ExternalToolSupportTask::getListener(int listenerNumber) {
+ExternalToolListener* ExternalToolSupportTask::getListener(int listenerNumber) {
     CHECK(listeners.size() > listenerNumber, nullptr);
     return listeners.at(listenerNumber);
 }
 
 ////////////////////////////////////////
 // ExternalToolRunTaskHelper
-ExternalToolRunTaskHelper::ExternalToolRunTaskHelper(ExternalToolRunTask *t)
+ExternalToolRunTaskHelper::ExternalToolRunTaskHelper(ExternalToolRunTask* t)
     : os(t->stateInfo), logParser(t->logParser), process(t->externalToolProcess), listener(nullptr) {
     logData.resize(1000);
     connect(process, SIGNAL(readyReadStandardOutput()), SLOT(sl_onReadyToReadLog()));
     connect(process, SIGNAL(readyReadStandardError()), SLOT(sl_onReadyToReadErrLog()));
 }
 
-ExternalToolRunTaskHelper::ExternalToolRunTaskHelper(QProcess *_process, ExternalToolLogParser *_logParser, U2OpStatus &_os)
+ExternalToolRunTaskHelper::ExternalToolRunTaskHelper(QProcess* _process, ExternalToolLogParser* _logParser, U2OpStatus& _os)
     : os(_os), logParser(_logParser), process(_process), listener(nullptr) {
     logData.resize(1000);
     connect(process, SIGNAL(readyReadStandardOutput()), SLOT(sl_onReadyToReadLog()));
@@ -218,7 +219,7 @@ ExternalToolRunTaskHelper::ExternalToolRunTaskHelper(QProcess *_process, Externa
 void ExternalToolRunTaskHelper::sl_onReadyToReadLog() {
     QMutexLocker locker(&logMutex);
 
-    CHECK(nullptr != process, );
+    CHECK(process != nullptr, );
     if (process->readChannel() == QProcess::StandardError) {
         process->setReadChannel(QProcess::StandardOutput);
     }
@@ -227,7 +228,7 @@ void ExternalToolRunTaskHelper::sl_onReadyToReadLog() {
         // call log parser
         QString line = QString::fromLocal8Bit(logData.constData(), numberReadChars);
         logParser->parseOutput(line);
-        if (nullptr != listener) {
+        if (listener != nullptr) {
             listener->addNewLogMessage(line, ExternalToolListener::OUTPUT_LOG);
         }
         numberReadChars = static_cast<int>(process->read(logData.data(), logData.size()));
@@ -238,7 +239,7 @@ void ExternalToolRunTaskHelper::sl_onReadyToReadLog() {
 void ExternalToolRunTaskHelper::sl_onReadyToReadErrLog() {
     QMutexLocker locker(&logMutex);
 
-    CHECK(nullptr != process, );
+    CHECK(process != nullptr, );
     if (process->readChannel() == QProcess::StandardOutput) {
         process->setReadChannel(QProcess::StandardError);
     }
@@ -247,7 +248,7 @@ void ExternalToolRunTaskHelper::sl_onReadyToReadErrLog() {
         // call log parser
         QString line = QString::fromLocal8Bit(logData.constData(), numberReadChars);
         logParser->parseErrOutput(line);
-        if (nullptr != listener) {
+        if (listener != nullptr) {
             listener->addNewLogMessage(line, ExternalToolListener::ERROR_LOG);
         }
         numberReadChars = static_cast<int>(process->read(logData.data(), logData.size()));
@@ -256,7 +257,7 @@ void ExternalToolRunTaskHelper::sl_onReadyToReadErrLog() {
     os.setProgress(logParser->getProgress());
 }
 
-void ExternalToolRunTaskHelper::addOutputListener(ExternalToolListener *_listener) {
+void ExternalToolRunTaskHelper::addOutputListener(ExternalToolListener* _listener) {
     listener = _listener;
 }
 
@@ -277,27 +278,27 @@ ExternalToolLogParser::ExternalToolLogParser(bool _writeErrorsToLog) {
     writeErrorsToLog = _writeErrorsToLog;
 }
 
-void ExternalToolLogParser::parseOutput(const QString &partOfLog) {
+void ExternalToolLogParser::parseOutput(const QString& partOfLog) {
     lastPartOfLog = partOfLog.split(QRegularExpression("\\r?\\n"));
     lastPartOfLog.first() = lastLine + lastPartOfLog.first();
     // It's a possible situation, that one message will be processed twice
     lastLine = lastPartOfLog.last();
-    foreach (const QString &buf, lastPartOfLog) {
+    foreach (const QString& buf, lastPartOfLog) {
         processLine(buf);
     }
 }
 
-void ExternalToolLogParser::parseErrOutput(const QString &partOfLog) {
+void ExternalToolLogParser::parseErrOutput(const QString& partOfLog) {
     lastPartOfLog = partOfLog.split(QRegularExpression("\\r?\\n"));
     lastPartOfLog.first() = lastErrLine + lastPartOfLog.first();
     // It's a possible situation, that one message will be processed twice
     lastErrLine = lastPartOfLog.last();
-    foreach (const QString &buf, lastPartOfLog) {
+    foreach (const QString& buf, lastPartOfLog) {
         processErrLine(buf);
     }
 }
 
-void ExternalToolLogParser::processLine(const QString &line) {
+void ExternalToolLogParser::processLine(const QString& line) {
     if (isError(line)) {
         setLastError(line);
     } else {
@@ -305,7 +306,7 @@ void ExternalToolLogParser::processLine(const QString &line) {
     }
 }
 
-void ExternalToolLogParser::processErrLine(const QString &line) {
+void ExternalToolLogParser::processErrLine(const QString& line) {
     if (isError(line)) {
         setLastError(line);
     } else {
@@ -313,11 +314,11 @@ void ExternalToolLogParser::processErrLine(const QString &line) {
     }
 }
 
-bool ExternalToolLogParser::isError(const QString &line) const {
+bool ExternalToolLogParser::isError(const QString& line) const {
     return line.contains("error", Qt::CaseInsensitive);
 }
 
-void ExternalToolLogParser::setLastError(const QString &value) {
+void ExternalToolLogParser::setLastError(const QString& value) {
     if (!value.isEmpty() && writeErrorsToLog) {
         ioLog.error(value);
     }
@@ -326,24 +327,18 @@ void ExternalToolLogParser::setLastError(const QString &value) {
 
 ////////////////////////////////////////
 // ExternalToolSupportUtils
-void ExternalToolSupportUtils::removeTmpDir(const QString &tmpDirUrl, U2OpStatus &os) {
-    if (tmpDirUrl.isEmpty()) {
+void ExternalToolSupportUtils::removeTmpDir(const QString& absolutePath, U2OpStatus& os) {
+    if (absolutePath.isEmpty()) {
         os.setError(tr("Can not remove temporary folder: path is empty."));
         return;
     }
-    QDir tmpDir(tmpDirUrl);
-    foreach (const QString &file, tmpDir.entryList(QDir::NoDotAndDotDot | QDir::AllEntries)) {
-        if (!tmpDir.remove(file)) {
-            os.setError(tr("Can not remove files from temporary folder."));
-            return;
-        }
-    }
-    if (!tmpDir.rmdir(tmpDir.absolutePath())) {
-        os.setError(tr("Can not remove folder for temporary files."));
+    QDir tmpDir(absolutePath);
+    if (!tmpDir.removeRecursively()) {
+        os.setError(tr("Can not remove folder for temporary files, folder \"%1\".").arg(tmpDir.absolutePath()));
     }
 }
 
-QString ExternalToolSupportUtils::createTmpDir(const QString &prePath, const QString &domain, U2OpStatus &os) {
+QString ExternalToolSupportUtils::createTmpDir(const QString& prePath, const QString& domain, U2OpStatus& os) {
     int i = 0;
     while (true) {
         QString tmpDirName = QString("d_%1").arg(i);
@@ -360,46 +355,50 @@ QString ExternalToolSupportUtils::createTmpDir(const QString &prePath, const QSt
     }
 }
 
-QString ExternalToolSupportUtils::createTmpDir(const QString &domain, U2OpStatus &os) {
+QString ExternalToolSupportUtils::createTmpDir(const QString& domain, U2OpStatus& os) {
     QString tmpDirPath = AppContext::getAppSettings()->getUserAppsSettings()->getCurrentProcessTemporaryDirPath();
     return createTmpDir(tmpDirPath, domain, os);
 }
 
-void ExternalToolSupportUtils::appendExistingFile(const QString &path, QStringList &files) {
+void ExternalToolSupportUtils::appendExistingFile(const QString& path, QStringList& files) {
     GUrl url(path);
     if (QFile::exists(url.getURLString())) {
         files << url.getURLString();
     }
 }
 
-bool ExternalToolSupportUtils::startExternalProcess(QProcess *process, const QString &program, const QStringList &arguments) {
+bool ExternalToolSupportUtils::startExternalProcess(QProcess* process, const QString& program, const QStringList& arguments) {
     process->start(program, arguments);
     bool started = process->waitForStarted(START_WAIT_MSEC);
 
-#ifdef Q_OS_WIN32
-    if (!started) {
-        QString execStr = WIN_LAUNCH_CMD_COMMAND + program;
-        foreach (const QString arg, arguments) {
-            execStr += " " + arg;
+    if (isOsWindows()) {
+        if (!started) {
+            QString execStr = WIN_LAUNCH_CMD_COMMAND + program;
+            foreach (const QString arg, arguments) {
+                execStr += " " + arg;
+            }
+            process->start(execStr);
+            coreLog.trace(tr("Can't run an executable file \"%1\" as it is. Try to run it as a cmd line command: \"%2\"")
+                              .arg(program)
+                              .arg(execStr));
+            started = process->waitForStarted(START_WAIT_MSEC);
         }
-        process->start(execStr);
-        coreLog.trace(tr("Can't run an executable file \"%1\" as it is. Try to run it as a cmd line command: \"%2\"")
-                          .arg(program)
-                          .arg(execStr));
-        started = process->waitForStarted(START_WAIT_MSEC);
     }
-#endif
 
     return started;
 }
 
-ProcessRun ExternalToolSupportUtils::prepareProcess(const QString &toolId, const QStringList &arguments, const QString &workingDirectory, const QStringList &additionalPaths, U2OpStatus &os, ExternalToolListener *listener) {
+ProcessRun ExternalToolSupportUtils::prepareProcess(const QString& toolId, const QStringList& arguments, const QString& workingDirectory, const QStringList& additionalPaths, U2OpStatus& os, ExternalToolListener* listener) {
     ProcessRun result;
     result.process = nullptr;
     result.arguments = arguments;
 
-    ExternalTool *tool = AppContext::getExternalToolRegistry()->getById(toolId);
-    CHECK_EXT(nullptr != tool, os.setError(tr("A tool with the ID %1 is absent").arg(toolId)), result);
+    ExternalTool* tool = AppContext::getExternalToolRegistry()->getById(toolId);
+    tool->checkArgsAndPaths(arguments, os);
+    if (os.hasError()) {
+        return result;
+    }
+    CHECK_EXT(tool != nullptr, os.setError(tr("A tool with the ID %1 is absent").arg(toolId)), result);
 
     const QString toolName = tool->getName();
     if (tool->getPath().isEmpty()) {
@@ -410,10 +409,10 @@ ProcessRun ExternalToolSupportUtils::prepareProcess(const QString &toolId, const
     QString toolRunnerProgram = tool->getToolRunnerProgramId();
 
     if (!toolRunnerProgram.isEmpty()) {
-        ScriptingToolRegistry *stregister = AppContext::getScriptingToolRegistry();
-        SAFE_POINT_EXT(nullptr != stregister, os.setError("No scripting tool registry"), result);
-        ScriptingTool *stool = stregister->getById(toolRunnerProgram);
-        if (nullptr == stool || stool->getPath().isEmpty()) {
+        ScriptingToolRegistry* stregister = AppContext::getScriptingToolRegistry();
+        SAFE_POINT_EXT(stregister != nullptr, os.setError("No scripting tool registry"), result);
+        ScriptingTool* stool = stregister->getById(toolRunnerProgram);
+        if (stool == nullptr || stool->getPath().isEmpty()) {
             os.setError(QString("The tool %1 that runs %2 is not installed. Please set the path of the tool in the External Tools settings").arg(toolRunnerProgram).arg(toolName));
             return result;
         }
@@ -422,18 +421,13 @@ ProcessRun ExternalToolSupportUtils::prepareProcess(const QString &toolId, const
         for (int i = stool->getRunParameters().size() - 1; i >= 0; i--) {
             result.arguments.prepend(stool->getRunParameters().at(i));
         }
-        foreach (const QString &param, tool->getToolRunnerAdditionalOptions()) {
+        foreach (const QString& param, tool->getToolRunnerAdditionalOptions()) {
             result.arguments.prepend(param);
         }
         result.program = stool->getPath();
     }
 
-#ifdef Q_OS_WIN
-    const QString pathVariableSeparator = ";";
-#else
-    const QString pathVariableSeparator = ":";
-#endif
-
+    QString pathVariableSeparator = isOsWindows() ? ";" : ":";
     QProcessEnvironment processEnvironment = QProcessEnvironment::systemEnvironment();
     QString path = additionalPaths.join(pathVariableSeparator) + pathVariableSeparator +
                    tool->getAdditionalPaths().join(pathVariableSeparator) + pathVariableSeparator +
@@ -452,17 +446,17 @@ ProcessRun ExternalToolSupportUtils::prepareProcess(const QString &toolId, const
 
     // QProcess wraps arguments that contain spaces in quotes automatically.
     // But launched line should look correctly in the log.
-    const QString commandWithArguments = GUrlUtils::getQuotedString(result.program) + ExternalToolSupportUtils::prepareArgumentsForCmdLine(result.arguments);
+    QString commandWithArguments = GUrlUtils::getQuotedString(result.program) + ExternalToolSupportUtils::prepareArgumentsForCmdLine(result.arguments);
     algoLog.details(tr("Launching %1 tool: %2").arg(toolName).arg(commandWithArguments));
 
-    if (nullptr != listener) {
+    if (listener != nullptr) {
         listener->setToolName(toolName);
         listener->addNewLogMessage(commandWithArguments, ExternalToolListener::PROGRAM_WITH_ARGUMENTS);
     }
     return result;
 }
 
-QString ExternalToolSupportUtils::prepareArgumentsForCmdLine(const QStringList &arguments) {
+QString ExternalToolSupportUtils::prepareArgumentsForCmdLine(const QStringList& arguments) {
     QString argumentsLine;
     foreach (QString argumentStr, arguments) {
         // Find start of the parameter value
@@ -478,7 +472,7 @@ QString ExternalToolSupportUtils::prepareArgumentsForCmdLine(const QStringList &
     return argumentsLine;
 }
 
-QStringList ExternalToolSupportUtils::splitCmdLineArguments(const QString &program) {
+QStringList ExternalToolSupportUtils::splitCmdLineArguments(const QString& program) {
     // a function body from "qprocess.cpp"
 
     QStringList args;
@@ -583,10 +577,113 @@ QVariantMap ExternalToolSupportUtils::getScoresGapDependencyMap() {
     return map;
 }
 
+bool checkHasNonLatin1Symbols(const QString& str) {
+    QByteArray tolatin1(str.toLatin1());
+    return QString::fromLatin1(tolatin1.constData(), tolatin1.size()) != str;
+}
+
+QString ExternalToolSupportUtils::checkArgumentPathLatinSymbols(const QStringList& args) {
+    for (const QString& path : qAsConst(args)) {
+        if (!path.isEmpty() && checkHasNonLatin1Symbols(path)) {
+            return tr("One of the arguments passed to \"%1\" external tool is not in Latin alphabet."
+                      " Make sure that the input and output files and folders"
+                      " are located in the paths which contain only Latin characters. Current problem path is: \"") +
+                   path + "\"";
+        }
+    }
+    return "";
+}
+
+QString ExternalToolSupportUtils::checkTemporaryDirLatinSymbols() {
+    QString path = AppContext::getAppSettings()->getUserAppsSettings()->getCurrentProcessTemporaryDirPath();
+    if (checkHasNonLatin1Symbols(path)) {
+        return tr("Your \"Temporary files\" directory contains non-latin symbols, \"%1\" external tool can't correct process it."
+                  " Please change it in Preferences on the Directories page, restart UGENE and try again. Current problem path is: ") +
+               path;
+    }
+    return "";
+}
+
+QString ExternalToolSupportUtils::checkToolPathLatinSymbols(const ExternalTool* tool) {
+    const QString& path = tool->getPath();
+    QByteArray tolatin1(path.toLatin1());
+    if (QString::fromLatin1(tolatin1.constData(), tolatin1.size()) != path) {
+        tr("\"%1\" external tool located in path which contains non-latin symbols."
+           " Please change it location to path which contains only latin symbols, set the new path in"
+           " Preferences on the External tools and try again. Current problem path is: ") +
+            path;
+    }
+    return "";
+}
+
+QString ExternalToolSupportUtils::checkIndexDirLatinSymbols() {
+    QString path = AppContext::getSettings()->getValue(SETTINGS_ROOT + INDEX_DIR, "", true).toString();
+    if (checkHasNonLatin1Symbols(path)) {
+        return tr("Your \"Build indexes\" directory contains non-latin symbols, \"%1\" external tool can't correct process it."
+                  " Please change it in Preferences on the Directories page, restart UGENE and try again. Current problem path is: ") +
+               path;
+    }
+    return "";
+}
+
+QString ExternalToolSupportUtils::checkSpacesArgumentsLikeMakeblastdb(const QStringList& args) {
+    QStringList agrsNoJoinedLines;
+    for (const QString& arg : qAsConst(args)) {
+        if (arg.startsWith("\"") && arg.endsWith("\"")) {
+            QStringList argsSplited = arg.mid(1, arg.size() - 2).split("\" \"");
+            for (const QString& splittedArg : qAsConst(argsSplited)) {
+                if (splittedArg.isEmpty()) {
+                    return tr("One of the arguments passed to \"%1\" external tool contains empty arguments.");
+                } else if (splittedArg.contains("\"") && splittedArg.contains("'") && splittedArg.contains("`")) {
+                    return tr("One of the arguments passed to \"%1\" external tool contains unexpected quotes. Current problem argument is: ") + splittedArg;
+                } else {
+                    agrsNoJoinedLines << splittedArg;
+                }
+            }
+        } else {
+            agrsNoJoinedLines << arg;
+        }
+    }
+    return checkArgumentPathSpaces(agrsNoJoinedLines);
+}
+
+QString ExternalToolSupportUtils::checkArgumentPathSpaces(const QStringList& args) {
+    for (const QString& path : qAsConst(args)) {
+        if (path.contains(" ")) {
+            return tr("One of the arguments passed to \"%1\" external tool contains spaces."
+                      " Make sure that the input and output files and folders"
+                      " are located in the paths which contain no spaces. Current problem path is: ") +
+                   path;
+        }
+    }
+    return "";
+}
+
+QString ExternalToolSupportUtils::checkTemporaryDirSpaces() {
+    QString path = AppContext::getAppSettings()->getUserAppsSettings()->getCurrentProcessTemporaryDirPath();
+    if (path.contains(" ")) {
+        return tr("Your \"Temporary files\" directory contains spaces, \"%1\" external tool can't correct process it."
+                  " Please change it in Preferences on the Directories page, restart UGENE and try again. Current problem path is: ") +
+               path;
+    }
+    return "";
+}
+
+QString ExternalToolSupportUtils::checkToolPathSpaces(const ExternalTool* tool) {
+    const QString& path = tool->getPath();
+    if (path.contains(" ")) {
+        return tr("\"%1\" external tool located in path which contains spaces symbols."
+                  " Please change it location to path which contains no spaces,  set the new path in"
+                  " Preferences on the External tools and try again. Current problem path is: ") +
+               path;
+    }
+    return "";
+}
+
 ExternalToolLogProcessor::~ExternalToolLogProcessor() {
 }
 
-ExternalToolListener::ExternalToolListener(ExternalToolLogProcessor *logProcessor)
+ExternalToolListener::ExternalToolListener(ExternalToolLogProcessor* logProcessor)
     : logProcessor(logProcessor) {
 }
 
@@ -594,16 +691,16 @@ ExternalToolListener::~ExternalToolListener() {
     delete logProcessor;
 }
 
-void ExternalToolListener::setToolName(const QString &_toolName) {
+void ExternalToolListener::setToolName(const QString& _toolName) {
     toolName = _toolName;
 }
 
-void ExternalToolListener::setLogProcessor(ExternalToolLogProcessor *newLogProcessor) {
+void ExternalToolListener::setLogProcessor(ExternalToolLogProcessor* newLogProcessor) {
     delete logProcessor;
     logProcessor = newLogProcessor;
 }
 
-const QString &ExternalToolListener::getToolName() const {
+const QString& ExternalToolListener::getToolName() const {
     return toolName;
 }
 
