@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __EXTRACT_ANNOTATED_REGION_TASK_H__
-#define __EXTRACT_ANNOTATED_REGION_TASK_H__
+#pragma once
 
 #include <U2Core/AnnotationData.h>
 #include <U2Core/DNASequence.h>
@@ -45,27 +44,25 @@ struct U2CORE_EXPORT ExtractAnnotatedRegionTaskSettings {
 class U2CORE_EXPORT ExtractAnnotatedRegionTask : public Task {
     Q_OBJECT
 public:
-    ExtractAnnotatedRegionTask(const DNASequence &sequence, const SharedAnnotationData &sd, const ExtractAnnotatedRegionTaskSettings &cfg);
+    ExtractAnnotatedRegionTask(const DNASequence& sequence, const SharedAnnotationData& sd, const ExtractAnnotatedRegionTaskSettings& cfg);
     void prepare();
     void run();
-    const QList<DNASequence> &getResultedSequences() const;
-    const SharedAnnotationData &getInputAnnotation() const;
+    const QList<DNASequence>& getResultedSequences() const;
+    const SharedAnnotationData& getInputAnnotation() const;
 
 private:
     void prepareTranslations();
-    void extractLocations(QList<QByteArray> &resParts, QVector<U2Region> &resLocation, const QVector<U2Region> &origLocation);
+    void extractLocations(QList<QByteArray>& resParts, QVector<U2Region>& resLocation, const QVector<U2Region>& origLocation);
 
     DNASequence inputSeq;
     const SharedAnnotationData inputAnn;
     ExtractAnnotatedRegionTaskSettings cfg;
 
     QVector<U2Region> extendedRegions;
-    const DNATranslation *complT;
-    const DNATranslation *aminoT;
+    const DNATranslation* complT;
+    const DNATranslation* aminoT;
 
     QList<DNASequence> resultedSeqList;
 };
 
 }  // namespace U2
-
-#endif
