@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FAIL_TASK_H_
-#define _U2_FAIL_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -29,12 +28,10 @@ namespace U2 {
 class U2CORE_EXPORT FailTask : public Task {
     Q_OBJECT
 public:
-    FailTask(const QString &msg)
+    FailTask(const QString& msg)
         : Task(tr("Failure"), TaskFlag_NoRun) {
         stateInfo.setError(msg);
     }
 };
 
 }  // namespace U2
-
-#endif
