@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LOAD_DOCUMENT_TASK_H_
-#define _U2_LOAD_DOCUMENT_TASK_H_
+#pragma once
 
 #include <QPointer>
 #include <QVariantMap>
@@ -41,46 +40,46 @@ class LoadDocumentTask;
 // NOTE: the default impl can create only limited set of objects
 class U2CORE_EXPORT LDTObjectFactory : public QObject {
 public:
-    LDTObjectFactory(QObject *p)
+    LDTObjectFactory(QObject* p)
         : QObject(p) {
     }
 
-    virtual GObject *create(const GObjectReference &ref);
+    virtual GObject* create(const GObjectReference& ref);
 };
 
 class U2CORE_EXPORT LoadDocumentTaskConfig {
 public:
-    LoadDocumentTaskConfig(bool _createDoc = false, const GObjectReference &_ref = GObjectReference(), LDTObjectFactory *_f = nullptr)
+    LoadDocumentTaskConfig(bool _createDoc = false, const GObjectReference& _ref = GObjectReference(), LDTObjectFactory* _f = nullptr)
         : createDoc(_createDoc), checkObjRef(_ref), objFactory(_f) {
     }
 
     bool createDoc;  // if document is failed to load and 'createDoc' is true -> it will be created
     GObjectReference checkObjRef;  // if is valid task checks that ref is found in doc, fails if not
-    LDTObjectFactory *objFactory;  // if not NULL and 'checkObjRef' is not found -> 'objFactory' is used to create obj
+    LDTObjectFactory* objFactory;  // if not NULL and 'checkObjRef' is not found -> 'objFactory' is used to create obj
 };
 
 class U2CORE_EXPORT LoadUnloadedDocumentTask : public DocumentProviderTask {
     Q_OBJECT
 public:
-    LoadUnloadedDocumentTask(Document *d, const LoadDocumentTaskConfig &config = LoadDocumentTaskConfig());
+    LoadUnloadedDocumentTask(Document* d, const LoadDocumentTaskConfig& config = LoadDocumentTaskConfig());
 
     virtual void prepare();
     virtual ReportResult report();
-    virtual Document *getDocument(bool mainThread = true);
+    virtual Document* getDocument(bool mainThread = true);
 
-    static QString getResourceName(Document *d);
+    static QString getResourceName(Document* d);
 
-    const LoadDocumentTaskConfig &getConfig() const {
+    const LoadDocumentTaskConfig& getConfig() const {
         return config;
     }
 
-    static LoadUnloadedDocumentTask *findActiveLoadingTask(Document *d);
-    static bool addLoadingSubtask(Task *t, const LoadDocumentTaskConfig &config);
+    static LoadUnloadedDocumentTask* findActiveLoadingTask(Document* d);
+    static bool addLoadingSubtask(Task* t, const LoadDocumentTaskConfig& config);
 
 private:
     void clearResourceUse();
 
-    LoadDocumentTask *loadTask;
+    LoadDocumentTask* loadTask;
     QPointer<Document> unloadedDoc;
     QString resName;
     LoadDocumentTaskConfig config;
@@ -89,38 +88,46 @@ private:
 class U2CORE_EXPORT LoadDocumentTask : public DocumentProviderTask {
     Q_OBJECT
 public:
-    static LoadDocumentTask *getDefaultLoadDocTask(const GUrl &url, const QVariantMap &hints = QVariantMap());
-    static LoadDocumentTask *getDefaultLoadDocTask(U2OpStatus &os, const GUrl &url, const QVariantMap &hints = QVariantMap());
-    static DocumentProviderTask *getCommonLoadDocTask(const GUrl &url);
+    static LoadDocumentTask* getDefaultLoadDocTask(const GUrl& url, const QVariantMap& hints = QVariantMap());
+    static LoadDocumentTask* getDefaultLoadDocTask(U2OpStatus& os, const GUrl& url, const QVariantMap& hints = QVariantMap());
+    static DocumentProviderTask* getCommonLoadDocTask(const GUrl& url);
 
 public:
-    LoadDocumentTask(DocumentFormatId format, const GUrl &url, IOAdapterFactory *iof, const QVariantMap &hints = QVariantMap(), const LoadDocumentTaskConfig &config = LoadDocumentTaskConfig());
+    LoadDocumentTask(DocumentFormatId format, const GUrl& url, IOAdapterFactory* iof, const QVariantMap& hints = QVariantMap(), const LoadDocumentTaskConfig& config = LoadDocumentTaskConfig());
 
-    LoadDocumentTask(DocumentFormat *format, const GUrl &url, IOAdapterFactory *iof, const QVariantMap &hints = QVariantMap(), const LoadDocumentTaskConfig &config = LoadDocumentTaskConfig());
+    LoadDocumentTask(DocumentFormat* format, const GUrl& url, IOAdapterFactory* iof, const QVariantMap& hints = QVariantMap(), const LoadDocumentTaskConfig& config = LoadDocumentTaskConfig());
 
-    virtual void run();
-    virtual void prepare();
-    virtual ReportResult report();
+    void run() override;
+    void prepare() override;
+    ReportResult report() override;
+
+    const GUrl& getURL() const;
 
-    const GUrl &getURL() const {
-        return url;
-    }
     QString getURLString() const;
 
+    /** When set to 'true' the result document will be moved to the main thread right after loading (run). */
+    bool moveDocumentToMainThread = false;
+
 private:
+    void loadDocument();
+
     void init();
-    void processObjRef();
+
+    /**
+     * Processes config.checkObjRef and config.checkObjRef.objFactory related settings.
+     * See 'LoadDocumentTaskConfig' for details.
+     */
+    void processObjRef(Document* loadedDocument);
+
     int calculateMemory() const;
 
-    static void renameObjects(Document *doc, const QStringList &names);
+    static void renameObjects(Document* doc, const QStringList& names);
 
-    DocumentFormat *format;
+    DocumentFormat* format;
     const GUrl url;
-    IOAdapterFactory *iof;
+    IOAdapterFactory* iof;
     QVariantMap hints;
     LoadDocumentTaskConfig config;
 };
 
 }  // namespace U2
-
-#endif
