@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -57,9 +57,36 @@ const QString RemoteDBRegistry::SWISS_PROT("SWISS-PROT");
 const QString RemoteDBRegistry::UNIPROTKB_SWISS_PROT("UniProtKB/Swiss-Prot");
 const QString RemoteDBRegistry::UNIPROTKB_TREMBL("UniProtKB/TrEMBL");
 
+static const QString ENSEMBL_EXTERNAL = "https://www.ensembl.org";
+static const QString GENBANK_DNA_EXTERNAL = "https://www.ncbi.nlm.nih.gov/nucleotide";
+static const QString GENBANK_PROTEIN_EXTERNAL = "https://www.ncbi.nlm.nih.gov/protein";
+static const QString PDB_EXTERNAL = "https://www.rcsb.org";
+static const QString UNIPROTKB_EXTERNAL = "https://www.uniprot.org";
+
+static const QString ENSEMBL_PAGE_ID = ENSEMBL_EXTERNAL + "/id/%1";
+static const QString GENBANK_DNA_PAGE_ID = GENBANK_DNA_EXTERNAL + "/%1?report=genbank";
+static const QString GENBANK_PROTEIN_PAGE_ID = GENBANK_PROTEIN_EXTERNAL + "/%1?report=genbank";
+static const QString PDB_PAGE_ID = PDB_EXTERNAL + "/structure/%1";
+static const QString UNIPROTKB_PAGE_ID = UNIPROTKB_EXTERNAL + "/uniprotkb/%1/entry";
+
+const QMap<QString, QString> RemoteDBRegistry::EXTERNAL_LINKS = { {ENSEMBL, ENSEMBL_EXTERNAL},
+                                                                  {GENBANK_DNA, GENBANK_DNA_EXTERNAL},
+                                                                  {GENBANK_PROTEIN, GENBANK_PROTEIN_EXTERNAL},
+                                                                  {PDB, PDB_EXTERNAL},
+                                                                  {SWISS_PROT, UNIPROTKB_EXTERNAL},
+                                                                  {UNIPROTKB_SWISS_PROT, UNIPROTKB_EXTERNAL},
+                                                                  {UNIPROTKB_TREMBL, UNIPROTKB_EXTERNAL} };
+const QMap<QString, QString> RemoteDBRegistry::PAGE_LINKS = { {ENSEMBL, ENSEMBL_PAGE_ID},
+                                                              {GENBANK_DNA, GENBANK_DNA_PAGE_ID},
+                                                              {GENBANK_PROTEIN, GENBANK_PROTEIN_PAGE_ID},
+                                                              {PDB, PDB_PAGE_ID},
+                                                              {SWISS_PROT, UNIPROTKB_PAGE_ID},
+                                                              {UNIPROTKB_SWISS_PROT, UNIPROTKB_PAGE_ID},
+                                                              {UNIPROTKB_TREMBL, UNIPROTKB_PAGE_ID} };
+
 ////////////////////////////////////////////////////////////////////////////
 // BaseLoadRemoteDocumentTask
-BaseLoadRemoteDocumentTask::BaseLoadRemoteDocumentTask(const QString &_downloadPath, const QVariantMap &hints, TaskFlags flags)
+BaseLoadRemoteDocumentTask::BaseLoadRemoteDocumentTask(const QString& _downloadPath, const QVariantMap& hints, TaskFlags flags)
     : DocumentProviderTask(tr("Load remote document"), flags), hints(hints) {
     downloadPath = _downloadPath;
     sourceUrl = GUrl("");
@@ -97,7 +124,7 @@ Task::ReportResult BaseLoadRemoteDocumentTask::report() {
     return ReportResult_Finished;
 }
 
-bool BaseLoadRemoteDocumentTask::prepareDownloadDirectory(QString &path) {
+bool BaseLoadRemoteDocumentTask::prepareDownloadDirectory(QString& path) {
     if (!QDir(path).exists()) {
         if (path == getDefaultDownloadDirectory()) {
             // Creating default folder if it doesn't exist
@@ -120,7 +147,7 @@ QString BaseLoadRemoteDocumentTask::getDefaultDownloadDirectory() {
 
 bool BaseLoadRemoteDocumentTask::initLoadDocumentTask() {
     // Check if the document has been loaded
-    Project *proj = AppContext::getProject();
+    Project* proj = AppContext::getProject();
     if (proj != nullptr) {
         resultDocument = proj->findDocumentByURL(fullPath);
         if (resultDocument != nullptr) {
@@ -135,7 +162,7 @@ bool BaseLoadRemoteDocumentTask::initLoadDocumentTask() {
         CHECK_EXT(!formats.isEmpty(), setError(tr("Unknown file format!")), false)
         formatId = formats.first().format->getFormatId();
     }
-    IOAdapterFactory *iow = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
+    IOAdapterFactory* iow = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
     loadDocumentTask = new LoadDocumentTask(formatId, fullPath, iow, hints);
 
     return true;
@@ -143,7 +170,7 @@ bool BaseLoadRemoteDocumentTask::initLoadDocumentTask() {
 
 bool BaseLoadRemoteDocumentTask::isCached() {
     // Check if the file has already been downloaded
-    RecentlyDownloadedCache *cache = AppContext::getRecentlyDownloadedCache();
+    RecentlyDownloadedCache* cache = AppContext::getRecentlyDownloadedCache();
     if (cache != nullptr && cache->contains(fileName)) {
         QString cachedUrl = cache->getFullPath(fileName);
         if (fullPath == cachedUrl) {
@@ -163,24 +190,24 @@ void BaseLoadRemoteDocumentTask::createLoadedDocument() {
     if (formatId.isEmpty()) {
         formatId = BaseDocumentFormats::PLAIN_GENBANK;
     }
-    IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(url));
-    DocumentFormat *dformat = AppContext::getDocumentFormatRegistry()->getFormatById(formatId);
+    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(url));
+    DocumentFormat* dformat = AppContext::getDocumentFormatRegistry()->getFormatById(formatId);
     U2OpStatus2Log os;
     resultDocument = dformat->createNewLoadedDocument(iof, url, os);
 }
 
 //////////////////////////////////////////////////////////////////////////
 // LoadRemoteDocumentTask
-LoadRemoteDocumentTask::LoadRemoteDocumentTask(const GUrl &url)
+
+LoadRemoteDocumentTask::LoadRemoteDocumentTask(const GUrl& url)
     : BaseLoadRemoteDocumentTask(),
-      loadDataFromEntrezTask(nullptr) {
+    loadDataFromEntrezTask(nullptr) {
     fileUrl = url;
     GCOUNTER(cvar, "LoadRemoteDocumentTask");
 }
 
-LoadRemoteDocumentTask::LoadRemoteDocumentTask(const QString &accId, const QString &dbName, const QString &fullPathDir, const QString &fileFormat, const QVariantMap &hints)
+LoadRemoteDocumentTask::LoadRemoteDocumentTask(const QString& accId, const QString& dbName, const QString& fullPathDir, const QString& fileFormat, const QVariantMap& hints)
     : BaseLoadRemoteDocumentTask(fullPathDir, hints),
-      loadDataFromEntrezTask(nullptr),
       accNumber(accId),
       dbName(dbName) {
     GCOUNTER(cvar, "LoadRemoteDocumentTask");
@@ -191,8 +218,8 @@ void LoadRemoteDocumentTask::prepare() {
     BaseLoadRemoteDocumentTask::prepare();
     if (!isCached()) {
         if (sourceUrl.isHyperLink()) {
-            IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::HTTP_FILE);
-            IOAdapterFactory *iow = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
+            IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::HTTP_FILE);
+            IOAdapterFactory* iow = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
             copyDataTask = new CopyDataTask(iof, sourceUrl, iow, fullPath);
             addSubTask(copyDataTask);
         } else {
@@ -209,7 +236,30 @@ void LoadRemoteDocumentTask::prepare() {
     }
 }
 
-QString LoadRemoteDocumentTask::getFileFormat(const QString &dbid) {
+QString LoadRemoteDocumentTask::generateReport() const {
+    CHECK(!hasError(), tr("Failed to download %1 from %2. Error: %3").arg(accNumber).arg(dbName).arg(getError()));
+    CHECK(!isCanceled(), {});
+
+    QString db = dbName;
+    QString acc = accNumber;
+    if (!fileUrl.isEmpty()) {
+        auto res = AppContext::getDBXRefRegistry()->getDbAndAccessionBytUrl(fileUrl.getURLString());
+        db = res.first;
+        acc = res.second;
+    }
+
+    QString res = tr("Document was successfully downloaded: [%1, %2] -> <a href='%3'>%3</a>").arg(db).arg(acc).arg(fullPath);
+    QString pageLink = RemoteDBRegistry::PAGE_LINKS.value(db);
+    SAFE_POINT(!pageLink.isEmpty(), QString("No database found: %1").arg(db), res);
+
+    pageLink = pageLink.arg(acc);
+    res += "<br>";
+    res += tr("External database link: <a href='%1'>%1</a>").arg(pageLink);
+
+    return res;
+}
+
+QString LoadRemoteDocumentTask::getFileFormat(const QString& dbid) {
     QString dbId = RemoteDBRegistry::getRemoteDBRegistry().getDbEntrezName(dbid);
     if (dbId == GENBANK_NUCLEOTIDE_ID || dbId == GENBANK_PROTEIN_ID) {
         return GENBANK_FORMAT;
@@ -246,8 +296,8 @@ QString LoadRemoteDocumentTask::getFileName() {
     return "";
 }
 
-QList<Task *> LoadRemoteDocumentTask::onSubTaskFinished(Task *subTask) {
-    QList<Task *> subTasks;
+QList<Task*> LoadRemoteDocumentTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> subTasks;
     if (subTask->hasError()) {
         if (subTask == copyDataTask || subTask == loadDataFromEntrezTask) {
             setError(tr("Cannot find %1 in %2 database").arg(accNumber).arg(dbName) + ": " + subTask->getError());
@@ -258,7 +308,7 @@ QList<Task *> LoadRemoteDocumentTask::onSubTaskFinished(Task *subTask) {
         if (initLoadDocumentTask()) {
             subTasks.append(loadDocumentTask);
             if (!subTask->isCanceled()) {
-                RecentlyDownloadedCache *cache = AppContext::getRecentlyDownloadedCache();
+                RecentlyDownloadedCache* cache = AppContext::getRecentlyDownloadedCache();
                 if (cache != nullptr) {
                     cache->append(fullPath);
                 }
@@ -284,7 +334,7 @@ QString LoadRemoteDocumentTask::getRetType() const {
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 RecentlyDownloadedCache::RecentlyDownloadedCache() {
     QStringList fileNames = AppContext::getAppSettings()->getUserAppsSettings()->getRecentlyDownloadedFileNames();
-    foreach (const QString &path, fileNames) {
+    foreach (const QString& path, fileNames) {
         QFileInfo info(path);
         if (info.exists()) {
             append(path);
@@ -292,7 +342,7 @@ RecentlyDownloadedCache::RecentlyDownloadedCache() {
     }
 }
 
-bool RecentlyDownloadedCache::contains(const QString &fileName) {
+bool RecentlyDownloadedCache::contains(const QString& fileName) {
     if (!urlMap.contains(fileName)) {
         return false;
     } else {
@@ -302,30 +352,30 @@ bool RecentlyDownloadedCache::contains(const QString &fileName) {
     }
 }
 
-void RecentlyDownloadedCache::append(const QString &fileName) {
+void RecentlyDownloadedCache::append(const QString& fileName) {
     QFileInfo info(fileName);
     urlMap.insert(info.fileName(), fileName);
 }
 
-void RecentlyDownloadedCache::remove(const QString &fullPath) {
+void RecentlyDownloadedCache::remove(const QString& fullPath) {
     urlMap.remove(QFileInfo(fullPath).fileName());
 }
 
-QString RecentlyDownloadedCache::getFullPath(const QString &fileName) {
+QString RecentlyDownloadedCache::getFullPath(const QString& fileName) {
     return urlMap.value(fileName);
 }
 
 RecentlyDownloadedCache::~RecentlyDownloadedCache() {
     // TODO: cache depends on AppSettings! get rid of this dependency!
     QStringList fileNames = urlMap.values();
-    AppSettings *settings = AppContext::getAppSettings();
-    UserAppsSettings *us = settings->getUserAppsSettings();
+    AppSettings* settings = AppContext::getAppSettings();
+    UserAppsSettings* us = settings->getUserAppsSettings();
     us->setRecentlyDownloadedFileNames(fileNames);
 }
 
 //////////////////////////////////////////////////////////////////////////
 
-BaseEntrezRequestTask::BaseEntrezRequestTask(const QString &taskName)
+BaseEntrezRequestTask::BaseEntrezRequestTask(const QString& taskName)
     : Task(taskName, TaskFlags_FOSCOE | TaskFlag_MinimizeSubtaskErrorText),
       loop(nullptr), networkManager(nullptr) {
 }
@@ -339,7 +389,7 @@ BaseEntrezRequestTask::~BaseEntrezRequestTask() {
 
 void BaseEntrezRequestTask::sl_onError() {
     loop->exit();
-    QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
+    auto reply = qobject_cast<QNetworkReply*>(sender());
     CHECK(reply != nullptr, )
     stateInfo.setError(reply->errorString());
 }
@@ -348,32 +398,32 @@ void BaseEntrezRequestTask::sl_uploadProgress(qint64 bytesSent, qint64 bytesTota
     stateInfo.progress = bytesSent / bytesTotal * 100;
 }
 
-void BaseEntrezRequestTask::onProxyAuthenticationRequired(const QNetworkProxy &proxy, QAuthenticator *auth) {
+void BaseEntrezRequestTask::onProxyAuthenticationRequired(const QNetworkProxy& proxy, QAuthenticator* auth) {
     auth->setUser(proxy.user());
     auth->setPassword(proxy.password());
-    disconnect(this, SLOT(onProxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)));
+    disconnect(this, SLOT(onProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
 }
 
-void BaseEntrezRequestTask::createLoopAndNetworkManager(const QString &queryString) {
-    SAFE_POINT(nullptr == networkManager, "Attempting to initialize network manager twice", );
-    networkManager = new QNetworkAccessManager;
-    connect(networkManager, SIGNAL(finished(QNetworkReply *)), this, SLOT(sl_replyFinished(QNetworkReply *)));
+void BaseEntrezRequestTask::createLoopAndNetworkManager(const QString& queryString) {
+    SAFE_POINT(networkManager == nullptr, "Attempting to initialize network manager twice", );
+    networkManager = new QNetworkAccessManager();
+    connect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(sl_replyFinished(QNetworkReply*)));
 
-    NetworkConfiguration *nc = AppContext::getAppSettings()->getNetworkConfiguration();
+    NetworkConfiguration* nc = AppContext::getAppSettings()->getNetworkConfiguration();
     QNetworkProxy proxy = nc->getProxyByUrl(queryString);
     networkManager->setProxy(proxy);
-    connect(networkManager, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)), this, SLOT(onProxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)));
+    connect(networkManager, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)), this, SLOT(onProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
 
-    SAFE_POINT(nullptr == loop, "Attempting to initialize loop twice", );
-    loop = new QEventLoop;
+    SAFE_POINT(loop == nullptr, "Attempting to initialize loop twice", );
+    loop = new QEventLoop();
 }
 
 //////////////////////////////////////////////////////////////////////////
 
-LoadDataFromEntrezTask::LoadDataFromEntrezTask(const QString &dbId,
-                                               const QString &accNum,
-                                               const QString &retType,
-                                               const QString &path)
+LoadDataFromEntrezTask::LoadDataFromEntrezTask(const QString& dbId,
+                                               const QString& accNum,
+                                               const QString& retType,
+                                               const QString& path)
     : BaseEntrezRequestTask("LoadDataFromEntrez"),
       searchReply(nullptr),
       downloadReply(nullptr),
@@ -388,35 +438,33 @@ void LoadDataFromEntrezTask::run() {
     ioLog.trace("Load data from Entrez started...");
 
     // Step one: download the file
-    QString traceFetchUrl = QString(EntrezUtils::NCBI_EFETCH_URL).arg(db).arg(accNumber).arg(format);
+    QString traceFetchUrl = EntrezUtils::NCBI_EFETCH_URL.arg(db).arg(accNumber).arg(format);
 
     createLoopAndNetworkManager(traceFetchUrl);
 
     ioLog.details(tr("Downloading file %1").arg(traceFetchUrl));
-    QUrl requestUrl(EntrezUtils::NCBI_EFETCH_URL.arg(db).arg(accNumber).arg(format));
+    QUrl requestUrl(traceFetchUrl);
     runRequest(requestUrl);
     loop->exec();
+    CHECK(!isCanceled(), );
+    ioLog.trace("Download finished.");
 
-    if (!isCanceled()) {
-        ioLog.trace("Download finished.");
-
-        QByteArray result = downloadReply->readAll();
-        if (((result.size() < 100) && result.contains("Nothing has been found")) || (result.contains("ID list is empty! In it there are neither IDs nor accessions"))) {
-            setError(tr("Sequence with ID=%1 is not found.").arg(accNumber));
-            return;
-        }
-
-        QFile downloadedFile(fullPath);
-        if (!downloadedFile.open(QIODevice::WriteOnly)) {
-            stateInfo.setError("Cannot open file to write!");
-            return;
-        }
-        downloadedFile.write(result);
-        downloadedFile.close();
+    QByteArray result = downloadReply->readAll();
+    if ((result.size() < 100 && result.contains("Nothing has been found")) || result.contains("ID list is empty! In it there are neither IDs nor accessions")) {
+        setError(tr("Sequence with ID=%1 is not found.").arg(accNumber));
+        return;
     }
+
+    QFile downloadedFile(fullPath);
+    if (!downloadedFile.open(QIODevice::WriteOnly)) {
+        stateInfo.setError("Cannot open file to write!");
+        return;
+    }
+    downloadedFile.write(result);
+    downloadedFile.close();
 }
 
-void LoadDataFromEntrezTask::runRequest(const QUrl &requestUrl) {
+void LoadDataFromEntrezTask::runRequest(const QUrl& requestUrl) {
     downloadReply = networkManager->get(QNetworkRequest(requestUrl));
     connect(downloadReply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(sl_onError()));
     connect(downloadReply, SIGNAL(uploadProgress(qint64, qint64)), this, SLOT(sl_uploadProgress(qint64, qint64)));
@@ -434,7 +482,7 @@ void LoadDataFromEntrezTask::sl_cancelCheck() {
     }
 }
 
-void LoadDataFromEntrezTask::sl_replyFinished(QNetworkReply *reply) {
+void LoadDataFromEntrezTask::sl_replyFinished(QNetworkReply* reply) {
     if (isCanceled()) {
         loop->exit();
         return;
@@ -448,7 +496,7 @@ void LoadDataFromEntrezTask::sl_replyFinished(QNetworkReply *reply) {
             return;
         }
         QXmlInputSource source(reply);
-        ESearchResultHandler *handler = new ESearchResultHandler;
+        auto handler = new ESearchResultHandler();
         xmlReader.setContentHandler(handler);
         xmlReader.setErrorHandler(handler);
         bool ok = xmlReader.parse(source);
@@ -463,12 +511,12 @@ void LoadDataFromEntrezTask::sl_replyFinished(QNetworkReply *reply) {
 
 //////////////////////////////////////////////////////////////////////////
 
-EntrezQueryTask::EntrezQueryTask(QXmlDefaultHandler *rHandler, const QString &searchQuery)
+EntrezQueryTask::EntrezQueryTask(QXmlDefaultHandler* rHandler, const QString& searchQuery)
     : BaseEntrezRequestTask("EntrezQueryTask"),
       queryReply(nullptr),
       resultHandler(rHandler),
       query(searchQuery) {
-    SAFE_POINT(nullptr != rHandler, "Invalid pointer encountered", );
+    SAFE_POINT(rHandler != nullptr, "Invalid pointer encountered", );
 }
 
 void EntrezQueryTask::run() {
@@ -486,11 +534,11 @@ void EntrezQueryTask::run() {
     }
 }
 
-const QXmlDefaultHandler *EntrezQueryTask::getResultHandler() const {
+const QXmlDefaultHandler* EntrezQueryTask::getResultHandler() const {
     return resultHandler;
 }
 
-void EntrezQueryTask::sl_replyFinished(QNetworkReply *reply) {
+void EntrezQueryTask::sl_replyFinished(QNetworkReply* reply) {
     assert(reply == queryReply);
     if (isCanceled()) {
         loop->exit();
@@ -514,15 +562,15 @@ void EntrezQueryTask::sl_replyFinished(QNetworkReply *reply) {
     loop->exit();
 }
 
-void EntrezQueryTask::runRequest(const QUrl &requestUrl) {
+void EntrezQueryTask::runRequest(const QUrl& requestUrl) {
     ioLog.trace(QString("Sending request: %1").arg(query));
     queryReply = networkManager->get(QNetworkRequest(requestUrl));
-    connect(queryReply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(sl_onError()));
+    connect(queryReply, &QNetworkReply::errorOccurred, this, &EntrezQueryTask::sl_onError);
 }
 
 //////////////////////////////////////////////////////////////////////////
 
-bool ESearchResultHandler::startElement(const QString &namespaceURI, const QString &localName, const QString &qName, const QXmlAttributes &attributes) {
+bool ESearchResultHandler::startElement(const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& attributes) {
     Q_UNUSED(namespaceURI);
     Q_UNUSED(localName);
     Q_UNUSED(attributes);
@@ -538,10 +586,10 @@ bool ESearchResultHandler::startElement(const QString &namespaceURI, const QStri
     return true;
 }
 
-bool ESearchResultHandler::endElement(const QString &namespaceURI, const QString &localName, const QString &qName) {
+bool ESearchResultHandler::endElement(const QString& namespaceURI, const QString& localName, const QString& qName) {
     Q_UNUSED(namespaceURI);
     Q_UNUSED(localName);
-    if ("Id" == qName) {
+    if (qName == "Id") {
         idList.append(curText);
     }
     return true;
@@ -551,19 +599,19 @@ ESearchResultHandler::ESearchResultHandler() {
     metESearchResult = false;
 }
 
-bool ESearchResultHandler::characters(const QString &str) {
+bool ESearchResultHandler::characters(const QString& str) {
     curText += str;
     return true;
 }
 
-bool ESearchResultHandler::fatalError(const QXmlParseException &exception) {
+bool ESearchResultHandler::fatalError(const QXmlParseException& exception) {
     Q_UNUSED(exception);
     assert(0);
     return false;
 }
 //////////////////////////////////////////////////////////////////////////
 
-bool ESummaryResultHandler::startElement(const QString &namespaceURI, const QString &localName, const QString &qName, const QXmlAttributes &attributes) {
+bool ESummaryResultHandler::startElement(const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& attributes) {
     Q_UNUSED(namespaceURI);
     Q_UNUSED(localName);
     Q_UNUSED(attributes);
@@ -580,22 +628,22 @@ bool ESummaryResultHandler::startElement(const QString &namespaceURI, const QStr
     return true;
 }
 
-bool ESummaryResultHandler::endElement(const QString &namespaceURI, const QString &localName, const QString &qName) {
+bool ESummaryResultHandler::endElement(const QString& namespaceURI, const QString& localName, const QString& qName) {
     Q_UNUSED(namespaceURI);
     Q_UNUSED(localName);
-    if ("DocSum" == qName) {
+    if (qName == "DocSum") {
         results.append(currentSummary);
         currentSummary = EntrezSummary();
-    } else if ("Id" == qName) {
+    } else if (qName == "Id") {
         currentSummary.id = curText;
-    } else if ("Item" == qName) {
+    } else if (qName == "Item") {
         QString itemName = curAttributes.value("Name");
 
-        if ("Caption" == itemName) {
+        if (itemName == "Caption") {
             currentSummary.name = curText;
-        } else if ("Title" == itemName) {
+        } else if (itemName == "Title") {
             currentSummary.title = curText;
-        } else if ("Length" == itemName) {
+        } else if (itemName == "Length") {
             currentSummary.size = curText.toInt();
         }
     }
@@ -607,19 +655,19 @@ ESummaryResultHandler::ESummaryResultHandler()
     metESummaryResult = false;
 }
 
-bool ESummaryResultHandler::characters(const QString &str) {
+bool ESummaryResultHandler::characters(const QString& str) {
     curText += str;
     return true;
 }
 
-bool ESummaryResultHandler::fatalError(const QXmlParseException &exception) {
+bool ESummaryResultHandler::fatalError(const QXmlParseException& exception) {
     errorStr = QString("ESummary result parsing failed: %1").arg(exception.message());
 
     return false;
 }
 
 //////////////////////////////////////////////////////////////////////////
-static QString makeIDLink(const QString &id) {
+static QString makeIDLink(const QString& id) {
     QString res = "<a href=\"%1\"><span style=\" text-decoration: underline;\">%1</span></a>";
 
     res = res.arg(id);
@@ -640,8 +688,8 @@ RemoteDBRegistry::RemoteDBRegistry() {
     aliases.insert("nucleotide", GENBANK_DNA);
     aliases.insert("protein", GENBANK_PROTEIN);
 
-    const QMap<QString, DBXRefInfo> &entries = AppContext::getDBXRefRegistry()->getEntries();
-    foreach (const DBXRefInfo &info, entries.values()) {
+    const QMap<QString, DBXRefInfo>& entries = AppContext::getDBXRefRegistry()->getEntries();
+    foreach (const DBXRefInfo& info, entries.values()) {
         if (!info.fileUrl.isEmpty()) {
             httpDBs.insert(info.name, info.fileUrl);
         }
@@ -656,16 +704,16 @@ RemoteDBRegistry::RemoteDBRegistry() {
     hints.insert(UNIPROTKB_TREMBL, QObject::tr("Use UniProtKB/TrEMBL accession number. For example: %1").arg(makeIDLink("D0VTW9")));
 }
 
-RemoteDBRegistry &RemoteDBRegistry::getRemoteDBRegistry() {
+RemoteDBRegistry& RemoteDBRegistry::getRemoteDBRegistry() {
     static RemoteDBRegistry registry;
     return registry;
 }
 
-QList<QString> RemoteDBRegistry::getDBs() {
+QList<QString> RemoteDBRegistry::getDBs() const {
     return (queryDBs.keys() + httpDBs.keys());
 }
 
-QString RemoteDBRegistry::getURL(const QString &accId, const QString &dbName) {
+QString RemoteDBRegistry::getURL(const QString& accId, const QString& dbName) const {
     QString result("");
     if (httpDBs.contains(dbName)) {
         result = QString(httpDBs.value(dbName)).arg(accId);
@@ -673,11 +721,11 @@ QString RemoteDBRegistry::getURL(const QString &accId, const QString &dbName) {
     return result;
 }
 
-QString RemoteDBRegistry::getDbEntrezName(const QString &dbName) {
+QString RemoteDBRegistry::getDbEntrezName(const QString& dbName) const {
     return queryDBs.value(dbName);
 }
 
-QString RemoteDBRegistry::getHint(const QString &dbName) {
+QString RemoteDBRegistry::getHint(const QString& dbName) const {
     if (hints.contains(dbName)) {
         return hints.value(dbName);
     } else {
@@ -685,13 +733,13 @@ QString RemoteDBRegistry::getHint(const QString &dbName) {
     }
 }
 
-void RemoteDBRegistry::convertAlias(QString &dbName) {
+void RemoteDBRegistry::convertAlias(QString& dbName) const {
     if (aliases.contains(dbName)) {
         dbName = aliases.value(dbName);
     }
 }
 
-bool RemoteDBRegistry::hasDbId(const QString &dbId) {
+bool RemoteDBRegistry::hasDbId(const QString& dbId) const {
     return queryDBs.contains(dbId) || httpDBs.contains(dbId);
 }
 
