@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MODIFY_SEQUENCE_OBJECT_TASK_H_
-#define _U2_MODIFY_SEQUENCE_OBJECT_TASK_H_
+#pragma once
 
 #include <U2Core/DNASequence.h>
 #include <U2Core/GUrl.h>
@@ -34,14 +33,14 @@ class Document;
 class U2CORE_EXPORT ModifySequenceContentTask : public Task {
     Q_OBJECT
 public:
-    ModifySequenceContentTask(const DocumentFormatId &dfId, U2SequenceObject *seqObj, const U2Region &regionToReplace, const DNASequence &sequence2Insert, bool recalculateQualifiers = false, U1AnnotationUtils::AnnotationStrategyForResize _str = U1AnnotationUtils::AnnotationStrategyForResize_Resize, const GUrl &url = GUrl(), bool mergeAnnotations = false);
+    ModifySequenceContentTask(const DocumentFormatId& dfId, U2SequenceObject* seqObj, const U2Region& regionToReplace, const DNASequence& sequence2Insert, bool recalculateQualifiers = false, U1AnnotationUtils::AnnotationStrategyForResize _str = U1AnnotationUtils::AnnotationStrategyForResize_Resize, const GUrl& url = GUrl(), bool mergeAnnotations = false);
 
     Task::ReportResult report();
     QString generateReport() const;
 
     // Returns number of bases inserted into sequence. If sequence size is reduced the returned value is < 0
     qint64 getSequenceLengthDelta() const;
-    U2SequenceObject *getSequenceObject() const {
+    U2SequenceObject* getSequenceObject() const {
         return seqObj;
     }
 
@@ -51,18 +50,16 @@ private:
     DocumentFormatId resultFormatId;
     bool mergeAnnotations;
     bool recalculateQualifiers;
-    Document *curDoc;
-    Document *newDoc;
+    Document* curDoc;
+    Document* newDoc;
     bool inplaceMod;
     GUrl url;
     U1AnnotationUtils::AnnotationStrategyForResize strat;
-    QList<Document *> docs;
-    U2SequenceObject *seqObj;
+    QList<Document*> docs;
+    U2SequenceObject* seqObj;
     U2Region regionToReplace;
     DNASequence sequence2Insert;
-    QMap<Annotation *, QList<QPair<QString, QString>>> annotationForReport;
+    QMap<Annotation*, QList<QPair<QString, QString>>> annotationForReport;
 };
 
 }  // namespace U2
-
-#endif
