@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MULTI_TASK_H_
-#define _U2_MULTI_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -32,32 +31,30 @@ class StateLock;
 class U2CORE_EXPORT MultiTask : public Task {
     Q_OBJECT
 public:
-    MultiTask(const QString &name, const QList<Task *> &taskz, bool withLock = false, TaskFlags f = TaskFlags_NR_FOSCOE);
+    MultiTask(const QString& name, const QList<Task*>& taskz, bool withLock = false, TaskFlags f = TaskFlags_NR_FOSCOE);
 
-    QList<Task *> getTasks() const;
+    QList<Task*> getTasks() const;
 
     ReportResult report();
     QString generateReport() const;
 
 private:
-    StateLock *l;
-    QList<Task *> tasks;
+    StateLock* l;
+    QList<Task*> tasks;
 };
 
 // waits until each given task is finished and runs the next task after that
 class U2CORE_EXPORT SequentialMultiTask : public Task {
     Q_OBJECT
 public:
-    SequentialMultiTask(const QString &name, const QList<Task *> &taskz, TaskFlags f = TaskFlags_NR_FOSCOE);
+    SequentialMultiTask(const QString& name, const QList<Task*>& taskz, TaskFlags f = TaskFlags_NR_FOSCOE);
 
     void prepare();
-    virtual QList<Task *> onSubTaskFinished(Task *subTask);
-    QList<Task *> getTasks() const;
+    virtual QList<Task*> onSubTaskFinished(Task* subTask);
+    QList<Task*> getTasks() const;
 
 private:
-    QList<Task *> tasks;
+    QList<Task*> tasks;
 };
 
 }  // namespace U2
-
-#endif
