@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_REMOVE_DOCUMENT_TASK_H_
-#define _U2_REMOVE_DOCUMENT_TASK_H_
+#pragma once
 
 #include <QPointer>
 
@@ -35,7 +34,7 @@ class StateLock;
 class U2CORE_EXPORT RemoveMultipleDocumentsTask : public Task {
     Q_OBJECT
 public:
-    RemoveMultipleDocumentsTask(Project *p, const QList<Document *> &docs, bool saveModifiedDocs, bool useGUI);
+    RemoveMultipleDocumentsTask(Project* p, const QList<Document*>& docs, bool saveModifiedDocs, bool useGUI);
     ~RemoveMultipleDocumentsTask();
 
     virtual void prepare();
@@ -46,10 +45,8 @@ private:
     QPointer<Project> p;
     bool saveModifiedDocs;
     bool useGUI;
-    StateLock *lock;
+    StateLock* lock;
     QList<QPointer<Document>> docPtrs;
 };
 
 }  // namespace U2
-
-#endif
