@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_REVERSE_SEQUENCE_TASK_H_
-#define _U2_REVERSE_SEQUENCE_TASK_H_
+#pragma once
 
 #include <U2Core/DocumentModel.h>
 #include <U2Core/Task.h>
@@ -35,48 +34,46 @@ class DNASequenceSelection;
 class U2CORE_EXPORT ReverseComplementSequenceTask : public Task {
     Q_OBJECT
 public:
-    ReverseComplementSequenceTask(U2SequenceObject *dnaObj,
-                                  const QList<AnnotationTableObject *> &annotations,
-                                  DNASequenceSelection *selection,
-                                  DNATranslation *complTT);
+    ReverseComplementSequenceTask(U2SequenceObject* dnaObj,
+                                  const QList<AnnotationTableObject*>& annotations,
+                                  DNASequenceSelection* selection,
+                                  DNATranslation* complTT);
 
 private:
-    U2SequenceObject *seqObj;
-    QList<AnnotationTableObject *> aObjs;
-    DNASequenceSelection *selection;
-    DNATranslation *complTT;
+    U2SequenceObject* seqObj;
+    QList<AnnotationTableObject*> aObjs;
+    DNASequenceSelection* selection;
+    DNATranslation* complTT;
 };
 
 class U2CORE_EXPORT ReverseSequenceTask : public Task {
     Q_OBJECT
 public:
-    ReverseSequenceTask(U2SequenceObject *seqObj,
-                        const QList<AnnotationTableObject *> &annotations,
-                        DNASequenceSelection *selection);
+    ReverseSequenceTask(U2SequenceObject* seqObj,
+                        const QList<AnnotationTableObject*>& annotations,
+                        DNASequenceSelection* selection);
     ReportResult report();
 
 private:
-    U2SequenceObject *seqObj;
-    QList<AnnotationTableObject *> aObjs;
-    DNASequenceSelection *selection;
+    U2SequenceObject* seqObj;
+    QList<AnnotationTableObject*> aObjs;
+    DNASequenceSelection* selection;
 };
 
 class U2CORE_EXPORT ComplementSequenceTask : public Task {
     Q_OBJECT
 public:
-    ComplementSequenceTask(U2SequenceObject *seqObj,
-                           const QList<AnnotationTableObject *> &annotations,
-                           DNASequenceSelection *selection,
-                           DNATranslation *complTT);
+    ComplementSequenceTask(U2SequenceObject* seqObj,
+                           const QList<AnnotationTableObject*>& annotations,
+                           DNASequenceSelection* selection,
+                           DNATranslation* complTT);
     ReportResult report();
 
 private:
-    U2SequenceObject *seqObj;
-    QList<AnnotationTableObject *> aObjs;
-    DNASequenceSelection *selection;
-    DNATranslation *complTT;
+    U2SequenceObject* seqObj;
+    QList<AnnotationTableObject*> aObjs;
+    DNASequenceSelection* selection;
+    DNATranslation* complTT;
 };
 
 }  // namespace U2
-
-#endif  // _U2_REVERSE_SEQUENCE_TASK_H_
