@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,13 +27,13 @@
 
 namespace U2 {
 
-SaveDocumentStreamingTask::SaveDocumentStreamingTask(Document *d, IOAdapter *i)
+SaveDocumentStreamingTask::SaveDocumentStreamingTask(Document* d, IOAdapter* i)
     : Task(tr("Save document"), TaskFlags(TaskFlag_None)), lock(nullptr), doc(d), io(i) {
-    if (nullptr == doc) {
+    if (doc == nullptr) {
         stateInfo.setError(L10N::badArgument("doc"));
         return;
     }
-    if (nullptr == io || !io->isOpen()) {
+    if (io == nullptr || !io->isOpen()) {
         stateInfo.setError(L10N::badArgument("IO adapter"));
         return;
     }
@@ -42,7 +42,7 @@ SaveDocumentStreamingTask::SaveDocumentStreamingTask(Document *d, IOAdapter *i)
 }
 
 SaveDocumentStreamingTask::~SaveDocumentStreamingTask() {
-    assert(nullptr == lock);
+    assert(lock == nullptr);
 }
 
 void SaveDocumentStreamingTask::prepare() {
@@ -56,23 +56,23 @@ void SaveDocumentStreamingTask::run() {
     if (stateInfo.hasError()) {
         return;
     }
-    DocumentFormat *df = doc->getDocumentFormat();
+    DocumentFormat* df = doc->getDocumentFormat();
     df->storeDocument(doc, io, stateInfo);
 }
 
 Task::ReportResult SaveDocumentStreamingTask::report() {
-    if (nullptr != doc) {
+    if (doc != nullptr) {
         doc->makeClean();
         doc->unlockState(lock);
     }
-    if (nullptr != lock) {
+    if (lock != nullptr) {
         delete lock;
         lock = nullptr;
     }
     return ReportResult_Finished;
 }
 
-Document *SaveDocumentStreamingTask::getDocument() const {
+Document* SaveDocumentStreamingTask::getDocument() const {
     return doc;
 }
 
