@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SAVE_DOCUMENT_STREAMING_TASK_H_
-#define _U2_SAVE_DOCUMENT_STREAMING_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -34,7 +33,7 @@ class U2CORE_EXPORT SaveDocumentStreamingTask : public Task {
     Q_OBJECT
 public:
     // io - opened io adapter
-    SaveDocumentStreamingTask(Document *doc, IOAdapter *io);
+    SaveDocumentStreamingTask(Document* doc, IOAdapter* io);
     ~SaveDocumentStreamingTask();
 
     virtual void prepare();
@@ -43,15 +42,13 @@ public:
 
     ReportResult report();
 
-    Document *getDocument() const;
+    Document* getDocument() const;
 
 private:
-    StateLock *lock;
-    Document *doc;
-    IOAdapter *io;
+    StateLock* lock;
+    Document* doc;
+    IOAdapter* io;
 
 };  // SaveDocumentStreamingTask
 
 }  // namespace U2
-
-#endif  // _U2_SAVE_DOCUMENT_STREAMING_TASK_H_
