@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,7 +28,7 @@ namespace U2 {
 void TaskStarter::registerTask() {
     switch (condition) {
         case NoProject:
-            if (nullptr != AppContext::getProject()) {
+            if (AppContext::getProject() != nullptr) {
                 delete t;
                 t = nullptr;
                 return;
