@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TASK_STARTER_H_
-#define _U2_TASK_STARTER_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -36,17 +35,15 @@ public:
         NoProject
     };
 
-    TaskStarter(Task *t, StartCondition condition = NoCondition)
+    TaskStarter(Task* t, StartCondition condition = NoCondition)
         : QObject(t), t(t), condition(condition) {
     }
 public slots:
     void registerTask();
 
 private:
-    Task *t;
+    Task* t;
     StartCondition condition;
 };
 
 }  // namespace U2
-
-#endif
