@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef TMPDIRCHECKER_H
-#define TMPDIRCHECKER_H
+#pragma once
 
 #include <QDir>
 
@@ -34,9 +33,9 @@ public:
     TmpDirChecker();
     void run();
     ReportResult report();
-    bool checkPath(QString &path);
+    bool checkPath(QString& path);
 
-    static QString getNewFilePath(const QString &dirPath, const QString &baseName);
+    static QString getNewFilePath(const QString& dirPath, const QString& baseName);
 
 signals:
     void si_checkFailed(QString path);
@@ -46,4 +45,3 @@ private:
 };
 
 }  // namespace U2
-#endif  // TMPDIRCHECKER_H
