@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_DIR_TO_DATABASE_TASK_H_
-#define _U2_IMPORT_DIR_TO_DATABASE_TASK_H_
+#pragma once
 
 #include <U2Core/ImportToDatabaseOptions.h>
 #include <U2Core/StrPackUtils.h>
@@ -36,7 +35,7 @@ class ImportFileToDatabaseTask;
 class U2CORE_EXPORT ImportDirToDatabaseTask : public Task {
     Q_OBJECT
 public:
-    ImportDirToDatabaseTask(const QString &srcUrl, const U2DbiRef &dstDbiRef, const QString &dstFolder, const ImportToDatabaseOptions &options);
+    ImportDirToDatabaseTask(const QString& srcUrl, const U2DbiRef& dstDbiRef, const QString& dstFolder, const ImportToDatabaseOptions& options);
 
     void prepare();
 
@@ -49,10 +48,8 @@ private:
     QString dstFolder;
     ImportToDatabaseOptions options;
 
-    QList<ImportDirToDatabaseTask *> importSubdirsTasks;
-    QList<ImportFileToDatabaseTask *> importSubfilesTasks;
+    QList<ImportDirToDatabaseTask*> importSubdirsTasks;
+    QList<ImportFileToDatabaseTask*> importSubfilesTasks;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_DIR_TO_DATABASE_TASK_H_
