@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_DOCUMENT_TO_DATABASE_TASK_H_
-#define _U2_IMPORT_DOCUMENT_TO_DATABASE_TASK_H_
+#pragma once
 
 #include <QPointer>
 
@@ -36,25 +35,25 @@ class GObject;
 class U2CORE_EXPORT ImportDocumentToDatabaseTask : public Task {
     Q_OBJECT
 public:
-    ImportDocumentToDatabaseTask(Document *document, const U2DbiRef &dstDbiRef, const QString &dstFolder, const ImportToDatabaseOptions &options);
+    ImportDocumentToDatabaseTask(Document* document, const U2DbiRef& dstDbiRef, const QString& dstFolder, const ImportToDatabaseOptions& options);
 
     void prepare();
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
     ReportResult report();
 
-    Document *getSourceDocument() const;
+    Document* getSourceDocument() const;
 
     QStringList getImportedObjectNames() const;
     QStringList getSkippedObjectNames() const;
 
-    QSet<GObject *> getImportedObjects() const;
-    const QString &getDstFolder() const;
-    const U2DbiRef &getDstDbiRef() const;
+    QSet<GObject*> getImportedObjects() const;
+    const QString& getDstFolder() const;
+    const U2DbiRef& getDstDbiRef() const;
 
 private:
-    QMap<GObject *, GObject *> getObjectPairs() const;
-    void propagateObjectsRelations(QStringList &errors) const;
-    static GObject *getAppropriateObject(const QList<GObject *> objects, const GObject *pattern);
+    QMap<GObject*, GObject*> getObjectPairs() const;
+    void propagateObjectsRelations(QStringList& errors) const;
+    static GObject* getAppropriateObject(const QList<GObject*> objects, const GObject* pattern);
 
     QPointer<Document> document;
     U2DbiRef dstDbiRef;
@@ -63,5 +62,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_DOCUMENT_TO_DATABASE_TASK_H_
