@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_FILE_TO_DATABASE_TASK_H_
-#define _U2_IMPORT_FILE_TO_DATABASE_TASK_H_
+#pragma once
 
 #include <U2Core/DocumentUtils.h>
 #include <U2Core/ImportToDatabaseOptions.h>
@@ -35,27 +34,25 @@ class DocumentProviderTask;
 class U2CORE_EXPORT ImportFileToDatabaseTask : public Task {
     Q_OBJECT
 public:
-    ImportFileToDatabaseTask(const QString &srcUrl, const U2DbiRef &dstDbiRef, const QString &dstFolder, const ImportToDatabaseOptions &options);
+    ImportFileToDatabaseTask(const QString& srcUrl, const U2DbiRef& dstDbiRef, const QString& dstFolder, const ImportToDatabaseOptions& options);
 
     void prepare();
     void run();
 
-    const QString &getFilePath() const;
+    const QString& getFilePath() const;
 
 private:
-    DocumentProviderTask *detectFormat();
+    DocumentProviderTask* detectFormat();
     QVariantMap prepareHints() const;
     QString getFolderName() const;
-    FormatDetectionResult getPreferredFormat(const QList<FormatDetectionResult> &detectedFormats) const;
+    FormatDetectionResult getPreferredFormat(const QList<FormatDetectionResult>& detectedFormats) const;
 
     QString srcUrl;
     U2DbiRef dstDbiRef;
     QString dstFolder;
     ImportToDatabaseOptions options;
 
-    DocumentFormat *format;
+    DocumentFormat* format;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_FILE_TO_DATABASE_TASK_H_
