@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,14 +29,14 @@
 
 namespace U2 {
 
-ImportObjectToDatabaseTask::ImportObjectToDatabaseTask(GObject *object, const U2DbiRef &dstDbiRef, const QString &dstFolder)
-    : Task(tr("Import object %1 to database").arg(nullptr != object ? object->getGObjectName() : ""), TaskFlag_None),
+ImportObjectToDatabaseTask::ImportObjectToDatabaseTask(GObject* object, const U2DbiRef& dstDbiRef, const QString& dstFolder)
+    : Task(tr("Import object %1 to database").arg(object != nullptr ? object->getGObjectName() : ""), TaskFlag_None),
       object(object),
       dstDbiRef(dstDbiRef),
       dstFolder(dstFolder),
       dstObject(nullptr) {
     GCOUNTER(cvar, "ImportObjectToDatabaseTask");
-    CHECK_EXT(nullptr != object, setError(tr("Invalid object to import")), );
+    CHECK_EXT(object != nullptr, setError(tr("Invalid object to import")), );
     CHECK_EXT(dstDbiRef.isValid(), setError(tr("Invalid database reference")), );
     tpm = Progress_Manual;
 }
@@ -44,9 +44,9 @@ ImportObjectToDatabaseTask::ImportObjectToDatabaseTask(GObject *object, const U2
 void ImportObjectToDatabaseTask::run() {
     DbiConnection con(dstDbiRef, stateInfo);
     CHECK_OP(stateInfo, );
-    SAFE_POINT_EXT(nullptr != con.dbi, setError(tr("Error! No DBI")), );
-    U2ObjectDbi *oDbi = con.dbi->getObjectDbi();
-    SAFE_POINT_EXT(nullptr != oDbi, setError(tr("Error! No object DBI")), );
+    SAFE_POINT_EXT(con.dbi != nullptr, setError(QString("Error! No DBI")), );
+    U2ObjectDbi* oDbi = con.dbi->getObjectDbi();
+    SAFE_POINT_EXT(oDbi != nullptr, setError(QString("Error! No object DBI")), );
 
     QVariantMap hints;
     hints[DocumentFormat::DBI_FOLDER_HINT] = U2DbiUtils::makeFolderCanonical(dstFolder);
@@ -58,25 +58,25 @@ void ImportObjectToDatabaseTask::run() {
     dstObject->moveToThread(QCoreApplication::instance()->thread());
 }
 
-GObject *ImportObjectToDatabaseTask::takeResult() {
-    GObject *result = dstObject;
+GObject* ImportObjectToDatabaseTask::takeResult() {
+    GObject* result = dstObject;
     dstObject = nullptr;
     return result;
 }
 
-GObject *ImportObjectToDatabaseTask::getSourceObject() const {
+GObject* ImportObjectToDatabaseTask::getSourceObject() const {
     return object.data();
 }
 
-GObject *ImportObjectToDatabaseTask::getDestinationObject() const {
+GObject* ImportObjectToDatabaseTask::getDestinationObject() const {
     return dstObject;
 }
 
-const QString &ImportObjectToDatabaseTask::getFolder() const {
+const QString& ImportObjectToDatabaseTask::getFolder() const {
     return dstFolder;
 }
 
-const U2DbiRef &ImportObjectToDatabaseTask::getDbiRef() const {
+const U2DbiRef& ImportObjectToDatabaseTask::getDbiRef() const {
     return dstDbiRef;
 }
 
