@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_OBJECT_TO_DATABASE_TASK_H_
-#define _U2_IMPORT_OBJECT_TO_DATABASE_TASK_H_
+#pragma once
 
 #include <QPointer>
 
@@ -34,24 +33,22 @@ class GObject;
 class U2CORE_EXPORT ImportObjectToDatabaseTask : public Task {
     Q_OBJECT
 public:
-    ImportObjectToDatabaseTask(GObject *object, const U2DbiRef &dstDbiRef, const QString &dstFolder);
+    ImportObjectToDatabaseTask(GObject* object, const U2DbiRef& dstDbiRef, const QString& dstFolder);
 
     void run();
 
-    GObject *takeResult();
+    GObject* takeResult();
 
-    GObject *getSourceObject() const;
-    GObject *getDestinationObject() const;
-    const QString &getFolder() const;
-    const U2DbiRef &getDbiRef() const;
+    GObject* getSourceObject() const;
+    GObject* getDestinationObject() const;
+    const QString& getFolder() const;
+    const U2DbiRef& getDbiRef() const;
 
 private:
     QPointer<GObject> object;
     U2DbiRef dstDbiRef;
     QString dstFolder;
-    GObject *dstObject;
+    GObject* dstObject;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_OBJECT_TO_DATABASE_TASK_H_
