@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,7 +32,7 @@
 
 namespace U2 {
 
-ImportToDatabaseTask::ImportToDatabaseTask(QList<U2::Task *> tasks, int maxParallelSubtasks)
+ImportToDatabaseTask::ImportToDatabaseTask(QList<U2::Task*> tasks, int maxParallelSubtasks)
     : MultiTask(tr("Import to the database"), tasks, false, TaskFlags(TaskFlag_ReportingIsSupported) | TaskFlag_ReportingIsEnabled | TaskFlag_PropagateSubtaskDesc) {
     GCOUNTER(cvar, "ImportToDatabaseTask");
     setMaxParallelSubtasks(maxParallelSubtasks);
@@ -54,19 +54,19 @@ Task::ReportResult ImportToDatabaseTask::report() {
 }
 
 void ImportToDatabaseTask::sortSubtasks() const {
-    foreach (const QPointer<Task> &subtask, getSubtasks()) {
-        ImportDirToDatabaseTask *dirSubtask = qobject_cast<ImportDirToDatabaseTask *>(subtask.data());
-        ImportDocumentToDatabaseTask *documentSubtask = qobject_cast<ImportDocumentToDatabaseTask *>(subtask.data());
-        ImportFileToDatabaseTask *fileSubtask = qobject_cast<ImportFileToDatabaseTask *>(subtask.data());
-        ImportObjectToDatabaseTask *objectSubtask = qobject_cast<ImportObjectToDatabaseTask *>(subtask.data());
+    foreach (const QPointer<Task>& subtask, getSubtasks()) {
+        auto dirSubtask = qobject_cast<ImportDirToDatabaseTask*>(subtask.data());
+        auto documentSubtask = qobject_cast<ImportDocumentToDatabaseTask*>(subtask.data());
+        auto fileSubtask = qobject_cast<ImportFileToDatabaseTask*>(subtask.data());
+        auto objectSubtask = qobject_cast<ImportObjectToDatabaseTask*>(subtask.data());
 
-        if (nullptr != dirSubtask) {
+        if (dirSubtask != nullptr) {
             dirSubtasks << dirSubtask;
-        } else if (nullptr != documentSubtask) {
+        } else if (documentSubtask != nullptr) {
             documentSubtasks << documentSubtask;
-        } else if (nullptr != fileSubtask) {
+        } else if (fileSubtask != nullptr) {
             fileSubtasks << fileSubtask;
-        } else if (nullptr != objectSubtask) {
+        } else if (objectSubtask != nullptr) {
             objectSubtasks << objectSubtask;
         }
     }
@@ -127,9 +127,9 @@ QString ImportToDatabaseTask::sayAboutImportedFilesAndDirs() const {
 QString ImportToDatabaseTask::sayAboutImportedDirs() const {
     QString result;
 
-    for (ImportDirToDatabaseTask *dirSubtask : qAsConst(dirSubtasks)) {
+    for (ImportDirToDatabaseTask* dirSubtask : qAsConst(dirSubtasks)) {
         const QStringList importedFiles = dirSubtask->getImportedFiles();
-        for (const QString &importedFile : qAsConst(importedFiles)) {
+        for (const QString& importedFile : qAsConst(importedFiles)) {
             result += importedFile + "<br>";
         }
     }
@@ -140,7 +140,7 @@ QString ImportToDatabaseTask::sayAboutImportedDirs() const {
 QString ImportToDatabaseTask::sayAboutImportedFiles() const {
     QString result;
 
-    foreach (ImportFileToDatabaseTask *fileSubtask, fileSubtasks) {
+    foreach (ImportFileToDatabaseTask* fileSubtask, fileSubtasks) {
         if (fileSubtask->isCanceled() || fileSubtask->hasError()) {
             continue;
         }
@@ -164,9 +164,9 @@ QString ImportToDatabaseTask::sayAboutImportedProjectItems() const {
 QString ImportToDatabaseTask::sayAboutImportedDocuments() const {
     QString result;
 
-    foreach (ImportDocumentToDatabaseTask *documentSubtask, documentSubtasks) {
-        Document *document = documentSubtask->getSourceDocument();
-        if (nullptr == document) {
+    foreach (ImportDocumentToDatabaseTask* documentSubtask, documentSubtasks) {
+        Document* document = documentSubtask->getSourceDocument();
+        if (document == nullptr) {
             continue;
         }
 
@@ -177,7 +177,7 @@ QString ImportToDatabaseTask::sayAboutImportedDocuments() const {
 
         result += tr("Document ") + document->getName() + ":<br>";
 
-        for (const QString &importedObjectName : qAsConst(importedObjectNames)) {
+        for (const QString& importedObjectName : qAsConst(importedObjectNames)) {
             result += "    " + importedObjectName + "<br>";
         }
 
@@ -190,13 +190,13 @@ QString ImportToDatabaseTask::sayAboutImportedDocuments() const {
 QString ImportToDatabaseTask::sayAboutImportedObjects() const {
     QString result;
 
-    foreach (ImportObjectToDatabaseTask *objectSubtask, objectSubtasks) {
+    foreach (ImportObjectToDatabaseTask* objectSubtask, objectSubtasks) {
         if (objectSubtask->isCanceled() || objectSubtask->hasError()) {
             continue;
         }
 
-        GObject *object = objectSubtask->getSourceObject();
-        if (nullptr != object) {
+        GObject* object = objectSubtask->getSourceObject();
+        if (object != nullptr) {
             result += object->getGObjectName() + "<br>";
         }
     }
@@ -218,9 +218,9 @@ QString ImportToDatabaseTask::sayAboutSkippedFilesAndDirs() const {
 QString ImportToDatabaseTask::sayAboutSkippedDirs() const {
     QString result;
 
-    for (ImportDirToDatabaseTask *dirSubtask : qAsConst(dirSubtasks)) {
+    for (ImportDirToDatabaseTask* dirSubtask : qAsConst(dirSubtasks)) {
         const StrStrMap skippedFiles = dirSubtask->getSkippedFiles();
-        foreach (const QString &skippedFile, skippedFiles.keys()) {
+        foreach (const QString& skippedFile, skippedFiles.keys()) {
             result += skippedFile + ": " + skippedFiles[skippedFile] + "<br>";
         }
     }
@@ -231,7 +231,7 @@ QString ImportToDatabaseTask::sayAboutSkippedDirs() const {
 QString ImportToDatabaseTask::sayAboutSkippedFiles() const {
     QString result;
 
-    foreach (ImportFileToDatabaseTask *fileSubtask, fileSubtasks) {
+    foreach (ImportFileToDatabaseTask* fileSubtask, fileSubtasks) {
         if (fileSubtask->isCanceled()) {
             result += fileSubtask->getFilePath() + ": " + tr("Import was cancelled") + "<br>";
         } else if (fileSubtask->hasError()) {
@@ -255,9 +255,9 @@ QString ImportToDatabaseTask::sayAboutSkippedProjectItems() const {
 QString ImportToDatabaseTask::sayAboutSkippedDocuments() const {
     QString result;
 
-    foreach (ImportDocumentToDatabaseTask *documentSubtask, documentSubtasks) {
-        Document *document = documentSubtask->getSourceDocument();
-        if (nullptr == document) {
+    foreach (ImportDocumentToDatabaseTask* documentSubtask, documentSubtasks) {
+        Document* document = documentSubtask->getSourceDocument();
+        if (document == nullptr) {
             continue;
         }
 
@@ -268,7 +268,7 @@ QString ImportToDatabaseTask::sayAboutSkippedDocuments() const {
 
         result += tr("Document ") + document->getName() + ":<br>";
 
-        for (const QString &skippedObjectName : qAsConst(skippedObjectNames)) {
+        for (const QString& skippedObjectName : qAsConst(skippedObjectNames)) {
             result += "    " + skippedObjectName + "<br>";
         }
 
@@ -281,13 +281,13 @@ QString ImportToDatabaseTask::sayAboutSkippedDocuments() const {
 QString ImportToDatabaseTask::sayAboutSkippedObjects() const {
     QString result;
 
-    foreach (ImportObjectToDatabaseTask *objectSubtask, objectSubtasks) {
+    foreach (ImportObjectToDatabaseTask* objectSubtask, objectSubtasks) {
         if (!objectSubtask->isCanceled() && !objectSubtask->hasError()) {
             continue;
         }
 
-        GObject *object = objectSubtask->getSourceObject();
-        if (nullptr != object) {
+        GObject* object = objectSubtask->getSourceObject();
+        if (object != nullptr) {
             result += object->getGObjectName() + "<br>";
         }
     }
