@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_TO_DATABASE_TASK_H_
-#define _U2_IMPORT_TO_DATABASE_TASK_H_
+#pragma once
 
 #include <U2Core/MultiTask.h>
 
@@ -34,7 +33,7 @@ class ImportObjectToDatabaseTask;
 class U2CORE_EXPORT ImportToDatabaseTask : public MultiTask {
     Q_OBJECT
 public:
-    ImportToDatabaseTask(QList<Task *> tasks, int maxParallelSubtasks = 1);
+    ImportToDatabaseTask(QList<Task*> tasks, int maxParallelSubtasks = 1);
 
     void run();
     QString generateReport() const;
@@ -61,14 +60,12 @@ private:
     QString reportString;
     qint64 startTime;
 
-    mutable QList<ImportDirToDatabaseTask *> dirSubtasks;
-    mutable QList<ImportDocumentToDatabaseTask *> documentSubtasks;
-    mutable QList<ImportFileToDatabaseTask *> fileSubtasks;
-    mutable QList<ImportObjectToDatabaseTask *> objectSubtasks;
+    mutable QList<ImportDirToDatabaseTask*> dirSubtasks;
+    mutable QList<ImportDocumentToDatabaseTask*> documentSubtasks;
+    mutable QList<ImportFileToDatabaseTask*> fileSubtasks;
+    mutable QList<ImportObjectToDatabaseTask*> objectSubtasks;
 
     static const int MAX_SHOWN_ITEMS_IN_REPORT = 100;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_TO_DATABASE_TASK_H_
