@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -47,59 +47,59 @@ const QString FMatrixSerializer::ID = "fm_1.14";
 
 namespace {
 template<class T>
-inline QByteArray packNum(const T &num) {
+inline QByteArray packNum(const T& num) {
     T leNum = qToLittleEndian<T>(num);
-    return QByteArray((char *)&leNum, sizeof(T));
+    return QByteArray((char*)&leNum, sizeof(T));
 }
 template<>
-inline QByteArray packNum(const double &num) {
+inline QByteArray packNum(const double& num) {
     QByteArray numStr = QByteArray::number(num);
     return packNum<int>(numStr.size()) + numStr;
 }
 template<>
-inline QByteArray packNum(const float &num) {
+inline QByteArray packNum(const float& num) {
     QByteArray numStr = QByteArray::number(num);
     return packNum<int>(numStr.size()) + numStr;
 }
 template<class T>
-inline T unpackNum(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline T unpackNum(const uchar* data, int length, int& offset, U2OpStatus& os) {
     CHECK_SIZE(int(sizeof(T)), T());
     T result = qFromLittleEndian<T>(data + offset);
     offset += sizeof(T);
     return result;
 }
-inline QByteArray unpackReal(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline QByteArray unpackReal(const uchar* data, int length, int& offset, U2OpStatus& os) {
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, "");
     CHECK_SIZE(size, "");
-    QByteArray result((const char *)data + offset, size);
+    QByteArray result((const char*)data + offset, size);
     offset += size;
     return result;
 }
 template<>
-inline double unpackNum(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline double unpackNum(const uchar* data, int length, int& offset, U2OpStatus& os) {
     QByteArray numStr = unpackReal(data, length, offset, os);
     CHECK_OP(os, 0.0);
     return numStr.toDouble();
 }
 template<>
-inline float unpackNum(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline float unpackNum(const uchar* data, int length, int& offset, U2OpStatus& os) {
     QByteArray numStr = unpackReal(data, length, offset, os);
     CHECK_OP(os, 0.0f);
     return numStr.toFloat();
 }
 
 template<class T>
-inline QByteArray packNumVector(const QVector<T> &vector) {
+inline QByteArray packNumVector(const QVector<T>& vector) {
     QByteArray result;
     result += packNum<int>(vector.size());
-    foreach (const T &num, vector) {
+    foreach (const T& num, vector) {
         result += packNum<T>(num);
     }
     return result;
 }
 template<class T>
-inline QVector<T> unpackNumVector(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline QVector<T> unpackNumVector(const uchar* data, int length, int& offset, U2OpStatus& os) {
     QVector<T> result;
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -111,15 +111,15 @@ inline QVector<T> unpackNumVector(const uchar *data, int length, int &offset, U2
     return result;
 }
 
-inline QByteArray packCharVector(const QVector<char> &vector) {
+inline QByteArray packCharVector(const QVector<char>& vector) {
     QByteArray result;
     result += packNum<int>(vector.size());
-    foreach (const char &c, vector) {
+    foreach (const char& c, vector) {
         result += c;
     }
     return result;
 }
-inline QVector<char> unpackCharVector(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline QVector<char> unpackCharVector(const uchar* data, int length, int& offset, U2OpStatus& os) {
     QVector<char> result;
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -136,7 +136,7 @@ inline QByteArray packBool(bool value) {
     return QByteArray(1, c);
 }
 
-inline bool unpackBool(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline bool unpackBool(const uchar* data, int length, int& offset, U2OpStatus& os) {
     CHECK_SIZE(1, false);
     uchar c = data[offset];
     offset++;
@@ -147,7 +147,7 @@ inline bool unpackBool(const uchar *data, int length, int &offset, U2OpStatus &o
 /************************************************************************/
 /* DNAChromatogramSerializer */
 /************************************************************************/
-QByteArray DNAChromatogramSerializer::serialize(const DNAChromatogram &chroma) {
+QByteArray DNAChromatogramSerializer::serialize(const DNAChromatogram& chroma) {
     QByteArray result;
     result += packNum<int>(chroma.traceLength);
     result += packNum<int>(chroma.seqLength);
@@ -164,9 +164,9 @@ QByteArray DNAChromatogramSerializer::serialize(const DNAChromatogram &chroma) {
     return result;
 }
 
-DNAChromatogram DNAChromatogramSerializer::deserialize(const QByteArray &binary, U2OpStatus &os) {
+DNAChromatogram DNAChromatogramSerializer::deserialize(const QByteArray& binary, U2OpStatus& os) {
     DNAChromatogram result;
-    const uchar *data = (const uchar *)(binary.data());
+    auto data = (const uchar*)(binary.data());
     int offset = 0;
     int length = binary.length();
 
@@ -199,49 +199,38 @@ DNAChromatogram DNAChromatogramSerializer::deserialize(const QByteArray &binary,
 /************************************************************************/
 /* NewickPhyTreeSerializer */
 /************************************************************************/
-namespace {
-enum ReadState { RS_NAME,
-                 RS_WEIGHT,
-                 RS_QUOTED_NAME,
-                 RS_NAME_OR_WEIGHT };
+enum ReadState {
+    RS_NAME,
+    RS_WEIGHT,
+    RS_QUOTED_NAME,
+    RS_AFTER_CLOSING_BRACE
+};
 
-void packTreeNode(QString &resultText, const PhyNode *node, U2OpStatus &os) {
-    int branchCount = node->branchCount();
-    const QString &nodeName = node->getName();
-    if (branchCount == 1 && (nodeName.isEmpty() || nodeName == "ROOT")) {
-        const PhyNode *sibling = node->getSecondNodeOfBranch(0);
-        CHECK_EXT(node != sibling, os.setError(DatatypeSerializers::tr("Invalid tree topology")), );
-        packTreeNode(resultText, sibling, os);
-        CHECK_OP(os, );
-        return;
-    }
-    if (branchCount > 1) {
+static void packTreeNode(QString& resultText, const PhyNode* node, U2OpStatus& os) {
+    const QList<PhyBranch*>& childBranches = node->getChildBranches();
+    if (!childBranches.isEmpty()) {
         resultText.append("(");
-        bool first = true;
-        for (int i = 0; i < branchCount; ++i) {
-            if (node->getSecondNodeOfBranch(i) != node) {
-                if (first) {
-                    first = false;
-                } else {
-                    resultText.append(",");
-                }
-                packTreeNode(resultText, node->getSecondNodeOfBranch(i), os);
-                CHECK_OP(os, );
-                if (node->getBranchesNodeValue(i) >= 0) {
-                    resultText.append(QString::number(node->getBranchesNodeValue(i)));
-                }
-                resultText.append(":");
-                resultText.append(QString::number(node->getBranchesDistance(i)));
+        for (int i = 0; i < childBranches.size(); i++) {
+            PhyBranch* childBranch = childBranches[i];
+            if (i > 0) {
+                resultText.append(",");
             }
+            packTreeNode(resultText, childBranch->childNode, os);
+            CHECK_OP(os, );
+            if (childBranch->nodeValue >= 0) {
+                // TODO: this must be node name, not 'value'!
+                resultText.append(QString::number(childBranch->nodeValue));
+            }
+            resultText.append(":");
+            resultText.append(QString::number(childBranch->distance));
         }
         resultText.append(")");
-    } else if (nodeName.contains(QRegExp("\\s|[(]|[)]|[:]|[;]|[,]"))) {
-        resultText.append(QString("\'%1\'").arg(nodeName));
+    } else if (node->name.contains(QRegExp("\\s|[(]|[)]|[:]|[;]|[,]"))) {
+        resultText.append(QString("\'%1\'").arg(node->name));
     } else {
-        resultText.append(QString(nodeName));
+        resultText.append(node->name);
     }
 }
-}  // namespace
 
 #define BUFF_SIZE 1024
 /* TODO:
@@ -251,12 +240,11 @@ void packTreeNode(QString &resultText, const PhyNode *node, U2OpStatus &os) {
  Newlines may appear anywhere except within labels or branch_lengths.
  Comments are enclosed in square brackets and may appear anywhere newlines are permitted.
  */
-QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2OpStatus &si) {
+QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader& reader, U2OpStatus& si) {
     QList<PhyTree> result;
     QString block;
     int blockLen;
     bool done = true;
-    bool haveNodeLabels = false;
 
     QBitArray ops(256);
     ops['('] = true;
@@ -270,13 +258,13 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
     QString lastStr;
     auto rootNode = new PhyNode();
 
-    QStack<PhyNode *> nodeStack;
-    QStack<PhyBranch *> branchStack;
+    QStack<PhyNode*> nodeStack;
+    QStack<PhyBranch*> branchStack;
     nodeStack.push(rootNode);
     while ((blockLen = reader.read(si, block, BUFF_SIZE)) > 0) {
         for (int i = 0; i < blockLen; i++) {
             QChar ch = block[i];
-            uchar latin1CharCode = (uchar)ch.toLatin1();
+            auto latin1CharCode = (uchar)ch.toLatin1();
             if (TextUtils::WHITES[latin1CharCode]) {
                 if (state == RS_QUOTED_NAME) {
                     lastStr.append(ch);
@@ -290,8 +278,8 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
             }
             // use cached value
 
-            if (state == RS_NAME_OR_WEIGHT) {
-                state = ch == ':' ? RS_WEIGHT : RS_NAME;
+            if (state == RS_AFTER_CLOSING_BRACE) {
+                state = ch == ':' && lastStr.isEmpty() ? RS_WEIGHT : RS_NAME;
             }
 
             if (ch == '\'') {
@@ -314,7 +302,7 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
 
             if (!lastStr.isEmpty()) {
                 if (state == RS_NAME) {
-                    nodeStack.top()->setName(lastStr);
+                    nodeStack.top()->name = lastStr;
                 } else {
                     CHECK_EXT_BREAK(state == RS_WEIGHT, si.setError(DatatypeSerializers::tr("Incorrect tree parsing state")));
                     if (!branchStack.isEmpty()) {  // Ignore root node weight if present.
@@ -331,8 +319,8 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
             // Advance in state.
             if (ch == '(') {  // A new child.
                 CHECK_EXT_BREAK(!nodeStack.isEmpty(), si.setError(DatatypeSerializers::tr("Tree node stack is empty")));
-                PhyNode *pn = new PhyNode();
-                PhyBranch *bd = PhyTreeData::addBranch(nodeStack.top(), pn, 0);
+                auto pn = new PhyNode();
+                PhyBranch* bd = PhyTreeUtils::addBranch(nodeStack.top(), pn, 0);
                 nodeStack.push(pn);
                 branchStack.push(bd);
                 state = RS_NAME;
@@ -344,15 +332,13 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
                         if (!ok) {
                             si.setError(DatatypeSerializers::tr("Error parsing nodeValue: %1").arg(lastStr));
                             break;
-                        } else {
-                            haveNodeLabels = true;
                         }
                     }
                 }
                 state = RS_WEIGHT;
             } else if (ch == ',') {  // New sibling.
-                CHECK_EXT_BREAK(!nodeStack.isEmpty(), si.setError(DatatypeSerializers::tr("Tree node stack is empty")));
-                CHECK_EXT_BREAK(!branchStack.isEmpty(), si.setError(DatatypeSerializers::tr("Branch node stack is empty")));
+                CHECK_EXT_BREAK(!nodeStack.isEmpty(), si.setError(DatatypeSerializers::tr("Missing nodes in node stack")));
+                CHECK_EXT_BREAK(!branchStack.isEmpty(), si.setError(DatatypeSerializers::tr("Missing branches in branch stack")));
                 if (nodeStack.isEmpty() || branchStack.isEmpty()) {
                     si.setError(DatatypeSerializers::tr("Unexpected new sibling %1").arg(lastStr));
                     break;
@@ -360,7 +346,7 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
                 nodeStack.pop();
                 branchStack.pop();
                 auto node = new PhyNode();
-                PhyBranch *branch = PhyTreeData::addBranch(nodeStack.top(), node, 0);
+                PhyBranch* branch = PhyTreeUtils::addBranch(nodeStack.top(), node, 0);
                 nodeStack.push(node);
                 branchStack.push(branch);
                 state = RS_NAME;
@@ -372,7 +358,7 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
                 }
                 CHECK_EXT_BREAK(!branchStack.isEmpty(), si.setError(DatatypeSerializers::tr("Branch node stack is empty")));
                 branchStack.pop();
-                state = RS_NAME_OR_WEIGHT;
+                state = RS_AFTER_CLOSING_BRACE;
             } else if (ch == ';') {
                 if (!branchStack.isEmpty() || nodeStack.size() != 1) {
                     si.setError(DatatypeSerializers::tr("Unexpected end of file"));
@@ -380,7 +366,6 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
                 }
                 PhyTree tree(new PhyTreeData());
                 tree->setRootNode(nodeStack.pop());
-                tree->setUsingNodeLabels(haveNodeLabels);
                 result << tree;
                 rootNode = new PhyNode();
                 nodeStack.push(rootNode);
@@ -402,10 +387,9 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
             return result;
         }
         if (!done) {
-            PhyNode *node = nodeStack.pop();
+            PhyNode* node = nodeStack.pop();
             PhyTree tree(new PhyTreeData());
             tree->setRootNode(node);
-            tree->setUsingNodeLabels(haveNodeLabels);
             result << tree;
         } else {
             delete rootNode;
@@ -417,7 +401,7 @@ QList<PhyTree> NewickPhyTreeSerializer::parseTrees(IOAdapterReader &reader, U2Op
     return result;
 }
 
-QString NewickPhyTreeSerializer::serialize(const PhyTree &tree, U2OpStatus &os) {
+QString NewickPhyTreeSerializer::serialize(const PhyTree& tree, U2OpStatus& os) {
     QString result;
     packTreeNode(result, tree->getRootNode(), os);
     CHECK_OP(os, "")
@@ -425,8 +409,8 @@ QString NewickPhyTreeSerializer::serialize(const PhyTree &tree, U2OpStatus &os)
     return result;
 }
 
-PhyTree NewickPhyTreeSerializer::deserialize(const QString &text, U2OpStatus &os) {
-    auto ioFactory = qobject_cast<StringAdapterFactory *>(AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::STRING));
+PhyTree NewickPhyTreeSerializer::deserialize(const QString& text, U2OpStatus& os) {
+    auto ioFactory = qobject_cast<StringAdapterFactory*>(AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::STRING));
     SAFE_POINT(ioFactory, "Failed to get StringAdapterFactory", {})
     StringAdapter io(text.toUtf8(), ioFactory);
     IOAdapterReader reader(&io);
@@ -442,45 +426,45 @@ PhyTree NewickPhyTreeSerializer::deserialize(const QString &text, U2OpStatus &os
 namespace {
 class PackContext {
 public:
-    QHash<const AtomData *, SharedAtom> atoms;
-    QHash<const AtomData *, int> atomPositions;
-    QHash<int, const AtomData *> atomByPosition;
+    QHash<const AtomData*, SharedAtom> atoms;
+    QHash<const AtomData*, int> atomPositions;
+    QHash<int, const AtomData*> atomByPosition;
 };
 
 template<class T>
-T unpack(const uchar *data, int length, int &offset, U2OpStatus &os);
+T unpack(const uchar* data, int length, int& offset, U2OpStatus& os);
 template<class T>
-T unpack(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext &ctx);
+T unpack(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& ctx);
 
 template<>
-inline char unpack(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline char unpack(const uchar* data, int length, int& offset, U2OpStatus& os) {
     CHECK_SIZE(1, 0);
     char result = (char)data[offset];
     offset++;
     return result;
 }
 
-inline QByteArray pack(const QByteArray &data) {
+inline QByteArray pack(const QByteArray& data) {
     return packNum<int>(data.size()) + data;
 }
 template<>
-inline QByteArray unpack(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline QByteArray unpack(const uchar* data, int length, int& offset, U2OpStatus& os) {
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_SIZE(size, "");
-    QByteArray result((const char *)data + offset, size);
+    QByteArray result((const char*)data + offset, size);
     offset += size;
     return result;
 }
 
-inline QByteArray pack(const QString &data) {
+inline QByteArray pack(const QString& data) {
     return pack(data.toUtf8());
 }
 template<>
-inline QString unpack(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline QString unpack(const uchar* data, int length, int& offset, U2OpStatus& os) {
     return QString::fromUtf8(unpack<QByteArray>(data, length, offset, os));
 }
 
-inline QByteArray pack(const ResidueIndex &data) {
+inline QByteArray pack(const ResidueIndex& data) {
     QByteArray result;
     result += packNum<int>(data.toInt());
     result += packNum<int>(data.getOrder());
@@ -488,7 +472,7 @@ inline QByteArray pack(const ResidueIndex &data) {
     return result;
 }
 template<>
-inline ResidueIndex unpack(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline ResidueIndex unpack(const uchar* data, int length, int& offset, U2OpStatus& os) {
     int resId = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, ResidueIndex());
     int order = unpackNum<int>(data, length, offset, os);
@@ -501,15 +485,15 @@ inline ResidueIndex unpack(const uchar *data, int length, int &offset, U2OpStatu
     return result;
 }
 template<>
-inline QByteArray packNum(const ResidueIndex &num) {
+inline QByteArray packNum(const ResidueIndex& num) {
     return pack(num);
 }
 template<>
-inline ResidueIndex unpackNum(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline ResidueIndex unpackNum(const uchar* data, int length, int& offset, U2OpStatus& os) {
     return unpack<ResidueIndex>(data, length, offset, os);
 }
 
-inline QByteArray pack(const ResidueData &data) {
+inline QByteArray pack(const ResidueData& data) {
     QByteArray result;
     result += char(data.type);
     result += pack(data.name);
@@ -517,11 +501,11 @@ inline QByteArray pack(const ResidueData &data) {
     result += packNum<int>(data.chainIndex);
     return result;
 }
-inline QByteArray pack(const SharedResidue &data, PackContext & /*ctx*/) {
+inline QByteArray pack(const SharedResidue& data, PackContext& /*ctx*/) {
     return pack(*data.data());
 }
 template<>
-inline SharedResidue unpack(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext & /*ctx*/) {
+inline SharedResidue unpack(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& /*ctx*/) {
     SharedResidue result(new ResidueData());
     result->type = ResidueData::Type(unpack<char>(data, length, offset, os));
     CHECK_OP(os, result);
@@ -536,7 +520,7 @@ inline SharedResidue unpack(const uchar *data, int length, int &offset, U2OpStat
     return result;
 }
 
-inline QByteArray pack(const Vector3D &data) {
+inline QByteArray pack(const Vector3D& data) {
     QByteArray result;
     result += packNum<double>(data.x);
     result += packNum<double>(data.y);
@@ -544,7 +528,7 @@ inline QByteArray pack(const Vector3D &data) {
     return result;
 }
 template<>
-inline Vector3D unpack(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline Vector3D unpack(const uchar* data, int length, int& offset, U2OpStatus& os) {
     Vector3D result;
     result.x = unpackNum<double>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -554,7 +538,7 @@ inline Vector3D unpack(const uchar *data, int length, int &offset, U2OpStatus &o
     return result;
 }
 
-inline QByteArray pack(const Matrix44 &data) {
+inline QByteArray pack(const Matrix44& data) {
     QByteArray result;
     for (int i = 0; i < 16; i++) {
         result += packNum<float>(data[i]);
@@ -562,7 +546,7 @@ inline QByteArray pack(const Matrix44 &data) {
     return result;
 }
 template<>
-inline Matrix44 unpack(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline Matrix44 unpack(const uchar* data, int length, int& offset, U2OpStatus& os) {
     Matrix44 result;
     for (int i = 0; i < 16; i++) {
         result[i] = unpackNum<float>(data, length, offset, os);
@@ -571,7 +555,7 @@ inline Matrix44 unpack(const uchar *data, int length, int &offset, U2OpStatus &o
     return result;
 }
 
-inline QByteArray pack(const AtomData &data) {
+inline QByteArray pack(const AtomData& data) {
     QByteArray result;
     result += packNum<int>(data.atomicNumber);
     result += packNum<int>(data.chainIndex);
@@ -582,7 +566,7 @@ inline QByteArray pack(const AtomData &data) {
     result += packNum<float>(data.temperature);
     return result;
 }
-inline QByteArray pack(const SharedAtom &data, PackContext &ctx) {
+inline QByteArray pack(const SharedAtom& data, PackContext& ctx) {
     int num = ctx.atomPositions.value(data.constData(), -1);
     if (-1 != num) {
         return packNum<int>(num);
@@ -600,7 +584,7 @@ inline QByteArray pack(const SharedAtom &data, PackContext &ctx) {
     return result;
 }
 template<>
-inline AtomData unpack(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline AtomData unpack(const uchar* data, int length, int& offset, U2OpStatus& os) {
     AtomData result;
     result.atomicNumber = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -618,7 +602,7 @@ inline AtomData unpack(const uchar *data, int length, int &offset, U2OpStatus &o
     return result;
 }
 template<>
-inline SharedAtom unpack(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext &ctx) {
+inline SharedAtom unpack(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& ctx) {
     int num = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, SharedAtom());
     if (num < ctx.atoms.size()) {
@@ -637,21 +621,21 @@ inline SharedAtom unpack(const uchar *data, int length, int &offset, U2OpStatus
     return result;
 }
 
-inline QByteArray pack(const Bond &data, PackContext &ctx) {
+inline QByteArray pack(const Bond& data, PackContext& ctx) {
     QByteArray result;
     result += pack(data.getAtom1(), ctx);
     result += pack(data.getAtom2(), ctx);
     return result;
 }
 template<>
-inline Bond unpack(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext &ctx) {
+inline Bond unpack(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& ctx) {
     SharedAtom atom1 = unpack<SharedAtom>(data, length, offset, os, ctx);
     CHECK_OP(os, Bond(SharedAtom(), SharedAtom()));
     SharedAtom atom2 = unpack<SharedAtom>(data, length, offset, os, ctx);
-    return Bond(atom1, atom2);
+    return {atom1, atom2};
 }
 
-inline QByteArray pack(const SecondaryStructure &data) {
+inline QByteArray pack(const SecondaryStructure& data) {
     QByteArray result;
     result += char(data.type);
     result += data.chainIdentifier;
@@ -660,11 +644,11 @@ inline QByteArray pack(const SecondaryStructure &data) {
     result += packNum<int>(data.endSequenceNumber);
     return result;
 }
-inline QByteArray pack(const SharedSecondaryStructure &data, PackContext & /*ctx*/) {
+inline QByteArray pack(const SharedSecondaryStructure& data, PackContext& /*ctx*/) {
     return pack(*data.data());
 }
 template<>
-inline SharedSecondaryStructure unpack(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext & /*ctx*/) {
+inline SharedSecondaryStructure unpack(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& /*ctx*/) {
     SharedSecondaryStructure result(new SecondaryStructure());
     result->type = SecondaryStructure::Type(unpack<char>(data, length, offset, os));
     CHECK_OP(os, result);
@@ -679,16 +663,16 @@ inline SharedSecondaryStructure unpack(const uchar *data, int length, int &offse
 }
 
 template<class T>
-inline QByteArray packList(const QList<T> &data, PackContext &ctx) {
+inline QByteArray packList(const QList<T>& data, PackContext& ctx) {
     QByteArray result;
     result += packNum<int>(data.size());
-    foreach (const T &d, data) {
+    foreach (const T& d, data) {
         result += pack(d, ctx);
     }
     return result;
 }
 template<class T>
-inline QList<T> unpackList(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext &ctx) {
+inline QList<T> unpackList(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& ctx) {
     QList<T> result;
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -699,14 +683,14 @@ inline QList<T> unpackList(const uchar *data, int length, int &offset, U2OpStatu
     return result;
 }
 
-inline QByteArray pack(const Molecule3DModel &data, PackContext &ctx) {
+inline QByteArray pack(const Molecule3DModel& data, PackContext& ctx) {
     QByteArray result;
     result += packList<SharedAtom>(data.atoms, ctx);
     result += packList<Bond>(data.bonds, ctx);
     return result;
 }
 template<>
-inline Molecule3DModel unpack(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext &ctx) {
+inline Molecule3DModel unpack(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& ctx) {
     Molecule3DModel result;
     result.atoms = unpackList<SharedAtom>(data, length, offset, os, ctx);
     CHECK_OP(os, result);
@@ -716,17 +700,17 @@ inline Molecule3DModel unpack(const uchar *data, int length, int &offset, U2OpSt
 }
 
 template<class KeyT, class ValueT>
-inline QByteArray packMap(const QMap<KeyT, ValueT> &data, PackContext &ctx) {
+inline QByteArray packMap(const QMap<KeyT, ValueT>& data, PackContext& ctx) {
     QByteArray result;
     result += packNum<int>(data.size());
-    foreach (const KeyT &idx, data.keys()) {
+    foreach (const KeyT& idx, data.keys()) {
         result += packNum<KeyT>(idx);
         result += pack(data[idx], ctx);
     }
     return result;
 }
 template<class KeyT, class ValueT>
-inline QMap<KeyT, ValueT> unpackMap(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext &ctx) {
+inline QMap<KeyT, ValueT> unpackMap(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& ctx) {
     QMap<KeyT, ValueT> result;
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -740,7 +724,7 @@ inline QMap<KeyT, ValueT> unpackMap(const uchar *data, int length, int &offset,
     return result;
 }
 
-inline QByteArray pack(const MoleculeData &data, PackContext &ctx) {
+inline QByteArray pack(const MoleculeData& data, PackContext& ctx) {
     QByteArray result;
     result += packMap<ResidueIndex, SharedResidue>(data.residueMap, ctx);
     result += packMap<int, Molecule3DModel>(data.models, ctx);
@@ -749,11 +733,11 @@ inline QByteArray pack(const MoleculeData &data, PackContext &ctx) {
     result += packBool(data.engineered);
     return result;
 }
-inline QByteArray pack(const SharedMolecule &data, PackContext &ctx) {
+inline QByteArray pack(const SharedMolecule& data, PackContext& ctx) {
     return pack(*data.data(), ctx);
 }
 template<>
-inline SharedMolecule unpack(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext &ctx) {
+inline SharedMolecule unpack(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& ctx) {
     SharedMolecule result(new MoleculeData());
     result->residueMap = unpackMap<ResidueIndex, SharedResidue>(data, length, offset, os, ctx);
     CHECK_OP(os, result);
@@ -767,7 +751,7 @@ inline SharedMolecule unpack(const uchar *data, int length, int &offset, U2OpSta
     return result;
 }
 
-inline QByteArray pack(const AtomCoordSet &data, PackContext &ctx) {
+inline QByteArray pack(const AtomCoordSet& data, PackContext& ctx) {
     QByteArray result;
     result += packNum<int>(data.size());
     foreach (int idx, data.keys()) {
@@ -777,7 +761,7 @@ inline QByteArray pack(const AtomCoordSet &data, PackContext &ctx) {
     return result;
 }
 template<>
-inline AtomCoordSet unpack(const uchar *data, int length, int &offset, U2OpStatus &os, PackContext &ctx) {
+inline AtomCoordSet unpack(const uchar* data, int length, int& offset, U2OpStatus& os, PackContext& ctx) {
     AtomCoordSet result;
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -792,7 +776,7 @@ inline AtomCoordSet unpack(const uchar *data, int length, int &offset, U2OpStatu
 }
 }  // namespace
 
-QByteArray BioStruct3DSerializer::serialize(const BioStruct3D &bioStruct) {
+QByteArray BioStruct3DSerializer::serialize(const BioStruct3D& bioStruct) {
     PackContext ctx;
     QByteArray result;
     result += packMap<int, SharedMolecule>(bioStruct.moleculeMap, ctx);
@@ -807,8 +791,8 @@ QByteArray BioStruct3DSerializer::serialize(const BioStruct3D &bioStruct) {
     return result;
 }
 
-BioStruct3D BioStruct3DSerializer::deserialize(const QByteArray &binary, U2OpStatus &os) {
-    const uchar *data = (const uchar *)(binary.data());
+BioStruct3D BioStruct3DSerializer::deserialize(const QByteArray& binary, U2OpStatus& os) {
+    auto data = (const uchar*)(binary.data());
     int offset = 0;
     int length = binary.length();
 
@@ -839,16 +823,16 @@ BioStruct3D BioStruct3DSerializer::deserialize(const QByteArray &binary, U2OpSta
 /************************************************************************/
 namespace {
 template<class T>
-inline QByteArray packArray(const QVarLengthArray<T> &data) {
+inline QByteArray packArray(const QVarLengthArray<T>& data) {
     QByteArray result;
     result += packNum<int>(data.size());
-    foreach (const T &d, data) {
+    foreach (const T& d, data) {
         result += packNum<T>(d);
     }
     return result;
 }
 template<class T>
-inline QVarLengthArray<T> unpackArray(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline QVarLengthArray<T> unpackArray(const uchar* data, int length, int& offset, U2OpStatus& os) {
     QVarLengthArray<T> result;
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -858,16 +842,16 @@ inline QVarLengthArray<T> unpackArray(const uchar *data, int length, int &offset
     }
     return result;
 }
-inline QByteArray packMap(const QMap<QString, QString> &data) {
+inline QByteArray packMap(const QMap<QString, QString>& data) {
     QByteArray result;
     result += packNum<int>(data.size());
-    foreach (const QString &key, data.keys()) {
+    foreach (const QString& key, data.keys()) {
         result += pack(key);
         result += pack(data[key]);
     }
     return result;
 }
-inline QMap<QString, QString> unpackMap(const uchar *data, int length, int &offset, U2OpStatus &os) {
+inline QMap<QString, QString> unpackMap(const uchar* data, int length, int& offset, U2OpStatus& os) {
     QMap<QString, QString> result;
     int size = unpackNum<int>(data, length, offset, os);
     CHECK_OP(os, result);
@@ -882,7 +866,7 @@ inline QMap<QString, QString> unpackMap(const uchar *data, int length, int &offs
 }
 }  // namespace
 
-QByteArray WMatrixSerializer::serialize(const PWMatrix &matrix) {
+QByteArray WMatrixSerializer::serialize(const PWMatrix& matrix) {
     QByteArray result;
     result += packArray<float>(matrix.data);
     result += char(matrix.type);
@@ -890,14 +874,14 @@ QByteArray WMatrixSerializer::serialize(const PWMatrix &matrix) {
     return result;
 }
 
-PWMatrix WMatrixSerializer::deserialize(const QByteArray &binary, U2OpStatus &os) {
-    const uchar *data = (const uchar *)(binary.data());
+PWMatrix WMatrixSerializer::deserialize(const QByteArray& binary, U2OpStatus& os) {
+    auto data = (const uchar*)(binary.data());
     int offset = 0;
     int length = binary.length();
 
     QVarLengthArray<float> matrix = unpackArray<float>(data, length, offset, os);
     CHECK_OP(os, PWMatrix());
-    PWMatrixType type = PWMatrixType(unpack<char>(data, length, offset, os));
+    auto type = PWMatrixType(unpack<char>(data, length, offset, os));
     CHECK_OP(os, PWMatrix());
     QMap<QString, QString> props = unpackMap(data, length, offset, os);
     CHECK_OP(os, PWMatrix());
@@ -911,7 +895,7 @@ PWMatrix WMatrixSerializer::deserialize(const QByteArray &binary, U2OpStatus &os
 /************************************************************************/
 /* FMatrixSerializer */
 /************************************************************************/
-QByteArray FMatrixSerializer::serialize(const PFMatrix &matrix) {
+QByteArray FMatrixSerializer::serialize(const PFMatrix& matrix) {
     QByteArray result;
     result += packArray<int>(matrix.data);
     result += char(matrix.type);
@@ -919,14 +903,14 @@ QByteArray FMatrixSerializer::serialize(const PFMatrix &matrix) {
     return result;
 }
 
-PFMatrix FMatrixSerializer::deserialize(const QByteArray &binary, U2OpStatus &os) {
-    const uchar *data = (const uchar *)(binary.data());
+PFMatrix FMatrixSerializer::deserialize(const QByteArray& binary, U2OpStatus& os) {
+    auto data = (const uchar*)(binary.data());
     int offset = 0;
     int length = binary.length();
 
     QVarLengthArray<int> matrix = unpackArray<int>(data, length, offset, os);
     CHECK_OP(os, PFMatrix());
-    PFMatrixType type = PFMatrixType(unpack<char>(data, length, offset, os));
+    auto type = PFMatrixType(unpack<char>(data, length, offset, os));
     CHECK_OP(os, PFMatrix());
     QMap<QString, QString> props = unpackMap(data, length, offset, os);
     CHECK_OP(os, PFMatrix());
