@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DATATYPE_SERIALIZE_UTILS_H_
-#define _U2_DATATYPE_SERIALIZE_UTILS_H_
+#pragma once
 
 #include <U2Core/BioStruct3D.h>
 #include <U2Core/DNAChromatogram.h>
@@ -47,12 +46,12 @@ public:
     /**
      * Returns the binary representation of @chroma.
      */
-    static QByteArray serialize(const DNAChromatogram &chroma);
+    static QByteArray serialize(const DNAChromatogram& chroma);
 
     /**
      * Returns DNAChromatogram extracted from @binary.
      */
-    static DNAChromatogram deserialize(const QByteArray &binary, U2OpStatus &os);
+    static DNAChromatogram deserialize(const QByteArray& binary, U2OpStatus& os);
 };
 
 /**
@@ -66,13 +65,13 @@ public:
     static const QString ID;
 
     /** Returns serialized (textual) representation of the tree. */
-    static QString serialize(const PhyTree &tree, U2OpStatus &os);
+    static QString serialize(const PhyTree& tree, U2OpStatus& os);
 
     /** Returns PhyTree extracted from form serial representation. */
-    static PhyTree deserialize(const QString &text, U2OpStatus &os);
+    static PhyTree deserialize(const QString& text, U2OpStatus& os);
 
     /** Returns the list of trees parsed from reader stream. */
-    static QList<PhyTree> parseTrees(IOAdapterReader &reader, U2OpStatus &os);
+    static QList<PhyTree> parseTrees(IOAdapterReader& reader, U2OpStatus& os);
 };
 
 /**
@@ -89,12 +88,12 @@ public:
     /**
      * Returns the binary representation of @bioStruct.
      */
-    static QByteArray serialize(const BioStruct3D &bioStruct);
+    static QByteArray serialize(const BioStruct3D& bioStruct);
 
     /**
      * Returns BioStruct3D extracted from @binary.
      */
-    static BioStruct3D deserialize(const QByteArray &binary, U2OpStatus &os);
+    static BioStruct3D deserialize(const QByteArray& binary, U2OpStatus& os);
 };
 
 /**
@@ -111,12 +110,12 @@ public:
     /**
      * Returns the binary representation of @matrix.
      */
-    static QByteArray serialize(const PWMatrix &matrix);
+    static QByteArray serialize(const PWMatrix& matrix);
 
     /**
      * Returns PWMatrix extracted from @binary.
      */
-    static PWMatrix deserialize(const QByteArray &binary, U2OpStatus &os);
+    static PWMatrix deserialize(const QByteArray& binary, U2OpStatus& os);
 };
 
 /**
@@ -133,12 +132,12 @@ public:
     /**
      * Returns the binary representation of @matrix.
      */
-    static QByteArray serialize(const PFMatrix &matrix);
+    static QByteArray serialize(const PFMatrix& matrix);
 
     /**
      * Returns PFMatrix extracted from @binary.
      */
-    static PFMatrix deserialize(const QByteArray &binary, U2OpStatus &os);
+    static PFMatrix deserialize(const QByteArray& binary, U2OpStatus& os);
 };
 
 class DatatypeSerializers : public QObject {
@@ -146,5 +145,3 @@ class DatatypeSerializers : public QObject {
 };
 
 }  // namespace U2
-
-#endif  // _U2_DATATYPE_SERIALIZE_UTILS_H_
