@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_CHROMATOGRAM_UTILS_H_
-#define _U2_DNA_CHROMATOGRAM_UTILS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -30,10 +29,8 @@ class DNAChromatogram;
 
 class U2CORE_EXPORT DnaChromatogramUtils {
 public:
-    static void append(DNAChromatogram &chromatogram, const DNAChromatogram &appendedChromatogram);
-    static void crop(DNAChromatogram &chromatogram, int startPos, int length);
+    static void append(DNAChromatogram& chromatogram, const DNAChromatogram& appendedChromatogram);
+    static void crop(DNAChromatogram& chromatogram, int startPos, int length);
 };
 
 }  // namespace U2
-
-#endif  // _U2_DNA_CHROMATOGRAM_UTILS_H_
