@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,8 +23,11 @@
 
 #include <QDir>
 #include <QTemporaryFile>
+#include <QTextStream>
 
+#include <U2Core/GUrlUtils.h>
 #include <U2Core/Log.h>
+#include <U2Core/TextUtils.h>
 #include <U2Core/TmpDirChecker.h>
 #include <U2Core/U2SafePoints.h>
 
@@ -40,17 +43,17 @@ const QString FileAndDirectoryUtils::HOME_DIR_IDENTIFIER = "~/";
 const QString FileAndDirectoryUtils::HOME_DIR_IDENTIFIER = "%UserProfile%/";
 #endif
 
-QString FileAndDirectoryUtils::getFormatId(const FormatDetectionResult &r) {
-    if (nullptr != r.format) {
+QString FileAndDirectoryUtils::getFormatId(const FormatDetectionResult& r) {
+    if (r.format != nullptr) {
         return r.format->getFormatId();
     }
-    if (nullptr != r.importer) {
+    if (r.importer != nullptr) {
         return r.importer->getId();
     }
     return "";
 }
 
-QString FileAndDirectoryUtils::getWorkingDir(const QString &fileUrl, int dirMode, const QString &customDir, const QString &workingDir) {
+QString FileAndDirectoryUtils::getWorkingDir(const QString& fileUrl, int dirMode, const QString& customDir, const QString& workingDir) {
     QString result;
 
     bool useInternal = false;
@@ -92,7 +95,7 @@ QString FileAndDirectoryUtils::getWorkingDir(const QString &fileUrl, int dirMode
     return result;
 }
 
-QString FileAndDirectoryUtils::createWorkingDir(const QString &fileUrl, int dirMode, const QString &customDir, const QString &workingDir) {
+QString FileAndDirectoryUtils::createWorkingDir(const QString& fileUrl, int dirMode, const QString& customDir, const QString& workingDir) {
     const QString result = getWorkingDir(fileUrl, dirMode, customDir, workingDir);
     QDir dir(result);
     if (!dir.exists(result)) {
@@ -101,7 +104,7 @@ QString FileAndDirectoryUtils::createWorkingDir(const QString &fileUrl, int dirM
     return result;
 }
 
-QString FileAndDirectoryUtils::detectFormat(const QString &url) {
+QString FileAndDirectoryUtils::detectFormat(const QString& url) {
     FormatDetectionConfig cfg;
     cfg.bestMatchesOnly = false;
     cfg.useImporters = true;
@@ -115,7 +118,7 @@ QString FileAndDirectoryUtils::detectFormat(const QString &url) {
     return getFormatId(formats.first());
 }
 
-bool FileAndDirectoryUtils::isFileEmpty(const QString &url) {
+bool FileAndDirectoryUtils::isFileEmpty(const QString& url) {
     QFile file(url);
     if (!file.exists()) {
         return true;
@@ -126,15 +129,23 @@ bool FileAndDirectoryUtils::isFileEmpty(const QString &url) {
     return false;
 }
 
-void FileAndDirectoryUtils::dumpStringToFile(QFile *f, QString &str) {
-    if (Q_LIKELY(f == nullptr || str.length() <= MIN_LENGTH_TO_WRITE)) {
-        return;
-    }
+void FileAndDirectoryUtils::dumpStringToFile(QFile* f, QString& str) {
+    CHECK(f != nullptr && str.length() >= MIN_LENGTH_TO_WRITE, );
     f->write(str.toLocal8Bit());
     str.clear();
 }
 
-QString FileAndDirectoryUtils::getAbsolutePath(const QString &filePath) {
+bool FileAndDirectoryUtils::storeTextToFile(const QString& filePath, const QString& text) {
+    QFile file(filePath);
+    if (!file.open(QFile::WriteOnly)) {
+        return false;
+    }
+    QTextStream out(&file);
+    out << text;
+    return true;
+}
+
+QString FileAndDirectoryUtils::getAbsolutePath(const QString& filePath) {
     CHECK(!filePath.isEmpty(), filePath);
     QString result = QDir::fromNativeSeparators(filePath);
     if (result.startsWith(HOME_DIR_IDENTIFIER, Qt::CaseInsensitive)) {
@@ -144,7 +155,7 @@ QString FileAndDirectoryUtils::getAbsolutePath(const QString &filePath) {
     return QFileInfo(result).absoluteFilePath();
 }
 
-bool FileAndDirectoryUtils::isDirectoryWritable(const QString &dirPath) {
+bool FileAndDirectoryUtils::isDirectoryWritable(const QString& dirPath) {
     QDir dir(dirPath);
     if (!dir.exists()) {
         return false;
@@ -160,7 +171,7 @@ bool FileAndDirectoryUtils::isDirectoryWritable(const QString &dirPath) {
     return true;
 }
 
-bool FileAndDirectoryUtils::canWriteToPath(const QString &absoluteDirPath) {
+bool FileAndDirectoryUtils::canWriteToPath(const QString& absoluteDirPath) {
     if (absoluteDirPath.isEmpty()) {
         return true;
     }
@@ -194,4 +205,25 @@ bool FileAndDirectoryUtils::canWriteToPath(const QString &absoluteDirPath) {
     return true;
 }
 
+NP<FILE> FileAndDirectoryUtils::openFile(const QString& fileUrl, const QString& mode) {
+#ifdef Q_OS_WIN
+    QScopedPointer<wchar_t> unicodeFileName(TextUtils::toWideCharsArray(GUrlUtils::getNativeAbsolutePath(fileUrl)));
+    QString modeWithBinaryFlag = mode;
+    if (!modeWithBinaryFlag.contains("b")) {
+        modeWithBinaryFlag += "b";  // Always open file in binary mode, so any kind of sam, sam.gz, bam, bai files are processed the same way.
+    }
+    QScopedPointer<wchar_t> unicodeMode(TextUtils::toWideCharsArray(modeWithBinaryFlag));
+    return _wfopen(unicodeFileName.data(), unicodeMode.data());
+#else
+    return fopen(fileUrl.toLocal8Bit(), mode.toLatin1());
+#endif
+}
+
+/** Closes file descriptor if the file descriptor is defined and is open. */
+void FileAndDirectoryUtils::closeFileIfOpen(FILE* file) {
+    int fd = file == nullptr ? -1 : fileno(file);
+    CHECK(fd > 0, );
+    fclose(file);
+}
+
 }  // namespace U2
