@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,17 +31,17 @@ namespace U2 {
 
 using namespace FileStorage;
 
-static QString getCommonHashForFile(const QString &url) {
+static QString getCommonHashForFile(const QString& url) {
     QFileInfo info(url);
     qint64 modified = info.lastModified().toSecsSinceEpoch();
 
     return QByteArray::number(modified);
 }
 
-QString FileStorageUtils::getFileToFileInfo(const QString &srcUrl, const QString &role, WorkflowProcess &process) {
-    AppFileStorage *fileStorage = AppContext::getAppFileStorage();
+QString FileStorageUtils::getFileToFileInfo(const QString& srcUrl, const QString& role, WorkflowProcess& process) {
+    AppFileStorage* fileStorage = AppContext::getAppFileStorage();
 
-    if (nullptr != fileStorage) {
+    if (fileStorage != nullptr) {
         U2OpStatus2Log os;
         QString dstUrl = fileStorage->getFileInfo(srcUrl, role, process, os);
         CHECK_OP(os, "");
@@ -67,10 +67,10 @@ QString FileStorageUtils::getFileToFileInfo(const QString &srcUrl, const QString
     return "";
 }
 
-void FileStorageUtils::addFileToFileInfo(const FileInfo &fileToFileInfo, WorkflowProcess &process) {
+void FileStorageUtils::addFileToFileInfo(const FileInfo& fileToFileInfo, WorkflowProcess& process) {
     CHECK(fileToFileInfo.isFileToFileInfo(), );
-    AppFileStorage *fileStorage = AppContext::getAppFileStorage();
-    CHECK(nullptr != fileStorage, );
+    AppFileStorage* fileStorage = AppContext::getAppFileStorage();
+    CHECK(fileStorage != nullptr, );
 
     U2OpStatus2Log os;
     fileStorage->addFileInfo(fileToFileInfo, process, os);
@@ -85,20 +85,20 @@ void FileStorageUtils::addFileToFileInfo(const FileInfo &fileToFileInfo, Workflo
     CHECK_OP(os, );
 }
 
-QString FileStorageUtils::getSortedBamUrl(const QString &bamUrl, WorkflowProcess &process) {
+QString FileStorageUtils::getSortedBamUrl(const QString& bamUrl, WorkflowProcess& process) {
     return getFileToFileInfo(bamUrl, StorageRoles::SORTED_BAM, process);
 }
 
-QString FileStorageUtils::getSamToBamConvertInfo(const QString &samUrl, WorkflowProcess &process) {
+QString FileStorageUtils::getSamToBamConvertInfo(const QString& samUrl, WorkflowProcess& process) {
     return getFileToFileInfo(samUrl, StorageRoles::SAM_TO_BAM, process);
 }
 
-void FileStorageUtils::addSortedBamUrl(const QString &bamUrl, const QString &sortedBamUrl, WorkflowProcess &process) {
+void FileStorageUtils::addSortedBamUrl(const QString& bamUrl, const QString& sortedBamUrl, WorkflowProcess& process) {
     FileInfo fToFInfo(bamUrl, StorageRoles::SORTED_BAM, sortedBamUrl);
     addFileToFileInfo(fToFInfo, process);
 }
 
-void FileStorageUtils::addSamToBamConvertInfo(const QString &samUrl, const QString &bamUrl, WorkflowProcess &process) {
+void FileStorageUtils::addSamToBamConvertInfo(const QString& samUrl, const QString& bamUrl, WorkflowProcess& process) {
     FileInfo fToFInfo(samUrl, StorageRoles::SAM_TO_BAM, bamUrl);
     addFileToFileInfo(fToFInfo, process);
 }
