@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FILES_ITERATOR_
-#define _U2_FILES_ITERATOR_
+#pragma once
 
 #include <QDir>
 
@@ -32,9 +31,9 @@ class FilesIterator;
 
 class U2CORE_EXPORT FilesIteratorFactory {
 public:
-    static FilesIterator *createDirectoryScanner(const QStringList &dirs, const QString &includeFilter, const QString &excludeFilter, bool recursive);
+    static FilesIterator* createDirectoryScanner(const QStringList& dirs, const QString& includeFilter, const QString& excludeFilter, bool recursive);
 
-    static FilesIterator *createFileList(const QStringList &files);
+    static FilesIterator* createFileList(const QStringList& files);
 };
 
 class U2CORE_EXPORT FilesIterator {
@@ -55,7 +54,7 @@ public:
 /************************************************************************/
 class U2CORE_EXPORT DirectoryScanner : public FilesIterator {
 public:
-    DirectoryScanner(const QStringList &dirs, const QString &includeFilter, const QString &excludeFilter, bool recursive);
+    DirectoryScanner(const QStringList& dirs, const QString& includeFilter, const QString& excludeFilter, bool recursive);
 
     virtual QString getNextFile();
     virtual bool hasNext();
@@ -73,13 +72,13 @@ private:
     QStringList readyResults;
 
 private:
-    QFileInfoList scanDirectory(const QDir &dir);
-    bool isPassedByFilters(const QString &fileName) const;
+    QFileInfoList scanDirectory(const QDir& dir);
+    bool isPassedByFilters(const QString& fileName) const;
 };
 
 class U2CORE_EXPORT FileList : public FilesIterator {
 public:
-    FileList(const QStringList &files);
+    FileList(const QStringList& files);
 
     virtual QString getNextFile();
     virtual bool hasNext();
@@ -89,5 +88,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_FILES_ITERATOR_
