@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_AUTODELETE_LIST_H_
-#define _U2_AUTODELETE_LIST_H_
+#pragma once
 
 #include <QObject>
 
@@ -29,31 +28,29 @@ namespace U2 {
 template<class T>
 class GAutoDeleteList : public QObject {
 public:
-    GAutoDeleteList(QObject *p = nullptr)
+    GAutoDeleteList(QObject* p = nullptr)
         : QObject(p) {
     }
     virtual ~GAutoDeleteList() {
         qDeleteAll(qlist);
     }
-    QList<T *> qlist;
+    QList<T*> qlist;
 };
 
 // todo: move to separate header
 template<class T>
 class gauto_array {
 public:
-    gauto_array(T *p = nullptr)
+    gauto_array(T* p = nullptr)
         : data(p) {
     }
     ~gauto_array() {
         delete[] data;
     }
-    T *get() const {
+    T* get() const {
         return data;
     }
-    T *data;
+    T* data;
 };
 
 }  // namespace U2
-
-#endif
