@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_TO_DATABASE_OPTIONS_H_
-#define _U2_IMPORT_TO_DATABASE_OPTIONS_H_
+#pragma once
 
 #include <QStringList>
 
@@ -49,8 +48,8 @@ public:
     QStringList preferredFormats;
     bool processFoldersRecursively;
 
-    bool operator==(const ImportToDatabaseOptions &other) const;
-    bool operator!=(const ImportToDatabaseOptions &other) const;
+    bool operator==(const ImportToDatabaseOptions& other) const;
+    bool operator!=(const ImportToDatabaseOptions& other) const;
 
     static const QString DESTINATION_FOLDER;
     static const QString KEEP_FOLDERS_STRUCTURE;
@@ -65,5 +64,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_TO_DATABASE_OPTIONS_H_
