@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,7 +29,7 @@ namespace U2 {
 
 const qint64 MaIterator::INVALID_POSITION = -1;
 
-MaIterator::MaIterator(const MultipleAlignment &ma, NavigationDirection direction, const QList<int> &_rowsIndexes)
+MaIterator::MaIterator(const MultipleAlignment& ma, NavigationDirection direction, const QList<int>& _rowsIndexes)
     : ma(ma),
       rowsIndexes(_rowsIndexes),
       direction(direction),
@@ -38,7 +38,7 @@ MaIterator::MaIterator(const MultipleAlignment &ma, NavigationDirection directio
       position(-1),
       maSquare(static_cast<qint64>(ma->getLength()) * rowsIndexes.size()) {
     if (rowsIndexes.isEmpty()) {
-        for (int index = 0; index < ma->getNumRows(); index++) {
+        for (int index = 0; index < ma->getRowCount(); index++) {
             rowsIndexes << index;
         }
         maSquare = static_cast<qint64>(ma->getLength()) * rowsIndexes.size();
@@ -55,7 +55,7 @@ char MaIterator::next() {
     return *(operator++());
 }
 
-MaIterator &MaIterator::operator++() {
+MaIterator& MaIterator::operator++() {
     SAFE_POINT(hasNext(), "Out of boundaries", *this);
     position = getNextPosition();
     SAFE_POINT(isInRange(position), "Out of boundaries", *this);
@@ -66,13 +66,13 @@ char MaIterator::operator*() {
     SAFE_POINT(isInRange(position), "Out of boundaries", U2Msa::INVALID_CHAR);
     const QPoint maPoint = getMaPoint();
     SAFE_POINT(0 <= maPoint.x() && maPoint.x() < ma->getLength() &&
-                   0 <= maPoint.y() && maPoint.y() < ma->getNumRows(),
+                   0 <= maPoint.y() && maPoint.y() < ma->getRowCount(),
                "Out of boundaries",
                U2Msa::INVALID_CHAR);
     return ma->charAt(maPoint.y(), maPoint.x());
 }
 
-bool MaIterator::operator==(const MaIterator &other) const {
+bool MaIterator::operator==(const MaIterator& other) const {
     return ma == other.ma && position == other.position;
 }
 
@@ -84,7 +84,7 @@ void MaIterator::setIterateInCoreRegionsOnly(bool coreRegionsOnly) {
     this->coreRegionsOnly = coreRegionsOnly;
 }
 
-void MaIterator::setMaPoint(const QPoint &maPoint) {
+void MaIterator::setMaPoint(const QPoint& maPoint) {
     const qint64 newPosition = maPoint.y() * ma->getLength() + maPoint.x();
     SAFE_POINT(isInRange(newPosition), "The new position is out of boundaries", );
     position = newPosition;
