@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MCA_ROW_INNER_DATA_H_
-#define _U2_MCA_ROW_INNER_DATA_H_
+#pragma once
 
 #include <U2Core/DNAChromatogramObject.h>
 #include <U2Core/DNASequence.h>
@@ -34,7 +33,7 @@ public:
     McaRowMemoryData();
 
     DNAChromatogram chromatogram;
-    U2MsaRowGapModel gapModel;
+    QVector<U2MsaGap> gapModel;
     DNASequence sequence;
     qint64 rowLength;
     QVariantMap additionalInfo;
@@ -46,11 +45,9 @@ public:
 
     U2Chromatogram chromatogram;
     U2Sequence sequence;
-    U2MsaRowGapModel gapModel;
+    QVector<U2MsaGap> gapModel;
     qint64 rowLength;
     QVariantMap additionalInfo;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MCA_ROW_INNER_DATA_H_
