@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MULTIPLE_SEQUENCE_ALIGNMENT_WALKER_H_
-#define _U2_MULTIPLE_SEQUENCE_ALIGNMENT_WALKER_H_
+#pragma once
 
 #include <U2Core/MultipleSequenceAlignment.h>
 
@@ -30,19 +29,17 @@ class RowWalker;
 
 class U2CORE_EXPORT MultipleSequenceAlignmentWalker {
 public:
-    MultipleSequenceAlignmentWalker(const MultipleSequenceAlignment &msa, char gapChar = U2Msa::GAP_CHAR);
+    MultipleSequenceAlignmentWalker(const MultipleSequenceAlignment& msa, char gapChar = U2Msa::GAP_CHAR);
     ~MultipleSequenceAlignmentWalker();
 
     bool isEnded() const;
 
-    QList<QByteArray> nextData(int length, U2OpStatus &os);
+    QList<QByteArray> nextData(int length, U2OpStatus& os);
 
 private:
-    const MultipleSequenceAlignment &msa;
+    const MultipleSequenceAlignment& msa;
     int currentOffset;
-    QList<RowWalker *> rowWalkerList;
+    QList<RowWalker*> rowWalkerList;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MULTIPLE_SEQUENCE_ALIGNMENT_WALKER_H_
