@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PMATRIX_SERIALIZE_UTILS_H_
-#define _U2_PMATRIX_SERIALIZE_UTILS_H_
+#pragma once
 
 #include <U2Core/RawDataUdrSchema.h>
 #include <U2Core/U2OpStatusUtils.h>
@@ -31,8 +30,8 @@ namespace U2 {
 template<class Serializer, class Matrix>
 class PMatrixSerializeUtils {
 public:
-    static U2EntityRef commit(const Matrix &matrix, const QString &objectName, const U2DbiRef &dbiRef, const QString &dstFolder, U2RawData &object, U2OpStatus &os);
-    static void retrieve(const U2EntityRef &entityRef, Matrix &matrix, U2OpStatus &os);
+    static U2EntityRef commit(const Matrix& matrix, const QString& objectName, const U2DbiRef& dbiRef, const QString& dstFolder, U2RawData& object, U2OpStatus& os);
+    static void retrieve(const U2EntityRef& entityRef, Matrix& matrix, U2OpStatus& os);
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -40,12 +39,12 @@ public:
 //////////////////////////////////////////////////////////////////////////
 
 template<class Serializer, class Matrix>
-U2EntityRef PMatrixSerializeUtils<Serializer, Matrix>::commit(const Matrix &matrix,
-                                                              const QString &objectName,
-                                                              const U2DbiRef &dbiRef,
-                                                              const QString &dstFolder,
-                                                              U2RawData &object,
-                                                              U2OpStatus &os) {
+U2EntityRef PMatrixSerializeUtils<Serializer, Matrix>::commit(const Matrix& matrix,
+                                                              const QString& objectName,
+                                                              const U2DbiRef& dbiRef,
+                                                              const QString& dstFolder,
+                                                              U2RawData& object,
+                                                              U2OpStatus& os) {
     object.visualName = objectName;
     object.serializer = Serializer::ID;
 
@@ -59,9 +58,9 @@ U2EntityRef PMatrixSerializeUtils<Serializer, Matrix>::commit(const Matrix &matr
 }
 
 template<class Serializer, class Matrix>
-void PMatrixSerializeUtils<Serializer, Matrix>::retrieve(const U2EntityRef &entityRef,
-                                                         Matrix &matrix,
-                                                         U2OpStatus &os) {
+void PMatrixSerializeUtils<Serializer, Matrix>::retrieve(const U2EntityRef& entityRef,
+                                                         Matrix& matrix,
+                                                         U2OpStatus& os) {
     const QString serializer = RawDataUdrSchema::getObject(entityRef, os).serializer;
     CHECK_OP(os, );
     SAFE_POINT(Serializer::ID == serializer, "Unknown serializer id", );
@@ -72,5 +71,3 @@ void PMatrixSerializeUtils<Serializer, Matrix>::retrieve(const U2EntityRef &enti
 }
 
 }  // namespace U2
-
-#endif  // _U2_PMATRIX_SERIALIZE_UTILS_H_
