@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_QVARUTILS_H_
-#define _U2_QVARUTILS_H_
+#pragma once
 
 #include <QDataStream>
 #include <QList>
@@ -34,12 +33,12 @@ namespace U2 {
 
 class U2CORE_EXPORT QVariantUtils {
 public:
-    static QVariant String2Var(const QString &string) {
+    static QVariant String2Var(const QString& string) {
         QDataStream s(QByteArray::fromBase64(string.toLatin1()));
         return QVariant(s);
     }
 
-    static QVariantMap string2Map(const QString &string, bool emptyMapIfError) {
+    static QVariantMap string2Map(const QString& string, bool emptyMapIfError) {
         QDataStream s(QByteArray::fromBase64(string.toLatin1()));
         QVariant res(QVariant::Map);
         s >> res;
@@ -50,7 +49,7 @@ public:
         return QVariantMap();
     }
 
-    static QString var2String(const QVariant &v) {
+    static QString var2String(const QVariant& v) {
         QByteArray a;
         QDataStream s(&a, QIODevice::WriteOnly);
         s << v;
@@ -58,11 +57,11 @@ public:
         return res;
     }
 
-    static QString map2String(const QVariantMap &map) {
+    static QString map2String(const QVariantMap& map) {
         return var2String(QVariant(map));
     }
 
-    static QVariant addStr2List(const QVariant &v, const QString &s) {
+    static QVariant addStr2List(const QVariant& v, const QString& s) {
         if (v.canConvert(QVariant::StringList)) {
             QStringList l = v.toStringList();
             return (l << s);
@@ -72,7 +71,7 @@ public:
         return QVariant(s);
     }
 
-    static QVariant addStr2List(const QVariant &v, const QStringList &sl) {
+    static QVariant addStr2List(const QVariant& v, const QStringList& sl) {
         if (v.canConvert(QVariant::StringList)) {
             QStringList l = v.toStringList();
             return QVariant(l += sl);
@@ -84,4 +83,3 @@ public:
 };
 
 }  // namespace U2
-#endif
