@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __SYNC_HTTP_H__
-#define __SYNC_HTTP_H__
+#pragma once
 
 #include <QAuthenticator>
 #include <QBasicTimer>
@@ -37,7 +36,7 @@ namespace U2 {
 class U2CORE_EXPORT SyncHttp : public QNetworkAccessManager {
     Q_OBJECT
 public:
-    SyncHttp(U2OpStatus &os, QObject *parent = nullptr);
+    SyncHttp(U2OpStatus& os, QObject* parent = nullptr);
     ~SyncHttp();
 
     /**
@@ -45,7 +44,7 @@ public:
      * The method creates new event loop that will block the current one until request is finished.
      * Consider a better approach before start using this method.
      */
-    QString syncGet(const QUrl &url, int timeoutMillis);
+    QString syncGet(const QUrl& url, int timeoutMillis);
 
     QNetworkReply::NetworkError error() const {
         return err;
@@ -54,33 +53,31 @@ public:
         return errString;
     }
 protected slots:
-    virtual void finished(QNetworkReply *);
-    virtual void onProxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *);
+    virtual void finished(QNetworkReply*);
+    virtual void onProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*);
     void sl_taskCancellingCheck();
 
 private:
     void runStateCheckTimer();
 
-    QEventLoop *loop;
+    QEventLoop* loop;
     QNetworkReply::NetworkError err;
     QString errString;
-    U2OpStatus &os;
+    U2OpStatus& os;
 };
 
 class ReplyTimeout : public QObject {
     Q_OBJECT
 public:
-    ReplyTimeout(QNetworkReply *reply, int timeoutMillis);
+    ReplyTimeout(QNetworkReply* reply, int timeoutMillis);
 
-    static void set(QNetworkReply *reply, int timeoutMillis);
+    static void set(QNetworkReply* reply, int timeoutMillis);
 
 protected:
-    void timerEvent(QTimerEvent *timerEvent);
+    void timerEvent(QTimerEvent* timerEvent);
 
 private:
     QBasicTimer timer;
 };
 
 }  // namespace U2
-
-#endif
