@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -33,8 +33,6 @@ static QBitArray getBinary();
 static QByteArray getUpperCaseMap();
 static QByteArray getLowerCaseMap();
 static QByteArray getSpaceLine();
-static QBitArray getLessThan();
-static QBitArray getGreaterThan();
 static QBitArray getQualNameAllowedSymbols();
 
 const QBitArray TextUtils::ALPHAS = getAlphas();
@@ -46,8 +44,6 @@ const QBitArray TextUtils::BINARY = getBinary();
 const QByteArray TextUtils::UPPER_CASE_MAP = getUpperCaseMap();
 const QByteArray TextUtils::LOWER_CASE_MAP = getLowerCaseMap();
 const QByteArray TextUtils::SPACE_LINE = getSpaceLine();
-const QBitArray TextUtils::LESS_THAN = getLessThan();
-const QBitArray TextUtils::GREATER_THAN = getGreaterThan();
 const QBitArray TextUtils::QUALIFIER_NAME_CHARS = getAlphas() | getNums() | getQualNameAllowedSymbols();
 
 // TODO: optimize shared data structs access! -> replace it with arrays with bounds checking in debug
@@ -58,7 +54,7 @@ static QBitArray getEmptyBitMap() {
 
 static QBitArray getQualNameAllowedSymbols() {
     QBitArray res = getEmptyBitMap();
-    res['-'] = res['\''] = res['_'] = res['*'] = true;
+    res['-'] = res['\''] = res['_'] = res['*'] = res['%'] = true;
     return res;
 }
 
@@ -101,25 +97,13 @@ QBitArray getLines() {
     return res;
 }
 
-QBitArray getLessThan() {
-    QBitArray res = getEmptyBitMap();
-    res['<'] = true;
-    return res;
-}
-
-QBitArray getGreaterThan() {
-    QBitArray res = getEmptyBitMap();
-    res['>'] = true;
-    return res;
-}
-
 QBitArray TextUtils::createBitMap(char c1) {
     QBitArray res = getEmptyBitMap();
     res[quint8(c1)] = true;
     return res;
 }
 
-QBitArray TextUtils::createBitMap(const QByteArray &chars, bool val) {
+QBitArray TextUtils::createBitMap(const QByteArray& chars, bool val) {
     QBitArray res = getEmptyBitMap();
     for (int i = 0, n = chars.size(); i < n; i++) {
         char c = chars[i];
@@ -128,7 +112,7 @@ QBitArray TextUtils::createBitMap(const QByteArray &chars, bool val) {
     return res;
 }
 
-QByteArray TextUtils::createMap(const QBitArray &bits, char defaultChar) {
+QByteArray TextUtils::createMap(const QBitArray& bits, char defaultChar) {
     assert(bits.size() == 256);
     QByteArray res(256, 0);
     for (int i = 0; i < 256; i++) {
@@ -161,13 +145,18 @@ static QByteArray getLowerCaseMap() {
     return b;
 }
 
+/**
+ * Returns array of spaces with a length of 4K+1 ending with 0 (the last byte).
+ * The constData() method from the returned array can be safely used as a 0-terminated 1-byte string of length 4k.
+ */
 static QByteArray getSpaceLine() {
-    QByteArray res(4096, ' ');
-    res[4096] = '\0';
+    int spaceCount = 4096;
+    QByteArray res(spaceCount + 1, ' ');
+    res[spaceCount] = '\0';
     return res;
 }
 
-QString TextUtils::variate(const QString &prefix, const QString &sep, const QSet<QString> &filter, bool mustHaveSuffix, int startSeed) {
+QString TextUtils::variate(const QString& prefix, const QString& sep, const QSet<QString>& filter, bool mustHaveSuffix, int startSeed) {
     int seed = startSeed;
     QString res = prefix;
     if (!mustHaveSuffix && !filter.contains(res) && !res.isEmpty()) {
@@ -179,7 +168,7 @@ QString TextUtils::variate(const QString &prefix, const QString &sep, const QSet
     return res;
 }
 
-QByteArray TextUtils::cutByteOrderMarks(const QByteArray &data, QString &errorMessage) {
+QByteArray TextUtils::cutByteOrderMarks(const QByteArray& data, QString& errorMessage) {
     QTextStream textStream(data);
     textStream.setGenerateByteOrderMark(false);
     QByteArray resultData = textStream.readAll().toLocal8Bit();
@@ -190,7 +179,7 @@ QByteArray TextUtils::cutByteOrderMarks(const QByteArray &data, QString &errorMe
     return resultData;
 }
 
-qint64 TextUtils::cutByteOrderMarks(char *data, QString &errorMessage, qint64 buffLen) {
+qint64 TextUtils::cutByteOrderMarks(char* data, QString& errorMessage, qint64 buffLen) {
     CHECK(buffLen != 0, 0);
 
     QByteArray byteArrayData = buffLen != -1 ? QByteArray(data, buffLen) : QByteArray(data);
@@ -203,7 +192,7 @@ qint64 TextUtils::cutByteOrderMarks(char *data, QString &errorMessage, qint64 bu
     return result;
 }
 
-QStringList TextUtils::split(const QString &text, int chunkSize) {
+QStringList TextUtils::split(const QString& text, int chunkSize) {
     if (text.length() < chunkSize) {
         return {text};
     }
@@ -214,7 +203,7 @@ QStringList TextUtils::split(const QString &text, int chunkSize) {
     return result;
 }
 
-QList<QByteArray> TextUtils::split(const QByteArray &text, int chunkSize) {
+QList<QByteArray> TextUtils::split(const QByteArray& text, int chunkSize) {
     if (text.length() < chunkSize) {
         return {text};
     }
@@ -225,7 +214,7 @@ QList<QByteArray> TextUtils::split(const QByteArray &text, int chunkSize) {
     return result;
 }
 
-void TextUtils::replace(QString &text, const QBitArray &latin1CharCodeMap, QChar replacementChar) {
+void TextUtils::replace(QString& text, const QBitArray& latin1CharCodeMap, QChar replacementChar) {
     for (int i = 0; i < text.length(); i++) {
         uchar latin1Char = text.at(i).toLatin1();
         if (latin1CharCodeMap.at(latin1Char)) {
@@ -234,23 +223,41 @@ void TextUtils::replace(QString &text, const QBitArray &latin1CharCodeMap, QChar
     }
 }
 
-QString TextUtils::readFirstLine(const QString &text) {
+QString TextUtils::readFirstLine(const QString& text) {
     QString textCopy = text;
     QTextStream stream(&textCopy);
     return stream.readLine();
 }
 
-bool TextUtils::isLineBreak(const QString &text, int charIndex) {
+bool TextUtils::isLineBreak(const QString& text, int charIndex) {
     uchar bitIndex = uchar((text.at(charIndex).toLatin1()));
     return LINE_BREAKS.testBit(bitIndex);
 }
 
-bool TextUtils::isWhiteSpace(const QString &text, int charIndex) {
+bool TextUtils::isWhiteSpace(const QString& text, int charIndex) {
     uchar bitIndex = uchar((text.at(charIndex).toLatin1()));
     return WHITES.testBit(bitIndex);
 }
 
-QString TextUtils::skip(const QBitArray &map, const QString &text) {
+bool TextUtils::isWhiteSpace(const QString& text) {
+    for (int i = 0; i < text.length(); i++) {
+        if (!isWhiteSpace(text, i)) {
+            return false;
+        }
+    }
+    return true;
+}
+
+int TextUtils::findIndexOfFirstWhiteSpace(const QString& text) {
+    for (int i = 0; i < text.length(); i++) {
+        if (isWhiteSpace(text, i)) {
+            return i;
+        }
+    }
+    return -1;
+}
+
+QString TextUtils::skip(const QBitArray& map, const QString& text) {
     for (int i = 0, n = text.length(); i < n; i++) {
         uchar c = uchar(text[i].toLatin1());
         if (!map.testBit(c)) {
@@ -260,4 +267,12 @@ QString TextUtils::skip(const QBitArray &map, const QString &text) {
     return "";
 }
 
+wchar_t* TextUtils::toWideCharsArray(const QString& text) {
+    auto wideCharsText = new wchar_t[text.length() + 1];
+    int unicodeFileNameLength = text.toWCharArray(wideCharsText);
+    wideCharsText[unicodeFileNameLength] = 0;
+    return wideCharsText;
+}
+
+
 }  // namespace U2
