@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_READ_ITERATOR_H_
-#define _U2_ASSEMBLY_READ_ITERATOR_H_
+#pragma once
 
 #include <U2Core/U2Assembly.h>
 
@@ -48,7 +47,7 @@ public:
      * Constructs iterator from raw data and CIGAR model. Iterations can be started
      * form any position using startPos argument.
      */
-    U2AssemblyReadIterator(const QByteArray &read_, QList<U2CigarToken> cigar_, int startPos = 0);
+    U2AssemblyReadIterator(const QByteArray& read_, QList<U2CigarToken> cigar_, int startPos = 0);
 
     /**
      * Returns true if the next letter is a match (mismatch) or deletion/skip.
@@ -74,7 +73,7 @@ private:
     bool isPaddingOrHardClip() const;
 
     int offsetInRead;
-    const QByteArray &read;
+    const QByteArray& read;
 
     int offsetInToken;
     int offsetInCigar;
@@ -84,4 +83,3 @@ private:
 extern void shortReadIteratorSmokeTest();
 
 }  // namespace U2
-#endif
