@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_UTILS_H_
-#define _U2_ASSEMBLY_UTILS_H_
+#pragma once
 
 #include <U2Core/U2Assembly.h>
 #include <U2Core/U2OpStatus.h>
@@ -48,7 +47,7 @@ public:
         Returns CIGAR operation for the given char, case insensitive
         If failed, error text is stored in 'err'
     */
-    static U2CigarOp char2Cigar(char c, QString &err);
+    static U2CigarOp char2Cigar(char c, QString& err);
 
     /**
         Returns char representation of the given CIGAR op
@@ -60,30 +59,30 @@ public:
         Returns the result as a set of U2CigarTokens.
         If parsing is failed, the fail reason is stored in 'err' parameter
     */
-    static QList<U2CigarToken> parseCigar(const QByteArray &cigarString, QString &err);
+    static QList<U2CigarToken> parseCigar(const QByteArray& cigarString, QString& err);
 
     /**
         Returns string representation of the CIGAR
     */
-    static QByteArray cigar2String(const QList<U2CigarToken> &cigar);
+    static QByteArray cigar2String(const QList<U2CigarToken>& cigar);
 
     /**
         Returns extra read length produced by CIGAR. Can be negative.
     */
-    static qint64 getCigarExtraLength(const QList<U2CigarToken> &cigar);
+    static qint64 getCigarExtraLength(const QList<U2CigarToken>& cigar);
 
     /** Returns read effective length: sequence length + CIGAR */
-    static qint64 getEffectiveReadLength(const U2AssemblyRead &read);
+    static qint64 getEffectiveReadLength(const U2AssemblyRead& read);
 
     /**
         Serializes Coverage Statistics to byte array for storing in dbi attribute
     */
-    static QByteArray serializeCoverageStat(const U2AssemblyCoverageStat &coverageStat);
+    static QByteArray serializeCoverageStat(const U2AssemblyCoverageStat& coverageStat);
 
     /**
         Deserializes Coverage Statistics that was serialized with serializeCoverageStat function
     */
-    static void deserializeCoverageStat(QByteArray data, U2AssemblyCoverageStat &res, U2OpStatus &os);
+    static void deserializeCoverageStat(QByteArray data, U2AssemblyCoverageStat& res, U2OpStatus& os);
 
     /**
         Size of array of cached coverage
@@ -92,5 +91,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
