@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ATTRIBUTE_UTILS_H_
-#define _U2_ATTRIBUTE_UTILS_H_
+#pragma once
 
 #include <U2Core/U2Attribute.h>
 #include <U2Core/U2Type.h>
@@ -44,26 +43,24 @@ private:
     }
 
 public:
-    static U2IntegerAttribute findIntegerAttribute(U2AttributeDbi *adbi, const U2DataId &objectId, const QString &name, U2OpStatus &os);
+    static U2IntegerAttribute findIntegerAttribute(U2AttributeDbi* adbi, const U2DataId& objectId, const QString& name, U2OpStatus& os);
 
-    static U2RealAttribute findRealAttribute(U2AttributeDbi *adbi, const U2DataId &objectId, const QString &name, U2OpStatus &os);
+    static U2RealAttribute findRealAttribute(U2AttributeDbi* adbi, const U2DataId& objectId, const QString& name, U2OpStatus& os);
 
-    static U2ByteArrayAttribute findByteArrayAttribute(U2AttributeDbi *adbi, const U2DataId &objectId, const QString &name, U2OpStatus &os);
+    static U2ByteArrayAttribute findByteArrayAttribute(U2AttributeDbi* adbi, const U2DataId& objectId, const QString& name, U2OpStatus& os);
 
-    static U2StringAttribute findStringAttribute(U2AttributeDbi *adbi, const U2DataId &objectId, const QString &name, U2OpStatus &os);
+    static U2StringAttribute findStringAttribute(U2AttributeDbi* adbi, const U2DataId& objectId, const QString& name, U2OpStatus& os);
 
     /** Calls 'findStringAttribute(dbi, objectId, name, os)' using dbi & objectId from object->entityRef. */
-    static U2StringAttribute findStringAttribute(const GObject *object, const QString &name, U2OpStatus &os);
+    static U2StringAttribute findStringAttribute(const GObject* object, const QString& name, U2OpStatus& os);
 
-    static void init(U2Attribute &attr, const U2Object &obj, const QString &name);
+    static void init(U2Attribute& attr, const U2Object& obj, const QString& name);
 
-    static void removeAttribute(U2AttributeDbi *adbi, const U2DataId &attrId, U2OpStatus &os);
+    static void removeAttribute(U2AttributeDbi* adbi, const U2DataId& attrId, U2OpStatus& os);
 
-    static void copyObjectAttributes(const U2DataId &srcObjId, const U2DataId &dstObjId, U2AttributeDbi *srcAttributeDbi, U2AttributeDbi *dstAttributeDbi, U2OpStatus &os);
+    static void copyObjectAttributes(const U2DataId& srcObjId, const U2DataId& dstObjId, U2AttributeDbi* srcAttributeDbi, U2AttributeDbi* dstAttributeDbi, U2OpStatus& os);
 
-    static void copyObjectAttributes(const U2EntityRef &srcObjRef, const U2EntityRef &dstObjRef, U2OpStatus &os);
+    static void copyObjectAttributes(const U2EntityRef& srcObjRef, const U2EntityRef& dstObjRef, U2OpStatus& os);
 };
 
 }  // namespace U2
-
-#endif
