@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DBI_UPGRADER_H_
-#define _U2_DBI_UPGRADER_H_
+#pragma once
 
 #include <U2Core/Version.h>
 
@@ -30,12 +29,12 @@ class U2OpStatus;
 
 class U2CORE_EXPORT U2DbiUpgrader {
 public:
-    U2DbiUpgrader(const Version &versionFrom, const Version &versionTo);
+    U2DbiUpgrader(const Version& versionFrom, const Version& versionTo);
     virtual ~U2DbiUpgrader();
 
-    virtual void upgrade(U2OpStatus &os) const = 0;
-    bool isAppliable(const Version &dbVersion) const;
-    bool operator<(const U2DbiUpgrader &other) const;
+    virtual void upgrade(U2OpStatus& os) const = 0;
+    bool isApplicable(const Version& dbVersion) const;
+    bool operator<(const U2DbiUpgrader& other) const;
 
 protected:
     const Version versionFrom;
@@ -43,5 +42,3 @@ protected:
 };
 
 }  // namespace U2
-
-#endif  // _U2_DBI_UPGRADER_H_
