@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OBJECT_TYPE_UTILS_H_
-#define _U2_OBJECT_TYPE_UTILS_H_
+#pragma once
 
 #include <U2Core/U2IdTypes.h>
 #include <U2Core/U2Type.h>
@@ -29,10 +28,8 @@ namespace U2 {
 
 class U2CORE_EXPORT U2ObjectTypeUtils {
 public:
-    static U2DataType toDataType(const GObjectType &gType);
-    static GObjectType toGObjectType(const U2DataType &dbType);
+    static U2DataType toDataType(const GObjectType& gType);
+    static GObjectType toGObjectType(const U2DataType& dbType);
 };
 
 }  // namespace U2
-
-#endif  // _U2_OBJECT_TYPE_UTILS_H_
