@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OPSTATUS_UTILS_H_
-#define _U2_OPSTATUS_UTILS_H_
+#pragma once
 
 #include <U2Core/Log.h>
 #include <U2Core/U2OpStatus.h>
@@ -55,7 +54,7 @@ public:
     }
 #endif
 
-    virtual void setError(const QString &err) {
+    virtual void setError(const QString& err) {
         error = err;
     }
     virtual QString getError() const {
@@ -85,20 +84,20 @@ public:
     virtual QString getDescription() const {
         return statusDesc;
     }
-    virtual void setDescription(const QString &desc) {
+    virtual void setDescription(const QString& desc) {
         statusDesc = desc;
     }
 
     virtual bool hasWarnings() const {
         return !warnings.isEmpty();
     }
-    virtual void addWarning(const QString &w) {
+    virtual void addWarning(const QString& w) {
         warnings << w;
     }
     virtual QStringList getWarnings() const {
         return warnings;
     }
-    virtual void addWarnings(const QStringList &wList) {
+    virtual void addWarnings(const QStringList& wList) {
         warnings << wList;
     }
 
@@ -137,7 +136,7 @@ public:
     U2OpStatus2Log(LogLevel l = LogLevel_ERROR)
         : level(l) {
     }
-    virtual void setError(const QString &err) {
+    virtual void setError(const QString& err) {
         U2OpStatusImpl::setError(err);
         coreLog.message(level, err);
     }
@@ -157,10 +156,10 @@ public:
 
 class U2OpStatusChildImpl : public U2OpStatusImpl {
 public:
-    U2OpStatusChildImpl(U2OpStatus *_parent = 0, const U2OpStatusMapping &_mapping = U2OpStatusMapping(0, 100))
+    U2OpStatusChildImpl(U2OpStatus* _parent = 0, const U2OpStatusMapping& _mapping = U2OpStatusMapping(0, 100))
         : parent(_parent), mapping(_mapping) {
     }
-    virtual void setError(const QString &err) {
+    virtual void setError(const QString& err) {
         parent->setError(err);
         error = err;
     }
@@ -182,16 +181,14 @@ public:
         progress = v;
     }
 
-    virtual void setDescription(const QString &desc) {
+    virtual void setDescription(const QString& desc) {
         parent->setDescription(desc);
         statusDesc = desc;
     }
 
 private:
-    U2OpStatus *parent;
+    U2OpStatus* parent;
     U2OpStatusMapping mapping;
 };
 
 }  // namespace U2
-
-#endif
