@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@
 #include "U2SequenceUtils.h"
 
 #include <QApplication>
+#include <QScopedPointer>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/DNASequenceObject.h>
@@ -43,20 +44,20 @@ namespace U2 {
 const QString U2SequenceDbiHints::UPDATE_SEQUENCE_LENGTH = "update-length";
 const QString U2SequenceDbiHints::EMPTY_SEQUENCE = "empty-sequence";
 
-DNAAlphabetType U2SequenceUtils::alphabetType(const U2EntityRef &ref, U2OpStatus &os) {
+DNAAlphabetType U2SequenceUtils::alphabetType(const U2EntityRef& ref, U2OpStatus& os) {
     DNAAlphabetType res = DNAAlphabet_RAW;
     DbiConnection con(ref.dbiRef, os);
 
     U2Sequence seq = con.dbi->getSequenceDbi()->getSequenceObject(ref.entityId, os);
     CHECK_OP(os, res);
 
-    const DNAAlphabet *al = AppContext::getDNAAlphabetRegistry()->findById(seq.alphabet.id);
+    const DNAAlphabet* al = AppContext::getDNAAlphabetRegistry()->findById(seq.alphabet.id);
     CHECK_EXT(al != nullptr, os.setError(tr("Alphabet is not found!")), res);
 
     return al->getType();
 }
 
-qint64 U2SequenceUtils::length(const U2EntityRef &ref, U2OpStatus &os) {
+qint64 U2SequenceUtils::length(const U2EntityRef& ref, U2OpStatus& os) {
     DbiConnection con(ref.dbiRef, os);
 
     U2Sequence seq = con.dbi->getSequenceDbi()->getSequenceObject(ref.entityId, os);
@@ -65,7 +66,7 @@ qint64 U2SequenceUtils::length(const U2EntityRef &ref, U2OpStatus &os) {
     return seq.length;
 }
 
-U2Sequence U2SequenceUtils::copySequence(const DNASequence &srcSeq, const U2DbiRef &dstDbi, const QString &dstFolder, U2OpStatus &os) {
+U2Sequence U2SequenceUtils::copySequence(const DNASequence& srcSeq, const U2DbiRef& dstDbi, const QString& dstFolder, U2OpStatus& os) {
     U2Sequence res;
     // TODO: ClustalW format does not assign sequence alphabets!
     res.alphabet = srcSeq.alphabet == nullptr ? nullptr : srcSeq.alphabet->getId();
@@ -92,13 +93,13 @@ U2Sequence U2SequenceUtils::copySequence(const DNASequence &srcSeq, const U2DbiR
     return res;
 }
 
-U2Sequence U2SequenceUtils::copySequence(const U2EntityRef &srcSeq, const U2DbiRef &dstDbi, const QString &dstFolder, U2OpStatus &os) {
+U2Sequence U2SequenceUtils::copySequence(const U2EntityRef& srcSeq, const U2DbiRef& dstDbi, const QString& dstFolder, U2OpStatus& os) {
     U2Sequence res;
     DbiConnection srcCon(srcSeq.dbiRef, os);
     CHECK_OP(os, res);
 
-    U2SequenceDbi *srcSeqDbi = srcCon.dbi->getSequenceDbi();
-    SAFE_POINT_EXT(nullptr != srcSeqDbi, os.setError(tr("Invalid sequence DBI")), res);
+    U2SequenceDbi* srcSeqDbi = srcCon.dbi->getSequenceDbi();
+    SAFE_POINT_EXT(srcSeqDbi != nullptr, os.setError("Invalid sequence DBI"), res);
     U2Sequence seq = srcSeqDbi->getSequenceObject(srcSeq.entityId, os);
     CHECK_OP(os, res);
 
@@ -113,8 +114,8 @@ U2Sequence U2SequenceUtils::copySequence(const U2EntityRef &srcSeq, const U2DbiR
 
     DbiConnection dstCon(dstDbi, os);
     CHECK_OP(os, res);
-    U2SequenceDbi *dstSeqDbi = dstCon.dbi->getSequenceDbi();
-    SAFE_POINT_EXT(nullptr != dstSeqDbi, os.setError(tr("Invalid sequence DBI")), res);
+    U2SequenceDbi* dstSeqDbi = dstCon.dbi->getSequenceDbi();
+    SAFE_POINT_EXT(dstSeqDbi != nullptr, os.setError("Invalid sequence DBI"), res);
     dstSeqDbi->createSequenceObject(res, dstFolder, os);
     CHECK_OP(os, res);
 
@@ -141,11 +142,11 @@ U2Sequence U2SequenceUtils::copySequence(const U2EntityRef &srcSeq, const U2DbiR
     return res;
 }
 
-void U2SequenceUtils::updateSequenceName(const U2EntityRef &entityRef, const QString &newName, U2OpStatus &os) {
+void U2SequenceUtils::updateSequenceName(const U2EntityRef& entityRef, const QString& newName, U2OpStatus& os) {
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, );
 
-    U2SequenceDbi *sequenceDbi = con.dbi->getSequenceDbi();
+    U2SequenceDbi* sequenceDbi = con.dbi->getSequenceDbi();
     U2Sequence sequenceObject = sequenceDbi->getSequenceObject(entityRef.entityId, os);
     CHECK_OP(os, );
     if (sequenceObject.visualName != newName) {
@@ -154,12 +155,12 @@ void U2SequenceUtils::updateSequenceName(const U2EntityRef &entityRef, const QSt
     }
 }
 
-static QList<QByteArray> _extractRegions(const U2EntityRef &seqRef, const QVector<U2Region> &regions, const DNATranslation *complTT, U2OpStatus &os) {
+static QList<QByteArray> _extractRegions(const U2EntityRef& seqRef, const QVector<U2Region>& regions, const DNATranslation* complTT, U2OpStatus& os) {
     QList<QByteArray> res;
 
     DbiConnection con(seqRef.dbiRef, os);
     CHECK_OP(os, res);
-    U2SequenceDbi *seqDbi = con.dbi->getSequenceDbi();
+    U2SequenceDbi* seqDbi = con.dbi->getSequenceDbi();
     U2Sequence seq = seqDbi->getSequenceObject(seqRef.entityId, os);
     CHECK_OP(os, res);
 
@@ -167,7 +168,7 @@ static QList<QByteArray> _extractRegions(const U2EntityRef &seqRef, const QVecto
     U2Region::bound(0, seq.length, safeLocation);
 
     for (int i = 0, n = safeLocation.size(); i < n; i++) {
-        const U2Region &oReg = safeLocation.at(i);
+        const U2Region& oReg = safeLocation.at(i);
         if (complTT == nullptr) {
             QByteArray part = seqDbi->getSequenceData(seq.id, U2Region(oReg.startPos, oReg.length), os);
             CHECK_OP(os, QList<QByteArray>());
@@ -183,20 +184,20 @@ static QList<QByteArray> _extractRegions(const U2EntityRef &seqRef, const QVecto
     return res;
 }
 
-QList<QByteArray> U2SequenceUtils::extractRegions(const U2EntityRef &seqRef, const QVector<U2Region> &origLocation, const DNATranslation *complTT, const DNATranslation *aminoTT, bool join, U2OpStatus &os) {
+QList<QByteArray> U2SequenceUtils::extractRegions(const U2EntityRef& seqRef, const QVector<U2Region>& origLocation, const DNATranslation* complTT, const DNATranslation* aminoTT, bool join, U2OpStatus& os) {
     QList<QByteArray> res = _extractRegions(seqRef, origLocation, complTT, os);
     CHECK_OP(os, res)
 
     DbiConnection con(seqRef.dbiRef, os);
     CHECK_OP(os, res);
 
-    U2SequenceDbi *seqDbi = con.dbi->getSequenceDbi();
+    U2SequenceDbi* seqDbi = con.dbi->getSequenceDbi();
     U2Sequence seq = seqDbi->getSequenceObject(seqRef.entityId, os);
     CHECK_OP(os, res);
 
     if (seq.circular && res.size() > 1) {
-        const U2Region &firstL = origLocation.first();
-        const U2Region &lastL = origLocation.last();
+        const U2Region& firstL = origLocation.first();
+        const U2Region& lastL = origLocation.last();
         if (firstL.startPos == 0 && lastL.endPos() == seq.length) {
             QByteArray lastS = res.last();
             QByteArray firstS = res.first();
@@ -217,11 +218,11 @@ QList<QByteArray> U2SequenceUtils::extractRegions(const U2EntityRef &seqRef, con
     return res;
 }
 
-U2EntityRef U2SequenceUtils::import(U2OpStatus &os, const U2DbiRef &dbiRef, const DNASequence &seq, const U2AlphabetId &alphabetId) {
+U2EntityRef U2SequenceUtils::import(U2OpStatus& os, const U2DbiRef& dbiRef, const DNASequence& seq, const U2AlphabetId& alphabetId) {
     return import(os, dbiRef, U2ObjectDbi::ROOT_FOLDER, seq, alphabetId);
 }
 
-U2EntityRef U2SequenceUtils::import(U2OpStatus &os, const U2DbiRef &dbiRef, const QString &folder, const DNASequence &seq, const U2AlphabetId &alphabetId) {
+U2EntityRef U2SequenceUtils::import(U2OpStatus& os, const U2DbiRef& dbiRef, const QString& folder, const DNASequence& seq, const U2AlphabetId& alphabetId) {
     U2EntityRef res;
     U2SequenceImporter i;
 
@@ -245,7 +246,7 @@ U2EntityRef U2SequenceUtils::import(U2OpStatus &os, const U2DbiRef &dbiRef, cons
     return res;
 }
 
-void U2SequenceUtils::setQuality(const U2EntityRef &entityRef, const DNAQuality &q) {
+void U2SequenceUtils::setQuality(const U2EntityRef& entityRef, const DNAQuality& q) {
     U2OpStatus2Log os;
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, );
@@ -270,7 +271,7 @@ void U2SequenceUtils::setQuality(const U2EntityRef &entityRef, const DNAQuality
     CHECK_OP(os, );
 }
 
-void U2SequenceUtils::setSequenceInfo(U2OpStatus &os, const U2EntityRef &entityRef, const QVariantMap &info) {
+void U2SequenceUtils::setSequenceInfo(U2OpStatus& os, const U2EntityRef& entityRef, const QVariantMap& info) {
     DbiConnection con(entityRef.dbiRef, os);
     CHECK_OP(os, );
     QList<U2DataId> chainIdList = con.dbi->getAttributeDbi()->getObjectAttributes(entityRef.entityId, DNAInfo::CHAIN_ID, os);
@@ -302,7 +303,7 @@ void U2SequenceUtils::setSequenceInfo(U2OpStatus &os, const U2EntityRef &entityR
     CHECK_OP(os, );
 }
 
-QVariantMap U2SequenceUtils::getSequenceInfo(U2OpStatus &os, const U2EntityRef &entityRef, const QString &name) {
+QVariantMap U2SequenceUtils::getSequenceInfo(U2OpStatus& os, const U2EntityRef& entityRef, const QString& name) {
     QVariantMap resultingInfo;
     DbiConnection con(entityRef.dbiRef, os);
     QList<U2DataId> chainIdList = con.dbi->getAttributeDbi()->getObjectAttributes(entityRef.entityId, DNAInfo::CHAIN_ID, os);
@@ -348,12 +349,12 @@ QVariantMap U2SequenceUtils::getSequenceInfo(U2OpStatus &os, const U2EntityRef &
     return resultingInfo;
 }
 
-U2Sequence U2SequenceUtils::getSequenceDbInfo(U2SequenceObject *seqObj) {
+U2Sequence U2SequenceUtils::getSequenceDbInfo(U2SequenceObject* seqObj) {
     U2Sequence seq;
 
     seq.id = seqObj->getEntityRef().entityId;
     seq.dbiId = seqObj->getEntityRef().dbiRef.dbiId;
-    if (nullptr != seqObj->getAlphabet()) {
+    if (seqObj->getAlphabet() != nullptr) {
         seq.alphabet.id = seqObj->getAlphabet()->getId();
     }
     seq.circular = seqObj->isCircular();
@@ -372,7 +373,7 @@ U2Sequence U2SequenceUtils::getSequenceDbInfo(U2SequenceObject *seqObj) {
  * then the method verifies the value and returns it (if it is correct).
  * Otherwise, returns NO_CASE_ANNS.
  */
-static CaseAnnotationsMode getCaseAnnotationsModeHint(const QVariantMap &fs) {
+static CaseAnnotationsMode getCaseAnnotationsModeHint(const QVariantMap& fs) {
     if (fs.keys().contains(GObjectHint_CaseAnns)) {
         QVariant caseAnnsVariant = fs.value(GObjectHint_CaseAnns);
         SAFE_POINT(caseAnnsVariant.canConvert<int>(), "Can't convert a case annotations hint!", NO_CASE_ANNS);
@@ -394,7 +395,7 @@ static CaseAnnotationsMode getCaseAnnotationsModeHint(const QVariantMap &fs) {
 const QString U2SequenceImporter::EMPTY_SEQUENCE_ERROR = QApplication::translate("U2SequenceImporter",
                                                                                  "Sequence was not imported. Probably, this is because the sequence is empty.");
 
-U2SequenceImporter::U2SequenceImporter(const QVariantMap &fs, bool lazyMode, bool singleThread)
+U2SequenceImporter::U2SequenceImporter(const QVariantMap& fs, bool lazyMode, bool singleThread)
     : lazyMode(lazyMode), singleThread(singleThread), sequenceCreated(false) {
     insertBlockSize = DEFAULT_SEQUENCE_INSERT_BLOCK_SIZE;
     currentLength = 0;
@@ -404,7 +405,7 @@ U2SequenceImporter::U2SequenceImporter(const QVariantMap &fs, bool lazyMode, boo
     committedLength = 0;
 }
 
-U2SequenceImporter::U2SequenceImporter(qint64 _insertBlockSize, const QVariantMap &fs, bool lazyMode, bool singleThread)
+U2SequenceImporter::U2SequenceImporter(qint64 _insertBlockSize, const QVariantMap& fs, bool lazyMode, bool singleThread)
     : insertBlockSize(_insertBlockSize), lazyMode(lazyMode), singleThread(singleThread) {
     insertBlockSize = qMin((qint64)10, insertBlockSize);
     currentLength = 0;
@@ -422,12 +423,22 @@ U2SequenceImporter::~U2SequenceImporter() {
     }
 }
 
-void U2SequenceImporter::startSequence(U2OpStatus &os,
-                                       const U2DbiRef &dbiRef,
-                                       const QString &dstFolder,
-                                       const QString &visualName,
+void U2SequenceImporter::enableAminoTranslation(const DNATranslation* newAminoTT) {
+    SAFE_POINT(!sequenceCreated, "enableAminoTranslation can be set only during initialization", );
+    this->aminoTT = newAminoTT;
+}
+
+void U2SequenceImporter::enableReverseComplement(const DNATranslation* newComplTT) {
+    SAFE_POINT(!sequenceCreated, "enableReverseComplement can be set only during initialization", );
+    this->complTT = newComplTT;
+}
+
+void U2SequenceImporter::startSequence(U2OpStatus& os,
+                                       const U2DbiRef& dbiRef,
+                                       const QString& dstFolder,
+                                       const QString& visualName,
                                        bool circular,
-                                       const U2AlphabetId &alphabetId) {
+                                       const U2AlphabetId& alphabetId) {
     SAFE_POINT(!con.isOpen(), "Connection is already opened!", );
     con.open(dbiRef, true, os);
     CHECK_OP(os, );
@@ -443,6 +454,8 @@ void U2SequenceImporter::startSequence(U2OpStatus &os,
     isUnfinishedRegion = false;
     annList.clear();
 
+    alphabetCharacterHit.reset();
+
     if (!lazyMode) {
         con.dbi->getSequenceDbi()->createSequenceObject(sequence, folder, os);
         CHECK_OP(os, );
@@ -450,24 +463,19 @@ void U2SequenceImporter::startSequence(U2OpStatus &os,
     }
 }
 
-void U2SequenceImporter::addBlock(const char *data, qint64 len, U2OpStatus &os) {
-    // derive common alphabet
-    const DNAAlphabet *blockAl = U2AlphabetUtils::findBestAlphabet(data, len);
-    CHECK_EXT(blockAl != nullptr, os.setError("Failed to match sequence alphabet!"), );
-
-    const DNAAlphabet *oldAl = U2AlphabetUtils::getById(sequence.alphabet);
-    const DNAAlphabet *resAl = blockAl;
-    if (oldAl != nullptr) {
-        if (oldAl->getType() == DNAAlphabet_AMINO && resAl->getType() == DNAAlphabet_NUCL) {
-            resAl = oldAl;
-        } else if (resAl->getType() == DNAAlphabet_AMINO && oldAl->getType() == DNAAlphabet_NUCL) {
-            oldAl = resAl;
-        } else {
-            resAl = U2AlphabetUtils::deriveCommonAlphabet(blockAl, oldAl);
-        }
-        CHECK_EXT(resAl != nullptr, os.setError(U2SequenceUtils::tr("Failed to derive sequence alphabet!")), );
+void U2SequenceImporter::addBlock(const char* data, qint64 len, U2OpStatus& os) {
+    CHECK(len > 0, );
+    for (int i = 0; i < len; i++) {
+        alphabetCharacterHit.set((unsigned char)data[i], true);
     }
-
+    QByteArray bytes;
+    for (size_t i = 0; i < alphabetCharacterHit.size(); i++) {
+        if (alphabetCharacterHit[i]) {
+            bytes.append(i);
+        }
+    }
+    const DNAAlphabet* resAl = U2AlphabetUtils::findBestAlphabet(bytes);
+    CHECK_EXT(resAl != nullptr, os.setError("Failed to match sequence alphabet!"), );
     if (resAl != U2AlphabetUtils::getById(sequence.alphabet)) {
         sequence.alphabet.id = resAl->getId();
         if (sequenceCreated) {
@@ -484,7 +492,7 @@ void U2SequenceImporter::addBlock(const char *data, qint64 len, U2OpStatus &os)
     currentLength += len;
 }
 
-void U2SequenceImporter::addSequenceBlock(const U2EntityRef &sequenceRef, const U2Region &r, U2OpStatus &os) {
+void U2SequenceImporter::addSequenceBlock(const U2EntityRef& sequenceRef, const U2Region& r, U2OpStatus& os) {
     _addBuffer2Db(os);
     CHECK_OP(os, );
     DbiConnection con(sequenceRef.dbiRef, os);
@@ -496,10 +504,10 @@ void U2SequenceImporter::addSequenceBlock(const U2EntityRef &sequenceRef, const
     addBlock(arr.constData(), arr.size(), os);
 }
 
-void U2SequenceImporter::addDefaultSymbolsBlock(int n, U2OpStatus &os) {
+void U2SequenceImporter::addDefaultSymbolsBlock(int n, U2OpStatus& os) {
     SAFE_POINT(n >= 0, QString("Invalid number of symbols: %1").arg(n), );
-    const DNAAlphabet *al = AppContext::getDNAAlphabetRegistry()->findById(sequence.alphabet.id);
-    if (nullptr == al) {
+    const DNAAlphabet* al = AppContext::getDNAAlphabetRegistry()->findById(sequence.alphabet.id);
+    if (al == nullptr) {
         os.setError(QObject::tr("Unable to detect sequence alphabet. Probably, this is because some of merged sequences are empty."));
         return;
     }
@@ -509,18 +517,66 @@ void U2SequenceImporter::addDefaultSymbolsBlock(int n, U2OpStatus &os) {
     currentLength += n;
 }
 
-void U2SequenceImporter::_addBlock2Buffer(const char *data, qint64 len, U2OpStatus &os) {
-    if (len + sequenceBuffer.length() < insertBlockSize) {
-        sequenceBuffer.append(data, len);
+void U2SequenceImporter::_addBlock2Buffer(const char* data, qint64 dataLength, U2OpStatus& os) {
+    CHECK(dataLength > 0, );
+    const char* newBlock = data;
+    int newBlockLength = (int)dataLength;
+
+    QScopedPointer<QByteArray> complBlockPointer;  // container of the reverse-complementary block sequence.
+    if (complTT != nullptr) {
+        complBlockPointer.reset(new QByteArray(newBlockLength, Qt::Uninitialized));
+        char* revComplBlock = complBlockPointer->data();
+        TextUtils::reverse(newBlock, revComplBlock, newBlockLength);
+        complTT->translate(revComplBlock, newBlockLength);
+        newBlock = revComplBlock;
+    }
+
+    QScopedPointer<QByteArray> aminoBlockPointer;  // container of the translated block sequence.
+    if (aminoTT != nullptr) {
+        if (newBlockLength + aminoTranslationBuffer.size() < 3) {
+            aminoTranslationBuffer.append(newBlock, newBlockLength);
+            return;
+        }
+        const char* const dnaBlock = newBlock;
+        aminoBlockPointer.reset(new QByteArray(newBlockLength / 3 + 1, Qt::Uninitialized));
+        char* aminoBlock = aminoBlockPointer->data();
+        int remainingDnaBlockLength = newBlockLength;
+        int dnaBlockOffset = 0;
+        bool hasCharFromAminoBuffer = false;
+        // Finish the pending block first.
+        if (!aminoTranslationBuffer.isEmpty()) {
+            SAFE_POINT(aminoTranslationBuffer.length() <= 2, "Invalid size of aminoTranslationBuffer", );
+            hasCharFromAminoBuffer = true;
+            dnaBlockOffset = 3 - aminoTranslationBuffer.size();
+            aminoTranslationBuffer.append(dnaBlock, dnaBlockOffset);
+            aminoTT->translate(aminoTranslationBuffer.constData(), 3, aminoBlock, 1);
+            aminoBlockPointer->append(dnaBlock, 1);
+            remainingDnaBlockLength -= dnaBlockOffset;
+            aminoTranslationBuffer.clear();
+        }
+        int aminoBlockLength = remainingDnaBlockLength / 3;
+        aminoTT->translate(dnaBlock + dnaBlockOffset, remainingDnaBlockLength, aminoBlock + (hasCharFromAminoBuffer ? 1 : 0), aminoBlockLength);
+        remainingDnaBlockLength = remainingDnaBlockLength % 3;
+
+        newBlock = aminoBlock;
+        newBlockLength = (hasCharFromAminoBuffer ? 1 : 0) + aminoBlockLength;
+
+        if (remainingDnaBlockLength != 0) {
+            aminoTranslationBuffer.append(dnaBlock + dataLength - remainingDnaBlockLength, remainingDnaBlockLength);
+        }
+    }
+
+    if (newBlockLength + sequenceBuffer.length() < insertBlockSize) {
+        sequenceBuffer.append(newBlock, newBlockLength);
         return;
     }
     _addBlock2Db(sequenceBuffer.data(), sequenceBuffer.length(), os);
     CHECK_OP(os, );
     sequenceBuffer.clear();
-    _addBlock2Db(data, len, os);
+    _addBlock2Db(newBlock, newBlockLength, os);
 }
 
-void U2SequenceImporter::_addBlock2Db(const char *data, qint64 len, U2OpStatus &os) {
+void U2SequenceImporter::_addBlock2Db(const char* data, qint64 len, U2OpStatus& os) {
     SAFE_POINT(len >= 0, "Illegal block length!", );
     if (len == 0) {
         return;
@@ -562,13 +618,13 @@ void U2SequenceImporter::_addBlock2Db(const char *data, qint64 len, U2OpStatus &
     committedLength += len;
 }
 
-void U2SequenceImporter::_addBuffer2Db(U2OpStatus &os) {
+void U2SequenceImporter::_addBuffer2Db(U2OpStatus& os) {
     CHECK(!sequenceBuffer.isEmpty(), );
     _addBlock2Db(sequenceBuffer.data(), sequenceBuffer.length(), os);
     sequenceBuffer.clear();
 }
 
-U2Sequence U2SequenceImporter::finalizeSequence(U2OpStatus &os) {
+U2Sequence U2SequenceImporter::finalizeSequence(U2OpStatus& os) {
     _addBuffer2Db(os);
     LOG_OP(os);
     // If sequence is empty, addBlock is never called and alphabet is not set. So set it here to some default value
@@ -582,7 +638,7 @@ U2Sequence U2SequenceImporter::finalizeSequence(U2OpStatus &os) {
         annList << U1AnnotationUtils::finalizeUnfinishedRegion(isUnfinishedRegion, unfinishedRegion, LOWER_CASE == caseAnnsMode);
 
         if (1 == annList.size()) {
-            const QVector<U2Region> &regs = annList.first()->getRegions();
+            const QVector<U2Region>& regs = annList.first()->getRegions();
             if (1 == regs.size()) {
                 U2Region reg = regs.first();
                 if (0 == reg.startPos && sequence.length == reg.length) {
@@ -596,7 +652,7 @@ U2Sequence U2SequenceImporter::finalizeSequence(U2OpStatus &os) {
     return sequence;
 }
 
-U2Sequence U2SequenceImporter::finalizeSequenceAndValidate(U2OpStatus &os) {
+U2Sequence U2SequenceImporter::finalizeSequenceAndValidate(U2OpStatus& os) {
     U2Sequence result = finalizeSequence(os);
     CHECK_OP(os, result);
     if (!result.hasValidId()) {
@@ -613,7 +669,7 @@ bool U2SequenceImporter::isCaseAnnotationsModeOn() const {
     return caseAnnsMode != NO_CASE_ANNS;
 }
 
-QList<SharedAnnotationData> &U2SequenceImporter::getCaseAnnotations() {
+QList<SharedAnnotationData>& U2SequenceImporter::getCaseAnnotations() {
     return annList;
 }
 
@@ -621,18 +677,20 @@ qint64 U2SequenceImporter::getCurrentLength() const {
     return currentLength;
 }
 
-void U2MemorySequenceImporter::addBlock(const char *data, qint64 len, U2OpStatus &os) {
+void U2MemorySequenceImporter::addBlock(const char* data, qint64 len, U2OpStatus& os) {
+    SAFE_POINT(aminoTT == nullptr, "Import with amino translation is not supported by U2MemorySequenceImporter", );
+    SAFE_POINT(complTT == nullptr, "Import with reverse-complementary translation is not supported by U2MemorySequenceImporter", );
     if (qstrlen(data) < len) {
         os.setError("Wrong data length in addBlock");
         return;
     }
 
     // derive common alphabet
-    const DNAAlphabet *blockAl = U2AlphabetUtils::findBestAlphabet(data, len);
+    const DNAAlphabet* blockAl = U2AlphabetUtils::findBestAlphabet(data, len);
     CHECK_EXT(blockAl != nullptr, os.setError("Failed to match sequence alphabet!"), );
 
-    const DNAAlphabet *oldAl = U2AlphabetUtils::getById(sequence.alphabet);
-    const DNAAlphabet *resAl = blockAl;
+    const DNAAlphabet* oldAl = U2AlphabetUtils::getById(sequence.alphabet);
+    const DNAAlphabet* resAl = blockAl;
     if (oldAl != nullptr) {
         if (oldAl->getType() == DNAAlphabet_AMINO && resAl->getType() == DNAAlphabet_NUCL) {
             resAl = oldAl;
@@ -651,8 +709,8 @@ void U2MemorySequenceImporter::addBlock(const char *data, qint64 len, U2OpStatus
     sequenceData.append(data, len);
 }
 
-void U2MemorySequenceImporter::addDefaultSymbolsBlock(int n, U2OpStatus &os) {
-    SAFE_POINT_EXT(n >= 0, os.setError(QObject::tr("Invalid number of symbols: %1").arg(n)), );
+void U2MemorySequenceImporter::addDefaultSymbolsBlock(int n, U2OpStatus& os) {
+    SAFE_POINT_EXT(n >= 0, os.setError(QString("Invalid number of symbols: %1").arg(n)), );
     char defaultChar = U2AlphabetUtils::getDefaultSymbol(sequence.alphabet);
     QByteArray a(n, defaultChar);
 
@@ -663,38 +721,38 @@ qint64 U2MemorySequenceImporter::getCurrentLength() const {
     return sequenceData.length();
 }
 
-U2PseudoCircularization::U2PseudoCircularization(QObject *parent, bool isCircular, QByteArray &seq, qint64 circOverlap)
-    : QObject(parent) {
-    seqLen = seq.size();
-    if (isCircular) {
-        circOverlap = (circOverlap == -1 ? seqLen - 1 : circOverlap);
-        seq.append(QByteArray(seq).left(circOverlap));
+QByteArray U2PseudoCircularization::createSequenceWithCircularOverlaps(const QByteArray& sequence, int maxLinearRegionLength) {
+    int linearRegionLength = maxLinearRegionLength < 0 ? sequence.length() : maxLinearRegionLength;
+    QByteArray result = sequence;
+    result.append(result.left(linearRegionLength));
+    return result;
+}
+
+QVector<U2Region> U2PseudoCircularization::getOriginalSequenceCoordinates(const U2Region& circularRegion, qint64 originalSequenceLength) {
+    SAFE_POINT(circularRegion.endPos() <= originalSequenceLength * 2, "Invalid circular region", {});
+    if (circularRegion.endPos() <= originalSequenceLength) {
+        return {circularRegion};
+    }
+    if (circularRegion.startPos > originalSequenceLength) {
+        return {{circularRegion.startPos - originalSequenceLength, circularRegion.length}};
+    } else {
+        return {
+            {circularRegion.startPos, originalSequenceLength - circularRegion.startPos},
+            {0, circularRegion.endPos() - originalSequenceLength},
+        };
     }
 }
 
-QVector<U2Region> U2PseudoCircularization::uncircularizeRegion(const U2Region &region, bool &uncircularized) const {
-    uncircularized = false;
-    if ((region.startPos >= seqLen && region.endPos() >= seqLen) || (region.length > seqLen)) {  // dublicate
-        return QVector<U2Region>();
-    }
-    if (region.endPos() > seqLen) {
-        uncircularized = true;
-        return QVector<U2Region>() << U2Region(region.startPos, seqLen - region.startPos)
-                                   << U2Region(0, region.endPos() - seqLen);
-    }
-    return QVector<U2Region>() << region;
-}
-
-void U2PseudoCircularization::uncircularizeLocation(U2Location &location) const {
-    QVector<U2Region> res;
-    foreach (const U2Region &r, location->regions) {
-        bool regionWasSplitted = false;
-        res << uncircularizeRegion(r, regionWasSplitted);
-        if (regionWasSplitted) {
+void U2PseudoCircularization::convertToOriginalSequenceCoordinates(U2Location& location, qint64 originalSequenceLength) {
+    QVector<U2Region> regions;
+    for (const U2Region& region : qAsConst(location->regions)) {
+        QVector<U2Region> originalRegions = getOriginalSequenceCoordinates(region, originalSequenceLength);
+        if (originalRegions.length() > 1) {
             location->op = U2LocationOperator_Join;
         }
+        regions << originalRegions;
     }
-    location->regions = res;
+    location->regions = regions;
 }
 
 }  // namespace U2
