@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -18,8 +18,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA 02110-1301, USA.
  */
-#ifndef _U2_VARIATION_PROPERTIES_UTILS_H_
-#define _U2_VARIATION_PROPERTIES_UTILS_H_
+#pragma once
 
 #include <QByteArray>
 #include <QVector>
@@ -37,22 +36,22 @@ namespace U2 {
 assuming that variations are sorted by start pos*/
 class U2CORE_EXPORT SequenceQueryCache {
 public:
-    SequenceQueryCache(U2SequenceDbi *seqDbi, const U2DataId &seqDataId);
-    void setSequenceDbi(U2SequenceDbi *sDbi);
-    void setSequenceId(const U2DataId &seqDataId);
+    SequenceQueryCache(U2SequenceDbi* seqDbi, const U2DataId& seqDataId);
+    void setSequenceDbi(U2SequenceDbi* sDbi);
+    void setSequenceId(const U2DataId& seqDataId);
     void clear();
     U2Region getRegion() {
         return seqRegion;
     }
-    QByteArray getSequenceData(const U2Region &region, U2OpStatus &os);
+    QByteArray getSequenceData(const U2Region& region, U2OpStatus& os);
 
 private:
-    void fetchData(int startPos, U2OpStatus &os);
+    void fetchData(int startPos, U2OpStatus& os);
     const static int OVERLAP_SIZE = 1024;
     const static int SEQ_BUF_SIZE = 1 * 256 * 1024;
     U2Region seqRegion;
     QByteArray seqBuffer;
-    U2SequenceDbi *seqDbi;
+    U2SequenceDbi* seqDbi;
     U2DataId seqId;
 };
 
@@ -60,42 +59,42 @@ private:
 class U2CORE_EXPORT VariationPropertiesUtils {
 public:
     /*Convert damage effect matrix to compressed array*/
-    static QByteArray DamageEffectToArray(const QVector<float> &vect);
+    static QByteArray DamageEffectToArray(const QVector<float>& vect);
 
     /*Convert damage effect compressed array to matrix*/
-    static QVector<float> DamageEffectToVector(const QByteArray &ba);
+    static QVector<float> DamageEffectToVector(const QByteArray& ba);
 
     /*Check if a variation could damage protein of the gene*/
-    static bool isDamageProtein(const U2Variant &var, const Gene &gene);
+    static bool isDamageProtein(const U2Variant& var, const Gene& gene);
 
     /*The function is 'in silico' splicing. It provides start position of Variant in nucl sequence and corresponding codon number after splicing.
     Return true if spliced successfully and false otherwise*/
-    static bool getFrameStartPositionsForCoding(int *nuclSeqPos, int *aaSeqPos, int *codonPos, const U2Variant &var, const Gene &gene);
+    static bool getFrameStartPositionsForCoding(int* nuclSeqPos, int* aaSeqPos, int* codonPos, const U2Variant& var, const Gene& gene);
 
-    static int getFrameStartPosition(const U2Variant &var, const Gene &gene);
+    static int getFrameStartPosition(const U2Variant& var, const Gene& gene);
 
     static QByteArray getSortedAAcidAlphabet();
 
-    static QByteArray getDamagedTriplet(const Gene &gene, int nuclPos, const U2DataId &seqID, U2SequenceDbi *seqDbi, U2OpStatus &os);
+    static QByteArray getDamagedTriplet(const Gene& gene, int nuclPos, const U2DataId& seqID, U2SequenceDbi* seqDbi, U2OpStatus& os);
 
-    static QByteArray getDamagedTripletBufferedSeq(const Gene &gene, int nuclPos, SequenceQueryCache &seqCache, U2OpStatus &os);
+    static QByteArray getDamagedTripletBufferedSeq(const Gene& gene, int nuclPos, SequenceQueryCache& seqCache, U2OpStatus& os);
 
-    static float getDEffectValue(char aa, int aaPos, const QByteArray &compressedMatrix, int matrixLen);
+    static float getDEffectValue(char aa, int aaPos, const QByteArray& compressedMatrix, int matrixLen);
 
-    static QByteArray varyTriplet(const QByteArray &tripl, const U2Variant &var, int codonPos, DNATranslation *complTransl = nullptr);
+    static QByteArray varyTriplet(const QByteArray& tripl, const U2Variant& var, int codonPos, DNATranslation* complTransl = nullptr);
 
-    static QByteArray getCodingSequence(const Gene &gene, const U2DataId &seqId, U2SequenceDbi *dbi, U2OpStatus &os);
+    static QByteArray getCodingSequence(const Gene& gene, const U2DataId& seqId, U2SequenceDbi* dbi, U2OpStatus& os);
 
-    static QByteArray getAASequence(const QByteArray &nuclSeq);
+    static QByteArray getAASequence(const QByteArray& nuclSeq);
 
-    static QPair<QByteArray, QByteArray> getAASubstitution(U2Dbi *database, const Gene &gene, const U2DataId &seqId, const U2Variant &var, int *aaPos, U2OpStatus &os);
+    static QPair<QByteArray, QByteArray> getAASubstitution(U2Dbi* database, const Gene& gene, const U2DataId& seqId, const U2Variant& var, int* aaPos, U2OpStatus& os);
 
-    static inline bool isInDonorSpliceSite(const U2Region &exon, qint64 varPos, int spliceSiteLen) {
+    static inline bool isInDonorSpliceSite(const U2Region& exon, qint64 varPos, int spliceSiteLen) {
         bool res = false;
         res = U2Region(exon.endPos() - spliceSiteLen, 2 * spliceSiteLen).contains(varPos);
         return res;
     }
-    static inline bool isInAcceptorSpliceSite(const U2Region &exon, qint64 varPos, int spliceSiteLen) {
+    static inline bool isInAcceptorSpliceSite(const U2Region& exon, qint64 varPos, int spliceSiteLen) {
         bool res = false;
         res = U2Region(exon.startPos - spliceSiteLen, 2 * spliceSiteLen).contains(varPos);
         return res;
@@ -106,16 +105,14 @@ public:
     otherwise U2_REGION_MAX returned
     if in splice-site nearest exon and is donor/acceptor are set
     else neaarestExon = U2_REGION_MAX*/
-    static U2Region getIntron(const U2Region &geneRegion, const QVector<U2Region> &exons, qint64 varPos, U2Region &nearestExon, bool &isDonor);
+    static U2Region getIntron(const U2Region& geneRegion, const QVector<U2Region>& exons, qint64 varPos, U2Region& nearestExon, bool& isDonor);
 
-    static bool isInSpliceSite(const QVector<U2Region> &exons, qint64 varPos, int spliceSiteLen, bool isCompl);
+    static bool isInSpliceSite(const QVector<U2Region>& exons, qint64 varPos, int spliceSiteLen, bool isCompl);
 
-    static qint64 positionFromTranscriptionStart(const Gene &gene, const U2Variant &var);
+    static qint64 positionFromTranscriptionStart(const Gene& gene, const U2Variant& var);
 
 private:
     static QByteArray aaAlphabet;
 };
 
 }  // namespace U2
-
-#endif  //_U2_VARIATION_PROPERTIES_UTILS_H_
