@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -47,12 +47,10 @@
 
 namespace U2 {
 
-URLListWidget::URLListWidget(URLListController *_ctrl)
+URLListWidget::URLListWidget(URLListController* _ctrl)
     : QWidget(),
       ui(new Ui_DatasetWidget),
-      ctrl(_ctrl),
-      connectToDbDialog(new SharedConnectionsDialog(this)),
-      waitingForDbToConnect(false) {
+      ctrl(_ctrl) {
     ui->setupUi(this);
     popup = new OptionsPopup(this);
 
@@ -66,32 +64,25 @@ URLListWidget::URLListWidget(URLListController *_ctrl)
 
     ui->addFileButton->setIcon(fileIcon);
     ui->addDirButton->setIcon(dirIcon);
-    ui->addFromDbButton->setIcon(dbIcon);
     ui->deleteButton->setIcon(deleteIcon);
     ui->upButton->setIcon(upIcon);
     ui->downButton->setIcon(downIcon);
 
     connect(ui->addFileButton, SIGNAL(clicked()), SLOT(sl_addFileButton()));
     connect(ui->addDirButton, SIGNAL(clicked()), SLOT(sl_addDirButton()));
-    connect(ui->addFromDbButton, SIGNAL(clicked()), SLOT(sl_addFromDbButton()));
     connect(ui->downButton, SIGNAL(clicked()), SLOT(sl_downButton()));
     connect(ui->upButton, SIGNAL(clicked()), SLOT(sl_upButton()));
     connect(ui->deleteButton, SIGNAL(clicked()), SLOT(sl_deleteButton()));
-    connect(connectToDbDialog.data(), SIGNAL(si_connectionCompleted()), SLOT(sl_sharedDbConnected()));
 
     connect(ui->itemsArea, SIGNAL(itemSelectionChanged()), SLOT(sl_itemChecked()));
 
-    if (!readingFromDbIsSupported()) {
-        ui->addFromDbButton->hide();
-    }
-
-    QAction *deleteAction = new QAction(ui->itemsArea);
+    QAction* deleteAction = new QAction(ui->itemsArea);
     deleteAction->setShortcut(QKeySequence::Delete);
     deleteAction->setShortcutContext(Qt::WidgetShortcut);
     connect(deleteAction, SIGNAL(triggered()), SLOT(sl_deleteButton()));
     ui->itemsArea->addAction(deleteAction);
 
-    QAction *selectAction = new QAction(ui->itemsArea);
+    QAction* selectAction = new QAction(ui->itemsArea);
     selectAction->setShortcut(QKeySequence::SelectAll);
     selectAction->setShortcutContext(Qt::WidgetShortcut);
     connect(selectAction, SIGNAL(triggered()), SLOT(sl_selectAll()));
@@ -104,7 +95,7 @@ URLListWidget::~URLListWidget() {
     delete ui;
 }
 
-void URLListWidget::addUrlItem(UrlItem *urlItem) {
+void URLListWidget::addUrlItem(UrlItem* urlItem) {
     urlItem->setParent(ui->itemsArea);
     ui->itemsArea->addItem(urlItem);
     connect(urlItem, SIGNAL(si_dataChanged()), SLOT(sl_dataChanged()));
@@ -118,7 +109,7 @@ void URLListWidget::sl_addFileButton() {
     } else {
         files = U2FileDialog::getOpenFileNames(nullptr, tr("Select file"), lod.dir);
     }
-    for (const QString &file : qAsConst(files)) {
+    for (const QString& file : qAsConst(files)) {
         lod.url = file;
         addUrl(file);
     }
@@ -133,64 +124,7 @@ void URLListWidget::sl_addDirButton() {
     }
 }
 
-namespace {
-
-ProjectTreeControllerModeSettings createProjectTreeSettings(const QSet<GObjectType> &compatibleObjTypes) {
-    ProjectTreeControllerModeSettings settings;
-    settings.objectTypesToShow += compatibleObjTypes;
-
-    Project *proj = AppContext::getProject();
-    SAFE_POINT(nullptr != proj, "Invalid project", settings);
-
-    foreach (Document *doc, proj->getDocuments()) {
-        if (!doc->isDatabaseConnection()) {
-            settings.excludeDocList << doc;
-        }
-    }
-
-    return settings;
-}
-
-}  // namespace
-
-void URLListWidget::sl_sharedDbConnected() {
-    SAFE_POINT(waitingForDbToConnect, "Unexpected database state", );
-    waitingForDbToConnect = false;
-    sl_addFromDbButton();
-}
-
-void URLListWidget::sl_addFromDbButton() {
-    CHECK(!waitingForDbToConnect, );
-    if (!ProjectUtils::areSharedDatabasesAvailable()) {
-        const int dialogResult = connectToDbDialog->exec();
-        CHECK(!connectToDbDialog.isNull(), );
-        if (QDialog::Accepted == dialogResult) {
-            waitingForDbToConnect = true;
-        }
-        return;
-    } else {
-        waitingForDbToConnect = false;
-    }
-
-    const QSet<GObjectType> compatTypes = ctrl->getCompatibleObjTypes();
-    SAFE_POINT(!compatTypes.isEmpty(), "Invalid object types", );
-    const ProjectTreeControllerModeSettings settings = createProjectTreeSettings(compatTypes);
-
-    QList<Folder> folders;
-    QList<GObject *> objects;
-    ProjectTreeItemSelectorDialog::selectObjectsAndFolders(settings, this, folders, objects);
-
-    foreach (const Folder &f, folders) {
-        // FIXME when readers for different data types appear
-        addUrl(SharedDbUrlUtils::createDbFolderUrl(f, U2ObjectTypeUtils::toDataType(*compatTypes.begin())));
-    }
-
-    foreach (GObject *obj, objects) {
-        addUrl(SharedDbUrlUtils::createDbObjectUrl(obj));
-    }
-}
-
-void URLListWidget::addUrl(const QString &url) {
+void URLListWidget::addUrl(const QString& url) {
     U2OpStatusImpl os;
     ctrl->addUrl(url, os);
     if (os.hasError()) {
@@ -216,16 +150,12 @@ void URLListWidget::reset() {
     popup->hideOptions();
 }
 
-bool URLListWidget::readingFromDbIsSupported() const {
-    return !ctrl->getCompatibleObjTypes().isEmpty();
-}
-
 void URLListWidget::sl_downButton() {
     CHECK(ui->itemsArea->selectedItems().size() > 0, );
 
     for (int pos = ui->itemsArea->count() - 2; pos >= 0; pos--) {  // without last item
         if (ui->itemsArea->item(pos)->isSelected()) {
-            QListWidgetItem *item = ui->itemsArea->takeItem(pos);
+            QListWidgetItem* item = ui->itemsArea->takeItem(pos);
             ui->itemsArea->insertItem(pos + 1, item);
             item->setSelected(true);
             ctrl->replaceUrl(pos, pos + 1);
@@ -238,7 +168,7 @@ void URLListWidget::sl_upButton() {
 
     for (int pos = 1; pos < ui->itemsArea->count(); pos++) {  // without first item
         if (ui->itemsArea->item(pos)->isSelected()) {
-            QListWidgetItem *item = ui->itemsArea->takeItem(pos);
+            QListWidgetItem* item = ui->itemsArea->takeItem(pos);
             ui->itemsArea->insertItem(pos - 1, item);
             item->setSelected(true);
             ctrl->replaceUrl(pos, pos - 1);
@@ -247,7 +177,7 @@ void URLListWidget::sl_upButton() {
 }
 
 void URLListWidget::sl_deleteButton() {
-    foreach (QListWidgetItem *item, ui->itemsArea->selectedItems()) {
+    foreach (QListWidgetItem* item, ui->itemsArea->selectedItems()) {
         int pos = ui->itemsArea->row(item);
         ctrl->deleteUrl(pos);
         delete ui->itemsArea->takeItem(pos);
@@ -261,24 +191,24 @@ void URLListWidget::sl_selectAll() {
 }
 
 void URLListWidget::sl_dataChanged() {
-    ctrl->updateUrl(dynamic_cast<UrlItem *>(sender()));
+    ctrl->updateUrl(dynamic_cast<UrlItem*>(sender()));
 }
 
-bool URLListWidget::eventFilter(QObject *obj, QEvent *event) {
+bool URLListWidget::eventFilter(QObject* obj, QEvent* event) {
     CHECK(ui->itemsArea == obj, false);
     if (event->type() == QEvent::ContextMenu) {
         CHECK(1 == ui->itemsArea->selectedItems().size(), false);
 
-        QContextMenuEvent *e = static_cast<QContextMenuEvent *>(event);
-        QListWidgetItem *item = ui->itemsArea->itemAt(e->pos());
-        CHECK(nullptr != item, false);
+        auto e = static_cast<QContextMenuEvent*>(event);
+        QListWidgetItem* item = ui->itemsArea->itemAt(e->pos());
+        CHECK(item != nullptr, false);
         CHECK(item->isSelected(), false);
 
-        UrlItem *urlItem = static_cast<UrlItem *>(item);
-        CHECK(nullptr != urlItem, false);
+        auto urlItem = static_cast<UrlItem*>(item);
+        CHECK(urlItem != nullptr, false);
 
-        QWidget *options = urlItem->getOptionsWidget();
-        if (nullptr != options) {
+        QWidget* options = urlItem->getOptionsWidget();
+        if (options != nullptr) {
             popup->showOptions(options, ui->itemsArea->mapToGlobal(e->pos()));
         }
         return true;
@@ -289,7 +219,7 @@ bool URLListWidget::eventFilter(QObject *obj, QEvent *event) {
 /************************************************************************/
 /* OptionsPopup */
 /************************************************************************/
-OptionsPopup::OptionsPopup(QWidget *parent)
+OptionsPopup::OptionsPopup(QWidget* parent)
     : QFrame(parent) {
     l = new QVBoxLayout(this);
     l->setMargin(0);
@@ -297,12 +227,12 @@ OptionsPopup::OptionsPopup(QWidget *parent)
     setFrameShape(QFrame::StyledPanel);
 }
 
-void OptionsPopup::closeEvent(QCloseEvent *event) {
+void OptionsPopup::closeEvent(QCloseEvent* event) {
     removeOptions();
     QWidget::closeEvent(event);
 }
 
-void OptionsPopup::showOptions(QWidget *options, const QPoint &p) {
+void OptionsPopup::showOptions(QWidget* options, const QPoint& p) {
     l->insertWidget(0, options);
     move(p);
     show();
@@ -320,8 +250,8 @@ void OptionsPopup::showOptions(QWidget *options, const QPoint &p) {
 }
 
 void OptionsPopup::removeOptions() {
-    QLayoutItem *child;
-    while (nullptr != (child = l->takeAt(0))) {
+    QLayoutItem* child;
+    while ((child = l->takeAt(0)) != nullptr) {
         child->widget()->setParent(nullptr);
         delete child;
     }
