@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -51,120 +51,117 @@ public:
         : urlItem(nullptr) {
     }
 
-    virtual void visit(FileUrlContainer *url) {
+    void visit(FileUrlContainer* url) override {
         urlItem = new FileItem(url->getUrl());
     }
 
-    virtual void visit(DirUrlContainer *url) {
-        DirectoryItem *dItem = new DirectoryItem(url->getUrl());
+    void visit(DirUrlContainer* url) override {
+        auto dItem = new DirectoryItem(url->getUrl());
         dItem->setIncludeFilter(url->getIncludeFilter());
         dItem->setExcludeFilter(url->getExcludeFilter());
         dItem->setRecursive(url->isRecursive());
         urlItem = dItem;
     }
 
-    virtual void visit(DbObjUrlContainer *url) {
+    void visit(DbObjUrlContainer* url) override {
         urlItem = new DbObjectItem(url->getUrl());
     }
 
-    virtual void visit(DbFolderUrlContainer *url) {
-        DbFolderItem *dItem = new DbFolderItem(url->getUrl());
+    void visit(DbFolderUrlContainer* url) override {
+        auto dItem = new DbFolderItem(url->getUrl());
         dItem->setRecursive(url->isRecursive());
         urlItem = dItem;
     }
 
-    UrlItem *getWidget() {
+    UrlItem* getWidget() {
         return urlItem;
     }
 
 private:
-    UrlItem *urlItem;
+    UrlItem* urlItem;
 };
 
 class URLContainerUpdateHelper : public UrlItemVisitor {
 public:
-    URLContainerUpdateHelper(FileUrlContainer * /*url*/)
+    URLContainerUpdateHelper(FileUrlContainer* /*url*/)
         : dirUrl(nullptr), dbFolderUrl(nullptr) {
     }
-    URLContainerUpdateHelper(DirUrlContainer *url)
+    URLContainerUpdateHelper(DirUrlContainer* url)
         : dirUrl(url), dbFolderUrl(nullptr) {
     }
-    URLContainerUpdateHelper(DbObjUrlContainer * /*url*/)
+    URLContainerUpdateHelper(DbObjUrlContainer* /*url*/)
         : dirUrl(nullptr), dbFolderUrl(nullptr) {
     }
-    URLContainerUpdateHelper(DbFolderUrlContainer *url)
+    URLContainerUpdateHelper(DbFolderUrlContainer* url)
         : dirUrl(nullptr), dbFolderUrl(url) {
     }
 
-    virtual void visit(DirectoryItem *item) {
-        SAFE_POINT(nullptr != dirUrl, "NULL folder url", );
+    void visit(DirectoryItem* item) override {
+        SAFE_POINT(dirUrl != nullptr, "NULL folder url", );
         dirUrl->setIncludeFilter(item->getIncludeFilter());
         dirUrl->setExcludeFilter(item->getExcludeFilter());
         dirUrl->setRecursive(item->isRecursive());
     }
 
-    virtual void visit(FileItem * /*item*/) {
+    void visit(FileItem* /*item*/) override {
     }
 
-    virtual void visit(DbObjectItem * /*item*/) {
+    void visit(DbObjectItem* /*item*/) override {
     }
 
-    virtual void visit(DbFolderItem *item) {
-        SAFE_POINT(nullptr != dbFolderUrl, "NULL folder url", );
+    void visit(DbFolderItem* item) override {
+        SAFE_POINT(dbFolderUrl != nullptr, "NULL folder url", );
         dbFolderUrl->setRecursive(item->isRecursive());
     }
 
 private:
-    DirUrlContainer *dirUrl;
-    DbFolderUrlContainer *dbFolderUrl;
+    DirUrlContainer* dirUrl;
+    DbFolderUrlContainer* dbFolderUrl;
 };
 
 class URLContainerUpdater : public URLContainerVisitor {
 public:
-    URLContainerUpdater(UrlItem *_item)
+    URLContainerUpdater(UrlItem* _item)
         : item(_item) {
     }
 
-    virtual void visit(FileUrlContainer *url) {
+    void visit(FileUrlContainer* url) override {
         URLContainerUpdateHelper helper(url);
         item->accept(&helper);
     }
 
-    virtual void visit(DirUrlContainer *url) {
+    void visit(DirUrlContainer* url) override {
         URLContainerUpdateHelper helper(url);
         item->accept(&helper);
     }
 
-    virtual void visit(DbObjUrlContainer *url) {
+    void visit(DbObjUrlContainer* url) override {
         URLContainerUpdateHelper helper(url);
         item->accept(&helper);
     }
 
-    virtual void visit(DbFolderUrlContainer *url) {
+    void visit(DbFolderUrlContainer* url) override {
         URLContainerUpdateHelper helper(url);
         item->accept(&helper);
     }
 
 private:
-    UrlItem *item;
+    UrlItem* item;
 };
 
 /************************************************************************/
 /* Controller */
 /************************************************************************/
-DatasetsController::DatasetsController(const QSet<GObjectType> &compatibleObjTypes, QObject *parent)
+DatasetsController::DatasetsController(const QSet<GObjectType>& compatibleObjTypes, QObject* parent)
     : QObject(parent),
       compatibleObjTypes(compatibleObjTypes) {
 }
 
-DatasetsController::~DatasetsController() {
-}
-
 void DatasetsController::update() {
     emit si_attributeChanged();
 }
 
-void DatasetsController::checkName(const QString &newName, U2OpStatus &os, const QString &exception) {
+void DatasetsController::checkName(const QString& newName, U2OpStatus& os, const QString& exception) {
     if (newName.isEmpty()) {
         os.setError(tr("Dataset name is empty"));
         return;
@@ -173,7 +170,7 @@ void DatasetsController::checkName(const QString &newName, U2OpStatus &os, const
         os.setError(tr("Dataset name can not contain ':' and ';' symbols"));
         return;
     }
-    foreach (const QString &name, names()) {
+    foreach (const QString& name, names()) {
         if (name != exception && name == newName) {
             os.setError(tr("This dataset name already exists"));
             return;
@@ -181,30 +178,30 @@ void DatasetsController::checkName(const QString &newName, U2OpStatus &os, const
     }
 }
 
-const QSet<GObjectType> &DatasetsController::getCompatibleObjTypes() const {
+const QSet<GObjectType>& DatasetsController::getCompatibleObjTypes() const {
     return compatibleObjTypes;
 }
 
 /************************************************************************/
 /* AttributeDatasetsController */
 /************************************************************************/
-AttributeDatasetsController::AttributeDatasetsController(QList<Dataset> &_sets, const QSet<GObjectType> &compatibleObjTypes)
+AttributeDatasetsController::AttributeDatasetsController(QList<Dataset>& _sets, const QSet<GObjectType>& compatibleObjTypes)
     : DatasetsController(compatibleObjTypes), datasetsWidget(nullptr) {
     initSets(_sets);
     initialize();
 }
 
-void AttributeDatasetsController::initSets(const QList<Dataset> &s) {
-    foreach (const Dataset &d, s) {
+void AttributeDatasetsController::initSets(const QList<Dataset>& s) {
+    foreach (const Dataset& d, s) {
         sets << new Dataset(d);
     }
 }
 
 void AttributeDatasetsController::initialize() {
-    SAFE_POINT(sets.size() > 0, "0 datasets count", );
+    SAFE_POINT(!sets.empty(), "0 datasets count", );
     datasetsWidget = new DatasetsListWidget(this);
 
-    foreach (Dataset *dSet, sets) {
+    foreach (Dataset* dSet, sets) {
         datasetsWidget->appendPage(dSet->getName(), createDatasetWidget(dSet));
     }
 }
@@ -216,28 +213,28 @@ AttributeDatasetsController::~AttributeDatasetsController() {
     sets.clear();
 }
 
-QWidget *AttributeDatasetsController::getWigdet() {
+QWidget* AttributeDatasetsController::getWidget() {
     return datasetsWidget;
 }
 
 QList<Dataset> AttributeDatasetsController::getDatasets() {
     QList<Dataset> result;
-    foreach (Dataset *d, sets) {
+    foreach (Dataset* d, sets) {
         result << Dataset(*d);
     }
     return result;
 }
 
-URLListWidget *AttributeDatasetsController::createDatasetWidget(Dataset *dSet) {
-    URLListController *ctrl = new URLListController(this, dSet);
+URLListWidget* AttributeDatasetsController::createDatasetWidget(Dataset* dSet) {
+    auto ctrl = new URLListController(this, dSet);
     return ctrl->getWidget();
 }
 
 void AttributeDatasetsController::deleteDataset(int dsNum) {
     SAFE_POINT(dsNum < sets.size(), "Datasets: out of range", );
 
-    Dataset *dSet = sets.at(dsNum);
-    SAFE_POINT(nullptr != dSet, "NULL dataset", );
+    Dataset* dSet = sets.at(dsNum);
+    SAFE_POINT(dSet != nullptr, "NULL dataset", );
 
     sets.removeOne(dSet);
 
@@ -252,7 +249,7 @@ void AttributeDatasetsController::deleteDataset(int dsNum) {
     update();
 }
 
-void AttributeDatasetsController::addDataset(const QString &name, U2OpStatus &os) {
+void AttributeDatasetsController::addDataset(const QString& name, U2OpStatus& os) {
     checkName(name, os);
     CHECK_OP(os, );
     sets << new Dataset(name);
@@ -261,40 +258,40 @@ void AttributeDatasetsController::addDataset(const QString &name, U2OpStatus &os
     update();
 }
 
-void AttributeDatasetsController::renameDataset(int dsNum, const QString &newName, U2OpStatus &os) {
+void AttributeDatasetsController::renameDataset(int dsNum, const QString& newName, U2OpStatus& os) {
     SAFE_POINT(dsNum < sets.size(), "Datasets: out of range", );
 
-    Dataset *dSet = sets.at(dsNum);
-    SAFE_POINT(nullptr != dSet, "NULL dataset", );
-
+    Dataset* dSet = sets.at(dsNum);
+    SAFE_POINT(dSet != nullptr, "NULL dataset", );
+    QPair<QString, QString> oldNewNames(dSet->getName(), newName);
     checkName(newName, os, dSet->getName());
     CHECK_OP(os, );
 
     dSet->setName(newName);
-    update();
+    emit si_datasetRenamed(oldNewNames);
 }
 
 QStringList AttributeDatasetsController::names() const {
     QStringList result;
-    foreach (Dataset *dSet, sets) {
+    foreach (Dataset* dSet, sets) {
         result << dSet->getName();
     }
     return result;
 }
 
-void AttributeDatasetsController::onUrlAdded(URLListController * /*ctrl*/, URLContainer * /*url*/) {
+void AttributeDatasetsController::onUrlAdded(URLListController* /*ctrl*/, URLContainer* /*url*/) {
 }
 
 /************************************************************************/
 /* PairedController */
 /************************************************************************/
-PairedReadsController::PairedReadsController(const QList<Dataset> &sets1, const QList<Dataset> &sets2, const QString &_label1, const QString &_label2)
+PairedReadsController::PairedReadsController(const QList<Dataset>& sets1, const QList<Dataset>& sets2, const QString& _label1, const QString& _label2)
     : DatasetsController(), label1(_label1), label2(_label2), datasetsWidget(nullptr) {
     initSets(sets1, sets2);
     initialize();
 }
 
-void PairedReadsController::initSets(const QList<Dataset> &s1, const QList<Dataset> &s2) {
+void PairedReadsController::initSets(const QList<Dataset>& s1, const QList<Dataset>& s2) {
     QList<Dataset>::ConstIterator it1 = s1.constBegin();
     QList<Dataset>::ConstIterator it2 = s2.constBegin();
     for (; it1 != s1.end() && it2 != s2.end(); it1++, it2++) {
@@ -307,20 +304,20 @@ void PairedReadsController::initSets(const QList<Dataset> &s1, const QList<Datas
 }
 
 void PairedReadsController::initialize() {
-    SAFE_POINT(sets.size() > 0, "0 datasets count", );
+    SAFE_POINT(!sets.empty(), "0 datasets count", );
     datasetsWidget = new DatasetsListWidget(this);
 
-    foreach (const SetsPair &p, sets) {
+    foreach (const SetsPair& p, sets) {
         datasetsWidget->appendPage(p.first->getName(), createDatasetWidget(p));
     }
 }
 
-static QWidget *getLayout(QWidget *widget, const QString &labelText) {
+static QWidget* getLayout(QWidget* widget, const QString& labelText) {
     if (labelText.isEmpty()) {
         return widget;
     }
 
-    QLabel *label = new QLabel(labelText);
+    auto label = new QLabel(labelText);
     label->setStyleSheet(
         "background: palette(midlight);"
         "border-style: solid;"
@@ -329,21 +326,21 @@ static QWidget *getLayout(QWidget *widget, const QString &labelText) {
         "text-align: center;"
         "padding: 2px;");
 
-    QWidget *result = new QWidget();
-    QVBoxLayout *l = new QVBoxLayout(result);
+    auto result = new QWidget();
+    auto l = new QVBoxLayout(result);
     l->setContentsMargins(0, 3, 0, 0);
     l->addWidget(label);
     l->addWidget(widget);
     return result;
 }
 
-QWidget *PairedReadsController::createDatasetWidget(const SetsPair &pair) {
+QWidget* PairedReadsController::createDatasetWidget(const SetsPair& pair) {
     CtrlsPair cp;
     cp.first = new URLListController(this, pair.first);
     cp.second = new URLListController(this, pair.second);
     ctrls << cp;
 
-    QSplitter *splitter = new QSplitter();
+    auto splitter = new QSplitter();
     splitter->setChildrenCollapsible(false);
     splitter->addWidget(getLayout(cp.first->getWidget(), label1));
     splitter->addWidget(getLayout(cp.second->getWidget(), label2));
@@ -353,35 +350,30 @@ QWidget *PairedReadsController::createDatasetWidget(const SetsPair &pair) {
 PairedReadsController::~PairedReadsController() {
     datasetsWidget->setParent(nullptr);
     delete datasetsWidget;
-    foreach (const SetsPair &p, sets) {
+    foreach (const SetsPair& p, sets) {
         delete p.first;
         delete p.second;
     }
     sets.clear();
 }
 
-QWidget *PairedReadsController::getWigdet() {
+QWidget* PairedReadsController::getWidget() {
     return datasetsWidget;
 }
 
 QList<Dataset> PairedReadsController::getDatasets(int num) {
     QList<Dataset> result;
-    foreach (const SetsPair &p, sets) {
-        Dataset *d = nullptr;
-        if (0 == num) {
-            d = p.first;
-        } else {
-            d = p.second;
-        }
+    foreach (const SetsPair& p, sets) {
+        Dataset* d = num == 0 ? p.first : p.second;
         result << Dataset(*d);
     }
     return result;
 }
 
-void PairedReadsController::renameDataset(int dsNum, const QString &newName, U2OpStatus &os) {
+void PairedReadsController::renameDataset(int dsNum, const QString& newName, U2OpStatus& os) {
     SAFE_POINT(dsNum < sets.size(), "Datasets: out of range", );
 
-    SetsPair &pair = sets[dsNum];
+    SetsPair& pair = sets[dsNum];
 
     checkName(newName, os, pair.first->getName());
     CHECK_OP(os, );
@@ -412,7 +404,7 @@ void PairedReadsController::deleteDataset(int dsNum) {
     update();
 }
 
-void PairedReadsController::addDataset(const QString &name, U2OpStatus &os) {
+void PairedReadsController::addDataset(const QString& name, U2OpStatus& os) {
     checkName(name, os);
     CHECK_OP(os, );
     sets << SetsPair(new Dataset(name), new Dataset(name));
@@ -423,13 +415,13 @@ void PairedReadsController::addDataset(const QString &name, U2OpStatus &os) {
 
 QStringList PairedReadsController::names() const {
     QStringList result;
-    foreach (const SetsPair &p, sets) {
+    foreach (const SetsPair& p, sets) {
         result << p.first->getName();
     }
     return result;
 }
 
-static QString replaceNum(const QString &name) {
+static QString replaceNum(const QString& name) {
     int onePos = name.lastIndexOf("1");
     int twoPos = name.lastIndexOf("2");
 
@@ -444,7 +436,7 @@ static QString replaceNum(const QString &name) {
     return name.left(pos) + dstNum + name.mid(pos + 1);
 }
 
-static QString getMateUrl(const QString &url) {
+static QString getMateUrl(const QString& url) {
     QFileInfo info(url);
     QString dir = info.dir().absolutePath();
     QString name = info.baseName();
@@ -455,7 +447,7 @@ static QString getMateUrl(const QString &url) {
     return "";
 }
 
-static bool askAboutAdding(const QString &mateUrl) {
+static bool askAboutAdding(const QString& mateUrl) {
     QString title = QObject::tr("Paired reads");
     QString file = QFileInfo(mateUrl).fileName();
     QString src = QFileInfo(mateUrl).isFile() ? QObject::tr("file") : QObject::tr("folder");
@@ -465,13 +457,13 @@ static bool askAboutAdding(const QString &mateUrl) {
     return (QMessageBox::Yes == answer);
 }
 
-void PairedReadsController::onUrlAdded(URLListController *ctrl, URLContainer *url) {
+void PairedReadsController::onUrlAdded(URLListController* ctrl, URLContainer* url) {
     QString mateUrl = getMateUrl(url->getUrl());
     CHECK(!mateUrl.isEmpty(), );
     CHECK(QFile::exists(mateUrl), );
 
-    URLListController *targetCtrl = pairedCtrl(ctrl);
-    CHECK(nullptr != targetCtrl, );
+    URLListController* targetCtrl = pairedCtrl(ctrl);
+    CHECK(targetCtrl != nullptr, );
     CHECK(!targetCtrl->dataset()->contains(mateUrl), );
 
     bool add = askAboutAdding(mateUrl);
@@ -481,9 +473,9 @@ void PairedReadsController::onUrlAdded(URLListController *ctrl, URLContainer *ur
     }
 }
 
-int PairedReadsController::pairNumByCtrl(URLListController *ctrl) const {
+int PairedReadsController::pairNumByCtrl(URLListController* ctrl) const {
     int result = 0;
-    foreach (const CtrlsPair &cp, ctrls) {
+    foreach (const CtrlsPair& cp, ctrls) {
         if (cp.first == ctrl || cp.second == ctrl) {
             return result;
         }
@@ -492,7 +484,7 @@ int PairedReadsController::pairNumByCtrl(URLListController *ctrl) const {
     return -1;
 }
 
-URLListController *PairedReadsController::pairedCtrl(URLListController *ctrl) const {
+URLListController* PairedReadsController::pairedCtrl(URLListController* ctrl) const {
     int dsNum = pairNumByCtrl(ctrl);
     SAFE_POINT(-1 != dsNum, "Unregistered url list controller", nullptr);
 
@@ -507,16 +499,16 @@ URLListController *PairedReadsController::pairedCtrl(URLListController *ctrl) co
 /************************************************************************/
 /* UrlAndDatasetController */
 /************************************************************************/
-UrlAndDatasetController::UrlAndDatasetController(const QList<Dataset> &_urls, const QList<Dataset> &_sets, const QString &_urlLabel, const QString &_datasetLabel)
+UrlAndDatasetController::UrlAndDatasetController(const QList<Dataset>& _urls, const QList<Dataset>& _sets, const QString& _urlLabel, const QString& _datasetLabel)
     : DatasetsController(), urlLabel(_urlLabel), datasetLabel(_datasetLabel), datasetsWidget(nullptr) {
     initSets(_urls, _sets);
     initialize();
     update();
 }
 
-void UrlAndDatasetController::initSets(const QList<Dataset> &_urls, const QList<Dataset> &s) {
-    foreach (Dataset urlSet, _urls) {
-        foreach (URLContainer *urlCon, urlSet.getUrls()) {
+void UrlAndDatasetController::initSets(const QList<Dataset>& _urls, const QList<Dataset>& s) {
+    for (Dataset urlSet : qAsConst(_urls)) {
+        foreach (URLContainer* urlCon, urlSet.getUrls()) {
             urls << urlCon->getUrl();
         }
     }
@@ -536,36 +528,33 @@ void UrlAndDatasetController::initSets(const QList<Dataset> &_urls, const QList<
 
     // Set datasets names
     for (int i = 0; i < urls.count(); ++i) {
-        QFileInfo info(urls[i]);
-        if (!info.fileName().isEmpty()) {
-            sets[i]->setName(info.fileName());
-        } else {
-            sets[i]->setName("Dataset " + QString::number(i + 1));
+        if (sets[i]->getName().isEmpty()) {
+            sets[i]->setName(QFileInfo(urls[i]).fileName());
         }
     }
 }
 
 void UrlAndDatasetController::initialize() {
-    SAFE_POINT(sets.size() > 0, "0 datasets count", );
+    SAFE_POINT(!sets.empty(), "0 datasets count", );
     datasetsWidget = new DatasetsListWidget(this);
 
-    foreach (Dataset *set, sets) {
+    foreach (Dataset* set, sets) {
         datasetsWidget->appendPage(set->getName(), createDatasetPageWidget(set));
     }
 }
 
-QWidget *UrlAndDatasetController::createDatasetPageWidget(Dataset *set) {
+QWidget* UrlAndDatasetController::createDatasetPageWidget(Dataset* set) {
     CtrlsPair cp;
 
-    URLDelegate *urlDelegate = new URLDelegate("", "", false, false, false);
-    connect(urlDelegate, SIGNAL(commitData(QWidget *)), SLOT(sl_urlChanged(QWidget *)));
+    auto urlDelegate = new URLDelegate("", "", false, false, false);
+    connect(urlDelegate, &URLDelegate::commitData, this, &UrlAndDatasetController::sl_urlChanged);
 
     cp.first = urlDelegate;
     cp.second = new URLListController(this, set);
     ctrls << cp;
 
-    QWidget *widget = new QWidget;
-    QVBoxLayout *layout = new QVBoxLayout;
+    auto widget = new QWidget();
+    auto layout = new QVBoxLayout();
     layout->setMargin(0);
     layout->setContentsMargins(0, 4, 0, 4);
     layout->setSpacing(6);
@@ -576,16 +565,16 @@ QWidget *UrlAndDatasetController::createDatasetPageWidget(Dataset *set) {
     return widget;
 }
 
-QWidget *UrlAndDatasetController::createUrlWidget(URLDelegate *ctrl, const QString &value) {
-    URLWidget *urlWidget = qobject_cast<URLWidget *>(ctrl->createEditor(nullptr, QStyleOptionViewItem(), QModelIndex()));
+QWidget* UrlAndDatasetController::createUrlWidget(URLDelegate* ctrl, const QString& value) {
+    auto urlWidget = qobject_cast<URLWidget*>(ctrl->createEditor(nullptr, QStyleOptionViewItem(), QModelIndex()));
     urlWidget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     urlWidget->setValue(value);
 
-    QWidget *labeledWidget = new QWidget();
-    QHBoxLayout *labeledLayout = new QHBoxLayout;
+    auto labeledWidget = new QWidget();
+    auto labeledLayout = new QHBoxLayout;
     labeledLayout->setContentsMargins(6, 8, 0, 7);
 
-    QLabel *urlLabelWidget = new QLabel(urlLabel);
+    auto urlLabelWidget = new QLabel(urlLabel);
     urlLabelWidget->setObjectName(urlLabel + " label");
     labeledLayout->addWidget(urlLabelWidget);
     labeledLayout->addWidget(urlWidget);
@@ -595,9 +584,9 @@ QWidget *UrlAndDatasetController::createUrlWidget(URLDelegate *ctrl, const QStri
     return labeledWidget;
 }
 
-QWidget *UrlAndDatasetController::createDatasetWidget(URLListController *ctrl) {
-    QGroupBox *result = new QGroupBox(datasetLabel);
-    QVBoxLayout *layout = new QVBoxLayout;
+QWidget* UrlAndDatasetController::createDatasetWidget(URLListController* ctrl) {
+    auto result = new QGroupBox(datasetLabel);
+    auto layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
 
     layout->addWidget(ctrl->getWidget());
@@ -613,13 +602,13 @@ UrlAndDatasetController::~UrlAndDatasetController() {
     qDeleteAll(sets);
 }
 
-QWidget *UrlAndDatasetController::getWigdet() {
+QWidget* UrlAndDatasetController::getWidget() {
     return datasetsWidget;
 }
 
 QList<Dataset> UrlAndDatasetController::getDatasets() const {
     QList<Dataset> result;
-    foreach (Dataset *set, sets) {
+    foreach (Dataset* set, sets) {
         result << *set;
     }
 
@@ -637,14 +626,14 @@ QList<Dataset> UrlAndDatasetController::getUrls() const {
     return result;
 }
 
-void UrlAndDatasetController::sl_urlChanged(QWidget *widget) {
-    URLDelegate *urlDelegate = qobject_cast<URLDelegate *>(sender());
+void UrlAndDatasetController::sl_urlChanged(QWidget* widget) {
+    auto urlDelegate = qobject_cast<URLDelegate*>(sender());
     SAFE_POINT(urlDelegate, "URL delegate is NULL", );
 
-    URLWidget *editor = qobject_cast<URLWidget *>(widget);
+    auto editor = qobject_cast<URLWidget*>(widget);
     SAFE_POINT(editor, "Unexpected widget", );
 
-    for (int i = 0; i < ctrls.count(); ++i) {
+    for (int i = 0; i < ctrls.count(); i++) {
         if (ctrls[i].first == urlDelegate) {
             urls[i] = editor->value().toString();
             update();
@@ -653,7 +642,7 @@ void UrlAndDatasetController::sl_urlChanged(QWidget *widget) {
     }
 }
 
-void UrlAndDatasetController::renameDataset(int dsNum, const QString &newName, U2OpStatus &os) {
+void UrlAndDatasetController::renameDataset(int dsNum, const QString& newName, U2OpStatus& os) {
     SAFE_POINT(dsNum < sets.size(), "Datasets: out of range", );
 
     checkName(newName, os, sets[dsNum]->getName());
@@ -683,7 +672,7 @@ void UrlAndDatasetController::deleteDataset(int dsNum) {
     update();
 }
 
-void UrlAndDatasetController::addDataset(const QString &name, U2OpStatus &os) {
+void UrlAndDatasetController::addDataset(const QString& name, U2OpStatus& os) {
     checkName(name, os);
     CHECK_OP(os, );
     sets << new Dataset(name);
@@ -695,43 +684,43 @@ void UrlAndDatasetController::addDataset(const QString &name, U2OpStatus &os) {
 
 QStringList UrlAndDatasetController::names() const {
     QStringList result;
-    foreach (Dataset *set, sets) {
+    foreach (Dataset* set, sets) {
         result << set->getName();
     }
     return result;
 }
 
-QString UrlAndDatasetController::getUrlByDataset(Dataset *set) const {
+QString UrlAndDatasetController::getUrlByDataset(Dataset* set) const {
     return urls.at(sets.indexOf(set));
 }
 
 /************************************************************************/
 /* URLListController */
 /************************************************************************/
-URLListController::URLListController(DatasetsController *parent, Dataset *_set)
+URLListController::URLListController(DatasetsController* parent, Dataset* _set)
     : QObject(parent), widget(nullptr), controller(parent), set(_set) {
 }
 
-URLListWidget *URLListController::getWidget() {
-    if (nullptr == widget) {
+URLListWidget* URLListController::getWidget() {
+    if (widget == nullptr) {
         createWidget();
     }
     return widget;
 }
 
-Dataset *URLListController::dataset() {
+Dataset* URLListController::dataset() {
     return set;
 }
 
 void URLListController::createWidget() {
     widget = new URLListWidget(this);
 
-    foreach (URLContainer *url, set->getUrls()) {
+    foreach (URLContainer* url, set->getUrls()) {
         addItemWidget(url);
     }
 }
 
-void URLListController::addItemWidget(URLContainer *url) {
+void URLListController::addItemWidget(URLContainer* url) {
     SAFE_POINT(widget != nullptr, "NULL url list widget", );
     ItemWidgetCreator wc;
     url->accept(&wc);
@@ -740,9 +729,9 @@ void URLListController::addItemWidget(URLContainer *url) {
     widget->addUrlItem(wc.getWidget());
 }
 
-void URLListController::updateUrl(UrlItem *item) {
-    URLContainer *url = urlMap[item];
-    SAFE_POINT(nullptr != url, "NULL url container", );
+void URLListController::updateUrl(UrlItem* item) {
+    URLContainer* url = urlMap[item];
+    SAFE_POINT(url != nullptr, "NULL url container", );
 
     URLContainerUpdater updater(item);
     url->accept(&updater);
@@ -750,8 +739,8 @@ void URLListController::updateUrl(UrlItem *item) {
 }
 
 void URLListController::replaceUrl(int pos, int newPos) {
-    URLContainer *url = getUrl(pos);
-    CHECK(nullptr != url, );
+    URLContainer* url = getUrl(pos);
+    CHECK(url != nullptr, );
 
     SAFE_POINT(newPos >= 0 && newPos < set->getUrls().size(),
                "New url position is out of range", );
@@ -761,8 +750,8 @@ void URLListController::replaceUrl(int pos, int newPos) {
     controller->update();
 }
 
-void URLListController::addUrl(const QString &url, U2OpStatus &os) {
-    URLContainer *urlCont = URLContainerFactory::createUrlContainer(url);
+void URLListController::addUrl(const QString& url, U2OpStatus& os) {
+    URLContainer* urlCont = URLContainerFactory::createUrlContainer(url);
     if (urlCont == nullptr) {
         os.setError(tr("This file or folder does not exist: %1").arg(url));
         return;
@@ -776,22 +765,22 @@ void URLListController::addUrl(const QString &url, U2OpStatus &os) {
 }
 
 void URLListController::deleteUrl(int pos) {
-    URLContainer *url = getUrl(pos);
-    CHECK(nullptr != url, );
+    URLContainer* url = getUrl(pos);
+    CHECK(url != nullptr, );
 
     set->removeUrl(url);
     delete url;
     controller->update();
 }
 
-URLContainer *URLListController::getUrl(int pos) {
+URLContainer* URLListController::getUrl(int pos) {
     SAFE_POINT(pos < set->getUrls().size(), "Urls: out of range", nullptr);
-    URLContainer *url = set->getUrls().at(pos);
-    SAFE_POINT(nullptr != url, "NULL url container", nullptr);
+    URLContainer* url = set->getUrls().at(pos);
+    SAFE_POINT(url != nullptr, "NULL url container", nullptr);
     return url;
 }
 
-const QSet<GObjectType> &URLListController::getCompatibleObjTypes() const {
+const QSet<GObjectType>& URLListController::getCompatibleObjTypes() const {
     return controller->getCompatibleObjTypes();
 }
 
