@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DATASETS_LIST_WIDGET_H_
-#define _U2_DATASETS_LIST_WIDGET_H_
+#pragma once
 
 #include <QTabWidget>
 
@@ -33,37 +32,35 @@ class DatasetsController;
 class DatasetsTabWidget : public QTabWidget {
     Q_OBJECT
 public:
-    DatasetsTabWidget(QWidget *parent);
+    DatasetsTabWidget(QWidget* parent);
 
 signals:
-    void si_contextMenu(const QPoint &p, int idx);
+    void si_contextMenu(const QPoint& p, int idx);
 
 private slots:
-    void sl_contextMenu(const QPoint &p);
+    void sl_contextMenu(const QPoint& p);
 };
 
 class DatasetsListWidget : public QWidget {
     Q_OBJECT
 public:
-    DatasetsListWidget(DatasetsController *ctrl);
+    DatasetsListWidget(DatasetsController* ctrl);
 
-    void appendPage(const QString &name, QWidget *page);
+    void appendPage(const QString& name, QWidget* page);
 
 private slots:
     void sl_deleteDataset(int idx);
     void sl_renameDataset();
     void sl_newDataset();
-    void sl_contextMenu(const QPoint &p, int idx);
+    void sl_contextMenu(const QPoint& p, int idx);
 
 private:
-    DatasetsController *ctrl;
-    QTabWidget *tabs;
+    DatasetsController* ctrl;
+    QTabWidget* tabs;
 
 private:
-    QString askDatasetName(const QString &tip, const QString &title, bool &ok);
+    QString askDatasetName(const QString& tip, const QString& title, bool& ok);
     QString getTip() const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_DATASETS_LIST_WIDGET_H_
