@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DB_FOLDER_ITEM_H_
-#define _U2_DB_FOLDER_ITEM_H_
+#pragma once
 
 #include "UrlItem.h"
 
@@ -33,23 +32,23 @@ class DbFolderOptions;
 class DbFolderItem : public UrlItem {
     Q_OBJECT
 public:
-    DbFolderItem(const QString &url, QListWidget *parent = nullptr);
+    DbFolderItem(const QString& url, QListWidget* parent = nullptr);
     ~DbFolderItem();
 
-    virtual void accept(UrlItemVisitor *visitor);
-    virtual QWidget *getOptionsWidget();
+    virtual void accept(UrlItemVisitor* visitor);
+    virtual QWidget* getOptionsWidget();
 
     void setRecursive(bool value);
     bool isRecursive() const;
 
 private:
-    DbFolderOptions *options;
+    DbFolderOptions* options;
 };
 
 class DbFolderOptions : public QWidget {
     Q_OBJECT
 public:
-    DbFolderOptions(QWidget *parent = nullptr);
+    DbFolderOptions(QWidget* parent = nullptr);
     ~DbFolderOptions();
 
     void setRecursive(bool value);
@@ -59,9 +58,7 @@ signals:
     void si_dataChanged();
 
 private:
-    Ui_DbFolderOptions *ui;
+    Ui_DbFolderOptions* ui;
 };
 
 }  // namespace U2
-
-#endif  //_U2_DB_FOLDER_ITEM_H_
