@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DB_OBJECT_ITEM_H_
-#define _U2_DB_OBJECT_ITEM_H_
+#pragma once
 
 #include "FileItem.h"
 
@@ -29,9 +28,7 @@ namespace U2 {
 class DbObjectItem : public FileItem {
     Q_OBJECT
 public:
-    DbObjectItem(const QString &url, QListWidget *parent = nullptr);
+    DbObjectItem(const QString& url, QListWidget* parent = nullptr);
 };
 
 }  // namespace U2
-
-#endif  // _U2_DB_OBJECT_ITEM_H_
