@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,17 +19,14 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DESIGNER_UTILS_H_
-#define _U2_DESIGNER_UTILS_H_
+#pragma once
 
 #include <U2Core/global.h>
 namespace U2 {
 
 class U2DESIGNER_EXPORT DesignerUtils {
 public:
-    static QString getSchemaFileFilter(bool any, bool addOldExt = false);
+    static QString getSchemaFileFilter();
 };  // DesignerUtils
 
 }  // namespace U2
-
-#endif
