@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _GROUPER_EDITOR_H_
-#define _GROUPER_EDITOR_H_
+#pragma once
 
 #include <U2Lang/ActorModel.h>
 #include <U2Lang/Configuration.h>
@@ -37,28 +36,26 @@ class U2DESIGNER_EXPORT GrouperEditor : public ActorConfigurationEditor {
     Q_OBJECT
 public:
     GrouperEditor();
-    GrouperEditor(const GrouperEditor &)
+    GrouperEditor(const GrouperEditor&)
         : ActorConfigurationEditor(), grouperModel(nullptr) {
     }
     virtual ~GrouperEditor();
-    virtual QWidget *getWidget();
-    virtual void setConfiguration(Actor *actor);
-    virtual ConfigurationEditor *clone() {
+    virtual QWidget* getWidget();
+    virtual void setConfiguration(Actor* actor);
+    virtual ConfigurationEditor* clone() {
         return new GrouperEditor(*this);
     }
 
 public slots:
-    void sl_onActionEdited(const GrouperOutSlot &outSlot);
-    void sl_onSlotAdded(const GrouperOutSlot &outSlot);
-    void sl_onSlotRemoved(const QString &outSlotName);
+    void sl_onActionEdited(const GrouperOutSlot& outSlot);
+    void sl_onSlotAdded(const GrouperOutSlot& outSlot);
+    void sl_onSlotRemoved(const QString& outSlotName);
 
 private:
-    GrouperSlotsCfgModel *grouperModel;
+    GrouperSlotsCfgModel* grouperModel;
 
-    QWidget *createGUI();
+    QWidget* createGUI();
 };  // GrouperEditor
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // _GROUPER_EDITOR_H_
