@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _GROUPER_EDITOR_WIDGET_H_
-#define _GROUPER_EDITOR_WIDGET_H_
+#pragma once
 
 #include <U2Lang/ActorModel.h>
 #include <U2Lang/GrouperOutSlot.h>
@@ -34,15 +33,15 @@ class GrouperSlotsCfgModel;
 class GrouperEditorWidget : public QWidget, public Ui_GrouperEditorWidget {
     Q_OBJECT
 public:
-    GrouperEditorWidget(GrouperSlotsCfgModel *gouperModel, Workflow::Actor *grouper, QWidget *parent = nullptr);
+    GrouperEditorWidget(GrouperSlotsCfgModel* gouperModel, Workflow::Actor* grouper, QWidget* parent = nullptr);
 
 signals:
     void si_grouperCfgChanged();
 
 private:
-    GrouperSlotsCfgModel *grouperModel;
-    Workflow::Actor *grouper;
-    Workflow::Port *inPort;
+    GrouperSlotsCfgModel* grouperModel;
+    Workflow::Actor* grouper;
+    Workflow::Port* inPort;
 
 private slots:
     void sl_onAddButtonClicked();
@@ -51,40 +50,38 @@ private slots:
 
     void sl_onGroupSlotChanged(int idx);
     void sl_onGroupOpChanged(int idx);
-    void sl_onItemSelected(const QModelIndex &idx);
-    void sl_onItemEntered(const QModelIndex &idx);
+    void sl_onItemSelected(const QModelIndex& idx);
+    void sl_onItemEntered(const QModelIndex& idx);
 
 private:
-    void setupGroupOpBox(int slotIdx, const QString &groupOp, const QMap<Descriptor, DataTypePtr> &busMap);
+    void setupGroupOpBox(int slotIdx, const QString& groupOp, const QMap<Descriptor, DataTypePtr>& busMap);
 };
 
 class GrouperSlotsCfgModel : public QAbstractTableModel {
     Q_OBJECT
 public:
-    GrouperSlotsCfgModel(QObject *parent, QList<GrouperOutSlot> &outSlots);
+    GrouperSlotsCfgModel(QObject* parent, QList<GrouperOutSlot>& outSlots);
 
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
-    int columnCount(const QModelIndex &) const;
-    int rowCount(const QModelIndex &) const;
-    Qt::ItemFlags flags(const QModelIndex &index) const;
-    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex());
+    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
+    bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
+    int columnCount(const QModelIndex&) const;
+    int rowCount(const QModelIndex&) const;
+    Qt::ItemFlags flags(const QModelIndex& index) const;
+    bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex());
 
     QStringList getMergeSeqSlotsNames() const;
-    GrouperSlotAction *getSlotAction(const QString &outSlotName) const;
-    void addGrouperSlot(const GrouperOutSlot &newSlot);
-    void setNewAction(const QString &outSlotName, const GrouperSlotAction &action);
+    GrouperSlotAction* getSlotAction(const QString& outSlotName) const;
+    void addGrouperSlot(const GrouperOutSlot& newSlot);
+    void setNewAction(const QString& outSlotName, const GrouperSlotAction& action);
 
 signals:
-    void si_actionEdited(const GrouperOutSlot &outSlot);
-    void si_slotAdded(const GrouperOutSlot &outSlot);
-    void si_slotRemoved(const QString &outSlotName);
+    void si_actionEdited(const GrouperOutSlot& outSlot);
+    void si_slotAdded(const GrouperOutSlot& outSlot);
+    void si_slotRemoved(const QString& outSlotName);
 
 private:
-    QList<GrouperOutSlot> &outSlots;
+    QList<GrouperOutSlot>& outSlots;
 };
 
 }  // namespace U2
-
-#endif  // _GROUPER_EDITOR_WIDGET_H_
