@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _MARKER_EDITOR_WIDGET_H_
-#define _MARKER_EDITOR_WIDGET_H_
+#pragma once
 
 #include "ui_EditIntegerMarkerWidget.h"
 #include "ui_EditMarkerDialog.h"
@@ -33,21 +32,19 @@ class Marker;
 class MarkerEditorWidget : public QWidget, public Ui_MarkerEditorWidget {
     Q_OBJECT
 public:
-    MarkerEditorWidget(QAbstractTableModel *markerModel, QWidget *parent = nullptr);
-    bool checkEditMarkerGroupResult(const QString &oldName, Marker *newMarker, QString &message);
-    bool checkAddMarkerGroupResult(Marker *newMarker, QString &message);
+    MarkerEditorWidget(QAbstractTableModel* markerModel, QWidget* parent = nullptr);
+    bool checkEditMarkerGroupResult(const QString& oldName, Marker* newMarker, QString& message);
+    bool checkAddMarkerGroupResult(Marker* newMarker, QString& message);
 
 private:
-    QAbstractTableModel *markerModel;
+    QAbstractTableModel* markerModel;
 
 private slots:
     void sl_onAddButtonClicked();
     void sl_onEditButtonClicked();
     void sl_onRemoveButtonClicked();
-    void sl_onItemSelected(const QModelIndex &idx);
-    void sl_onItemEntered(const QModelIndex &idx);
+    void sl_onItemSelected(const QModelIndex& idx);
+    void sl_onItemEntered(const QModelIndex& idx);
 };
 
 }  // namespace U2
-
-#endif  // _MARKER_EDITOR_WIDGET_H_
