@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _NEW_BREAKPOINT_DIALOG_H_
-#define _NEW_BREAKPOINT_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -33,19 +32,17 @@ namespace U2 {
 class U2DESIGNER_EXPORT NewBreakpointDialog : public QDialog {
     Q_OBJECT
 public:
-    NewBreakpointDialog(const QStringList &elementsNames, QWidget *parent = nullptr, Qt::WindowFlags f = 0);
+    NewBreakpointDialog(const QStringList& elementsNames, QWidget* parent = nullptr, Qt::WindowFlags f = 0);
     ~NewBreakpointDialog();
 
 signals:
-    void si_newBreakpointCreated(const QString &element);
+    void si_newBreakpointCreated(const QString& element);
 
 private slots:
     void sl_announceNewBreakpoint();
 
 private:
-    Ui_NewBreakpointDialog *ui;
+    Ui_NewBreakpointDialog* ui;
 };
 
 }  // namespace U2
-
-#endif  // _NEW_BREAKPOINT_DIALOG_H_
