@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,14 +32,14 @@
 
 namespace U2 {
 
-NewGrouperSlotDialog::NewGrouperSlotDialog(QWidget *parent, QList<Descriptor> &inSlots, QStringList &names)
+NewGrouperSlotDialog::NewGrouperSlotDialog(QWidget* parent, QList<Descriptor>& inSlots, QStringList& names)
     : QDialog(parent), inSlots(inSlots), names(names) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65930076");
     buttonBox->button(QDialogButtonBox::Ok)->setText(tr("OK"));
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
 
-    foreach (const Descriptor &d, inSlots) {
+    foreach (const Descriptor& d, inSlots) {
         slotBox->addItem(d.getDisplayName(), d.getId());
     }
 }
@@ -78,11 +78,11 @@ QString NewGrouperSlotDialog::getOutSlotName() const {
 /************************************************************************/
 /* Action dialogs */
 /************************************************************************/
-ActionDialog::ActionDialog(QWidget *parent)
+ActionDialog::ActionDialog(QWidget* parent)
     : QDialog(parent) {
 }
 
-ActionDialog *ActionDialog::getActionDialog(QWidget *parent, GrouperSlotAction *action, DataTypePtr type, QAbstractTableModel *grouperModel) {
+ActionDialog* ActionDialog::getActionDialog(QWidget* parent, GrouperSlotAction* action, DataTypePtr type, QAbstractTableModel* grouperModel) {
     if (BaseTypes::DNA_SEQUENCE_TYPE() == type) {
         return new SequeceActionDialog(parent, action);
     } else if (BaseTypes::MULTIPLE_ALIGNMENT_TYPE() == type) {
@@ -91,15 +91,15 @@ ActionDialog *ActionDialog::getActionDialog(QWidget *parent, GrouperSlotAction *
         return new StringActionDialog(parent, action);
     } else if (BaseTypes::ANNOTATION_TABLE_LIST_TYPE() == type ||
                BaseTypes::ANNOTATION_TABLE_TYPE() == type) {
-        GrouperSlotsCfgModel *m = dynamic_cast<GrouperSlotsCfgModel *>(grouperModel);
-        assert(nullptr != m);
+        auto m = dynamic_cast<GrouperSlotsCfgModel*>(grouperModel);
+        SAFE_POINT(m != nullptr, "getActionDialog: m is null", nullptr);
         QStringList mergeSeqSlots = m->getMergeSeqSlotsNames();
         return new AnnsActionDialog(parent, action, mergeSeqSlots);
     }
     return nullptr;
 }
 
-AnnsActionDialog::AnnsActionDialog(QWidget *parent, GrouperSlotAction *action, QStringList mergeSeqSlots)
+AnnsActionDialog::AnnsActionDialog(QWidget* parent, GrouperSlotAction* action, QStringList mergeSeqSlots)
     : ActionDialog(parent) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65930076");
@@ -107,12 +107,12 @@ AnnsActionDialog::AnnsActionDialog(QWidget *parent, GrouperSlotAction *action, Q
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
 
     slotBox->addItem(tr("Don't shift"));
-    foreach (const QString &slot, mergeSeqSlots) {
+    foreach (const QString& slot, mergeSeqSlots) {
         slotBox->addItem(slot);
     }
 
     int idx = 0;
-    if (nullptr != action) {
+    if (action != nullptr) {
         assert(ActionTypes::MERGE_ANNS == action->getType());
         if (action->hasParameter(ActionParameters::SEQ_SLOT)) {
             QString offsetSlot = action->getParameterValue(ActionParameters::SEQ_SLOT).toString();
@@ -145,14 +145,14 @@ GrouperSlotAction AnnsActionDialog::getAction() const {
     return action;
 }
 
-SequeceActionDialog::SequeceActionDialog(QWidget *parent, GrouperSlotAction *action)
+SequeceActionDialog::SequeceActionDialog(QWidget* parent, GrouperSlotAction* action)
     : ActionDialog(parent) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65930076");
     buttonBox->button(QDialogButtonBox::Ok)->setText(tr("OK"));
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
 
-    if (nullptr != action) {
+    if (action != nullptr) {
         if (ActionTypes::MERGE_SEQUENCE == action->getType()) {
             mergeSeqButton->setChecked(true);
 
@@ -209,13 +209,13 @@ GrouperSlotAction SequeceActionDialog::getAction() const {
     }
 }
 
-MsaActionDialog::MsaActionDialog(QWidget *parent, GrouperSlotAction *action)
+MsaActionDialog::MsaActionDialog(QWidget* parent, GrouperSlotAction* action)
     : ActionDialog(parent) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65930076");
     buttonBox->button(QDialogButtonBox::Ok)->setText(tr("OK"));
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
-    if (nullptr != action) {
+    if (action != nullptr) {
         assert(ActionTypes::MERGE_MSA == action->getType());
         if (action->hasParameter(ActionParameters::MSA_NAME)) {
             QString msaName = action->getParameterValue(ActionParameters::MSA_NAME).toString();
@@ -242,13 +242,13 @@ GrouperSlotAction MsaActionDialog::getAction() const {
     return action;
 }
 
-StringActionDialog::StringActionDialog(QWidget *parent, GrouperSlotAction *action)
+StringActionDialog::StringActionDialog(QWidget* parent, GrouperSlotAction* action)
     : ActionDialog(parent) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65930076");
     buttonBox->button(QDialogButtonBox::Ok)->setText(tr("OK"));
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
-    if (nullptr != action) {
+    if (action != nullptr) {
         assert(ActionTypes::MERGE_STRING == action->getType());
         if (action->hasParameter(ActionParameters::SEPARATOR)) {
             QString sep = action->getParameterValue(ActionParameters::SEPARATOR).toString();
