@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OUTPUTFILEDIALOG_H_
-#define _U2_OUTPUTFILEDIALOG_H_
+#pragma once
 
 #include "ui_CreateDirectoryDialog.h"
 #include "ui_OutputFileDialog.h"
@@ -35,7 +34,7 @@ class RunFileSystem;
 class OutputFileDialog : public QDialog, public Ui_OutputFileDialog {
     Q_OBJECT
 public:
-    OutputFileDialog(RunFileSystem *rfs, bool saveDir, CompletionFiller *filler, QWidget *parent);
+    OutputFileDialog(RunFileSystem* rfs, bool saveDir, CompletionFiller* filler, QWidget* parent);
     QString getResult() const;
     bool isSaveToFileSystem() const;
 
@@ -48,44 +47,44 @@ private slots:
 private:
     void updateSaveButton();
     QString selectedPath() const;
-    FSItem *selectedItem() const;
+    FSItem* selectedItem() const;
     void updateFocus();
     void setupSettings();
 
 private:
-    RunFileSystem *rfs;
+    RunFileSystem* rfs;
     bool saveDir;
-    RFSTreeModel *model;
-    QItemSelectionModel *selectionModel;
+    RFSTreeModel* model;
+    QItemSelectionModel* selectionModel;
     bool saveToFileSystem;
 };
 
 class RFSTreeModel : public QAbstractItemModel {
 public:
-    RFSTreeModel(FSItem *rootItem, bool saveDir, QObject *parent);
+    RFSTreeModel(FSItem* rootItem, bool saveDir, QObject* parent);
     ~RFSTreeModel();
 
-    QVariant data(const QModelIndex &index, int role) const;
-    Qt::ItemFlags flags(const QModelIndex &index) const;
+    QVariant data(const QModelIndex& index, int role) const;
+    Qt::ItemFlags flags(const QModelIndex& index) const;
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
-    QModelIndex index(int row, int column, const QModelIndex &parent) const;
-    QModelIndex parent(const QModelIndex &index) const;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const;
+    QModelIndex index(int row, int column, const QModelIndex& parent) const;
+    QModelIndex parent(const QModelIndex& index) const;
+    int rowCount(const QModelIndex& parent = QModelIndex()) const;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const;
 
-    FSItem *toItem(const QModelIndex &index) const;
-    QString getPath(FSItem *target) const;
-    QModelIndex addDir(const QModelIndex &index, const QString &dirName);
+    FSItem* toItem(const QModelIndex& index) const;
+    QString getPath(FSItem* target) const;
+    QModelIndex addDir(const QModelIndex& index, const QString& dirName);
 
 private:
-    FSItem *superRootItem;
+    FSItem* superRootItem;
     bool saveDir;
 };
 
 class CreateDirectoryDialog : public QDialog, public Ui_CreateDirectoryDialog {
     Q_OBJECT
 public:
-    CreateDirectoryDialog(RunFileSystem *rfs, const QString &parentDir, QWidget *parent);
+    CreateDirectoryDialog(RunFileSystem* rfs, const QString& parentDir, QWidget* parent);
 
     QString getResult() const;
 
@@ -93,10 +92,8 @@ private slots:
     void sl_textChanged();
 
 private:
-    RunFileSystem *rfs;
+    RunFileSystem* rfs;
     QString parentDir;
 };
 
 }  // namespace U2
-
-#endif  // _U2_OUTPUTFILEDIALOG_H_
