@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,12 +32,10 @@
 #include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/U2SafePoints.h>
 
-#include <U2Gui/EditConnectionDialog.h>
 #include <U2Gui/LastUsedDirHelper.h>
 #include <U2Gui/U2FileDialog.h>
 
 #include <U2Lang/SchemaConfig.h>
-#include <U2Lang/SharedDbUrlUtils.h>
 #include <U2Lang/URLContainer.h>
 #include <U2Lang/WorkflowUtils.h>
 
@@ -48,7 +46,7 @@ namespace U2 {
 /************************************************************************/
 /* AbstractDefaultPropertyWidget */
 /************************************************************************/
-BaseDefaultPropertyWidget::BaseDefaultPropertyWidget(QWidget *parent)
+BaseDefaultPropertyWidget::BaseDefaultPropertyWidget(QWidget* parent)
     : PropertyWidget(parent) {
 }
 
@@ -56,7 +54,7 @@ QVariant BaseDefaultPropertyWidget::value() {
     return lineEdit->text();
 }
 
-void BaseDefaultPropertyWidget::setValue(const QVariant &value) {
+void BaseDefaultPropertyWidget::setValue(const QVariant& value) {
     lineEdit->setText(value.toString());
 }
 
@@ -66,7 +64,7 @@ void BaseDefaultPropertyWidget::setRequired() {
     }
 }
 
-void BaseDefaultPropertyWidget::sl_valueChanged(const QString &value) {
+void BaseDefaultPropertyWidget::sl_valueChanged(const QString& value) {
     emit si_valueChanged(value);
 }
 
@@ -75,14 +73,14 @@ void BaseDefaultPropertyWidget::configureLineEdit(const int maxLength) {
         lineEdit->setMaxLength(maxLength);
     }
     addMainWidget(lineEdit);
-    connect(lineEdit, SIGNAL(textChanged(const QString &)), SLOT(sl_valueChanged(const QString &)));
+    connect(lineEdit, SIGNAL(textChanged(const QString&)), SLOT(sl_valueChanged(const QString&)));
 }
 
 /************************************************************************/
 /* DefaultPropertyWidget */
 /************************************************************************/
 
-DefaultPropertyWidget::DefaultPropertyWidget(int maxLength, QWidget *parent)
+DefaultPropertyWidget::DefaultPropertyWidget(int maxLength, QWidget* parent)
     : BaseDefaultPropertyWidget(parent) {
     lineEdit = new QLineEdit(this);
     configureLineEdit(maxLength);
@@ -92,7 +90,7 @@ DefaultPropertyWidget::DefaultPropertyWidget(int maxLength, QWidget *parent)
 /* IgnoreUpDownPropertyWidget */
 /************************************************************************/
 
-IgnoreUpDownPropertyWidget::IgnoreUpDownPropertyWidget(int maxLength, QWidget *parent)
+IgnoreUpDownPropertyWidget::IgnoreUpDownPropertyWidget(int maxLength, QWidget* parent)
     : BaseDefaultPropertyWidget(parent) {
     lineEdit = new LineEditIgnoreUpDown(this);
     configureLineEdit(maxLength);
@@ -102,11 +100,11 @@ IgnoreUpDownPropertyWidget::IgnoreUpDownPropertyWidget(int maxLength, QWidget *p
 /* LineEditIgnoreUpDown */
 /************************************************************************/
 
-LineEditIgnoreUpDown::LineEditIgnoreUpDown(QWidget *parent)
+LineEditIgnoreUpDown::LineEditIgnoreUpDown(QWidget* parent)
     : QLineEdit(parent) {
 }
 
-void LineEditIgnoreUpDown::keyPressEvent(QKeyEvent *e) {
+void LineEditIgnoreUpDown::keyPressEvent(QKeyEvent* e) {
     if ((e->key() == Qt::Key_Up) || (e->key() == Qt::Key_Down)) {
         e->ignore();
         return;
@@ -118,7 +116,7 @@ void LineEditIgnoreUpDown::keyPressEvent(QKeyEvent *e) {
 /************************************************************************/
 /* SpinBoxWidget */
 /************************************************************************/
-SpinBoxWidget::SpinBoxWidget(const QVariantMap &spinProperties, QWidget *parent)
+SpinBoxWidget::SpinBoxWidget(const QVariantMap& spinProperties, QWidget* parent)
     : PropertyWidget(parent) {
     spinBox = new QSpinBox(this);
     WorkflowUtils::setQObjectProperties(*spinBox, spinProperties);
@@ -132,7 +130,7 @@ QVariant SpinBoxWidget::value() {
     return spinBox->value();
 }
 
-void SpinBoxWidget::setValue(const QVariant &value) {
+void SpinBoxWidget::setValue(const QVariant& value) {
     spinBox->setValue(value.toInt());
 }
 
@@ -147,7 +145,7 @@ void SpinBoxWidget::processDelegateTags() {
     }
 }
 
-bool SpinBoxWidget::setProperty(const char *name, const QVariant &value) {
+bool SpinBoxWidget::setProperty(const char* name, const QVariant& value) {
     return spinBox->setProperty(name, value);
 }
 
@@ -159,7 +157,7 @@ void SpinBoxWidget::sl_valueChanged(int value) {
 /************************************************************************/
 /* DoubleSpinBoxWidget */
 /************************************************************************/
-DoubleSpinBoxWidget::DoubleSpinBoxWidget(const QVariantMap &spinProperties, QWidget *parent)
+DoubleSpinBoxWidget::DoubleSpinBoxWidget(const QVariantMap& spinProperties, QWidget* parent)
     : PropertyWidget(parent) {
     spinBox = new QDoubleSpinBox(this);
     spinBox->setMinimumWidth(1);
@@ -174,7 +172,7 @@ QVariant DoubleSpinBoxWidget::value() {
     return spinBox->value();
 }
 
-void DoubleSpinBoxWidget::setValue(const QVariant &value) {
+void DoubleSpinBoxWidget::setValue(const QVariant& value) {
     spinBox->setValue(value.toDouble());
 }
 
@@ -185,16 +183,16 @@ void DoubleSpinBoxWidget::sl_valueChanged(double value) {
 ////////////////////////////////////
 //// ComboBoxWidgetBase
 
-ComboBoxWidgetBase::ComboBoxWidgetBase(QWidget *parent, const QSharedPointer<StringFormatter> &_formatter, bool _isSorted)
+ComboBoxWidgetBase::ComboBoxWidgetBase(QWidget* parent, const QSharedPointer<StringFormatter>& _formatter, bool _isSorted)
     : PropertyWidget(parent), formatter(_formatter), isSorted(_isSorted) {
 }
 
-QString ComboBoxWidgetBase::getFormattedItemText(const QString &itemKey) const {
+QString ComboBoxWidgetBase::getFormattedItemText(const QString& itemKey) const {
     return formatter.isNull() ? itemKey : formatter->format(itemKey);
 }
 
-void ComboBoxWidgetBase::sortComboItemsByName(QList<ComboItem> &itemList) {
-    std::stable_sort(itemList.begin(), itemList.end(), [](auto &i1, auto &i2) {
+void ComboBoxWidgetBase::sortComboItemsByName(QList<ComboItem>& itemList) {
+    std::stable_sort(itemList.begin(), itemList.end(), [](auto& i1, auto& i2) {
         return QString::compare(i1.first, i2.first, Qt::CaseInsensitive) < 0;
     });
 }
@@ -202,22 +200,22 @@ void ComboBoxWidgetBase::sortComboItemsByName(QList<ComboItem> &itemList) {
 /************************************************************************/
 /* ComboBoxWidget */
 /************************************************************************/
-ComboBoxWidget::ComboBoxWidget(const QList<ComboItem> &items, QWidget *parent, const QSharedPointer<StringFormatter> &formatter, bool isSorted)
+ComboBoxWidget::ComboBoxWidget(const QList<ComboItem>& items, QWidget* parent, const QSharedPointer<StringFormatter>& formatter, bool isSorted)
     : ComboBoxWidgetBase(parent, formatter, isSorted) {
     comboBox = new QComboBox(this);
     addMainWidget(comboBox);
 
     QList<ComboItem> sortedItems;
-    for (const ComboItem &item : qAsConst(items)) {
+    for (const ComboItem& item : qAsConst(items)) {
         sortedItems.append({getFormattedItemText(item.first), item.second});
     }
     if (isSorted) {
         sortComboItemsByName(sortedItems);
     }
-    for (const ComboItem &item : qAsConst(sortedItems)) {
+    for (const ComboItem& item : qAsConst(sortedItems)) {
         comboBox->addItem(item.first, item.second);
     }
-    connect(comboBox, SIGNAL(activated(const QString &)), this, SIGNAL(valueChanged(const QString &)));
+    connect(comboBox, SIGNAL(activated(const QString&)), this, SIGNAL(valueChanged(const QString&)));
     connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(sl_valueChanged(int)));
 }
 
@@ -225,7 +223,7 @@ QVariant ComboBoxWidget::value() {
     return comboBox->itemData(comboBox->currentIndex());
 }
 
-void ComboBoxWidget::setValue(const QVariant &value) {
+void ComboBoxWidget::setValue(const QVariant& value) {
     int idx = comboBox->findData(value);
     comboBox->setCurrentIndex(idx);
 }
@@ -235,7 +233,7 @@ void ComboBoxWidget::sl_valueChanged(int) {
     emit si_valueChanged(value());
 }
 
-ComboBoxWidget *ComboBoxWidget::createBooleanWidget(QWidget *parent) {
+ComboBoxWidget* ComboBoxWidget::createBooleanWidget(QWidget* parent) {
     QList<ComboItem> values;
     values.append(qMakePair(ComboBoxWidget::tr("False"), false));
     values.append(qMakePair(ComboBoxWidget::tr("True"), true));
@@ -245,19 +243,19 @@ ComboBoxWidget *ComboBoxWidget::createBooleanWidget(QWidget *parent) {
 /************************************************************************/
 /* ComboBoxEditableWidget */
 /************************************************************************/
-ComboBoxEditableWidget::ComboBoxEditableWidget(const QVariantMap &items, QWidget *parent)
+ComboBoxEditableWidget::ComboBoxEditableWidget(const QVariantMap& items, QWidget* parent)
     : PropertyWidget(parent), customIdx(-1) {
     comboBox = new QComboBox(this);
     comboBox->setEditable(true);
     addMainWidget(comboBox);
 
-    foreach (const QString &key, items.keys()) {
+    foreach (const QString& key, items.keys()) {
         comboBox->addItem(key, items[key]);
     }
 
-    connect(comboBox, SIGNAL(editTextChanged(const QString &)), this, SLOT(sl_edit(const QString &)));
+    connect(comboBox, SIGNAL(editTextChanged(const QString&)), this, SLOT(sl_edit(const QString&)));
 
-    connect(comboBox, SIGNAL(activated(const QString &)), this, SIGNAL(valueChanged(const QString &)));
+    connect(comboBox, SIGNAL(activated(const QString&)), this, SIGNAL(valueChanged(const QString&)));
     connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(sl_valueChanged(int)));
 }
 
@@ -265,7 +263,7 @@ QVariant ComboBoxEditableWidget::value() {
     return comboBox->itemData(comboBox->currentIndex());
 }
 
-void ComboBoxEditableWidget::setValue(const QVariant &value) {
+void ComboBoxEditableWidget::setValue(const QVariant& value) {
     int idx = comboBox->findData(value);
     if (idx == -1) {
         // try by text
@@ -292,7 +290,7 @@ void ComboBoxEditableWidget::sl_valueChanged(int) {
     emit si_valueChanged(value());
 }
 
-void ComboBoxEditableWidget::sl_edit(const QString &val) {
+void ComboBoxEditableWidget::sl_edit(const QString& val) {
     if (!val.isEmpty()) {
         setValue(val);
         comboBox->setFocus();
@@ -302,32 +300,32 @@ void ComboBoxEditableWidget::sl_edit(const QString &val) {
 /************************************************************************/
 /* ComboBoxWithUrlWidget */
 /************************************************************************/
-ComboBoxWithUrlWidget::ComboBoxWithUrlWidget(const QVariantMap &items, bool _isPath, QWidget *parent)
+ComboBoxWithUrlWidget::ComboBoxWithUrlWidget(const QVariantMap& items, bool _isPath, QWidget* parent)
     : PropertyWidget(parent), customIdx(-1), isPath(_isPath) {
     comboBox = new QComboBox(this);
     addMainWidget(comboBox);
 
-    foreach (const QString &key, items.keys()) {
+    foreach (const QString& key, items.keys()) {
         comboBox->addItem(key, items[key]);
     }
 
-    QToolButton *toolButton = new QToolButton(this);
+    auto toolButton = new QToolButton(this);
     toolButton->setObjectName("browsePathBtn");
     toolButton->setText("...");
     toolButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
     connect(toolButton, SIGNAL(clicked()), SLOT(sl_browse()));
     layout()->addWidget(toolButton);
 
-#ifdef Q_OS_DARWIN
-    toolButton->setMinimumHeight(18);
-    QString style = "QComboBox {"
-                    "min-height: 19px;"
-                    "max-height: 24px;"
-                    "}";
-    comboBox->setStyleSheet(style);
-#endif
+    if (isOsMac()) {
+        toolButton->setMinimumHeight(18);
+        QString style = "QComboBox {"
+                        "min-height: 19px;"
+                        "max-height: 24px;"
+                        "}";
+        comboBox->setStyleSheet(style);
+    }
 
-    connect(comboBox, SIGNAL(activated(const QString &)), this, SIGNAL(valueChanged(const QString &)));
+    connect(comboBox, SIGNAL(activated(const QString&)), this, SIGNAL(valueChanged(const QString&)));
     connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(sl_valueChanged(int)));
 }
 
@@ -335,7 +333,7 @@ QVariant ComboBoxWithUrlWidget::value() {
     return comboBox->itemData(comboBox->currentIndex());
 }
 
-void ComboBoxWithUrlWidget::setValue(const QVariant &value) {
+void ComboBoxWithUrlWidget::setValue(const QVariant& value) {
     int idx = comboBox->findData(value);
     if (idx == -1) {
         if (customIdx == -1) {
@@ -377,76 +375,24 @@ void ComboBoxWithUrlWidget::sl_browse() {
     comboBox->setFocus();
 }
 
-/************************************************************************/
-/* ComboBoxWithDbUrlWidget */
-/************************************************************************/
-ComboBoxWithDbUrlWidget::ComboBoxWithDbUrlWidget(QWidget *parent)
-    : ComboBoxWithUrlWidget(SharedDbUrlUtils::getKnownDbs(), false, parent) {
-}
-
-void ComboBoxWithDbUrlWidget::sl_browse() {
-    QObjectScopedPointer<EditConnectionDialog> editDialog = new EditConnectionDialog(this);
-    editDialog->setWindowTitle(tr("Add New Connection"));
-
-    const int dialogResult = editDialog->exec();
-    CHECK(!editDialog.isNull(), );
-
-    if (QDialog::Accepted == dialogResult) {
-        const QString dbUrlWithoutProvider = editDialog->getFullDbiUrl();
-        U2DbiRef dbiRef(MYSQL_DBI_ID, dbUrlWithoutProvider);  // TODO: fix this hardcoded value when other shared DB providers appear
-        const QString dbUrl = SharedDbUrlUtils::createDbUrl(dbiRef);
-        SharedDbUrlUtils::saveNewDbConnection(editDialog->getName(), dbUrlWithoutProvider);
-        updateComboValues();
-        setValue(dbUrl);
-    }
-}
-
-void ComboBoxWithDbUrlWidget::updateComboValues() {
-    const QString currentText = comboBox->currentText();
-    const QVariantMap sharedDbs = SharedDbUrlUtils::getKnownDbs();
-
-    comboBox->clear();
-    foreach (const QString &key, sharedDbs.keys()) {
-        comboBox->addItem(key, sharedDbs[key]);
-    }
-
-    const int curIndex = comboBox->findText(currentText);
-    if (-1 != curIndex) {
-        comboBox->setCurrentIndex(curIndex);
-    } else if (comboBox->count() > 0) {
-        comboBox->setCurrentIndex(0);
-    }
-}
-
-QVariantMap ComboBoxWithDbUrlWidget::getItems() const {
-    QVariantMap result;
-    CHECK(comboBox->count() != 0, result);
-
-    for (int i = 0; i < comboBox->count(); ++i) {
-        result.insert(comboBox->itemText(i), comboBox->itemData(i));
-    }
-
-    return result;
-}
-
 /************************************************************************/
 /* ComboBoxWithChecksWidget */
 /************************************************************************/
-ComboBoxWithChecksWidget::ComboBoxWithChecksWidget(const QVariantMap &_items, QWidget *parent, const QSharedPointer<StringFormatter> &formatter, bool isSorted)
+ComboBoxWithChecksWidget::ComboBoxWithChecksWidget(const QVariantMap& _items, QWidget* parent, const QSharedPointer<StringFormatter>& formatter, bool isSorted)
     : ComboBoxWidgetBase(parent, formatter, isSorted), cm(nullptr), items(_items) {
     comboBox = new QComboBox(this);
     addMainWidget(comboBox);
     initModelView();
 
-    connect(cm, SIGNAL(itemChanged(QStandardItem *)), this, SLOT(sl_itemChanged(QStandardItem *)));
-    connect(comboBox, SIGNAL(activated(const QString &)), this, SIGNAL(valueChanged(const QString &)));
+    connect(cm, SIGNAL(itemChanged(QStandardItem*)), this, SLOT(sl_itemChanged(QStandardItem*)));
+    connect(comboBox, SIGNAL(activated(const QString&)), this, SIGNAL(valueChanged(const QString&)));
     connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(sl_valueChanged(int)));
 }
 
 QVariant ComboBoxWithChecksWidget::value() {
     QStringList sList;
-    const QList<QString> &keys = items.keys();
-    foreach (const QString &key, keys) {
+    const QList<QString>& keys = items.keys();
+    foreach (const QString& key, keys) {
         if (items[key].toBool()) {
             sList << key;
         }
@@ -454,11 +400,11 @@ QVariant ComboBoxWithChecksWidget::value() {
     return sList.join(",");
 }
 
-void ComboBoxWithChecksWidget::setValue(const QVariant &value) {
+void ComboBoxWithChecksWidget::setValue(const QVariant& value) {
     QStringList curList = value.toString().split(',', QString::SkipEmptyParts);
     // 0-item is a `ghostItem` with the result of all currently checked checkboxes. That's why we start with 1.
     for (int i = 1; i < cm->rowCount(); i++) {
-        QStandardItem *item = cm->item(i);
+        QStandardItem* item = cm->item(i);
         QString key = item->data().toString();
         bool checked = curList.contains(key, Qt::CaseInsensitive);
         items[key] = checked;
@@ -471,8 +417,8 @@ void ComboBoxWithChecksWidget::sl_valueChanged(int) {
     emit si_valueChanged(value());
 }
 
-void ComboBoxWithChecksWidget::sl_itemChanged(QStandardItem *item) {
-    QStandardItem *standardItem = item;
+void ComboBoxWithChecksWidget::sl_itemChanged(QStandardItem* item) {
+    QStandardItem* standardItem = item;
     QString key = standardItem->data().toString();
 
     if (items.contains(key)) {
@@ -489,7 +435,7 @@ void ComboBoxWithChecksWidget::sl_itemChanged(QStandardItem *item) {
 QString ComboBoxWithChecksWidget::getFormattedValue() {
     QStringList selectedValues = value().toString().split(",");
     QStringList formattedValues;
-    for (const QString &value : qAsConst(selectedValues)) {
+    for (const QString& value : qAsConst(selectedValues)) {
         formattedValues << getFormattedItemText(value);
     }
     if (isSorted) {
@@ -504,7 +450,7 @@ void ComboBoxWithChecksWidget::initModelView() {
     auto ghostItem = new QStandardItem(getFormattedValue());
     cm->appendRow(ghostItem);
 
-    QList<QStandardItem *> standardItems;
+    QList<QStandardItem*> standardItems;
     for (auto it = items.begin(); it != items.end(); ++it) {
         QString formattedValue = getFormattedItemText(it.key());
         auto item = new QStandardItem(formattedValue);
@@ -533,15 +479,16 @@ void ComboBoxWithChecksWidget::initModelView() {
 /************************************************************************/
 /* URLWidget */
 /************************************************************************/
-URLWidget::URLWidget(const QString &type, bool multi, bool isPath, bool saveFile, DelegateTags *tags, QWidget *parent)
+URLWidget::URLWidget(const QString& type, bool multi, bool isPath, bool saveFile, DelegateTags* tags, QWidget* parent)
     : PropertyWidget(parent, tags) {
     setAutoFillBackground(true);
 
     urlLine = new URLLineEdit(type, multi, isPath, saveFile, this);
     urlLine->setObjectName("urlLine");
     urlLine->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+    connect(urlLine, &QLineEdit::editingFinished, this, &URLWidget::sl_finished);
     connect(urlLine, SIGNAL(si_finished()), SLOT(sl_finished()));
-    connect(urlLine, SIGNAL(textChanged(const QString &)), SLOT(sl_textChanged(const QString &)));
+    connect(urlLine, SIGNAL(textChanged(const QString&)), SLOT(sl_textChanged(const QString&)));
     addMainWidget(urlLine);
 
     browseButton = new QToolButton(this);
@@ -563,7 +510,7 @@ URLWidget::URLWidget(const QString &type, bool multi, bool isPath, bool saveFile
     setObjectName("URLWidget");
 }
 
-void URLWidget::sl_textChanged(const QString &text) {
+void URLWidget::sl_textChanged(const QString& text) {
     if (!urlLine->isMulti()) {
         return;
     }
@@ -575,11 +522,12 @@ QVariant URLWidget::value() {
     return urlLine->text();
 }
 
-void URLWidget::setValue(const QVariant &value) {
+void URLWidget::setValue(const QVariant& value) {
     if (value.canConvert<QList<Dataset>>()) {
         QStringList urls;
-        foreach (const Dataset &set, value.value<QList<Dataset>>()) {
-            foreach (URLContainer *c, set.getUrls()) {
+        foreach (const Dataset& set, value.value<QList<Dataset>>()) {
+            QList<URLContainer*> containers = set.getUrls();
+            for (URLContainer* c : qAsConst(containers)) {
                 urls << c->getUrl();
             }
         }
@@ -607,15 +555,15 @@ void URLWidget::sl_browse() {
         urlLine->sl_onBrowse();
         return;
     }
-    RunFileSystem *rfs = getRFS();
-    if (nullptr == rfs) {
+    RunFileSystem* rfs = getRFS();
+    if (rfs == nullptr) {
         urlLine->sl_onBrowse();
     } else {
         QObjectScopedPointer<OutputFileDialog> d = new OutputFileDialog(rfs, urlLine->isPath, urlLine->getCompletionFillerInstance(), this);
-        const int dialogResult = d->exec();
+        int dialogResult = d->exec();
         CHECK(!d.isNull(), );
 
-        if (QDialog::Accepted == dialogResult) {
+        if (dialogResult == QDialog::Accepted) {
             urlLine->setText(d->getResult());
         } else if (d->isSaveToFileSystem()) {
             urlLine->sl_onBrowse();
@@ -625,8 +573,8 @@ void URLWidget::sl_browse() {
 }
 
 void URLWidget::sl_finished() {
-    RunFileSystem *rfs = getRFS();
-    if (nullptr != rfs) {
+    RunFileSystem* rfs = getRFS();
+    if (rfs != nullptr) {
         QString result = urlLine->text();
         if ((result != initialValue) && RFSUtils::isCorrectUrl(result)) {
             if (rfs->canAdd(result, urlLine->isPath)) {
@@ -637,46 +585,48 @@ void URLWidget::sl_finished() {
             }
         }
     }
-    urlLine->setText(finalyze(urlLine->text()));
+    QString resultText = handleNewUrlInput(urlLine->text());
+    urlLine->setText(resultText);
+
     emit si_valueChanged(urlLine->text());
     emit finished();
 }
 
-RunFileSystem *URLWidget::getRFS() {
-    CHECK(nullptr != schemaConfig, nullptr);
+RunFileSystem* URLWidget::getRFS() {
+    CHECK(schemaConfig != nullptr, nullptr);
     return schemaConfig->getRFS();
 }
 
-QString URLWidget::finalyze(const QString &url) {
+QString URLWidget::handleNewUrlInput(const QString& url) {
     return url;
 }
 
 /************************************************************************/
 /* NoFileURLWidget */
 /************************************************************************/
-NoFileURLWidget::NoFileURLWidget(const QString &type, bool multi, bool isPath, bool saveFile, DelegateTags *tags, QWidget *parent)
+NoFileURLWidget::NoFileURLWidget(const QString& type, bool multi, bool isPath, bool saveFile, DelegateTags* tags, QWidget* parent)
     : URLWidget(type, multi, isPath, saveFile, tags, parent) {
 }
 
 static const QString FILE_TAG("file");
 
-QString NoFileURLWidget::finalyze(const QString &url, DelegateTags *tags) {
+QString NoFileURLWidget::handleNewUrlInput(const QString& url, DelegateTags* tags) {
     QFileInfo info(url);
     if (url.isEmpty() || info.isDir() || info.isRelative() || !info.exists()) {
-        if (nullptr != tags) {
+        if (tags != nullptr) {
             tags->set(FILE_TAG, "");
         }
         return url;
     }
 
-    if (nullptr != tags) {
+    if (tags != nullptr) {
         tags->set(FILE_TAG, info.fileName());
     }
     return info.dir().absolutePath();
 }
 
-QString NoFileURLWidget::finalyze(const QString &url) {
-    return finalyze(url, const_cast<DelegateTags *>(tags()));
+QString NoFileURLWidget::handleNewUrlInput(const QString& url) {
+    return handleNewUrlInput(url, const_cast<DelegateTags*>(tags()));
 }
 
 }  // namespace U2
