@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PROPERTYWIDGET_H_
-#define _U2_PROPERTYWIDGET_H_
+#pragma once
 
 #include <QComboBox>
 #include <QDoubleSpinBox>
@@ -52,18 +51,18 @@ static const int NO_LIMIT = -1;
 class BaseDefaultPropertyWidget : public PropertyWidget {
     Q_OBJECT
 public:
-    BaseDefaultPropertyWidget(QWidget *parent);
-    virtual QVariant value();
-    virtual void setValue(const QVariant &value);
-    virtual void setRequired();
+    BaseDefaultPropertyWidget(QWidget* parent);
+    QVariant value() override;
+    void setValue(const QVariant& value) override;
+    void setRequired() override;
 
 protected:
-    void configureLineEdit(const int maxLength);
+    void configureLineEdit(int maxLength);
 
-    QLineEdit *lineEdit;
+    QLineEdit* lineEdit;
 
 private slots:
-    void sl_valueChanged(const QString &value);
+    void sl_valueChanged(const QString& value);
 };
 
 /************************************************************************/
@@ -73,7 +72,7 @@ private slots:
 class DefaultPropertyWidget : public BaseDefaultPropertyWidget {
     Q_OBJECT
 public:
-    DefaultPropertyWidget(int maxLength = NO_LIMIT, QWidget *parent = nullptr);
+    DefaultPropertyWidget(int maxLength = NO_LIMIT, QWidget* parent = nullptr);
 };
 
 /************************************************************************/
@@ -83,7 +82,7 @@ public:
 class IgnoreUpDownPropertyWidget : public BaseDefaultPropertyWidget {
     Q_OBJECT
 public:
-    IgnoreUpDownPropertyWidget(int maxLength = NO_LIMIT, QWidget *parent = nullptr);
+    IgnoreUpDownPropertyWidget(int maxLength = NO_LIMIT, QWidget* parent = nullptr);
 };
 
 /************************************************************************/
@@ -92,10 +91,10 @@ public:
 
 class LineEditIgnoreUpDown : public QLineEdit {
 public:
-    LineEditIgnoreUpDown(QWidget *parent = nullptr);
+    LineEditIgnoreUpDown(QWidget* parent = nullptr);
 
 private:
-    void keyPressEvent(QKeyEvent *e) override;
+    void keyPressEvent(QKeyEvent* e) override;
 };
 
 /************************************************************************/
@@ -104,19 +103,19 @@ private:
 class SpinBoxWidget : public PropertyWidget {
     Q_OBJECT
 public:
-    SpinBoxWidget(const QVariantMap &spinProperties, QWidget *parent = nullptr);
-    virtual QVariant value();
-    virtual void setValue(const QVariant &value);
-    virtual void processDelegateTags();
+    SpinBoxWidget(const QVariantMap& spinProperties, QWidget* parent = nullptr);
+    QVariant value() override;
+    void setValue(const QVariant& value) override;
+    void processDelegateTags() override;
 
     /** Override */
-    bool setProperty(const char *name, const QVariant &value);
+    bool setProperty(const char* name, const QVariant& value);
 
 signals:
     void valueChanged(int value);
 
 private:
-    QSpinBox *spinBox;
+    QSpinBox* spinBox;
 
 private slots:
     void sl_valueChanged(int value);
@@ -128,12 +127,12 @@ private slots:
 class DoubleSpinBoxWidget : public PropertyWidget {
     Q_OBJECT
 public:
-    DoubleSpinBoxWidget(const QVariantMap &spinProperties, QWidget *parent = nullptr);
-    virtual QVariant value();
-    virtual void setValue(const QVariant &value);
+    DoubleSpinBoxWidget(const QVariantMap& spinProperties, QWidget* parent = nullptr);
+    QVariant value() override;
+    void setValue(const QVariant& value) override;
 
 private:
-    QDoubleSpinBox *spinBox;
+    QDoubleSpinBox* spinBox;
 
 private slots:
     void sl_valueChanged(double value);
@@ -142,16 +141,16 @@ private slots:
 /** Base class for different kinds of ComboBox widgets that adds support of features like value formatting, sorting, etc.. */
 class ComboBoxWidgetBase : public PropertyWidget {
 public:
-    ComboBoxWidgetBase(QWidget *parent = nullptr,
-                       const QSharedPointer<StringFormatter> &formatter = nullptr,
+    ComboBoxWidgetBase(QWidget* parent = nullptr,
+                       const QSharedPointer<StringFormatter>& formatter = nullptr,
                        bool isSorted = false);
 
     /** Returns formatted value for the item with the given name. */
-    QString getFormattedItemText(const QString &itemKey) const;
+    QString getFormattedItemText(const QString& itemKey) const;
 
 protected:
     /** Sorts in-place combo box items by name (item.first) in case-insensitive mode. */
-    static void sortComboItemsByName(QList<ComboItem> &itemList);
+    static void sortComboItemsByName(QList<ComboItem>& itemList);
 
     QSharedPointer<StringFormatter> formatter;
 
@@ -165,21 +164,21 @@ protected:
 class ComboBoxWidget : public ComboBoxWidgetBase {
     Q_OBJECT
 public:
-    ComboBoxWidget(const QList<ComboItem> &items,
-                   QWidget *parent = nullptr,
-                   const QSharedPointer<StringFormatter> &formatter = nullptr,
+    ComboBoxWidget(const QList<ComboItem>& items,
+                   QWidget* parent = nullptr,
+                   const QSharedPointer<StringFormatter>& formatter = nullptr,
                    bool isSorted = false);
 
     QVariant value() override;
-    void setValue(const QVariant &value) override;
+    void setValue(const QVariant& value) override;
 
-    static ComboBoxWidget *createBooleanWidget(QWidget *parent = nullptr);
+    static ComboBoxWidget* createBooleanWidget(QWidget* parent = nullptr);
 
 signals:
-    void valueChanged(const QString &value);
+    void valueChanged(const QString& value);
 
 private:
-    QComboBox *comboBox;
+    QComboBox* comboBox;
 
 private slots:
     void sl_valueChanged(int index);
@@ -191,18 +190,18 @@ private slots:
 class ComboBoxEditableWidget : public PropertyWidget {
     Q_OBJECT
 public:
-    ComboBoxEditableWidget(const QVariantMap &items, QWidget *parent = nullptr);
-    virtual QVariant value();
-    virtual void setValue(const QVariant &value);
+    ComboBoxEditableWidget(const QVariantMap& items, QWidget* parent = nullptr);
+    QVariant value() override;
+    void setValue(const QVariant& value) override;
 
 signals:
-    void valueChanged(const QString &value);
+    void valueChanged(const QString& value);
 
 protected slots:
-    virtual void sl_edit(const QString &val);
+    virtual void sl_edit(const QString& val);
 
 protected:
-    QComboBox *comboBox;
+    QComboBox* comboBox;
     int customIdx;
 
 private slots:
@@ -215,18 +214,18 @@ private slots:
 class ComboBoxWithUrlWidget : public PropertyWidget {
     Q_OBJECT
 public:
-    ComboBoxWithUrlWidget(const QVariantMap &items, bool isPath = false, QWidget *parent = nullptr);
-    virtual QVariant value();
-    virtual void setValue(const QVariant &value);
+    ComboBoxWithUrlWidget(const QVariantMap& items, bool isPath = false, QWidget* parent = nullptr);
+    QVariant value() override;
+    void setValue(const QVariant& value) override;
 
 signals:
-    void valueChanged(const QString &value);
+    void valueChanged(const QString& value);
 
 protected slots:
     virtual void sl_browse();
 
 protected:
-    QComboBox *comboBox;
+    QComboBox* comboBox;
     int customIdx;
     bool isPath;
 
@@ -234,49 +233,32 @@ private slots:
     void sl_valueChanged(int index);
 };
 
-/************************************************************************/
-/* ComboBoxWithDbUrlWidget */
-/************************************************************************/
-class ComboBoxWithDbUrlWidget : public ComboBoxWithUrlWidget {
-    Q_OBJECT
-public:
-    ComboBoxWithDbUrlWidget(QWidget *parent = nullptr);
-
-    QVariantMap getItems() const;
-
-protected:
-    virtual void sl_browse();
-
-private:
-    void updateComboValues();
-};
-
 /************************************************************************/
 /* ComboBoxWithChecksWidget */
 /************************************************************************/
 class U2DESIGNER_EXPORT ComboBoxWithChecksWidget : public ComboBoxWidgetBase {
     Q_OBJECT
 public:
-    ComboBoxWithChecksWidget(const QVariantMap &items,
-                             QWidget *parent = nullptr,
-                             const QSharedPointer<StringFormatter> &formatter = nullptr,
+    ComboBoxWithChecksWidget(const QVariantMap& items,
+                             QWidget* parent = nullptr,
+                             const QSharedPointer<StringFormatter>& formatter = nullptr,
                              bool isSorted = false);
 
     QVariant value() override;
 
-    void setValue(const QVariant &value) override;
+    void setValue(const QVariant& value) override;
 
 signals:
-    void valueChanged(const QString &value);
+    void valueChanged(const QString& value);
 
 protected:
-    QComboBox *comboBox;
-    QStandardItemModel *cm;
+    QComboBox* comboBox;
+    QStandardItemModel* cm;
     QVariantMap items;
 
 protected slots:
     virtual void sl_valueChanged(int index);
-    virtual void sl_itemChanged(QStandardItem *item);
+    virtual void sl_itemChanged(QStandardItem* item);
 
 private:
     void initModelView();
@@ -293,13 +275,13 @@ class RunFileSystem;
 class U2DESIGNER_EXPORT URLWidget : public PropertyWidget {
     Q_OBJECT
 public:
-    URLWidget(const QString &type, bool multi, bool isPath, bool saveFile, DelegateTags *tags, QWidget *parent = nullptr);
+    URLWidget(const QString& type, bool multi, bool isPath, bool saveFile, DelegateTags* tags, QWidget* parent = nullptr);
 
     // PropertyWidget
-    virtual QVariant value();
-    virtual void setValue(const QVariant &value);
-    virtual void setRequired();
-    virtual void activate();
+    QVariant value() override;
+    void setValue(const QVariant& value) override;
+    void setRequired() override;
+    void activate() override;
 
 signals:
     void finished();
@@ -309,19 +291,19 @@ private slots:
     void sl_finished();
 
 protected:
-    virtual QString finalyze(const QString &url);
+    virtual QString handleNewUrlInput(const QString& url);
 
 private:
-    RunFileSystem *getRFS();
+    RunFileSystem* getRFS();
 
 private:
-    URLLineEdit *urlLine;
-    QToolButton *browseButton;
-    QToolButton *addButton;
+    URLLineEdit* urlLine;
+    QToolButton* browseButton;
+    QToolButton* addButton;
     QString initialValue;
 
 private slots:
-    void sl_textChanged(const QString &text);
+    void sl_textChanged(const QString& text);
 };
 
 /************************************************************************/
@@ -329,14 +311,12 @@ private slots:
 /************************************************************************/
 class NoFileURLWidget : public URLWidget {
 public:
-    NoFileURLWidget(const QString &type, bool multi, bool isPath, bool saveFile, DelegateTags *tags, QWidget *parent = nullptr);
+    NoFileURLWidget(const QString& type, bool multi, bool isPath, bool saveFile, DelegateTags* tags, QWidget* parent = nullptr);
 
-    static QString finalyze(const QString &url, DelegateTags *tags);
+    static QString handleNewUrlInput(const QString& url, DelegateTags* tags);
 
 protected:
-    virtual QString finalyze(const QString &url);
+    QString handleNewUrlInput(const QString& url) override;
 };
 
 }  // namespace U2
-
-#endif  // _U2_PROPERTYWIDGET_H_
