@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_GUI_UTILS_H_
-#define _U2_WORKFLOW_GUI_UTILS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -35,11 +34,9 @@ class Descriptor;
 
 class U2DESIGNER_EXPORT DesignerGUIUtils {
 public:
-    static void paintSamplesArrow(QPainter *painter);
-    static void paintSamplesDocument(QPainter *painter, QTextDocument *doc, int pageWidth, int pageHeight, const QPalette &pal);
-    static void setupSamplesDocument(const Descriptor &d, const QIcon &ico, QTextDocument *res);
+    static void paintSamplesArrow(QPainter* painter);
+    static void paintSamplesDocument(QPainter* painter, QTextDocument* doc, int pageWidth, int pageHeight, const QPalette& pal);
+    static void setupSamplesDocument(const Descriptor& d, const QIcon& ico, QTextDocument* res);
 };
 
 }  // namespace U2
-
-#endif
