@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.unipro.ru
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DASHBOARD_INFO_H_
-#define _U2_DASHBOARD_INFO_H_
+#pragma once
 
 #include <QString>
 
@@ -31,11 +30,11 @@ namespace U2 {
 class U2DESIGNER_EXPORT DashboardInfo {
 public:
     DashboardInfo();
-    DashboardInfo(const QString &dirPath, bool opened = true);
+    DashboardInfo(const QString& dirPath, bool opened = true);
 
-    const QString &getId() const;
+    const QString& getId() const;
 
-    bool operator==(const DashboardInfo &other) const;
+    bool operator==(const DashboardInfo& other) const;
 
     QString path;
     QString dirName;
@@ -46,5 +45,3 @@ public:
 }  // namespace U2
 
 Q_DECLARE_METATYPE(U2::DashboardInfo)
-
-#endif  // _U2_DASHBOARD_INFO_H_
