@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DASHBOARD_TAB_PAGE_H_
-#define _U2_DASHBOARD_TAB_PAGE_H_
+#pragma once
 
 #include <QLayout>
 #include <QScrollArea>
@@ -35,14 +34,13 @@ class U2DESIGNER_EXPORT DashboardTabPage : public QScrollArea {
     Q_OBJECT
 
 public:
-    DashboardTabPage(const QString &tabObjectName);
+    DashboardTabPage(const QString& tabObjectName);
 
-    DashboardWidget *addDashboardWidget(const QString &title, QWidget *contentWidget);
+    DashboardWidget* addDashboardWidget(const QString& title, QWidget* contentWidget);
 
 private:
-    QVBoxLayout *leftColumnLayout;
-    QVBoxLayout *rightColumnLayout;
+    QVBoxLayout* leftColumnLayout;
+    QVBoxLayout* rightColumnLayout;
 };
 
 }  // namespace U2
-#endif
