@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.unipro.ru
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_REMOVE_DASHBOARDS_TASK_H_
-#define _U2_REMOVE_DASHBOARDS_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -31,7 +30,7 @@ namespace U2 {
 class U2DESIGNER_EXPORT RemoveDashboardsTask : public Task {
     Q_OBJECT
 public:
-    RemoveDashboardsTask(const QList<DashboardInfo> &dashboardInfos);
+    RemoveDashboardsTask(const QList<DashboardInfo>& dashboardInfos);
 
 private:
     void run() override;
@@ -40,5 +39,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_REMOVE_DASHBOARDS_TASK_H_
