@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.unipro.ru
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SCAN_DASHBOARDS_DIR_TASK_H_
-#define _U2_SCAN_DASHBOARDS_DIR_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -33,17 +32,15 @@ class U2DESIGNER_EXPORT ScanDashboardsDirTask : public Task {
 public:
     ScanDashboardsDirTask();
 
-    const QList<DashboardInfo> &getResult() const;
+    const QList<DashboardInfo>& getResult() const;
 
 private:
     void run() override;
 
-    static bool isDashboardDir(const QString &dirPath);
-    static DashboardInfo readDashboardInfo(const QString &dirPath);
+    static bool isDashboardDir(const QString& dirPath);
+    static DashboardInfo readDashboardInfo(const QString& dirPath);
 
     QList<DashboardInfo> dashboardInfos;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SCAN_DASHBOARDS_DIR_TASK_H_
