@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OUTPUTDIRECTORYWIDGET_H_
-#define _U2_OUTPUTDIRECTORYWIDGET_H_
+#pragma once
 
 #include <QLineEdit>
 #include <QWidget>
@@ -36,7 +35,7 @@ namespace U2 {
 class U2DESIGNER_EXPORT OutputDirectoryWidget : public QWidget {
     Q_OBJECT
 public:
-    OutputDirectoryWidget(QWidget *parent, bool commitOnHide);
+    OutputDirectoryWidget(QWidget* parent, bool commitOnHide);
 
     QString getChoosenDir() {
         return pathEdit->text();
@@ -49,15 +48,13 @@ private slots:
     void sl_browse();
 
 protected:
-    void hideEvent(QHideEvent *event);
+    void hideEvent(QHideEvent* event);
 
 private:
     bool commitOnHide;
-    QLabel *label;
-    QLineEdit *pathEdit;
-    QToolButton *browseButton;
+    QLabel* label;
+    QLineEdit* pathEdit;
+    QToolButton* browseButton;
 };
 
 }  // namespace U2
-
-#endif  // _U2_OUTPUTDIRECTORYWIDGET_H_
