@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +22,6 @@
 #include "URLLineEdit.h"
 
 #include <QFocusEvent>
-#include <QLayout>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/DocumentModel.h>
@@ -33,19 +32,17 @@
 #include <U2Gui/SuggestCompleter.h>
 #include <U2Gui/U2FileDialog.h>
 
-#include <U2Lang/SchemaConfig.h>
-
 #include "PropertyWidget.h"
 
 namespace U2 {
 
 class FilenameCompletionFiller : public CompletionFiller {
 public:
-    FilenameCompletionFiller(URLWidget *_widget)
+    FilenameCompletionFiller(URLWidget* _widget)
         : CompletionFiller(), widget(_widget) {
     }
 
-    virtual QStringList getSuggestions(const QString &str) {
+    QStringList getSuggestions(const QString& str) override {
         QString fileName = str;
         if (fileName.endsWith(".")) {
             fileName = fileName.left(fileName.size() - 1);
@@ -58,30 +55,30 @@ public:
 
         const QStringList presetExtensions = DelegateTags::getStringList(widget->tags(), "extensions");
         if (presetExtensions.isEmpty()) {
-            bool ok = fillChoisesWithFormatExtensions(fileName, choices);
+            bool ok = fillChoicesWithFormatExtensions(fileName, choices);
             CHECK(ok, QStringList());
         } else {
-            fillChoisesWithPresetExtensions(fileName, presetExtensions, choices);
+            fillChoicesWithPresetExtensions(fileName, presetExtensions, choices);
         }
 
         return choices;
     }
 
-    bool fillChoisesWithFormatExtensions(const QString &fileName, QStringList &choices) {
+    bool fillChoicesWithFormatExtensions(const QString& fileName, QStringList& choices) {
         const QFileInfo f(fileName);
         const QString curExt = f.suffix();
         const QString baseName = f.completeBaseName();
         const QString completeFileName = f.fileName();
 
         const QString fileFormat = DelegateTags::getString(widget->tags(), "format");
-        DocumentFormat *format = AppContext::getDocumentFormatRegistry()->getFormatById(fileFormat);
-        CHECK(nullptr != format, false);
+        DocumentFormat* format = AppContext::getDocumentFormatRegistry()->getFormatById(fileFormat);
+        CHECK(format != nullptr, false);
 
         QStringList formats = format->getSupportedDocumentFileExtensions();
-        CHECK(formats.size() > 0, false);
+        CHECK(!formats.empty(), false);
         formats.append("gz");
 
-        foreach (const QString &ext, formats) {
+        foreach (const QString& ext, formats) {
             if (!curExt.isEmpty()) {
                 if (ext.startsWith(curExt, Qt::CaseInsensitive)) {
                     choices << baseName + "." + ext;
@@ -93,7 +90,7 @@ public:
         }
 
         if (choices.size() == 1) {
-            foreach (const QString &ext, formats) {
+            foreach (const QString& ext, formats) {
                 choices << completeFileName + "." + ext;
                 if (ext != "gz") {
                     choices << completeFileName + "." + ext + ".gz";
@@ -103,16 +100,16 @@ public:
         return true;
     }
 
-    static void fillChoisesWithPresetExtensions(const QString &fileName, const QStringList &presetExtensions, QStringList &choices) {
+    static void fillChoicesWithPresetExtensions(const QString& fileName, const QStringList& presetExtensions, QStringList& choices) {
         const QFileInfo f(fileName);
         const QString baseName = f.completeBaseName();
 
-        foreach (const QString &extenstion, presetExtensions) {
-            choices << baseName + "." + extenstion;
+        foreach (const QString& extension, presetExtensions) {
+            choices << baseName + "." + extension;
         }
     }
 
-    virtual QString finalyze(const QString &editorText, const QString &suggestion) {
+    QString handleNewUrlInput(const QString& editorText, const QString& suggestion) override {
         QString path = editorText;
         path.replace("\\", "/");
 
@@ -123,14 +120,14 @@ public:
     }
 
 private:
-    URLWidget *widget;
+    URLWidget* widget;
 };
 
-URLLineEdit::URLLineEdit(const QString &type,
+URLLineEdit::URLLineEdit(const QString& type,
                          bool multi,
                          bool isPath,
                          bool saveFile,
-                         URLWidget *_parent)
+                         URLWidget* _parent)
     : QLineEdit(_parent),
       schemaConfig(nullptr),
       type(type),
@@ -138,14 +135,14 @@ URLLineEdit::URLLineEdit(const QString &type,
       isPath(isPath),
       saveFile(saveFile),
       parent(_parent) {
-    if (saveFile && nullptr != parent) {
+    if (saveFile && parent != nullptr) {
         new BaseCompleter(new FilenameCompletionFiller(parent), this);
     }
     setPlaceholderText(DelegateTags::getString(parent->tags(), DelegateTags::PLACEHOLDER_TEXT));
 }
 
-CompletionFiller *URLLineEdit::getCompletionFillerInstance() {
-    if (saveFile && nullptr != parent) {
+CompletionFiller* URLLineEdit::getCompletionFillerInstance() const {
+    if (saveFile && parent != nullptr) {
         return new FilenameCompletionFiller(parent);
     }
     return nullptr;
@@ -161,7 +158,7 @@ void URLLineEdit::sl_onBrowseWithAdding() {
 
 void URLLineEdit::browse(bool addFiles) {
     QString FileFilter;
-    if (nullptr != parent) {
+    if (parent != nullptr) {
         FileFilter = DelegateTags::getString(parent->tags(), DelegateTags::FILTER);
     }
     LastUsedDirHelper lod(type);
@@ -200,15 +197,10 @@ void URLLineEdit::browse(bool addFiles) {
         }
     } else {
         if (saveFile) {
-            lod.url = name = U2FileDialog::getSaveFileName(nullptr, tr("Select a file"), lastDir, FileFilter, 0, QFileDialog::DontConfirmOverwrite);
+            lod.url = name = U2FileDialog::getSaveFileName(nullptr, tr("Select a file"), lastDir, FileFilter, nullptr, QFileDialog::DontConfirmOverwrite);
             this->checkExtension(name);
         } else {
-#ifdef Q_OS_DARWIN
-            if (qgetenv(ENV_GUI_TEST).toInt() == 1 && qgetenv(ENV_USE_NATIVE_DIALOGS).toInt() == 0) {
-                lod.url = name = U2FileDialog::getOpenFileName(nullptr, tr("Select a file"), lastDir, FileFilter, 0, QFileDialog::DontUseNativeDialog);
-            } else
-#endif
-                lod.url = name = U2FileDialog::getOpenFileName(nullptr, tr("Select a file"), lastDir, FileFilter);
+            lod.url = name = U2FileDialog::getOpenFileName(nullptr, tr("Select a file"), lastDir, FileFilter);
         }
     }
     if (!name.isEmpty()) {
@@ -221,29 +213,17 @@ void URLLineEdit::browse(bool addFiles) {
     emit si_finished();
 }
 
-void URLLineEdit::focusOutEvent(QFocusEvent *event) {
-    sl_completionFinished();
-    QLineEdit::focusOutEvent(event);
-}
-
-void URLLineEdit::keyPressEvent(QKeyEvent *event) {
-    if (Qt::Key_Enter == event->key()) {
-        sl_completionFinished();
-    }
-    QLineEdit::keyPressEvent(event);
-}
-
-void URLLineEdit::checkExtension(QString &name) {
+void URLLineEdit::checkExtension(QString& name) const {
     QString fileFormat;
-    if (nullptr != parent) {
+    if (parent != nullptr) {
         fileFormat = DelegateTags::getString(parent->tags(), DelegateTags::FORMAT);
     }
-    DocumentFormat *format = AppContext::getDocumentFormatRegistry()->getFormatById(fileFormat);
-    if (nullptr != format && !name.isEmpty()) {
+    DocumentFormat* format = AppContext::getDocumentFormatRegistry()->getFormatById(fileFormat);
+    if (format != nullptr && !name.isEmpty()) {
         QString newName(name);
         GUrl url(newName);
         QString lastSuffix = url.lastFileSuffix();
-        if ("gz" == lastSuffix) {
+        if (lastSuffix == "gz") {
             int dotPos = newName.length() - lastSuffix.length() - 1;
             if ((dotPos >= 0) && (QChar('.') == newName[dotPos])) {
                 newName = url.getURLString().left(dotPos);
@@ -253,7 +233,7 @@ void URLLineEdit::checkExtension(QString &name) {
         }
         bool foundExt = false;
         foreach (QString supExt, format->getSupportedDocumentFileExtensions()) {
-            if (lastSuffix == supExt) {
+            if (supExt == lastSuffix) {
                 foundExt = true;
                 break;
             }
@@ -269,12 +249,8 @@ void URLLineEdit::checkExtension(QString &name) {
     }
 }
 
-bool URLLineEdit::isMulti() {
+bool URLLineEdit::isMulti() const {
     return multi;
 }
 
-void URLLineEdit::sl_completionFinished() {
-    emit si_finished();
-}
-
 }  // namespace U2
