@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_URLLINEEDIT_H_
-#define _U2_URLLINEEDIT_H_
+#pragma once
 
 #include <QLineEdit>
 #include <QObject>
@@ -37,41 +36,34 @@ class URLWidget;
 class URLLineEdit : public QLineEdit {
     Q_OBJECT
 public:
-    URLLineEdit(const QString &type,
+    URLLineEdit(const QString& type,
                 bool multi,
                 bool isPath,
                 bool saveFile,
-                URLWidget *parent);
-    bool isMulti();
-    CompletionFiller *getCompletionFillerInstance();
-
-protected:
-    void focusOutEvent(QFocusEvent *event);
-    void keyPressEvent(QKeyEvent *event);
+                URLWidget* parent);
+    bool isMulti() const;
+    CompletionFiller* getCompletionFillerInstance() const;
 
 public slots:
     void sl_onBrowse();
 
 private slots:
     void sl_onBrowseWithAdding();
-    void sl_completionFinished();
 
 signals:
     void si_finished();
 
 public:
-    SchemaConfig *schemaConfig;
+    SchemaConfig* schemaConfig;
     QString type;
     bool multi;
     bool isPath;
     bool saveFile;
-    URLWidget *parent;
+    URLWidget* parent;
 
 private:
     void browse(bool addFiles = false);
-    void checkExtension(QString &name);
+    void checkExtension(QString& name) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_URLLINEEDIT_H_
