@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BOWTIEWIDGETCONTROLLER_H_
-#define _U2_BOWTIEWIDGETCONTROLLER_H_
+#pragma once
 
 #include <U2Lang/WizardWidget.h>
 
@@ -32,25 +31,23 @@ namespace U2 {
 class BowtieWidgetController : public WidgetController {
     Q_OBJECT
 public:
-    BowtieWidgetController(WizardController *wc, BowtieWidget *bw, int labelSize);
+    BowtieWidgetController(WizardController* wc, BowtieWidget* bw, int labelSize);
     ~BowtieWidgetController();
 
-    virtual QWidget *createGUI(U2OpStatus &os);
+    virtual QWidget* createGUI(U2OpStatus& os);
 
 private slots:
     void sl_browse();
 
 private:
-    QString finalyze(const QString &url);
+    QString handleNewUrlInput(const QString& url);
 
 private:
-    BowtieWidget *bw;
-    AttributeWidget *dirW;
-    AttributeWidget *nameW;
-    DefaultPropertyController *dirCtrl;
-    DefaultPropertyController *nameCtrl;
+    BowtieWidget* bw;
+    AttributeWidget* dirW;
+    AttributeWidget* nameW;
+    DefaultPropertyController* dirCtrl;
+    DefaultPropertyController* nameCtrl;
 };
 
 }  // namespace U2
-
-#endif  // _U2_BOWTIEWIDGETCONTROLLER_H_
