@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ELEMENTSELECTORCONTROLLER_H_
-#define _U2_ELEMENTSELECTORCONTROLLER_H_
+#pragma once
 
 #include <U2Lang/ElementSelectorWidget.h>
 #include <U2Lang/Schema.h>
@@ -35,19 +34,17 @@ class WizardController;
 class ElementSelectorController : public WidgetController {
     Q_OBJECT
 public:
-    ElementSelectorController(WizardController *wc, ElementSelectorWidget *widget, int labelSize);
+    ElementSelectorController(WizardController* wc, ElementSelectorWidget* widget, int labelSize);
     virtual ~ElementSelectorController();
 
-    virtual QWidget *createGUI(U2OpStatus &os);
+    virtual QWidget* createGUI(U2OpStatus& os);
 
 private:
-    ElementSelectorWidget *widget;
+    ElementSelectorWidget* widget;
     int labelSize;
 
 private slots:
-    void sl_valueChanged(const QVariant &newValue);
+    void sl_valueChanged(const QVariant& newValue);
 };
 
 }  // namespace U2
-
-#endif  // _U2_ELEMENTSELECTORCONTROLLER_H_
