@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PAIREDDATASETSCONTROLLER_H_
-#define _U2_PAIREDDATASETSCONTROLLER_H_
+#pragma once
 
 #include <U2Designer/DatasetsController.h>
 
@@ -33,19 +32,17 @@ namespace U2 {
 class PairedDatasetsController : public WidgetController {
     Q_OBJECT
 public:
-    PairedDatasetsController(WizardController *wc, PairedReadsWidget *widget);
+    PairedDatasetsController(WizardController* wc, PairedReadsWidget* widget);
     virtual ~PairedDatasetsController();
 
-    virtual QWidget *createGUI(U2OpStatus &os);
+    virtual QWidget* createGUI(U2OpStatus& os);
 
 private slots:
     void sl_datasetsChanged();
 
 private:
-    PairedReadsWidget *widget;
-    PairedReadsController *dsc;
+    PairedReadsWidget* widget;
+    PairedReadsController* dsc;
 };
 
 }  // namespace U2
-
-#endif  // _U2_PAIREDDATASETSCONTROLLER_H_
