@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_RADIOCONTROLLER_H_
-#define _U2_RADIOCONTROLLER_H_
+#pragma once
 
 #include <U2Designer/WizardController.h>
 
@@ -33,18 +32,16 @@ namespace U2 {
 class RadioController : public WidgetController {
     Q_OBJECT
 public:
-    RadioController(WizardController *wc, RadioWidget *rw);
+    RadioController(WizardController* wc, RadioWidget* rw);
     virtual ~RadioController();
 
-    virtual QWidget *createGUI(U2OpStatus &os);
+    virtual QWidget* createGUI(U2OpStatus& os);
 
 private slots:
-    void sl_buttonClicked(QAbstractButton *button);
+    void sl_buttonClicked(QAbstractButton* button);
 
 private:
-    RadioWidget *rw;
+    RadioWidget* rw;
 };
 
 }  // namespace U2
-
-#endif  // _U2_RADIOCONTROLLER_H_
