@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SETTINGS_CONTROLLER_H_
-#define _U2_SETTINGS_CONTROLLER_H_
+#pragma once
 
 #include <U2Designer/WizardController.h>
 
@@ -33,10 +32,10 @@ namespace U2 {
 class SettingsController : public WidgetController {
     Q_OBJECT
 public:
-    SettingsController(WizardController *wc, SettingsWidget *sw);
+    SettingsController(WizardController* wc, SettingsWidget* sw);
     virtual ~SettingsController();
 
-    virtual QWidget *createGUI(U2OpStatus &os);
+    virtual QWidget* createGUI(U2OpStatus& os);
 
     static const QString TYPE_URL;
 private slots:
@@ -44,14 +43,12 @@ private slots:
     void sl_fileSelect();
 
 private:
-    SettingsWidget *sw;
-    QLineEdit *lineEdit;
+    SettingsWidget* sw;
+    QLineEdit* lineEdit;
 
 private:
-    QWidget *createUrlSettingsWidget(U2OpStatus &os);
+    QWidget* createUrlSettingsWidget(U2OpStatus& os);
     QString getSettingValue();
 };
 
 }  // namespace U2
-
-#endif  // _U2_SETTINGS_CONTROLLER_H_
