@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -40,17 +40,17 @@
 
 namespace U2 {
 
-TophatSamplesWidgetController::TophatSamplesWidgetController(WizardController *wc, TophatSamplesWidget *tsw)
+TophatSamplesWidgetController::TophatSamplesWidgetController(WizardController* wc, TophatSamplesWidget* tsw)
     : WidgetController(wc), tsw(tsw) {
 }
 
-QWidget *TophatSamplesWidgetController::createGUI(U2OpStatus & /*os*/) {
+QWidget* TophatSamplesWidgetController::createGUI(U2OpStatus& /*os*/) {
     initSamplesMap();
     commit();
     return new TophatSamples(samples, this);
 }
 
-void TophatSamplesWidgetController::renameSample(int pos, const QString &newName, U2OpStatus &os) {
+void TophatSamplesWidgetController::renameSample(int pos, const QString& newName, U2OpStatus& os) {
     checkRange(pos, EXCLUSIVE, os);
     CHECK_OP(os, );
 
@@ -67,7 +67,7 @@ void TophatSamplesWidgetController::renameSample(int pos, const QString &newName
 
     // check duplicates
     for (int i = 0; i < samples.size(); i++) {
-        TophatSample &sample = samples[i];
+        TophatSample& sample = samples[i];
         if ((pos != i) && (sample.name == newName)) {
             os.setError(tr("Duplicate sample name"));
             return;
@@ -75,12 +75,12 @@ void TophatSamplesWidgetController::renameSample(int pos, const QString &newName
     }
 
     // update model
-    TophatSample &sample = samples[pos];
+    TophatSample& sample = samples[pos];
     sample.name = newName;
     commit();
 }
 
-bool TophatSamplesWidgetController::removeSample(int pos, QStringList &insertToFirst, QList<TophatSample> &append) {
+bool TophatSamplesWidgetController::removeSample(int pos, QStringList& insertToFirst, QList<TophatSample>& append) {
     U2OpStatusImpl os;
     checkRange(pos, EXCLUSIVE, os);
     CHECK_OP(os, false);
@@ -99,13 +99,13 @@ bool TophatSamplesWidgetController::removeSample(int pos, QStringList &insertToF
     return true;
 }
 
-TophatSample TophatSamplesWidgetController::insertSample(int pos, U2OpStatus &os) {
+TophatSample TophatSamplesWidgetController::insertSample(int pos, U2OpStatus& os) {
     TophatSample result("", QStringList());
     checkRange(pos, INCLUSIVE, os);
     CHECK_OP(os, result);
 
     QStringList names;
-    foreach (const TophatSample &s, samples) {
+    foreach (const TophatSample& s, samples) {
         names << s.name;
     }
 
@@ -125,14 +125,14 @@ TophatSample TophatSamplesWidgetController::insertSample(int pos, U2OpStatus &os
     return result;
 }
 
-void TophatSamplesWidgetController::replaceDataset(int oldSamplePos, int oldDatasetPos, int newSamplePos, int newDatasetPos, U2OpStatus &os) {
+void TophatSamplesWidgetController::replaceDataset(int oldSamplePos, int oldDatasetPos, int newSamplePos, int newDatasetPos, U2OpStatus& os) {
     checkDatasetRange(oldSamplePos, oldDatasetPos, EXCLUSIVE, os);
     CHECK_OP(os, );
     checkRange(newSamplePos, EXCLUSIVE, os);
     CHECK_OP(os, );
 
-    TophatSample &oldSample = samples[oldSamplePos];
-    TophatSample &newSample = samples[newSamplePos];
+    TophatSample& oldSample = samples[oldSamplePos];
+    TophatSample& newSample = samples[newSamplePos];
     RangeType type = (&oldSample == &newSample) ? EXCLUSIVE : INCLUSIVE;
     checkDatasetRange(newSamplePos, newDatasetPos, type, os);
     CHECK_OP(os, );
@@ -179,8 +179,8 @@ void TophatSamplesWidgetController::initSamplesMap() {
 void TophatSamplesWidgetController::removeMissedDatasets() {
     QStringList allDatasets = getAllDatasets();
     for (int i = 0; i < samples.size(); i++) {
-        QStringList &sampled = samples[i].datasets;
-        foreach (const QString &d, sampled) {
+        QStringList& sampled = samples[i].datasets;
+        foreach (const QString& d, sampled) {
             if (!allDatasets.contains(d)) {
                 sampled.removeAll(d);
             }
@@ -188,15 +188,15 @@ void TophatSamplesWidgetController::removeMissedDatasets() {
     }
 }
 
-void TophatSamplesWidgetController::checkRange(int pos, RangeType rangeType, U2OpStatus &os) const {
+void TophatSamplesWidgetController::checkRange(int pos, RangeType rangeType, U2OpStatus& os) const {
     int lastPos = (rangeType == INCLUSIVE) ? samples.size() : samples.size() - 1;
     SAFE_POINT_EXT(pos <= lastPos && pos > -1, os.setError("Out of range"), );
 }
 
-void TophatSamplesWidgetController::checkDatasetRange(int samplePos, int datasetPos, RangeType rangeType, U2OpStatus &os) const {
+void TophatSamplesWidgetController::checkDatasetRange(int samplePos, int datasetPos, RangeType rangeType, U2OpStatus& os) const {
     checkRange(samplePos, EXCLUSIVE, os);
     CHECK_OP(os, );
-    const TophatSample &s = samples[samplePos];
+    const TophatSample& s = samples[samplePos];
 
     int lastPos = (rangeType == INCLUSIVE) ? s.datasets.size() : s.datasets.size() - 1;
     SAFE_POINT_EXT(datasetPos <= lastPos && datasetPos > -1, os.setError("Out of range"), );
@@ -207,7 +207,7 @@ QStringList TophatSamplesWidgetController::getAllDatasets() const {
     QList<Dataset> datasets = wc->getAttributeValue(dsInfo).value<QList<Dataset>>();
 
     QStringList result;
-    foreach (const Dataset &d, datasets) {
+    foreach (const Dataset& d, datasets) {
         result << d.getName();
     }
     return result;
@@ -215,16 +215,16 @@ QStringList TophatSamplesWidgetController::getAllDatasets() const {
 
 QStringList TophatSamplesWidgetController::getSampledDatasets() const {
     QStringList result;
-    foreach (const TophatSample &s, samples) {
+    foreach (const TophatSample& s, samples) {
         result << s.datasets;
     }
     return result;
 }
 
-QStringList TophatSamplesWidgetController::getUnsampledDatasets(const QStringList &sampledDatasets) const {
+QStringList TophatSamplesWidgetController::getUnsampledDatasets(const QStringList& sampledDatasets) const {
     QStringList result;
     QStringList allDatasets = getAllDatasets();
-    foreach (const QString &d, allDatasets) {
+    foreach (const QString& d, allDatasets) {
         if (!sampledDatasets.contains(d)) {
             result << d;
         }
@@ -241,14 +241,14 @@ void TophatSamplesWidgetController::commit() {
 /************************************************************************/
 class SampleNameEdit : public QLineEdit {
 public:
-    SampleNameEdit(TophatSamples *samples, const QString &name, QWidget *parent)
+    SampleNameEdit(TophatSamples* samples, const QString& name, QWidget* parent)
         : QLineEdit(name, parent), samples(samples), initialName(name) {
         setValidator(new QRegExpValidator(QRegExp("\\w*"), this));
         setObjectName(name);
     }
 
 protected:
-    void focusOutEvent(QFocusEvent *e) {
+    void focusOutEvent(QFocusEvent* e) {
         bool renamed = samples->rename(this);
         if (!renamed) {
             setText(initialName);
@@ -257,23 +257,23 @@ protected:
     }
 
 private:
-    TophatSamples *samples;
+    TophatSamples* samples;
     QString initialName;
 };
 
 /************************************************************************/
 /* TophatSamples */
 /************************************************************************/
-TophatSamples::TophatSamples(const QList<TophatSample> &samples, TophatSamplesWidgetController *ctrl, QWidget *parent)
+TophatSamples::TophatSamples(const QList<TophatSample>& samples, TophatSamplesWidgetController* ctrl, QWidget* parent)
     : QWidget(parent), ctrl(ctrl), scrollArea(nullptr), listLayout(nullptr), upButton(nullptr), downButton(nullptr) {
     init(samples);
 }
 
-void TophatSamples::init(const QList<TophatSample> &samples) {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+void TophatSamples::init(const QList<TophatSample>& samples) {
+    QVBoxLayout* mainLayout = new QVBoxLayout(this);
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
-    QLabel *hint = new QLabel(this);
+    QLabel* hint = new QLabel(this);
     mainLayout->addWidget(hint);
     {
         hint->setWordWrap(true);
@@ -294,14 +294,14 @@ void TophatSamples::init(const QList<TophatSample> &samples) {
         hint->setStyleSheet(style);
     }
 
-    QHBoxLayout *hl = new QHBoxLayout();
+    QHBoxLayout* hl = new QHBoxLayout();
     mainLayout->addLayout(hl);
     hl->setContentsMargins(0, 0, 0, 0);
 
     hl->addWidget(createScrollArea());
     hl->addLayout(createControlButtonsLayout());
 
-    foreach (const TophatSample &sample, samples) {
+    foreach (const TophatSample& sample, samples) {
         appendSample(sample);
     }
 
@@ -313,31 +313,31 @@ void TophatSamples::init(const QList<TophatSample> &samples) {
     updateArrows();
 }
 
-void TophatSamples::appendSample(const TophatSample &sample) {
-    QWidget *sw = initSample(sample.name, sample.datasets);
+void TophatSamples::appendSample(const TophatSample& sample) {
+    QWidget* sw = initSample(sample.name, sample.datasets);
     order << sw;
     listLayout->addWidget(sw);
 }
 
-QWidget *TophatSamples::initSample(const QString &sampleName, const QStringList &datasets) {
-    QWidget *result = new QGroupBox(this);
-    QVBoxLayout *vl = new QVBoxLayout(result);
+QWidget* TophatSamples::initSample(const QString& sampleName, const QStringList& datasets) {
+    QWidget* result = new QGroupBox(this);
+    QVBoxLayout* vl = new QVBoxLayout(result);
     vl->setContentsMargins(5, 5, 5, 5);
 
-    QHBoxLayout *hl = new QHBoxLayout();
+    QHBoxLayout* hl = new QHBoxLayout();
     {  // header
         hl->setContentsMargins(0, 0, 0, 0);
-        QToolButton *removeButton = createButton(this, ":U2Designer/images/exit.png");
+        QToolButton* removeButton = createButton(this, ":U2Designer/images/exit.png");
         connect(removeButton, SIGNAL(clicked()), SLOT(sl_remove()));
         hl->addWidget(new SampleNameEdit(this, sampleName, this));
         hl->addWidget(removeButton);
     }
     vl->addLayout(hl);
 
-    QListWidget *datasetsList = new QListWidget(this);
+    QListWidget* datasetsList = new QListWidget(this);
     datasetsList->setObjectName(sampleName + " datasetsList");
     {  // datasets
-        foreach (const QString &dataset, datasets) {
+        foreach (const QString& dataset, datasets) {
             datasetsList->addItem(dataset);
         }
         connect(datasetsList, SIGNAL(itemSelectionChanged()), SLOT(sl_selectionChanged()));
@@ -347,8 +347,8 @@ QWidget *TophatSamples::initSample(const QString &sampleName, const QStringList
     return result;
 }
 
-bool TophatSamples::rename(QLineEdit *nameEdit) {
-    QWidget *sampleWidget = nameEdit->parentWidget();
+bool TophatSamples::rename(QLineEdit* nameEdit) {
+    QWidget* sampleWidget = nameEdit->parentWidget();
     CHECK(order.contains(sampleWidget), true);
 
     U2OpStatusImpl os;
@@ -363,10 +363,10 @@ bool TophatSamples::rename(QLineEdit *nameEdit) {
 }
 
 void TophatSamples::sl_remove() {
-    QToolButton *toolButton = dynamic_cast<QToolButton *>(sender());
-    SAFE_POINT(nullptr != toolButton, "NULL button", );
-    QWidget *sampleWidget = toolButton->parentWidget();
-    CHECK(nullptr != sampleWidget, );
+    auto toolButton = dynamic_cast<QToolButton*>(sender());
+    SAFE_POINT(toolButton != nullptr, "NULL button", );
+    QWidget* sampleWidget = toolButton->parentWidget();
+    CHECK(sampleWidget != nullptr, );
     CHECK(order.contains(sampleWidget), );
 
     // remove
@@ -378,12 +378,12 @@ void TophatSamples::sl_remove() {
     // update ui
     order.removeOne(sampleWidget);
     delete sampleWidget;
-    foreach (const TophatSample &sample, append) {
+    foreach (const TophatSample& sample, append) {
         appendSample(sample);
     }
 
-    QListWidget *list = getListWidget(0);
-    CHECK(nullptr != list, );
+    QListWidget* list = getListWidget(0);
+    CHECK(list != nullptr, );
     list->addItems(insertToFirst);
 
     updateArrows();
@@ -399,12 +399,12 @@ void TophatSamples::sl_add() {
 }
 
 void TophatSamples::sl_selectionChanged() {
-    QListWidget *selectedList = dynamic_cast<QListWidget *>(sender());
-    CHECK(nullptr != selectedList, );
+    auto selectedList = dynamic_cast<QListWidget*>(sender());
+    CHECK(selectedList != nullptr, );
     CHECK(selectedList->selectedItems().size() > 0, );
 
-    QWidget *sampleWidget = selectedList->parentWidget();
-    CHECK(nullptr != sampleWidget, );
+    QWidget* sampleWidget = selectedList->parentWidget();
+    CHECK(sampleWidget != nullptr, );
     CHECK(order.contains(sampleWidget), );
 
     selectSample(order.indexOf(sampleWidget));
@@ -413,8 +413,8 @@ void TophatSamples::sl_selectionChanged() {
 
 void TophatSamples::selectSample(int selectedPos) {
     for (int pos = 0; pos < order.size(); pos++) {
-        QListWidget *list = getListWidget(pos);
-        SAFE_POINT(nullptr != list, "NULL list widget", );
+        QListWidget* list = getListWidget(pos);
+        SAFE_POINT(list != nullptr, "NULL list widget", );
         if (pos != selectedPos) {
             list->clearSelection();
             list->setCurrentRow(-1);
@@ -422,7 +422,7 @@ void TophatSamples::selectSample(int selectedPos) {
     }
 }
 
-bool TophatSamples::isBorderCase(QListWidget *list, int datasetPos, Direction direction) const {
+bool TophatSamples::isBorderCase(QListWidget* list, int datasetPos, Direction direction) const {
     switch (direction) {
         case UP:
             return (0 == datasetPos);
@@ -433,7 +433,7 @@ bool TophatSamples::isBorderCase(QListWidget *list, int datasetPos, Direction di
     }
 }
 
-void TophatSamples::getNewPositions(QListWidget *oldList, int oldSamplePos, int oldDatasetPos, Direction direction, int &newSamplePos, int &newDatasetPos, QListWidget *&newList) const {
+void TophatSamples::getNewPositions(QListWidget* oldList, int oldSamplePos, int oldDatasetPos, Direction direction, int& newSamplePos, int& newDatasetPos, QListWidget*& newList) const {
     newSamplePos = oldSamplePos;
     newDatasetPos = (UP == direction) ? oldDatasetPos - 1 : oldDatasetPos + 1;
     newList = oldList;
@@ -441,15 +441,15 @@ void TophatSamples::getNewPositions(QListWidget *oldList, int oldSamplePos, int
     if (isBorderCase(oldList, oldDatasetPos, direction)) {
         newSamplePos = (UP == direction) ? oldSamplePos - 1 : oldSamplePos + 1;
         newList = getListWidget(newSamplePos);
-        SAFE_POINT(nullptr != newList, "NULL prev list widget", );
+        SAFE_POINT(newList != nullptr, "NULL prev list widget", );
         newDatasetPos = (UP == direction) ? (newList)->count() : 0;
     }
 }
 
-void TophatSamples::findSelectedDataset(int &samplePos, int &datasetPos) const {
+void TophatSamples::findSelectedDataset(int& samplePos, int& datasetPos) const {
     for (int pos = 0; pos < order.size(); pos++) {
-        QListWidget *list = getListWidget(pos);
-        SAFE_POINT(nullptr != list, "NULL list widget", );
+        QListWidget* list = getListWidget(pos);
+        SAFE_POINT(list != nullptr, "NULL list widget", );
 
         int currentRow = list->currentRow();
         if (-1 != currentRow) {
@@ -466,15 +466,15 @@ void TophatSamples::move(Direction direction) {
     int oldDatasetPos = -1;
     findSelectedDataset(oldSamplePos, oldDatasetPos);
     CHECK(-1 != oldSamplePos, );
-    QListWidget *oldList = getListWidget(oldSamplePos);
-    SAFE_POINT(nullptr != oldList, "NULL old list widget", );
+    QListWidget* oldList = getListWidget(oldSamplePos);
+    SAFE_POINT(oldList != nullptr, "NULL old list widget", );
 
     // find target position
     int newSamplePos = -1;
     int newDatasetPos = -1;
-    QListWidget *newList = nullptr;
+    QListWidget* newList = nullptr;
     getNewPositions(oldList, oldSamplePos, oldDatasetPos, direction, newSamplePos, newDatasetPos, newList);
-    SAFE_POINT(nullptr != newList, "NULL new list widget", );
+    SAFE_POINT(newList != nullptr, "NULL new list widget", );
 
     // move selected dataset
     U2OpStatusImpl os;
@@ -482,7 +482,7 @@ void TophatSamples::move(Direction direction) {
     CHECK_OP(os, );
 
     // update ui
-    QListWidgetItem *item = oldList->takeItem(oldDatasetPos);
+    QListWidgetItem* item = oldList->takeItem(oldDatasetPos);
     newList->insertItem(newDatasetPos, item->text());
     delete item;
 
@@ -501,22 +501,22 @@ void TophatSamples::sl_down() {
     move(DOWN);
 }
 
-QListWidget *TophatSamples::getListWidget(int pos) const {
+QListWidget* TophatSamples::getListWidget(int pos) const {
     CHECK((pos > -1) && (pos < order.size()), nullptr);
-    QWidget *first = order[pos];
-    return first->findChild<QListWidget *>();
+    QWidget* first = order[pos];
+    return first->findChild<QListWidget*>();
 }
 
-QToolButton *TophatSamples::createButton(QWidget *parent, const QString &icon) const {
-    QToolButton *result = new QToolButton(parent);
+QToolButton* TophatSamples::createButton(QWidget* parent, const QString& icon) const {
+    QToolButton* result = new QToolButton(parent);
     result->setIcon(QIcon(icon));
     result->setAutoRaise(true);
     return result;
 }
 
-QScrollArea *TophatSamples::createScrollArea() {
+QScrollArea* TophatSamples::createScrollArea() {
     scrollArea = new QScrollArea(this);
-    QWidget *scrollable = new QWidget(scrollArea);
+    QWidget* scrollable = new QWidget(scrollArea);
     scrollArea->setWidget(scrollable);
     scrollArea->setWidgetResizable(true);
     scrollArea->setFrameShape(QFrame::NoFrame);
@@ -527,8 +527,8 @@ QScrollArea *TophatSamples::createScrollArea() {
     return scrollArea;
 }
 
-QVBoxLayout *TophatSamples::createControlButtonsLayout() {
-    QVBoxLayout *result = new QVBoxLayout();
+QVBoxLayout* TophatSamples::createControlButtonsLayout() {
+    QVBoxLayout* result = new QVBoxLayout();
     result->setContentsMargins(0, 0, 0, 0);
     result->addSpacerItem(new QSpacerItem(0, 0, QSizePolicy::Maximum, QSizePolicy::Minimum));
     result->addLayout(createControlButtons());
@@ -536,11 +536,11 @@ QVBoxLayout *TophatSamples::createControlButtonsLayout() {
     return result;
 }
 
-QVBoxLayout *TophatSamples::createControlButtons() {
-    QVBoxLayout *result = new QVBoxLayout();
+QVBoxLayout* TophatSamples::createControlButtons() {
+    QVBoxLayout* result = new QVBoxLayout();
     result->setContentsMargins(0, 0, 0, 0);
 
-    QToolButton *addButton = createButton(this, ":U2Designer/images/add.png");
+    QToolButton* addButton = createButton(this, ":U2Designer/images/add.png");
     upButton = createButton(this, ":U2Designer/images/up.png");
     downButton = createButton(this, ":U2Designer/images/down.png");
     result->addWidget(addButton);
@@ -557,9 +557,9 @@ QVBoxLayout *TophatSamples::createControlButtons() {
 void TophatSamples::updateArrows() {
     SAFE_POINT(order.size() > 1, "Unexpected count of samples", );
     {  // check if the top dataset is selected
-        QListWidget *topList = getListWidget(0);
+        QListWidget* topList = getListWidget(0);
         if (topList->selectedItems().size() > 0) {
-            QListWidgetItem *topItem = topList->item(0);
+            QListWidgetItem* topItem = topList->item(0);
             upButton->setEnabled(!topItem->isSelected());
             downButton->setEnabled(true);
             return;
@@ -567,9 +567,9 @@ void TophatSamples::updateArrows() {
     }
 
     {  // check if the bottom dataset is selected
-        QListWidget *bottomList = getListWidget(order.size() - 1);
+        QListWidget* bottomList = getListWidget(order.size() - 1);
         if (bottomList->selectedItems().size() > 0) {
-            QListWidgetItem *bottomItem = bottomList->item(bottomList->count() - 1);
+            QListWidgetItem* bottomItem = bottomList->item(bottomList->count() - 1);
             upButton->setEnabled(true);
             downButton->setEnabled(!bottomItem->isSelected());
             return;
@@ -578,7 +578,7 @@ void TophatSamples::updateArrows() {
 
     // check other items
     for (int pos = 1; pos < order.size() - 1; pos++) {
-        QListWidget *list = getListWidget(pos);
+        QListWidget* list = getListWidget(pos);
         if (list->selectedItems().size() > 0) {
             upButton->setEnabled(true);
             downButton->setEnabled(true);
