@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,31 +27,28 @@
 
 namespace U2 {
 
-WDWizardPage::WDWizardPage(WizardPageController *controller, QWidget *parent)
+WDWizardPage::WDWizardPage(WizardPageController* controller, QWidget* parent)
     : QWizardPage(parent), controller(controller) {
     controller->setQtPage(this);
 }
 
-WDWizardPage::~WDWizardPage() {
-}
-
 void WDWizardPage::initializePage() {
     controller->applyLayout();
 }
 
-static QAbstractButton *getRunButton(QWizard *w) {
-    QAbstractButton *runButton = w->button(QWizard::CustomButton1);
-    CHECK(nullptr != runButton, nullptr);
+static QAbstractButton* getRunButton(QWizard* w) {
+    QAbstractButton* runButton = w->button(QWizard::CustomButton1);
+    CHECK(runButton != nullptr, nullptr);
     CHECK(!runButton->text().isEmpty(), nullptr);
     return runButton;
 }
 
-void WDWizardPage::showEvent(QShowEvent *event) {
+void WDWizardPage::showEvent(QShowEvent* event) {
     if (wizard()->currentPage() == this) {
         setupDialogSize();
     }
-    QAbstractButton *runButton = getRunButton(wizard());
-    if (nullptr != runButton) {
+    QAbstractButton* runButton = getRunButton(wizard());
+    if (runButton != nullptr) {
         runButton->setVisible(isFinalPage());
     }
     QWizardPage::showEvent(event);
