@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WDWIZARDPAGE_H_
-#define _U2_WDWIZARDPAGE_H_
+#pragma once
 
 #include <QWizardPage>
 
@@ -31,22 +30,19 @@ class WizardPageController;
 class WDWizardPage : public QWizardPage {
     Q_OBJECT
 public:
-    WDWizardPage(WizardPageController *controller, QWidget *parent = nullptr);
-    virtual ~WDWizardPage();
+    WDWizardPage(WizardPageController* controller, QWidget* parent = nullptr);
 
     virtual void initializePage();
     virtual int nextId() const;
 
 protected:
-    virtual void showEvent(QShowEvent *event);
+    virtual void showEvent(QShowEvent* event);
 
 private:
-    WizardPageController *controller;
+    WizardPageController* controller;
 
 private:
     void setupDialogSize();
 };
 
 }  // namespace U2
-
-#endif  // _U2_WDWIZARDPAGE_H_
