@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,7 +29,7 @@
 
 namespace U2 {
 
-WidgetController::WidgetController(WizardController *_wc)
+WidgetController::WidgetController(WizardController* _wc)
     : wc(_wc) {
 }
 
@@ -39,14 +39,15 @@ WidgetController::~WidgetController() {
 /************************************************************************/
 /* LabeledPropertyWidget */
 /************************************************************************/
-LabeledPropertyWidget::LabeledPropertyWidget(const QString &labelText, PropertyWidget *widget, QWidget *parent)
+LabeledPropertyWidget::LabeledPropertyWidget(const QString& labelText, PropertyWidget* widget, QWidget* parent)
     : QWidget(parent) {
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    setObjectName(labelText + "_propertyWidget");
+    auto layout = new QHBoxLayout(this);
     setLayout(layout);
 
     label = new QLabel(labelText, this);
     label->setObjectName(labelText + " label");
-    QWidget *mainWidget = widget->findChild<QWidget *>("mainWidget");
+    auto mainWidget = widget->findChild<QWidget*>("mainWidget");
     if (mainWidget != nullptr) {
         mainWidget->setObjectName(labelText + " widget");
     }
@@ -60,7 +61,7 @@ LabeledPropertyWidget::LabeledPropertyWidget(const QString &labelText, PropertyW
 }
 
 void LabeledPropertyWidget::setLabelWidth(int width) {
-    SAFE_POINT(nullptr != label, "NULL label", );
+    SAFE_POINT(label != nullptr, "NULL label", );
     label->setFixedWidth(width);
 }
 
