@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WIDGETCONTROLLER_H_
-#define _U2_WIDGETCONTROLLER_H_
+#pragma once
 
 #include <QLabel>
 #include <QWidget>
@@ -35,25 +34,23 @@ class WizardController;
 
 class WidgetController : public QObject {
 public:
-    WidgetController(WizardController *wc);
+    WidgetController(WizardController* wc);
     virtual ~WidgetController();
 
-    virtual QWidget *createGUI(U2OpStatus &os) = 0;
+    virtual QWidget* createGUI(U2OpStatus& os) = 0;
 
 protected:
-    WizardController *wc;
+    WizardController* wc;
 };
 
 class LabeledPropertyWidget : public QWidget {
 public:
-    LabeledPropertyWidget(const QString &labelText, PropertyWidget *widget, QWidget *parent = nullptr);
+    LabeledPropertyWidget(const QString& labelText, PropertyWidget* widget, QWidget* parent = nullptr);
 
     void setLabelWidth(int width);
 
 private:
-    QLabel *label;
+    QLabel* label;
 };
 
 }  // namespace U2
-
-#endif  // _U2_WIDGETCONTROLLER_H_
