@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WIZARDPAGECONTROLLER_H_
-#define _U2_WIZARDPAGECONTROLLER_H_
+#pragma once
 
 #include <U2Designer/WizardController.h>
 
@@ -34,26 +33,24 @@ class WDWizardPage;
 
 class WizardPageController {
 public:
-    WizardPageController(WizardController *wc, WizardPage *page);
+    WizardPageController(WizardController* wc, WizardPage* page);
     virtual ~WizardPageController();
 
-    void setQtPage(WDWizardPage *value);
-    WDWizardPage *getQtPage() const;
-    WizardPage *getPage() const;
+    void setQtPage(WDWizardPage* value);
+    WDWizardPage* getQtPage() const;
+    WizardPage* getPage() const;
     void applyLayout();
     int nextId() const;
 
 private:
-    WDWizardPage *wPage;
-    WizardController *wc;
-    WizardPage *page;
-    QList<WidgetController *> controllers;
+    WDWizardPage* wPage;
+    WizardController* wc;
+    WizardPage* page;
+    QList<WidgetController*> controllers;
 
 private:
-    void removeLayout(QLayout *layoutToRemove);
-    void setError(WDWizardPage *wPage);
+    void removeLayout(QLayout* layoutToRemove);
+    void setError(WDWizardPage* wPage);
 };
 
 }  // namespace U2
-
-#endif  // _U2_WIZARDPAGECONTROLLER_H_
