@@ -90,22 +90,17 @@ this merge sequence slot:</source>
         <translation>Добавить директорию</translation>
     </message>
     <message>
-        <location filename="../src/DatasetWidget.ui" line="84"/>
-        <source>Add data from shared databases</source>
-        <translation>Добавить данные из удаленной базы данных</translation>
-    </message>
-    <message>
-        <location filename="../src/DatasetWidget.ui" line="116"/>
+        <location filename="../src/DatasetWidget.ui" line="94"/>
         <source>Up url(s)</source>
         <translation>Переместить путь(и) выше</translation>
     </message>
     <message>
-        <location filename="../src/DatasetWidget.ui" line="141"/>
+        <location filename="../src/DatasetWidget.ui" line="119"/>
         <source>Down url(s)</source>
         <translation>Переместить путь(и) ниже</translation>
     </message>
     <message>
-        <location filename="../src/DatasetWidget.ui" line="166"/>
+        <location filename="../src/DatasetWidget.ui" line="144"/>
         <source>Delete urls(s)</source>
         <translation>Удалить путь(и)</translation>
     </message>
@@ -205,24 +200,17 @@ this merge sequence slot:</source>
         <translation>Интервал:</translation>
     </message>
     <message>
-        <location filename="../src/EditIntegerMarkerWidget.ui" line="26"/>
-        <location filename="../src/EditIntegerMarkerWidget.ui" line="67"/>
-        <location filename="../src/EditIntegerMarkerWidget.ui" line="97"/>
-        <source>radioButtonsGroup</source>
-        <translation>radioButtonsGroup</translation>
-    </message>
-    <message>
-        <location filename="../src/EditIntegerMarkerWidget.ui" line="45"/>
+        <location filename="../src/EditIntegerMarkerWidget.ui" line="42"/>
         <source>..</source>
         <translation>..</translation>
     </message>
     <message>
-        <location filename="../src/EditIntegerMarkerWidget.ui" line="64"/>
+        <location filename="../src/EditIntegerMarkerWidget.ui" line="61"/>
         <source>Less than:</source>
         <translation>Меньше чем:</translation>
     </message>
     <message>
-        <location filename="../src/EditIntegerMarkerWidget.ui" line="94"/>
+        <location filename="../src/EditIntegerMarkerWidget.ui" line="88"/>
         <source>Greater than:</source>
         <translation>Больше чем:</translation>
     </message>
@@ -242,7 +230,7 @@ this merge sequence slot:</source>
     <message>
         <location filename="../src/EditMarkerDialog.ui" line="35"/>
         <source>NewMarker</source>
-        <translation>NewMarker</translation>
+        <translation>Новый маркер</translation>
     </message>
 </context>
 <context>
@@ -260,7 +248,7 @@ this merge sequence slot:</source>
     <message>
         <location filename="../src/EditMarkerGroupDialog.ui" line="29"/>
         <source>NewMarkerGroup</source>
-        <translation>NewMarkerGroup</translation>
+        <translation>Новая группа маркеров</translation>
     </message>
     <message>
         <location filename="../src/EditMarkerGroupDialog.ui" line="36"/>
@@ -280,7 +268,7 @@ this merge sequence slot:</source>
     <message>
         <location filename="../src/EditMarkerGroupDialog.ui" line="80"/>
         <source>Edit</source>
-        <translation>Свойства</translation>
+        <translation>Редактивароть</translation>
     </message>
     <message>
         <location filename="../src/EditMarkerGroupDialog.ui" line="87"/>
@@ -301,25 +289,17 @@ this merge sequence slot:</source>
         <translation>Начиная с</translation>
     </message>
     <message>
-        <location filename="../src/EditStringMarkerWidget.ui" line="26"/>
-        <location filename="../src/EditStringMarkerWidget.ui" line="39"/>
-        <location filename="../src/EditStringMarkerWidget.ui" line="52"/>
-        <location filename="../src/EditStringMarkerWidget.ui" line="65"/>
-        <source>buttonGroup</source>
-        <translation>buttonGroup</translation>
-    </message>
-    <message>
-        <location filename="../src/EditStringMarkerWidget.ui" line="36"/>
+        <location filename="../src/EditStringMarkerWidget.ui" line="33"/>
         <source>Ends with</source>
         <translation>Заканчивая</translation>
     </message>
     <message>
-        <location filename="../src/EditStringMarkerWidget.ui" line="49"/>
+        <location filename="../src/EditStringMarkerWidget.ui" line="43"/>
         <source>Contains</source>
         <translation>Содержит</translation>
     </message>
     <message>
-        <location filename="../src/EditStringMarkerWidget.ui" line="62"/>
+        <location filename="../src/EditStringMarkerWidget.ui" line="53"/>
         <source>Regular expression</source>
         <translation>Регулярное выражение</translation>
     </message>
@@ -481,22 +461,22 @@ this merge sequence slot:</source>
         <translation>Двойной щелчок загрузит пример</translation>
     </message>
     <message>
-        <location filename="../src/DatasetsController.cpp" line="459"/>
+        <location filename="../src/DatasetsController.cpp" line="451"/>
         <source>Paired reads</source>
         <translation>Парные риды</translation>
     </message>
     <message>
-        <location filename="../src/DatasetsController.cpp" line="461"/>
+        <location filename="../src/DatasetsController.cpp" line="453"/>
         <source>file</source>
         <translation>файл</translation>
     </message>
     <message>
-        <location filename="../src/DatasetsController.cpp" line="461"/>
+        <location filename="../src/DatasetsController.cpp" line="453"/>
         <source>folder</source>
         <translation>папка</translation>
     </message>
     <message>
-        <location filename="../src/DatasetsController.cpp" line="462"/>
+        <location filename="../src/DatasetsController.cpp" line="454"/>
         <source>UGENE has found &quot;%1&quot; on the file system. Do you want to add it as a second %2 with paired reads?</source>
         <translation>UGENE обнаружил &quot;%1&quot; в файловой системе. Хотите дабавить в качестве %2 с парными ридами?</translation>
     </message>
@@ -544,17 +524,17 @@ this merge sequence slot:</source>
     <message>
         <location filename="../src/wizard/WizardController.cpp" line="423"/>
         <source>Actors selector is already defined: %1</source>
-        <translation>Actors selector is already defined: %1</translation>
+        <translation>Селектор уже определен: %1</translation>
     </message>
     <message>
         <location filename="../src/wizard/WizardController.cpp" line="433"/>
         <source>Unknown actors selector: %1</source>
-        <translation>Unknown actors selector: %1</translation>
+        <translation>Неизвестный селектор: %1</translation>
     </message>
     <message>
         <location filename="../src/wizard/WizardController.cpp" line="438"/>
         <source>Unknown actors selector value id: %1</source>
-        <translation>Unknown actors selector value id: %1</translation>
+        <translation>Неизвестный идентификатор значения селектора: %1</translation>
     </message>
     <message>
         <location filename="../src/wizard/WizardPageController.cpp" line="83"/>
@@ -575,33 +555,27 @@ this merge sequence slot:</source>
         <translation>Соединить в одну последовательность</translation>
     </message>
     <message>
-        <location filename="../src/SequenceActionDialog.ui" line="46"/>
-        <location filename="../src/SequenceActionDialog.ui" line="102"/>
-        <source>buttonGroup</source>
-        <translation>buttonGroup</translation>
-    </message>
-    <message>
-        <location filename="../src/SequenceActionDialog.ui" line="62"/>
+        <location filename="../src/SequenceActionDialog.ui" line="59"/>
         <source>Merged sequence name</source>
         <translation>Имя общей последовательности</translation>
     </message>
     <message>
-        <location filename="../src/SequenceActionDialog.ui" line="72"/>
+        <location filename="../src/SequenceActionDialog.ui" line="69"/>
         <source>Gap size</source>
         <translation>Размер пробела</translation>
     </message>
     <message>
-        <location filename="../src/SequenceActionDialog.ui" line="99"/>
+        <location filename="../src/SequenceActionDialog.ui" line="96"/>
         <source>Merge into alignment</source>
         <translation>Соединить в выравнивание</translation>
     </message>
     <message>
-        <location filename="../src/SequenceActionDialog.ui" line="118"/>
+        <location filename="../src/SequenceActionDialog.ui" line="112"/>
         <source>Alignment name</source>
         <translation>Имя выравнивания</translation>
     </message>
     <message>
-        <location filename="../src/SequenceActionDialog.ui" line="128"/>
+        <location filename="../src/SequenceActionDialog.ui" line="122"/>
         <source>Filter duplicated sequences</source>
         <translation>Отфильтровать повторяющиеся последовательности</translation>
     </message>
@@ -686,33 +660,25 @@ bowtie index file</source>
 <context>
     <name>U2::ComboBoxWidget</name>
     <message>
-        <location filename="../src/PropertyWidget.cpp" line="240"/>
+        <location filename="../src/PropertyWidget.cpp" line="238"/>
         <source>False</source>
         <translation>Ложь</translation>
     </message>
     <message>
-        <location filename="../src/PropertyWidget.cpp" line="241"/>
+        <location filename="../src/PropertyWidget.cpp" line="239"/>
         <source>True</source>
         <translation>Истина</translation>
     </message>
 </context>
-<context>
-    <name>U2::ComboBoxWithDbUrlWidget</name>
-    <message>
-        <location filename="../src/PropertyWidget.cpp" line="389"/>
-        <source>Add New Connection</source>
-        <translation>Добавить новое соединение</translation>
-    </message>
-</context>
 <context>
     <name>U2::ComboBoxWithUrlWidget</name>
     <message>
-        <location filename="../src/PropertyWidget.cpp" line="366"/>
+        <location filename="../src/PropertyWidget.cpp" line="364"/>
         <source>Select a folder</source>
         <translation>Укажите папку</translation>
     </message>
     <message>
-        <location filename="../src/PropertyWidget.cpp" line="371"/>
+        <location filename="../src/PropertyWidget.cpp" line="369"/>
         <source>Select a file</source>
         <translation>Выберите файл</translation>
     </message>
@@ -779,24 +745,24 @@ bowtie index file</source>
         <translation>Параметры</translation>
     </message>
     <message>
-        <location filename="../src/dashboard/Dashboard.cpp" line="322"/>
+        <location filename="../src/dashboard/Dashboard.cpp" line="326"/>
         <source>Can not create a folder: </source>
         <translation>Невозможно создать папку: </translation>
     </message>
     <message>
-        <location filename="../src/dashboard/Dashboard.cpp" line="328"/>
+        <location filename="../src/dashboard/Dashboard.cpp" line="332"/>
         <source>Failed to open Dashboard.html</source>
         <translation>Невозможно открыть Dashboard.html</translation>
     </message>
     <message>
-        <location filename="../src/dashboard/Dashboard.cpp" line="479"/>
+        <location filename="../src/dashboard/Dashboard.cpp" line="483"/>
         <source>Error reading dashboard file: %1</source>
-        <translation>Error reading dashboard file: %1</translation>
+        <translation>Ошибка чтения файла: %1</translation>
     </message>
     <message>
-        <location filename="../src/dashboard/Dashboard.cpp" line="491"/>
+        <location filename="../src/dashboard/Dashboard.cpp" line="495"/>
         <source>Error parsing dashboard file: &apos;%1&apos;, file: %2</source>
-        <translation>Error parsing dashboard file: &apos;%1&apos;, file: %2</translation>
+        <translation>Ошибка парсинга файла: &apos;%1&apos;, файл: %2</translation>
     </message>
 </context>
 <context>
@@ -827,7 +793,7 @@ bowtie index file</source>
     <message>
         <location filename="../src/dashboard/DashboardInfoRegistry.cpp" line="139"/>
         <source>Can&apos;t register a dashboard info: &apos;%1&apos;</source>
-        <translation>Can&apos;t register a dashboard info: &apos;%1&apos;</translation>
+        <translation>Не удается зарегистрировать информацию: &quot;%1&quot;</translation>
     </message>
 </context>
 <context>
@@ -841,17 +807,17 @@ bowtie index file</source>
 <context>
     <name>U2::DatasetsController</name>
     <message>
-        <location filename="../src/DatasetsController.cpp" line="169"/>
+        <location filename="../src/DatasetsController.cpp" line="166"/>
         <source>Dataset name is empty</source>
         <translation>Имя набора данных пустое</translation>
     </message>
     <message>
-        <location filename="../src/DatasetsController.cpp" line="173"/>
+        <location filename="../src/DatasetsController.cpp" line="170"/>
         <source>Dataset name can not contain &apos;:&apos; and &apos;;&apos; symbols</source>
         <translation>Имя набора данных не может содержать &apos;:&apos; и &apos;;&apos; символы</translation>
     </message>
     <message>
-        <location filename="../src/DatasetsController.cpp" line="178"/>
+        <location filename="../src/DatasetsController.cpp" line="175"/>
         <source>This dataset name already exists</source>
         <translation>Это имя набора данных уже существует</translation>
     </message>
@@ -931,23 +897,23 @@ bowtie index file</source>
 <context>
     <name>U2::EditMarkerDialog</name>
     <message>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="402"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="403"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="403"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="404"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="411"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="412"/>
         <source>Create Marker</source>
         <translation>Создание маркера</translation>
     </message>
     <message>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="449"/>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="454"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="451"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="456"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
@@ -971,9 +937,9 @@ bowtie index file</source>
     </message>
     <message>
         <location filename="../src/EditMarkerGroupDialog.cpp" line="190"/>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="290"/>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="297"/>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="302"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="291"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="298"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="303"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
@@ -1011,7 +977,7 @@ bowtie index file</source>
         <translation>Повторящееся имя маркера: %1</translation>
     </message>
     <message>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="290"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="291"/>
         <source>Parameter &apos;%1&apos; is not set</source>
         <translation>Параметр &apos;%1&apos; не установлен</translation>
     </message>
@@ -1019,22 +985,22 @@ bowtie index file</source>
 <context>
     <name>U2::GroupBox</name>
     <message>
-        <location filename="../src/wizard/WizardController.cpp" line="909"/>
+        <location filename="../src/wizard/WizardController.cpp" line="910"/>
         <source>Show</source>
         <translation>Показать</translation>
     </message>
     <message>
-        <location filename="../src/wizard/WizardController.cpp" line="914"/>
+        <location filename="../src/wizard/WizardController.cpp" line="915"/>
         <source>Hide</source>
         <translation>Скрыть</translation>
     </message>
     <message>
-        <location filename="../src/wizard/WizardController.cpp" line="934"/>
+        <location filename="../src/wizard/WizardController.cpp" line="935"/>
         <source>additional</source>
         <translation>дополнительно</translation>
     </message>
     <message>
-        <location filename="../src/wizard/WizardController.cpp" line="938"/>
+        <location filename="../src/wizard/WizardController.cpp" line="939"/>
         <source> settings</source>
         <translation> настройки</translation>
     </message>
@@ -1078,13 +1044,13 @@ bowtie index file</source>
 <context>
     <name>U2::MarkerEditorWidget</name>
     <message>
-        <location filename="../src/MarkerEditorWidget.cpp" line="123"/>
-        <location filename="../src/MarkerEditorWidget.cpp" line="138"/>
+        <location filename="../src/MarkerEditorWidget.cpp" line="127"/>
+        <location filename="../src/MarkerEditorWidget.cpp" line="143"/>
         <source>Duplicate marker&apos;s name: %1</source>
         <translation>Повторящееся имя маркера: %1</translation>
     </message>
     <message>
-        <location filename="../src/MarkerEditorWidget.cpp" line="145"/>
+        <location filename="../src/MarkerEditorWidget.cpp" line="150"/>
         <source>Marker&apos;s name contains spaces: %1</source>
         <translation>Имя маркера содержит пробелы: %1</translation>
     </message>
@@ -1092,12 +1058,12 @@ bowtie index file</source>
 <context>
     <name>U2::MarkerListCfgModel</name>
     <message>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="349"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="350"/>
         <source>Marker name</source>
         <translation>Имя маркера</translation>
     </message>
     <message>
-        <location filename="../src/EditMarkerGroupDialog.cpp" line="351"/>
+        <location filename="../src/EditMarkerGroupDialog.cpp" line="352"/>
         <source>Marker value</source>
         <translation>Значение маркера</translation>
     </message>
@@ -1240,14 +1206,14 @@ Set up the folder:</source>
 <context>
     <name>U2::ParametersDashboardWidget</name>
     <message>
-        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="217"/>
-        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="283"/>
+        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="224"/>
+        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="290"/>
         <source>Parameter</source>
         <translation>Параметр</translation>
     </message>
     <message>
-        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="217"/>
-        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="283"/>
+        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="224"/>
+        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="290"/>
         <source>Value</source>
         <translation>Значение</translation>
     </message>
@@ -1255,7 +1221,7 @@ Set up the folder:</source>
 <context>
     <name>U2::QDCreateAnnotationsTask</name>
     <message>
-        <location filename="../src/QDScheduler.h" line="196"/>
+        <location filename="../src/QDScheduler.h" line="195"/>
         <source>Prepare annotations task</source>
         <translation>Подготовка задачи аннотирования</translation>
     </message>
@@ -1263,15 +1229,15 @@ Set up the folder:</source>
 <context>
     <name>U2::QDFindLocationTask</name>
     <message>
-        <location filename="../src/QDScheduler.h" line="138"/>
+        <location filename="../src/QDScheduler.h" line="137"/>
         <source>Find resultLocation</source>
-        <translation>Поиск resultLocation</translation>
+        <translation>Поиск расположения результата</translation>
     </message>
 </context>
 <context>
     <name>U2::QDLinkResultsTask</name>
     <message>
-        <location filename="../src/QDScheduler.h" line="163"/>
+        <location filename="../src/QDScheduler.h" line="162"/>
         <source>Link results</source>
         <translation>Ссылка на результаты</translation>
     </message>
@@ -1284,32 +1250,22 @@ Set up the folder:</source>
         <translation>QDScheduler</translation>
     </message>
     <message>
-        <location filename="../src/QDScheduler.cpp" line="76"/>
+        <location filename="../src/QDScheduler.cpp" line="77"/>
         <source>Can&apos;t find annotation object: %1 in document: %2</source>
         <translation>Невозможно найти объект аннотация: %1 в документе: %2</translation>
     </message>
     <message>
-        <location filename="../src/QDScheduler.cpp" line="109"/>
+        <location filename="../src/QDScheduler.cpp" line="110"/>
         <source>Annotation object is not available</source>
         <translation>Объект аннотация недоступен</translation>
     </message>
     <message>
-        <location filename="../src/QDScheduler.cpp" line="158"/>
-        <source>Invalid applications settings detected</source>
-        <translation>Invalid applications settings detected</translation>
-    </message>
-    <message>
-        <location filename="../src/QDScheduler.cpp" line="161"/>
-        <source>Invalid users applications settings detected</source>
-        <translation>Invalid users applications settings detected</translation>
-    </message>
-    <message>
-        <location filename="../src/QDScheduler.cpp" line="367"/>
+        <location filename="../src/QDScheduler.cpp" line="369"/>
         <source>No results have been found for this scheme</source>
         <translation>Для этой схемы результатов не найдено</translation>
     </message>
     <message>
-        <location filename="../src/QDScheduler.cpp" line="484"/>
+        <location filename="../src/QDScheduler.cpp" line="486"/>
         <source>Too many results have been found for this scheme. Try to set stricter search conditions.</source>
         <translation>Было найдено очень много результатов для этой схемы. Попробуйте изменить условия поиска.</translation>
     </message>
@@ -1317,7 +1273,7 @@ Set up the folder:</source>
 <context>
     <name>U2::QDTask</name>
     <message>
-        <location filename="../src/QDScheduler.cpp" line="755"/>
+        <location filename="../src/QDScheduler.cpp" line="760"/>
         <source>Query task: %1</source>
         <translation>Запрос: %1</translation>
     </message>
@@ -1341,12 +1297,12 @@ Set up the folder:</source>
 <context>
     <name>U2::SchemaRunModeDelegate</name>
     <message>
-        <location filename="../src/DelegateEditors.cpp" line="644"/>
+        <location filename="../src/DelegateEditors.cpp" line="600"/>
         <source>This computer</source>
         <translation>Данный компьютер</translation>
     </message>
     <message>
-        <location filename="../src/DelegateEditors.cpp" line="645"/>
+        <location filename="../src/DelegateEditors.cpp" line="601"/>
         <source>Remote computer</source>
         <translation>Удаленный компьютер</translation>
     </message>
@@ -1440,17 +1396,17 @@ Set up the folder:</source>
 <context>
     <name>U2::StringListDelegate</name>
     <message>
-        <location filename="../src/DelegateEditors.cpp" line="770"/>
+        <location filename="../src/DelegateEditors.cpp" line="726"/>
         <source>Enter items</source>
         <translation>Введите элементы</translation>
     </message>
     <message>
-        <location filename="../src/DelegateEditors.cpp" line="772"/>
+        <location filename="../src/DelegateEditors.cpp" line="728"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/DelegateEditors.cpp" line="774"/>
+        <location filename="../src/DelegateEditors.cpp" line="730"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
@@ -1489,19 +1445,18 @@ Set up the folder:</source>
 <context>
     <name>U2::URLLineEdit</name>
     <message>
-        <location filename="../src/support/URLLineEdit.cpp" line="185"/>
+        <location filename="../src/support/URLLineEdit.cpp" line="182"/>
         <source>Select a folder</source>
         <translation>Укажите папку</translation>
     </message>
     <message>
+        <location filename="../src/support/URLLineEdit.cpp" line="200"/>
         <location filename="../src/support/URLLineEdit.cpp" line="203"/>
-        <location filename="../src/support/URLLineEdit.cpp" line="208"/>
-        <location filename="../src/support/URLLineEdit.cpp" line="211"/>
         <source>Select a file</source>
         <translation>Выберите файл</translation>
     </message>
     <message>
-        <location filename="../src/support/URLLineEdit.cpp" line="188"/>
+        <location filename="../src/support/URLLineEdit.cpp" line="185"/>
         <source>Select file(s)</source>
         <translation>Выберите файл(ы)</translation>
     </message>
@@ -1509,7 +1464,7 @@ Set up the folder:</source>
 <context>
     <name>U2::URLListController</name>
     <message>
-        <location filename="../src/DatasetsController.cpp" line="767"/>
+        <location filename="../src/DatasetsController.cpp" line="756"/>
         <source>This file or folder does not exist: %1</source>
         <translation>Этот файл или папка не существует: %1</translation>
     </message>
@@ -1517,18 +1472,18 @@ Set up the folder:</source>
 <context>
     <name>U2::URLListWidget</name>
     <message>
-        <location filename="../src/DatasetWidget.cpp" line="117"/>
-        <location filename="../src/DatasetWidget.cpp" line="119"/>
+        <location filename="../src/DatasetWidget.cpp" line="108"/>
+        <location filename="../src/DatasetWidget.cpp" line="110"/>
         <source>Select file</source>
         <translation>Выберите файл</translation>
     </message>
     <message>
-        <location filename="../src/DatasetWidget.cpp" line="129"/>
+        <location filename="../src/DatasetWidget.cpp" line="120"/>
         <source>Select a folder</source>
         <translation>Укажите папку</translation>
     </message>
     <message>
-        <location filename="../src/DatasetWidget.cpp" line="197"/>
+        <location filename="../src/DatasetWidget.cpp" line="131"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
@@ -1536,7 +1491,7 @@ Set up the folder:</source>
 <context>
     <name>U2::URLWidget</name>
     <message>
-        <location filename="../src/PropertyWidget.cpp" line="558"/>
+        <location filename="../src/PropertyWidget.cpp" line="505"/>
         <source>add</source>
         <translation>добавить</translation>
     </message>
@@ -1580,22 +1535,22 @@ Set up the folder:</source>
 <context>
     <name>U2::WorkflowUtils</name>
     <message>
-        <location filename="../src/DelegateEditors.cpp" line="632"/>
+        <location filename="../src/DelegateEditors.cpp" line="588"/>
         <source>Overwrite</source>
         <translation>Переписать</translation>
     </message>
     <message>
-        <location filename="../src/DelegateEditors.cpp" line="633"/>
+        <location filename="../src/DelegateEditors.cpp" line="589"/>
         <source>Rename</source>
         <translation>Переименовать</translation>
     </message>
     <message>
-        <location filename="../src/DelegateEditors.cpp" line="635"/>
+        <location filename="../src/DelegateEditors.cpp" line="591"/>
         <source>Append</source>
         <translation>Дописать</translation>
     </message>
     <message>
-        <location filename="../src/DesignerUtils.cpp" line="36"/>
+        <location filename="../src/DesignerUtils.cpp" line="33"/>
         <source>UGENE workflow documents</source>
         <translation>Вычислительные схемы UGENE</translation>
     </message>
