@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -45,16 +45,17 @@
 
 namespace U2 {
 
-ABIFormat::ABIFormat(QObject *p)
-    : DocumentFormat(p, BaseDocumentFormats::ABIF, DocumentFormatFlag_SupportStreaming, {"ab1", "abi", "abif"}) {
+ABIFormat::ABIFormat(QObject* p)
+    : DocumentFormat(p, BaseDocumentFormats::ABIF, DocumentFormatFlag_SupportStreaming | DocumentFormatFlag_OnlyOneObject
+    , {"ab1", "abi", "abif"}) {
     formatName = tr("ABIF");
     formatDescription = tr("A chromatogram file format");
     supportedObjectTypes += GObjectTypes::SEQUENCE;
     supportedObjectTypes += GObjectTypes::CHROMATOGRAM;
 }
 
-FormatCheckResult ABIFormat::checkRawData(const QByteArray &rawData, const GUrl &) const {
-    const char *data = rawData.constData();
+FormatCheckResult ABIFormat::checkRawData(const QByteArray& rawData, const GUrl&) const {
+    const char* data = rawData.constData();
     int size = rawData.size();
 
     if (size <= 4 || data[0] != 'A' || data[1] != 'B' || data[2] != 'I' || data[3] != 'F') {
@@ -74,7 +75,7 @@ FormatCheckResult ABIFormat::checkRawData(const QByteArray &rawData, const GUrl
 
 #define MAX_SUPPORTED_ABIF_SIZE 10 * 1024 * 1024
 
-Document *ABIFormat::loadDocument(IOAdapter *io, const U2DbiRef &dbiRef, const QVariantMap &fs, U2OpStatus &os) {
+Document* ABIFormat::loadDocument(IOAdapter* io, const U2DbiRef& dbiRef, const QVariantMap& fs, U2OpStatus& os) {
     QByteArray readBuff;
     QByteArray block(BUFF_SIZE, 0);
     quint64 len = 0;
@@ -87,13 +88,13 @@ Document *ABIFormat::loadDocument(IOAdapter *io, const U2DbiRef &dbiRef, const Q
     sf.head = readBuff.constData();
     sf.pos = 0;
     sf.size = readBuff.size();
-    Document *doc = parseABI(dbiRef, &sf, io, fs, os);
+    Document* doc = parseABI(dbiRef, &sf, io, fs, os);
     CHECK_OP(os, nullptr)
     CHECK_EXT(doc != nullptr, os.setError(tr("Not a valid ABIF file: %1").arg(io->toString())), nullptr);
     return doc;
 }
 
-DNASequence *ABIFormat::loadSequence(IOAdapter *io, U2OpStatus &os) {
+DNASequence* ABIFormat::loadSequence(IOAdapter* io, U2OpStatus& os) {
     if (io->isEof()) {
         return nullptr;
     }
@@ -112,7 +113,7 @@ DNASequence *ABIFormat::loadSequence(IOAdapter *io, U2OpStatus &os) {
     sf.pos = 0;
     sf.size = readBuff.size();
 
-    DNASequence *seq = new DNASequence();
+    DNASequence* seq = new DNASequence();
     DNAChromatogram cd;
 
     if (!loadABIObjects(&sf, (*seq), cd)) {
@@ -191,7 +192,7 @@ DNASequence *ABIFormat::loadSequence(IOAdapter *io, U2OpStatus &os) {
  * Gets the offset of the ABI index.
  * Returns -1 for failure, 0 for success.
  */
-static int getABIIndexOffset(SeekableBuf *fp, uint *indexO) {
+static int getABIIndexOffset(SeekableBuf* fp, uint* indexO) {
     uint magic = 0;
 
     /*
@@ -219,7 +220,7 @@ static int getABIIndexOffset(SeekableBuf *fp, uint *indexO) {
  * from the `count'th entry labelled `label'.
  * The result is 0 for failure, or index offset for success.
  */
-int getABIIndexEntryLW(SeekableBuf *fp, int indexO, uint label, uint count, int lw, uint *val) {
+int getABIIndexEntryLW(SeekableBuf* fp, int indexO, uint label, uint count, int lw, uint* val) {
     int entryNum = -1;
     int i;
     uint entryLabel, entryLw1;
@@ -251,7 +252,7 @@ int getABIIndexEntryLW(SeekableBuf *fp, int indexO, uint label, uint count, int
  * from the `count'th entry labelled `label'.
  * The result is 0 for failure, or index offset for success.
  */
-int getABIIndexEntrySW(SeekableBuf *fp, int indexO, uint label, uint count, int sw, ushort *val) {
+int getABIIndexEntrySW(SeekableBuf* fp, int indexO, uint label, uint count, int sw, ushort* val) {
     int entryNum = -1;
     int i;
     uint entryLabel, entryLw1;
@@ -290,7 +291,7 @@ int getABIIndexEntrySW(SeekableBuf *fp, int indexO, uint label, uint count, int
  *
  * Returns -1 for failure, string length for success.
  */
-int getABIString(SeekableBuf *fp, int indexO, uint label, uint count, char *string) {
+int getABIString(SeekableBuf* fp, int indexO, uint label, uint count, char* string) {
     uint off;
     uint len;
     quint16 type;
@@ -341,7 +342,7 @@ int getABIString(SeekableBuf *fp, int indexO, uint label, uint count, char *stri
  * up to max_data_len elements, but it gives an indication of whether there
  * was more to come).
  */
-int getABIint1(SeekableBuf *fp, int indexO, uint label, uint count, uchar *data, int max_data_len) {
+int getABIint1(SeekableBuf* fp, int indexO, uint label, uint count, uchar* data, int max_data_len) {
     uint off;
     uint len, len2;
 
@@ -365,7 +366,7 @@ int getABIint1(SeekableBuf *fp, int indexO, uint label, uint count, uchar *data,
         len = len2 = max_data_len;
     }
 
-    fp->read((char *)data, len2);
+    fp->read((char*)data, len2);
 
     return len;
 }
@@ -378,18 +379,18 @@ int getABIint1(SeekableBuf *fp, int indexO, uint label, uint count, uchar *data,
  * up to max_data_len elements, but it gives an indication of whether there
  * was more to come).
  */
-int getABIint2(SeekableBuf *fp, int indexO, uint label, uint count, ushort *data, int max_data_len) {
+int getABIint2(SeekableBuf* fp, int indexO, uint label, uint count, ushort* data, int max_data_len) {
     int len, l2;
     int i;
 
-    len = getABIint1(fp, indexO, label, count, (uchar *)data, max_data_len * 2);
+    len = getABIint1(fp, indexO, label, count, (uchar*)data, max_data_len * 2);
     if (-1 == len)
         return -1;
 
     len /= 2;
     l2 = qMin(len, max_data_len);
     for (i = 0; i < l2; i++) {
-        data[i] = be_int2((uchar *)(data + i));
+        data[i] = be_int2((uchar*)(data + i));
     }
 
     return len;
@@ -403,25 +404,25 @@ int getABIint2(SeekableBuf *fp, int indexO, uint label, uint count, ushort *data
  * up to max_data_len elements, but it gives an indication of whether there
  * was more to come).
  */
-int getABIint4(SeekableBuf *fp, int indexO, uint label, uint count, uint *data, int max_data_len) {
+int getABIint4(SeekableBuf* fp, int indexO, uint label, uint count, uint* data, int max_data_len) {
     int len, l2;
     int i;
 
-    len = getABIint1(fp, indexO, label, count, (uchar *)data, max_data_len * 4);
+    len = getABIint1(fp, indexO, label, count, (uchar*)data, max_data_len * 4);
     if (-1 == len)
         return -1;
 
     len /= 4;
     l2 = qMin(len, max_data_len);
     for (i = 0; i < l2; i++) {
-        data[i] = be_int4((uchar *)(data + i));
+        data[i] = be_int4((uchar*)(data + i));
     }
 
     return len;
 }
 
-static void replace_nl(char *string) {
-    char *cp;
+static void replace_nl(char* string) {
+    char* cp;
 
     for (cp = string; *cp; cp++) {
         if (*cp == '\n')
@@ -429,7 +430,7 @@ static void replace_nl(char *string) {
     }
 }
 
-Document *ABIFormat::parseABI(const U2DbiRef &dbiRef, SeekableBuf *fp, IOAdapter *io, const QVariantMap &fs, U2OpStatus &os) {
+Document* ABIFormat::parseABI(const U2DbiRef& dbiRef, SeekableBuf* fp, IOAdapter* io, const QVariantMap& fs, U2OpStatus& os) {
     DbiOperationsBlock opBlock(dbiRef, os);
     CHECK_OP(os, nullptr);
     DNASequence dna;
@@ -442,7 +443,7 @@ Document *ABIFormat::parseABI(const U2DbiRef &dbiRef, SeekableBuf *fp, IOAdapter
         dna.setName("Sequence");
     }
 
-    QList<GObject *> objects;
+    QList<GObject*> objects;
     QVariantMap hints;
     QString folder = fs.value(DBI_FOLDER_HINT, U2ObjectDbi::ROOT_FOLDER).toString();
     hints.insert(DBI_FOLDER_HINT, folder);
@@ -452,24 +453,24 @@ Document *ABIFormat::parseABI(const U2DbiRef &dbiRef, SeekableBuf *fp, IOAdapter
     }
     U2EntityRef ref = U2SequenceUtils::import(os, dbiRef, folder, dna, dna.alphabet->getId());
     CHECK_OP(os, nullptr);
-    U2SequenceObject *seqObj = new U2SequenceObject(dna.getName(), ref);
+    U2SequenceObject* seqObj = new U2SequenceObject(dna.getName(), ref);
     objects.append(seqObj);
 
-    DNAChromatogramObject *chromObj = DNAChromatogramObject::createInstance(cd, "Chromatogram", dbiRef, os, hints);
+    DNAChromatogramObject* chromObj = DNAChromatogramObject::createInstance(cd, "Chromatogram", dbiRef, os, hints);
     CHECK_OP(os, nullptr);
     objects.append(chromObj);
 
     QString seqComment = dna.info.value(DNAInfo::COMMENT).toStringList().join("\n");
-    TextObject *textObj = TextObject::createInstance(seqComment, "Info", dbiRef, os, hints);
+    TextObject* textObj = TextObject::createInstance(seqComment, "Info", dbiRef, os, hints);
     CHECK_OP(os, nullptr);
     objects.append(textObj);
 
-    Document *doc = new Document(this, io->getFactory(), io->getURL(), dbiRef, objects, fs);
+    Document* doc = new Document(this, io->getFactory(), io->getURL(), dbiRef, objects, fs);
     chromObj->addObjectRelation(GObjectRelation(GObjectReference(seqObj), ObjectRole_Sequence));
     return doc;
 }
 
-bool ABIFormat::loadABIObjects(SeekableBuf *fp, DNASequence &dna, DNAChromatogram &cd) {
+bool ABIFormat::loadABIObjects(SeekableBuf* fp, DNASequence& dna, DNAChromatogram& cd) {
     uint numPoints, numBases;
     uint signalO;
     int no_bases = 0;
@@ -539,7 +540,7 @@ bool ABIFormat::loadABIObjects(SeekableBuf *fp, DNASequence &dna, DNAChromatogra
      * Juggle around with data pointers to get it right
      */
     if (sections & READ_SAMPLES) {
-        uint *dataxO[4];
+        uint* dataxO[4];
 
         dataxO[0] = &dataCO;
         dataxO[1] = &dataAO;
@@ -696,8 +697,8 @@ skip_bases:
         int clen = getABIString(fp, indexO, CMNTLabel, 1, commstr);
         if (clen != -1) {
             commstr[clen] = 0;
-            char *commstrp = commstr;
-            char *p;
+            char* commstrp = commstr;
+            char* p;
             do {
                 if ((p = strchr(commstrp, '\n'))) {
                     *p++ = 0;
@@ -721,24 +722,24 @@ skip_bases:
         /* Get Signal Strength Offset */
         if (getABIIndexEntryLW(fp, indexO, SignalEntryLabel, 1, 5, &signalO)) {
             short C, A, G, T;
-            short *base[4];
+            short* base[4];
             base[0] = &C;
             base[1] = &A;
             base[2] = &G;
             base[3] = &T;
 
             if (SeekBuf(fp, signalO, 0) != -1 &&
-                be_read_int_2(fp, (ushort *)base[baseIndex((char)(fwo_ >> 24 & 255))]) &&
-                be_read_int_2(fp, (ushort *)base[baseIndex((char)(fwo_ >> 16 & 255))]) &&
-                be_read_int_2(fp, (ushort *)base[baseIndex((char)(fwo_ >> 8 & 255))]) &&
-                be_read_int_2(fp, (ushort *)base[baseIndex((char)(fwo_ & 255))])) {
+                be_read_int_2(fp, (ushort*)base[baseIndex((char)(fwo_ >> 24 & 255))]) &&
+                be_read_int_2(fp, (ushort*)base[baseIndex((char)(fwo_ >> 16 & 255))]) &&
+                be_read_int_2(fp, (ushort*)base[baseIndex((char)(fwo_ >> 8 & 255))]) &&
+                be_read_int_2(fp, (ushort*)base[baseIndex((char)(fwo_ & 255))])) {
                 sequenceComment.append(QString("SIGN=A=%1,C=%2,G=%3,T=%4\n").arg(A).arg(C).arg(G).arg(T));
             }
         }
 
         /* Get the spacing.. it's a float but don't worry yet */
         float fspacing = 0;
-        if (-1 != getABIint4(fp, indexO, SpacingEntryLabel, 1, (uint *)&spacing, 1)) {
+        if (-1 != getABIint4(fp, indexO, SpacingEntryLabel, 1, (uint*)&spacing, 1)) {
             fspacing = int_to_float(spacing);
             sequenceComment.append(QString("SPAC=%1\n").arg(fspacing));  //-6.2f",
         }
@@ -755,7 +756,7 @@ skip_bases:
         }
 
         /* Get primer position */
-        if (getABIIndexEntryLW(fp, indexO, PPOSLabel, 1, 5, (uint *)&i4)) {
+        if (getABIIndexEntryLW(fp, indexO, PPOSLabel, 1, 5, (uint*)&i4)) {
             /* ppos stores in MBShort of pointer */
             sequenceComment.append(QString("PRIM=%1\n").arg(i4 >> 16));
         }
@@ -765,68 +766,27 @@ skip_bases:
             getABIIndexEntryLW(fp, indexO, RUNDLabel, 2, 5, &offset2) &&
             getABIIndexEntryLW(fp, indexO, RUNTLabel, 1, 5, &offset3) &&
             getABIIndexEntryLW(fp, indexO, RUNTLabel, 2, 5, &offset4)) {
-            // char buffer[1025];
-            char buffer_s[1025];
-            char buffer_e[1025];
-            struct tm t;
-            uint rund_s, rund_e, runt_s, runt_e;
+            quint32 rund_s = offset;
+            quint32 rund_e = offset2;
+            quint32 runt_s = offset3;
+            quint32 runt_e = offset4;
 
-            rund_s = offset;
-            rund_e = offset2;
-            runt_s = offset3;
-            runt_e = offset4;
+            QLatin1Char zeroFillChar('0');
+            QString rundBuffer = QString("%1-%2-%3 %4:%5:%6 - %7-%8-%9 %10:%11:%12")
+                                     .arg(rund_s >> 16, 4, 10, zeroFillChar)
+                                     .arg(rund_s >> 8 & 0xff, 2, 10, zeroFillChar)
+                                     .arg(rund_s & 0xff, 2, 10, zeroFillChar)
+                                     .arg(runt_s >> 24, 2, 10, zeroFillChar)
+                                     .arg(runt_s >> 16 & 0xff, 2, 10, zeroFillChar)
+                                     .arg(runt_s >> 8 & 0xff, 2, 10, zeroFillChar)
+                                     .arg(rund_e >> 16, 4, 10, zeroFillChar)
+                                     .arg(rund_e >> 8 & 0xff, 2, 10, zeroFillChar)
+                                     .arg(rund_e & 0xff, 2, 10, zeroFillChar)
+                                     .arg(runt_e >> 24, 2, 10, zeroFillChar)
+                                     .arg(runt_e >> 16 & 0xff, 2, 10, zeroFillChar)
+                                     .arg(runt_e >> 8 & 0xff, 2, 10, zeroFillChar);
 
-            //                 sprintf(buffer, "%04d%02d%02d.%02d%02d%02d - %04d%02d%02d.%02d%02d%02d",
-            //                     rund_s >> 16, (rund_s >> 8) & 0xff, rund_s & 0xff,
-            //                     runt_s >> 24, (runt_s >> 16) & 0xff, (runt_s >> 8) & 0xff,
-            //                     rund_e >> 16, (rund_e >> 8) & 0xff, rund_e & 0xff,
-            //                     runt_e >> 24, (runt_e >> 16) & 0xff, (runt_e >> 8) & 0xff);
-            QString rundBuffer = QString("%1%2%3.%4%5%6 - %7%8%9.%10%11%12")
-                                     .arg((rund_s >> 16), 4, 10, QLatin1Char('0'))
-                                     .arg((rund_s >> 8) & 0xff, 2, 10, QLatin1Char('0'))
-                                     .arg((rund_s & 0xff), 2, 10, QLatin1Char('0'))
-                                     .arg(runt_s >> 24, 2, 10, QLatin1Char('0'))
-                                     .arg((runt_s >> 16) & 0xff, 2, 10, QLatin1Char('0'))
-                                     .arg((runt_s >> 8) & 0xff, 2, 10, QLatin1Char('0'))
-                                     .arg(rund_e >> 16, 4, 10, QLatin1Char('0'))
-                                     .arg((rund_e >> 8) & 0xff, 2, 10, QLatin1Char('0'))
-                                     .arg(rund_e & 0xff, 2, 10, QLatin1Char('0'))
-                                     .arg(runt_e >> 24, 2, 10, QLatin1Char('0'))
-                                     .arg((runt_e >> 16) & 0xff, 2, 10, QLatin1Char('0'))
-                                     .arg((runt_e >> 8) & 0xff, 2, 10, QLatin1Char('0'));
-
-            memset(&t, 0, sizeof(t));
-            t.tm_mday = rund_s & 0xff;
-            t.tm_mon = ((rund_s >> 8) & 0xff) - 1;
-            t.tm_year = (rund_s >> 16) - 1900;
-            t.tm_hour = runt_s >> 24;
-            t.tm_min = (runt_s >> 16) & 0xff;
-            t.tm_sec = (runt_s >> 8) & 0xff;
-            t.tm_isdst = -1;
-            /*
-             * Convert struct tm to time_t. We ignore the time_t value, but
-             * the conversion process will update the tm_wday element of
-             * struct tm.
-             */
-            mktime(&t);
-            strftime(buffer_s, 1024, "%a %d %b %H:%M:%S %Y", &t);
-
-            t.tm_mday = rund_e & 0xff;
-            t.tm_mon = ((rund_e >> 8) & 0xff) - 1;
-            t.tm_year = (rund_e >> 16) - 1900;
-            t.tm_hour = runt_e >> 24;
-            t.tm_min = (runt_e >> 16) & 0xff;
-            t.tm_sec = (runt_e >> 8) & 0xff;
-            t.tm_isdst = -1;
-            /*
-             * Convert struct tm to time_t. We ignore the time_t value, but
-             * the conversion process will update the tm_wday element of
-             * struct tm.
-             */
-            mktime(&t);
-            strftime(buffer_e, 1024, "%a %d %b %H:%M:%S %Y", &t);
-
-            sequenceComment.append(QString("DATE=%1 to %2\nRUND=%3\n").arg(buffer_s).arg(buffer_e).arg(rundBuffer));
+            sequenceComment.append(QString("RUND/RUNT=%1\n").arg(rundBuffer));
         }
 
         /* Get Dye Primer Offset */
