@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASN_FORMAT_H_
-#define _U2_ASN_FORMAT_H_
+#pragma once
 
 #include <QSharedDataPointer>
 #include <QStack>
@@ -49,38 +48,39 @@ enum AsnElementKind {
     ASN_ROOT
 };
 
-class U2FORMATS_EXPORT AsnNode : public QObject {
-    Q_OBJECT
-
+class U2FORMATS_EXPORT AsnNode {
 public:
-    AsnNode();
-    AsnNode(const QByteArray &_name, AsnElementKind _kind);
+    AsnNode(const QByteArray& name, const AsnElementKind& kind, AsnNode* parent);
     ~AsnNode();
-    QByteArray name, value;
-    AsnElementKind kind;
-    QList<AsnNode *> children;
-    AsnNode *findChildByName(const QByteArray &name);
-    AsnNode *getChildById(int id);
+    const QByteArray name;
+    QByteArray value;
+    AsnElementKind kind = ASN_NO_KIND;
+
+    AsnNode* findChildByName(const QByteArray& childName) const;
+    AsnNode* getChild(int index) const;
+
+    const QList<AsnNode*>& getChildren() const;
 
 private:
-    static void deleteChildren(AsnNode *node);
+    AsnNode* parent = nullptr;
+    QList<AsnNode*> children;
 };
 
-typedef QList<AsnNode *> AsnNodeList;
+typedef QList<AsnNode*> AsnNodeList;
 
 class U2FORMATS_EXPORT ASNFormat : public DocumentFormat {
     Q_OBJECT
 public:
-    ASNFormat(QObject *p);
+    ASNFormat(QObject* p);
     ~ASNFormat();
-    virtual FormatCheckResult checkRawData(const QByteArray &data, const GUrl & = GUrl()) const;
+    virtual FormatCheckResult checkRawData(const QByteArray& data, const GUrl& = GUrl()) const;
 
 protected:
-    virtual Document *loadDocument(IOAdapter *io, const U2DbiRef &dbiRef, const QVariantMap &fs, U2OpStatus &os);
+    virtual Document* loadDocument(IOAdapter* io, const U2DbiRef& dbiRef, const QVariantMap& fs, U2OpStatus& os);
 
 public:
     class U2FORMATS_EXPORT AsnParser {
-        static const char *filetypeTag;
+        static const char* filetypeTag;
 
         // Parsing state
         struct ParseState {
@@ -94,8 +94,8 @@ public:
         };
 
         // Data
-        IOAdapter *io;
-        U2OpStatus &ts;
+        IOAdapter* io;
+        U2OpStatus& ts;
         QByteArray buffer;
         char prev;
         ParseState curState;
@@ -110,35 +110,35 @@ public:
         bool readRootElement();
         bool readNextElement();
         void processValue();
-        void parseNextElement(AsnNode *node);
+        void parseNextElement(AsnNode* node);
         void saveState();
         void restoreState();
         void dbgPrintCurrentState();
-        void initState(const QByteArray &parentName);
+        void initState(const QByteArray& parentName);
 
         // Utility
-        static bool isQuoted(const QByteArray &str);
-        static void removeQuotes(QByteArray &str);
-        static void dbgPrintAsnTree(const AsnNode *rootElem, int level = 0);
+        static bool isQuoted(const QByteArray& str);
+        static void removeQuotes(QByteArray& str);
+        static void dbgPrintAsnTree(const AsnNode* rootElem, int level = 0);
 
     public:
-        AsnParser(IOAdapter *_io, U2OpStatus &_ts)
+        AsnParser(IOAdapter* _io, U2OpStatus& _ts)
             : io(_io), ts(_ts), prev(' '), curElementKind(ASN_NO_KIND),
               haveErrors(false), insideRoot(false), fileAtEnd(false) {
         }
         ~AsnParser() {
         }
-        AsnNode *loadAsnTree();
+        AsnNode* loadAsnTree();
     };
 
-    static QString getAsnNodeTypeName(const AsnNode *node);
-    static AsnNode *findFirstNodeByName(AsnNode *rootElem, const QString &nodeName);
-    static AsnNodeList findNodesByName(AsnNode *root, const QString &nodeName, AsnNodeList &lst);
+    static QString getAsnNodeTypeName(const AsnNode* node);
+    static AsnNode* findFirstNodeByName(AsnNode* rootElem, const QString& nodeName);
+    static AsnNodeList findNodesByName(AsnNode* root, const QString& nodeName, AsnNodeList& lst);
 
 private:
-    struct AsnBaseException {
+    struct AsnBaseException : public std::exception {
         QString msg;
-        AsnBaseException(const QString &what)
+        AsnBaseException(const QString& what)
             : msg(what) {
         }
     };
@@ -150,13 +150,13 @@ private:
     };
 
     struct AsnParserError : public AsnBaseException {
-        AsnParserError(const QString &what)
+        AsnParserError(const QString& what)
             : AsnBaseException(what) {
         }
     };
 
     struct AsnBioStructError : public AsnBaseException {
-        AsnBioStructError(const QString &what)
+        AsnBioStructError(const QString& what)
             : AsnBaseException(ASNFormat::tr("biostruct3d obj loading error: %1").arg(what)) {
         }
     };
@@ -166,30 +166,30 @@ private:
         BioStructLoader()
             : standardDictionary(0), localDictionary(0) {
         }
-        void loadBioStructFromAsnTree(AsnNode *rootNode, BioStruct3D &struc, U2OpStatus &os);
-        const StdResidueDictionary *getStandardDictionary() const {
+        void loadBioStructFromAsnTree(AsnNode* rootNode, BioStruct3D& struc, U2OpStatus& os);
+        const StdResidueDictionary* getStandardDictionary() const {
             return standardDictionary;
         }
-        void setStandardDictionary(const StdResidueDictionary *_standardDictionary) {
+        void setStandardDictionary(const StdResidueDictionary* _standardDictionary) {
             standardDictionary = _standardDictionary;
         }
 
     private:
-        void loadBioStructModels(QList<AsnNode *> models, BioStruct3D &struc);
-        void loadBioStructGraph(AsnNode *graphNode, BioStruct3D &struc);
-        void loadBioStructPdbId(AsnNode *rootNode, BioStruct3D &struc);
-        void loadBioStructSecondaryStruct(AsnNode *rootNode, BioStruct3D &struc);
-        void loadBioStructFeature(AsnNode *featureNode, BioStruct3D &struc);
-        void loadModelCoordsFromNode(AsnNode *node, AtomCoordSet &coordSet, QMap<int, Molecule3DModel> &molModels, const BioStruct3D &struc);
-        void loadMoleculeFromNode(AsnNode *moleculeNode, MoleculeData *molecule);
-        void loadIntraResidueBonds(BioStruct3D &struc);
-        const StdResidue loadResidueFromNode(AsnNode *resNode, ResidueData *residue);
+        void loadBioStructModels(QList<AsnNode*> models, BioStruct3D& struc);
+        void loadBioStructGraph(AsnNode* graphNode, BioStruct3D& struc);
+        void loadBioStructPdbId(AsnNode* rootNode, BioStruct3D& struc);
+        void loadBioStructSecondaryStruct(AsnNode* rootNode, BioStruct3D& struc);
+        void loadBioStructFeature(AsnNode* featureNode, BioStruct3D& struc);
+        void loadModelCoordsFromNode(AsnNode* node, AtomCoordSet& coordSet, QMap<int, Molecule3DModel>& molModels, const BioStruct3D& struc);
+        void loadMoleculeFromNode(AsnNode* moleculeNode, MoleculeData* molecule);
+        void loadIntraResidueBonds(BioStruct3D& struc);
+        StdResidue loadResidueFromNode(AsnNode* resNode, ResidueData* residue);
 
         // chain_id -> molecule name
-        static QMap<char, QString> loadMoleculeNames(AsnNode *biostructGraphDescr);
+        static QMap<char, QString> loadMoleculeNames(AsnNode* biostructGraphDescr);
 
     private:
-        const StdResidueDictionary *standardDictionary;
+        const StdResidueDictionary* standardDictionary;
         QScopedPointer<StdResidueDictionary> localDictionary;
         QHash<quint64, StdResidue> stdResidueCache;
         QMap<quint64, AtomCoordSet> atomSetCache;
@@ -197,5 +197,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  //_U2_ASN_FORMAT_H_
