@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CLUSTAL_W_ALN_FORMAT_H_
-#define _U2_CLUSTAL_W_ALN_FORMAT_H_
+#pragma once
 
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentModel.h>
@@ -34,20 +33,18 @@ class IOAdapter;
 class U2FORMATS_EXPORT ClustalWAlnFormat : public TextDocumentFormat {
     Q_OBJECT
 public:
-    static const QString CLUSTAL_HEADER;
+    ClustalWAlnFormat(QObject* p);
 
-    ClustalWAlnFormat(QObject *p);
+    void storeTextDocument(IOAdapterWriter& writer, Document* d, U2OpStatus& os) override;
 
-    void storeTextDocument(IOAdapterWriter &writer, Document *d, U2OpStatus &os) override;
+    void storeTextEntry(IOAdapterWriter& writer, const QMap<GObjectType, QList<GObject*>>& objectsMap, U2OpStatus& os) override;
 
-    void storeTextEntry(IOAdapterWriter &writer, const QMap<GObjectType, QList<GObject *>> &objectsMap, U2OpStatus &os) override;
+    FormatCheckResult checkRawTextData(const QString& dataPrefix, const GUrl& originalDataUrl) const override;
 
-    FormatCheckResult checkRawTextData(const QString &dataPrefix, const GUrl &originalDataUrl) const override;
-
-    Document *loadTextDocument(IOAdapterReader &reader, const U2DbiRef &dbiRef, const QVariantMap &hints, U2OpStatus &os) override;
+    Document* loadTextDocument(IOAdapterReader& reader, const U2DbiRef& dbiRef, const QVariantMap& hints, U2OpStatus& os) override;
 
 private:
-    static void load(IOAdapterReader &reader, const U2DbiRef &dbiRef, QList<GObject *> &objects, const QVariantMap &hints, U2OpStatus &os);
+    static void load(IOAdapterReader& reader, const U2DbiRef& dbiRef, QList<GObject*>& objects, const QVariantMap& hints, U2OpStatus& os);
 
     static const int MAX_LINE_LEN;
     static const int MAX_NAME_LEN;
@@ -56,5 +53,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
