@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_COLUMNDATAPARSER_H_
-#define _U2_COLUMNDATAPARSER_H_
+#pragma once
 
 #include <QStringList>
 
@@ -37,14 +36,14 @@ public:
         DOUBLE
     };
     struct Column {
-        Column(const QString &name);
-        Column(const QString &name, ColumnType type, const QString defaultValue = "-", bool required = false);
+        Column(const QString& name);
+        Column(const QString& name, ColumnType type, const QString defaultValue = "-", bool required = false);
         QString name;
         ColumnType type;
         QString defaultValue;
         bool required;
 
-        bool operator==(const Column &other) const;
+        bool operator==(const Column& other) const;
     };
     class Iterator {
         friend class ColumnDataParser;
@@ -54,13 +53,13 @@ public:
         ColumnType currentType() const;
         QString currentName() const;
         QString takeString();
-        int takeInt(U2OpStatus &os);
-        double takeDouble(U2OpStatus &os);
+        int takeInt(U2OpStatus& os);
+        double takeDouble(U2OpStatus& os);
         QString getPrevious() const;
         QString look() const;
 
     private:
-        Iterator(const QList<Column> &columns, const QStringList &values);
+        Iterator(const QList<Column>& columns, const QStringList& values);
         QString take();
         bool check() const;
 
@@ -73,10 +72,10 @@ public:
         QString previous;
     };
 
-    ColumnDataParser(const QList<Column> &formatColumns, const QString &separator);
-    void init(const QString &headerLine, U2OpStatus &os);
-    Iterator parseLine(const QString &line, U2OpStatus &os) const;
-    const QList<Column> &getCurrentColumns() const;
+    ColumnDataParser(const QList<Column>& formatColumns, const QString& separator);
+    void init(const QString& headerLine, U2OpStatus& os);
+    Iterator parseLine(const QString& line, U2OpStatus& os) const;
+    const QList<Column>& getCurrentColumns() const;
 
 private:
     bool inited;
@@ -86,5 +85,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_COLUMNDATAPARSER_H_
