@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_QUALITY_IO_UTILS_H_
-#define _U2_DNA_QUALITY_IO_UTILS_H_
+#pragma once
 
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/U2OpStatus.h>
@@ -30,11 +29,9 @@ namespace U2 {
 class U2FORMATS_EXPORT DNAQualityIOUtils : public QObject {
     Q_OBJECT
 public:
-    static void writeDNAQuality(const U2SequenceObject *seqObj, const QString &fileName, bool appendData, bool decode, U2OpStatus &op);
+    static void writeDNAQuality(const U2SequenceObject* seqObj, const QString& fileName, bool appendData, bool decode, U2OpStatus& op);
 
-    static void writeDNAQuality(const QString &seqName, const DNAQuality &quality, const QString &filePath, bool appendData, bool decode, U2OpStatus &op);
+    static void writeDNAQuality(const QString& seqName, const DNAQuality& quality, const QString& filePath, bool appendData, bool decode, U2OpStatus& op);
 };
 
 }  // namespace U2
-
-#endif  // _U2_DNA_QUALITY_IO_UTILS_H_
