@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DIFFERENTIALFORMAT_H_
-#define _U2_DIFFERENTIALFORMAT_H_
+#pragma once
 
 #include <U2Core/AnnotationData.h>
 #include <U2Core/DocumentModel.h>
@@ -39,27 +38,27 @@ namespace U2 {
 class U2FORMATS_EXPORT DifferentialFormat : public TextDocumentFormat {
     Q_OBJECT
 public:
-    DifferentialFormat(QObject *parent);
+    DifferentialFormat(QObject* parent);
 
 protected:
-    FormatCheckResult checkRawTextData(const QString &dataPrefix, const GUrl &originalDataUrl) const override;
+    FormatCheckResult checkRawTextData(const QString& dataPrefix, const GUrl& originalDataUrl) const override;
 
-    Document *loadTextDocument(IOAdapterReader &reader, const U2DbiRef &dbiRef, const QVariantMap &hints, U2OpStatus &os) override;
+    Document* loadTextDocument(IOAdapterReader& reader, const U2DbiRef& dbiRef, const QVariantMap& hints, U2OpStatus& os) override;
 
-    void storeTextDocument(IOAdapterWriter &writer, Document *document, U2OpStatus &os) override;
+    void storeTextDocument(IOAdapterWriter& writer, Document* document, U2OpStatus& os) override;
 
 private:
     static QList<ColumnDataParser::Column> getColumns();
     static QString getAnnotationName();
-    static QList<SharedAnnotationData> parseAnnotations(IOAdapterReader &reader, U2OpStatus &os);
-    static QList<SharedAnnotationData> parseAnnotations(const ColumnDataParser &parser, IOAdapterReader &reader, U2OpStatus &os);
-    static QList<ColumnDataParser::Column> getHeaderColumns(const QList<GObject *> &anns, U2OpStatus &os);
-    static void writeHeader(IOAdapterWriter &writer, const QList<ColumnDataParser::Column> &columns, U2OpStatus &os);
+    static QList<SharedAnnotationData> parseAnnotations(IOAdapterReader& reader, U2OpStatus& os);
+    static QList<SharedAnnotationData> parseAnnotations(const ColumnDataParser& parser, IOAdapterReader& reader, U2OpStatus& os);
+    static QList<ColumnDataParser::Column> getHeaderColumns(const QList<GObject*>& anns, U2OpStatus& os);
+    static void writeHeader(IOAdapterWriter& writer, const QList<ColumnDataParser::Column>& columns, U2OpStatus& os);
 
-    static QString readLine(IOAdapterReader &reader, QByteArray &buffer, U2OpStatus &os);
-    static bool parseLocus(const QString &locus, SharedAnnotationData &data, U2OpStatus &os);
-    static QString createLocus(const SharedAnnotationData &data, U2OpStatus &os);
-    static QString createValue(const SharedAnnotationData &data, const ColumnDataParser::Column &column, U2OpStatus &os);
+    static QString readLine(IOAdapterReader& reader, QByteArray& buffer, U2OpStatus& os);
+    static bool parseLocus(const QString& locus, SharedAnnotationData& data, U2OpStatus& os);
+    static QString createLocus(const SharedAnnotationData& data, U2OpStatus& os);
+    static QString createValue(const SharedAnnotationData& data, const ColumnDataParser::Column& column, U2OpStatus& os);
 
 private:
     /** Maximum line length supported by the format. */
@@ -67,5 +66,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_DIFFERENTIALFORMAT_H_
