@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,22 +29,19 @@
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/GObjectRelationRoles.h>
-#include <U2Core/GObjectTypes.h>
 #include <U2Core/GenbankFeatures.h>
 #include <U2Core/L10n.h>
 #include <U2Core/MultipleSequenceAlignment.h>
 #include <U2Core/MultipleSequenceAlignmentObject.h>
 #include <U2Core/TextUtils.h>
-#include <U2Core/U2AlphabetUtils.h>
 #include <U2Core/U2DbiRegistry.h>
 #include <U2Core/U2ObjectDbi.h>
 #include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/U2SafePoints.h>
-#include <U2Core/U2SequenceUtils.h>
 
 namespace U2 {
 
-static int getIntSettings(const QVariantMap &fs, const char *sName, int defVal) {
+static int getIntSettings(const QVariantMap& fs, const char* sName, int defVal) {
     QVariant v = fs.value(sName);
     if (v.type() != QVariant::Int) {
         return defVal;
@@ -52,14 +49,14 @@ static int getIntSettings(const QVariantMap &fs, const char *sName, int defVal)
     return v.toInt();
 }
 
-AnnotationTableObject *DocumentFormatUtils::addAnnotationsForMergedU2Sequence(const GObjectReference &mergedSequenceRef,
-                                                                              const U2DbiRef &dbiRef,
-                                                                              const QStringList &contigNames,
-                                                                              const QVector<U2Region> &mergedMapping,
-                                                                              const QVariantMap &hints) {
+AnnotationTableObject* DocumentFormatUtils::addAnnotationsForMergedU2Sequence(const GObjectReference& mergedSequenceRef,
+                                                                              const U2DbiRef& dbiRef,
+                                                                              const QStringList& contigNames,
+                                                                              const QVector<U2Region>& mergedMapping,
+                                                                              const QVariantMap& hints) {
     QVariantMap objectHints;
     objectHints.insert(DocumentFormat::DBI_FOLDER_HINT, hints.value(DocumentFormat::DBI_FOLDER_HINT, U2ObjectDbi::ROOT_FOLDER));
-    AnnotationTableObject *ao = new AnnotationTableObject("Contigs", dbiRef, objectHints);
+    AnnotationTableObject* ao = new AnnotationTableObject("Contigs", dbiRef, objectHints);
 
     // save relation if mergedSequenceRef is valid
     if (mergedSequenceRef.isValid()) {
@@ -81,43 +78,29 @@ AnnotationTableObject *DocumentFormatUtils::addAnnotationsForMergedU2Sequence(co
     return ao;
 }
 
-class ExtComparator {
-public:
-    ExtComparator(const QString &_ext)
-        : ext(_ext) {
-    }
-
-    bool operator()(const DocumentFormat *f1, const DocumentFormat *f2) const {
-        int v1 = f1->getSupportedDocumentFileExtensions().contains(ext) ? 1 : 0;
-        int v2 = f2->getSupportedDocumentFileExtensions().contains(ext) ? 1 : 0;
-        return v2 < v1;  // reverse sort -> make higher vals on the top
-    }
-    QString ext;
-};
-
-QList<DocumentFormatId> DocumentFormatUtils::toIds(const QList<DocumentFormat *> &formats) {
+QList<DocumentFormatId> DocumentFormatUtils::toIds(const QList<DocumentFormat*>& formats) {
     QList<DocumentFormatId> result;
-    foreach (DocumentFormat *f, formats) {
+    foreach (DocumentFormat* f, formats) {
         result.append(f->getFormatId());
     }
     return result;
 }
 
-QList<AnnotationSettings *> DocumentFormatUtils::predefinedSettings() {
-    QList<AnnotationSettings *> predefined;
+QList<AnnotationSettings*> DocumentFormatUtils::predefinedSettings() {
+    QList<AnnotationSettings*> predefined;
     foreach (GBFeatureKeyInfo fi, GBFeatureUtils::allKeys()) {
-        AnnotationSettings *as = new AnnotationSettings();
-        as->name = fi.text;
-        as->amino = fi.showOnaminoFrame;
-        as->color = fi.color;
-        as->visible = as->name != "source";
-        as->nameQuals = fi.namingQuals;
+        auto settings = new AnnotationSettings();
+        settings->name = fi.text;
+        settings->amino = U2FeatureTypes::isShowOnAminoFrame(fi.type);
+        settings->color = U2FeatureTypes::getColor(fi.type);
+        settings->visible = settings->name != "source";
+        settings->nameQuals = fi.namingQuals;
         if (!fi.namingQuals.isEmpty()) {
-            as->showNameQuals = true;
+            settings->showNameQuals = true;
         }
-        predefined.append(as);
+        predefined.append(settings);
     }
-    AnnotationSettings *secStructAnnotationSettings = new AnnotationSettings(BioStruct3D::SecStructAnnotationTag, true, QColor(102, 255, 0), true);
+    AnnotationSettings* secStructAnnotationSettings = new AnnotationSettings(BioStruct3D::SecStructAnnotationTag, true, QColor(102, 255, 0), true);
     secStructAnnotationSettings->nameQuals.append(BioStruct3D::SecStructTypeQualifierName);
     secStructAnnotationSettings->showNameQuals = true;
     predefined.append(secStructAnnotationSettings);
@@ -129,21 +112,21 @@ QList<AnnotationSettings *> DocumentFormatUtils::predefinedSettings() {
     return predefined;
 }
 
-QList<DNASequence> DocumentFormatUtils::toSequences(const GObject *obj) {
+QList<DNASequence> DocumentFormatUtils::toSequences(const GObject* obj) {
     QList<DNASequence> res;
     SAFE_POINT(obj != nullptr, "Gobject is NULL", res);
-    const U2SequenceObject *seqObj = qobject_cast<const U2SequenceObject *>(obj);
+    auto seqObj = qobject_cast<const U2SequenceObject*>(obj);
     U2OpStatus2Log os;
     if (seqObj != nullptr) {
         res << seqObj->getWholeSequence(os);
         CHECK_OP_EXT(os, res.removeLast(), res);
         return res;
     }
-    const MultipleSequenceAlignmentObject *maObj = qobject_cast<const MultipleSequenceAlignmentObject *>(obj);
+    auto maObj = qobject_cast<const MultipleSequenceAlignmentObject*>(obj);
     CHECK(maObj != nullptr, res);  // MultipleSequenceAlignmentObject is NULL
-    const DNAAlphabet *al = maObj->getAlphabet();
+    const DNAAlphabet* al = maObj->getAlphabet();
     qint64 alLen = maObj->getMsa()->getLength();
-    foreach (const MultipleSequenceAlignmentRow &row, maObj->getMsa()->getMsaRows()) {
+    foreach (const MultipleSequenceAlignmentRow& row, maObj->getMsa()->getMsaRows()) {
         DNASequence seq;
         seq.seq = row->toByteArray(os, alLen);
         seq.setName(row->getName());
@@ -157,7 +140,7 @@ QList<DNASequence> DocumentFormatUtils::toSequences(const GObject *obj) {
 // we keep this property for compatibility with previous version of UGENE only
 #define MERGE_MULTI_DOC_GAP_SIZE_SETTINGS_DEPRECATED "merge_gap"
 
-int DocumentFormatUtils::getMergeGap(const QVariantMap &hints) {
+int DocumentFormatUtils::getMergeGap(const QVariantMap& hints) {
     int res = getIntSettings(hints, DocumentReadingMode_SequenceMergeGapSize, -1);
     if (res == -1) {
         res = getIntSettings(hints, MERGE_MULTI_DOC_GAP_SIZE_SETTINGS_DEPRECATED, -1);
@@ -165,32 +148,32 @@ int DocumentFormatUtils::getMergeGap(const QVariantMap &hints) {
     return res;
 }
 
-int DocumentFormatUtils::getMergedSize(const QVariantMap &hints, int defaultVal) {
+int DocumentFormatUtils::getMergedSize(const QVariantMap& hints, int defaultVal) {
     int res = getIntSettings(hints, DocumentReadingMode_SequenceMergingFinalSizeHint, defaultVal);
     return res;
 }
 
-void DocumentFormatUtils::updateFormatHints(QList<GObject *> &objects, QVariantMap &fs) {
+void DocumentFormatUtils::updateFormatHints(QList<GObject*>& objects, QVariantMap& fs) {
     // 1. remove all cached sequence sizes
     // 2. add new sizes
-    QList<GObject *> sequences;
-    foreach (GObject *obj, objects) {
+    QList<GObject*> sequences;
+    foreach (GObject* obj, objects) {
         if (obj->getGObjectType() == GObjectTypes::SEQUENCE) {
             sequences.append(obj);
         }
     }
     if (sequences.size() == 1) {
-        U2SequenceObject *so = qobject_cast<U2SequenceObject *>(sequences.first());
+        auto so = qobject_cast<U2SequenceObject*>(sequences.first());
         int len = so->getSequenceLength();
         fs[DocumentReadingMode_SequenceMergingFinalSizeHint] = len;
     }
 }
 
-QString DocumentFormatUtils::getFormatNameById(const DocumentFormatId &formatId) {
-    DocumentFormatRegistry *registry = AppContext::getDocumentFormatRegistry();
-    SAFE_POINT(nullptr != registry, L10N::nullPointerError("document format registry"), "");
-    DocumentFormat *format = registry->getFormatById(formatId);
-    SAFE_POINT(nullptr != format, QString("Document format '%1' is not registered").arg(formatId), "");
+QString DocumentFormatUtils::getFormatNameById(const DocumentFormatId& formatId) {
+    DocumentFormatRegistry* registry = AppContext::getDocumentFormatRegistry();
+    SAFE_POINT_NN(registry, "");
+    DocumentFormat* format = registry->getFormatById(formatId);
+    SAFE_POINT(format != nullptr, QString("Document format '%1' is not registered").arg(formatId), "");
     return format->getFormatName();
 }
 
