@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EMBL_PLAIN_TEXT_FORMAT_H_
-#define _U2_EMBL_PLAIN_TEXT_FORMAT_H_
+#pragma once
 
 #include "EMBLGenbankAbstractDocument.h"
 
@@ -29,17 +28,15 @@ namespace U2 {
 class U2FORMATS_EXPORT EMBLPlainTextFormat : public EMBLGenbankAbstractDocument {
     Q_OBJECT
 public:
-    EMBLPlainTextFormat(QObject *p);
+    EMBLPlainTextFormat(QObject* p);
 
 protected:
-    virtual FormatCheckResult checkRawTextData(const QByteArray &rawData, const GUrl & = GUrl()) const;
+    virtual FormatCheckResult checkRawTextData(const QByteArray& rawData, const GUrl& = GUrl()) const;
 
-    bool readIdLine(ParserState *);
-    bool readEntry(ParserState *, U2SequenceImporter &, int &seqSize, int &fullSeqSize, bool merge, int gapSize, U2OpStatus &);
+    bool readIdLine(ParserState*);
+    bool readEntry(ParserState*, U2SequenceImporter&, int& seqSize, int& fullSeqSize, bool merge, int gapSize, U2OpStatus&);
     // void readAnnotations(ParserState*, int offset);
     QMap<QString, QString> tagMap;
 };
 
 }  // namespace U2
-
-#endif
