@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FASTQ_FORMAT_H_
-#define _U2_FASTQ_FORMAT_H_
+#pragma once
 
 #include <QStringList>
 
@@ -37,26 +36,24 @@ class DNASequence;
 class U2FORMATS_EXPORT FastqFormat : public TextDocumentFormatDeprecated {
     Q_OBJECT
 public:
-    FastqFormat(QObject *p);
+    FastqFormat(QObject* p);
 
-    virtual void storeDocument(Document *d, IOAdapter *io, U2OpStatus &os);
+    virtual void storeDocument(Document* d, IOAdapter* io, U2OpStatus& os);
 
     virtual bool isStreamingSupport() {
         return true;
     }
 
-    virtual void storeEntry(IOAdapter *io, const QMap<GObjectType, QList<GObject *>> &objectsMap, U2OpStatus &os);
+    virtual void storeEntry(IOAdapter* io, const QMap<GObjectType, QList<GObject*>>& objectsMap, U2OpStatus& os);
 
-    static void writeEntry(const QString &seqName, const DNASequence &seq, IOAdapter *io, const QString &errorMessage, U2OpStatus &os, bool cutLines = true);
+    static void writeEntry(const QString& seqName, const DNASequence& seq, IOAdapter* io, const QString& errorMessage, U2OpStatus& os, bool cutLines = true);
 
 protected:
-    virtual FormatCheckResult checkRawTextData(const QByteArray &rawData, const GUrl & = GUrl()) const;
+    virtual FormatCheckResult checkRawTextData(const QByteArray& rawData, const GUrl& = GUrl()) const;
 
-    virtual DNASequence *loadTextSequence(IOAdapter *io, U2OpStatus &os);
+    virtual DNASequence* loadTextSequence(IOAdapter* io, U2OpStatus& os);
 
-    virtual Document *loadTextDocument(IOAdapter *io, const U2DbiRef &dbiRef, const QVariantMap &fs, U2OpStatus &os);
+    virtual Document* loadTextDocument(IOAdapter* io, const U2DbiRef& dbiRef, const QVariantMap& fs, U2OpStatus& os);
 };
 
 }  // namespace U2
-
-#endif
