@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _SAM_FORMAT_H
-#define _SAM_FORMAT_H
+#pragma once
 
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentModel.h>
@@ -35,15 +34,15 @@ class DNASequence;
 class U2FORMATS_EXPORT SAMFormat : public TextDocumentFormatDeprecated {
     Q_OBJECT
 public:
-    SAMFormat(QObject *p = nullptr);
+    SAMFormat(QObject* p = nullptr);
 
-    virtual void storeDocument(Document *d, IOAdapter *io, U2OpStatus &os);
+    virtual void storeDocument(Document* d, IOAdapter* io, U2OpStatus& os);
 
-    virtual void storeEntry(IOAdapter *io, const QMap<GObjectType, QList<GObject *>> &objectsMap, U2OpStatus &os);
+    virtual void storeEntry(IOAdapter* io, const QMap<GObjectType, QList<GObject*>>& objectsMap, U2OpStatus& os);
 
-    bool storeHeader(IOAdapter *io, const QVector<QByteArray> &names, const QVector<int> &lengths, bool coordinateSorted);
+    bool storeHeader(IOAdapter* io, const QVector<QByteArray>& names, const QVector<int>& lengths, bool coordinateSorted);
 
-    bool storeAlignedRead(int offset, const DNASequence &read, IOAdapter *io, const QByteArray &refName, int refLength, bool first, bool useCigar = false, const QByteArray &cigar = "");
+    bool storeAlignedRead(int offset, const DNASequence& read, IOAdapter* io, const QByteArray& refName, int refLength, bool first, bool useCigar = false, const QByteArray& cigar = "");
 
     /** Temporary method to avoid conflict of SAM and importer */
     void setNeverDetect(bool val) {
@@ -65,14 +64,14 @@ public:
     };
 
 protected:
-    virtual FormatCheckResult checkRawTextData(const QByteArray &rawData, const GUrl & = GUrl()) const;
+    virtual FormatCheckResult checkRawTextData(const QByteArray& rawData, const GUrl& = GUrl()) const;
 
-    virtual Document *loadTextDocument(IOAdapter *io, const U2DbiRef &dbiRef, const QVariantMap &fs, U2OpStatus &os);
+    virtual Document* loadTextDocument(IOAdapter* io, const U2DbiRef& dbiRef, const QVariantMap& fs, U2OpStatus& os);
 
 private:
-    static bool getSectionTags(QByteArray &line, const QByteArray &sectionName, QList<QByteArray> &tags);
+    static bool getSectionTags(QByteArray& line, const QByteArray& sectionName, QList<QByteArray>& tags);
 
-    static bool validateField(int num, QByteArray &field, U2OpStatus *ti = nullptr);
+    static bool validateField(int num, QByteArray& field, U2OpStatus* ti = nullptr);
 
     static const QByteArray VERSION;
 
@@ -110,5 +109,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  //_SAM_FORMAT_H
