@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SCF_FORMAT_H_
-#define _U2_SCF_FORMAT_H_
+#pragma once
 
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentModel.h>
@@ -36,23 +35,21 @@ class U2OpStatus;
 class U2FORMATS_EXPORT SCFFormat : public DocumentFormat {
     Q_OBJECT
 public:
-    SCFFormat(QObject *p);
+    SCFFormat(QObject* p);
 
-    virtual FormatCheckResult checkRawData(const QByteArray &rawData, const GUrl & = GUrl()) const;
+    virtual FormatCheckResult checkRawData(const QByteArray& rawData, const GUrl& = GUrl()) const;
 
-    static void exportDocumentToSCF(const QString &fileName, const DNAChromatogram &cd, const QByteArray &seq, U2OpStatus &ts);
+    static void exportDocumentToSCF(const QString& fileName, const DNAChromatogram& cd, const QByteArray& seq, U2OpStatus& ts);
 
 protected:
-    virtual Document *loadDocument(IOAdapter *io, const U2DbiRef &dbiRef, const QVariantMap &fs, U2OpStatus &os);
+    virtual Document* loadDocument(IOAdapter* io, const U2DbiRef& dbiRef, const QVariantMap& fs, U2OpStatus& os);
 
-    virtual DNASequence *loadSequence(IOAdapter *io, U2OpStatus &ti);
+    virtual DNASequence* loadSequence(IOAdapter* io, U2OpStatus& ti);
 
 private:
-    Document *parseSCF(const U2DbiRef &dbiRef, IOAdapter *io, const QVariantMap &fs, U2OpStatus &os);
+    Document* parseSCF(const U2DbiRef& dbiRef, IOAdapter* io, const QVariantMap& fs, U2OpStatus& os);
 
-    bool loadSCFObjects(IOAdapter *io, DNASequence &dna, DNAChromatogram &cd, U2OpStatus &os);
+    bool loadSCFObjects(IOAdapter* io, DNASequence& dna, DNAChromatogram& cd, U2OpStatus& os);
 };
 
 }  // namespace U2
-
-#endif
