@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,18 +24,15 @@
 
 #include <U2Formats/Database.h>
 
-#ifndef _U2_DATABASE_UTILS_
 #    define _U2_DATABASE_UTILS_
 
 namespace U2 {
 
 class U2FORMATS_EXPORT SNPDatabaseUtils {
 public:
-    static Database *openDatabase(const QString &path);
+    static Database* openDatabase(const QString& path);
 
-    static U2DataId getSequenceId(const QString &sequenceName, U2ObjectDbi *objectDbi);
+    static U2DataId getSequenceId(const QString& sequenceName, U2ObjectDbi* objectDbi);
 };
 
 }  // namespace U2
-
-#endif  // _U2_DATABASE_UTILS_
