@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_STD_RESIDUE_DICTIONARY_H_
-#define _U2_STD_RESIDUE_DICTIONARY_H_
+#pragma once
 
 #include <QByteArray>
 #include <QHash>
@@ -58,22 +57,20 @@ struct StdResidue {
 
 class StdResidueDictionary {
     QHash<int, StdResidue> residues;
-    bool load(const QString &fileName);
-    void buildDictionaryFromAsnTree(AsnNode *rootElem);
+    bool load(const QString& fileName);
+    void buildDictionaryFromAsnTree(AsnNode* rootElem);
     bool validate() const;
     static QMutex standardDictionaryLock;
     static QScopedPointer<StdResidueDictionary> standardDictionary;
 
 public:
     ~StdResidueDictionary();
-    static StdResidueDictionary *createStandardDictionary();
-    static StdResidueDictionary *createFromAsnTree(AsnNode *rootElem);
+    static StdResidueDictionary* createStandardDictionary();
+    static StdResidueDictionary* createFromAsnTree(AsnNode* rootElem);
     // TODO : move this method to AppContext
-    static const StdResidueDictionary *getStandardDictionary();
-    static ResidueType getResidueTypeByName(const QByteArray &name);
+    static const StdResidueDictionary* getStandardDictionary();
+    static ResidueType getResidueTypeByName(const QByteArray& name);
     const StdResidue getResidueById(int id) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_STD_RESIDUE_DICTIONARY_H_
