@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_STREAM_SEQUENCE_READER_H_
-#define _U2_STREAM_SEQUENCE_READER_H_
+#pragma once
 
 #include <QList>
 #include <QString>
@@ -53,8 +52,8 @@ class U2FORMATS_EXPORT StreamSequenceReader : public QObject {
         ReaderContext()
             : io(nullptr), format(nullptr) {
         }
-        IOAdapter *io;
-        DocumentFormat *format;
+        IOAdapter* io;
+        DocumentFormat* format;
     };
     QList<ReaderContext> readers;
     int currentReaderIndex;
@@ -67,11 +66,11 @@ public:
     StreamSequenceReader();
     ~StreamSequenceReader();
 
-    bool init(const QStringList &urls);
-    bool init(const QList<GUrl> &urls);
+    bool init(const QStringList& urls);
+    bool init(const QList<GUrl>& urls);
 
-    const IOAdapter *getIO() const;
-    DocumentFormat *getFormat() const;
+    const IOAdapter* getIO() const;
+    DocumentFormat* getFormat() const;
 
     bool hasNext();
     bool hasError() {
@@ -79,11 +78,9 @@ public:
     }
     int getProgress();
     QString getErrorMessage();
-    DNASequence *getNextSequenceObject();
+    DNASequence* getNextSequenceObject();
 
-    static int getNumberOfSequences(const QString &url, U2OpStatus &os);
+    static int getNumberOfSequences(const QString& url, U2OpStatus& os);
 };
 
 }  // namespace U2
-
-#endif  //_U2_STREAM_SEQUENCE_READER_H_
