@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TEXT_FORMAT_H_
-#define _U2_TEXT_FORMAT_H_
+#pragma once
 
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentModel.h>
@@ -38,15 +37,15 @@ class IOAdapterWriter;
  */
 class U2FORMATS_EXPORT TextDocumentFormatDeprecated : public DocumentFormat {
 public:
-    TextDocumentFormatDeprecated(QObject *p, const DocumentFormatId &id, DocumentFormatFlags _flags, const QStringList &fileExts = QStringList());
-    virtual FormatCheckResult checkRawData(const QByteArray &rawData, const GUrl & = GUrl()) const;
+    TextDocumentFormatDeprecated(QObject* p, const DocumentFormatId& id, DocumentFormatFlags _flags, const QStringList& fileExts = QStringList());
+    virtual FormatCheckResult checkRawData(const QByteArray& rawData, const GUrl& = GUrl()) const;
 
 protected:
-    virtual DNASequence *loadSequence(IOAdapter *io, U2OpStatus &ti);
-    virtual Document *loadDocument(IOAdapter *io, const U2DbiRef &dbiRef, const QVariantMap &fs, U2OpStatus &os);
-    virtual FormatCheckResult checkRawTextData(const QByteArray &rawData, const GUrl & = GUrl()) const = 0;
-    virtual DNASequence *loadTextSequence(IOAdapter *io, U2OpStatus &ti);
-    virtual Document *loadTextDocument(IOAdapter *io, const U2DbiRef &dbiRef, const QVariantMap &fs, U2OpStatus &os) = 0;
+    virtual DNASequence* loadSequence(IOAdapter* io, U2OpStatus& ti);
+    virtual Document* loadDocument(IOAdapter* io, const U2DbiRef& dbiRef, const QVariantMap& fs, U2OpStatus& os);
+    virtual FormatCheckResult checkRawTextData(const QByteArray& rawData, const GUrl& = GUrl()) const = 0;
+    virtual DNASequence* loadTextSequence(IOAdapter* io, U2OpStatus& ti);
+    virtual Document* loadTextDocument(IOAdapter* io, const U2DbiRef& dbiRef, const QVariantMap& fs, U2OpStatus& os) = 0;
 };
 
 /*
@@ -54,56 +53,54 @@ protected:
  */
 class U2FORMATS_EXPORT TextDocumentFormat : public DocumentFormat {
 public:
-    TextDocumentFormat(QObject *p, const DocumentFormatId &id, DocumentFormatFlags _flags, const QStringList &fileExts = QStringList());
+    TextDocumentFormat(QObject* p, const DocumentFormatId& id, DocumentFormatFlags _flags, const QStringList& fileExts = QStringList());
 
 protected:
     /** Checks if the 'dataPrefix' text is stored using this document format. */
-    virtual FormatCheckResult checkRawTextData(const QString &dataPrefix, const GUrl &originalDataUrl) const = 0;
+    virtual FormatCheckResult checkRawTextData(const QString& dataPrefix, const GUrl& originalDataUrl) const = 0;
 
     /**
      * Loads a document from the given stream.
      * 'hints' map contains set of loading hints like 'DocumentReadingMode_SequenceMergeGapSize', etc…
      * If loading is failed the nullptr is returned and the error is stored in 'os', otherwise a non-nullptr value is returned.
      */
-    virtual Document *loadTextDocument(IOAdapterReader &reader, const U2DbiRef &dbiRef, const QVariantMap &hints, U2OpStatus &os) = 0;
+    virtual Document* loadTextDocument(IOAdapterReader& reader, const U2DbiRef& dbiRef, const QVariantMap& hints, U2OpStatus& os) = 0;
 
     /**
      * Loads a DNASequence object from the current state of the reader.
      * Returns a valid sequence object or nullptr if there are no more sequences left in the stream.
      * By default returns nullptr & error that sequence loading is not supported by the current format.
      */
-    virtual DNASequence *loadTextSequence(IOAdapterReader &reader, U2OpStatus &os);
+    virtual DNASequence* loadTextSequence(IOAdapterReader& reader, U2OpStatus& os);
 
     /**
      * Serializes 'document' into the given text stream. Sets error to 'os' if serialization fails.
      * By default text documents do not support writing, so this method must be re-implemented in every format to support serialization.
      */
-    virtual void storeTextDocument(IOAdapterWriter &writer, Document *document, U2OpStatus &os);
+    virtual void storeTextDocument(IOAdapterWriter& writer, Document* document, U2OpStatus& os);
 
     /**
      * Stores all supported document types from the given map of objects.
      * The document format should preserve the objects order in the map when possible.
      * The default implementation does nothing and sets 'unsupported' error to 'os'.
      */
-    virtual void storeTextEntry(IOAdapterWriter &writer, const QMap<GObjectType, QList<GObject *>> &objectsMap, U2OpStatus &os);
+    virtual void storeTextEntry(IOAdapterWriter& writer, const QMap<GObjectType, QList<GObject*>>& objectsMap, U2OpStatus& os);
 
 private:
     /** Detects encoding of the raw binary data and calls 'checkRawTextData'. */
-    FormatCheckResult checkRawData(const QByteArray &rawBinaryData, const GUrl &originalDataUrl) const override;
+    FormatCheckResult checkRawData(const QByteArray& rawBinaryData, const GUrl& originalDataUrl) const override;
 
     /** Delegates this call to 'loadTextDocument' with a valid text reader instance. */
-    Document *loadDocument(IOAdapter *io, const U2DbiRef &dbiRef, const QVariantMap &hints, U2OpStatus &os) override;
+    Document* loadDocument(IOAdapter* io, const U2DbiRef& dbiRef, const QVariantMap& hints, U2OpStatus& os) override;
 
     /** Delegates this call to 'loadTextSequence' with a valid text reader instance. */
-    DNASequence *loadSequence(IOAdapter *io, U2OpStatus &os) override;
+    DNASequence* loadSequence(IOAdapter* io, U2OpStatus& os) override;
 
     /** Delegates this call to 'storeTextDocument' with a valid text writer instance. */
-    void storeDocument(Document *document, IOAdapter *io, U2OpStatus &os) override;
+    void storeDocument(Document* document, IOAdapter* io, U2OpStatus& os) override;
 
     /** Delegates this call to 'storeTextEntry' with a valid text writer instance. */
-    void storeEntry(IOAdapter *io, const QMap<GObjectType, QList<GObject *>> &objectsMap, U2OpStatus &os) override;
+    void storeEntry(IOAdapter* io, const QMap<GObjectType, QList<GObject*>>& objectsMap, U2OpStatus& os) override;
 };
 
 }  // namespace U2
-
-#endif
