@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_VCF4_VARIATION_FORMAT_H_
-#define _U2_VCF4_VARIATION_FORMAT_H_
+#pragma once
 
 #include <U2Formats/AbstractVariationFormat.h>
 
@@ -29,12 +28,10 @@ namespace U2 {
 class U2FORMATS_EXPORT VCF4VariationFormat : public AbstractVariationFormat {
     Q_OBJECT
 public:
-    VCF4VariationFormat(QObject *p);
+    VCF4VariationFormat(QObject* p);
 
 protected:
     bool checkFormatByColumnCount(int columnCount) const override;
 };
 
 }  // namespace U2
-
-#endif  // _U2_VCF4_VARIATION_FORMAT_H_
