@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ACE_IMPORTER_H_
-#define _U2_ACE_IMPORTER_H_
+#pragma once
 
 #include <U2Core/DocumentImport.h>
 #include <U2Core/DocumentProviderTask.h>
@@ -34,19 +33,19 @@ class LoadDocumentTask;
 class AceImporterTask : public DocumentProviderTask {
     Q_OBJECT
 public:
-    AceImporterTask(const GUrl &url, const QVariantMap &settings);
+    AceImporterTask(const GUrl& url, const QVariantMap& settings);
 
     void prepare() override;
-    QList<Task *> onSubTaskFinished(Task *subTask) override;
+    QList<Task*> onSubTaskFinished(Task* subTask) override;
     ReportResult report() override;
 
 private:
     void initCloneObjectTasks();
     void initLoadDocumentTask();
 
-    ConvertAceToSqliteTask *convertTask;
-    QList<Task *> cloneTasks;
-    LoadDocumentTask *loadDocTask;
+    ConvertAceToSqliteTask* convertTask;
+    QList<Task*> cloneTasks;
+    LoadDocumentTask* loadDocTask;
 
     bool isSqliteDbTransit;
 
@@ -67,13 +66,11 @@ class U2FORMATS_EXPORT AceImporter : public DocumentImporter {
 public:
     AceImporter();
 
-    FormatCheckResult checkRawData(const QByteArray &rawData, const GUrl &url) override;
-    DocumentProviderTask *createImportTask(const FormatDetectionResult &res, bool showGui, const QVariantMap &hints) override;
+    FormatCheckResult checkRawData(const QByteArray& rawData, const GUrl& url) override;
+    DocumentProviderTask* createImportTask(const FormatDetectionResult& res, bool showGui, const QVariantMap& hints) override;
 
     static const QString ID;
     static const QString SRC_URL;
 };
 
 }  // namespace U2
-
-#endif  // _U2_ACE_IMPORTER_H_
