@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CLONE_ASSEMBLY_WITH_REFERENCE_TO_DBI_TASK_H_
-#define _U2_CLONE_ASSEMBLY_WITH_REFERENCE_TO_DBI_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 #include <U2Core/U2Assembly.h>
@@ -33,11 +32,11 @@ class CloneObjectTask;
 class CloneAssemblyWithReferenceToDbiTask : public Task {
     Q_OBJECT
 public:
-    CloneAssemblyWithReferenceToDbiTask(const U2Assembly &assembly,
-                                        const U2Sequence &reference,
-                                        const U2DbiRef &srcDbiRef,
-                                        const U2DbiRef &dstDbiRef,
-                                        const QVariantMap &hints);
+    CloneAssemblyWithReferenceToDbiTask(const U2Assembly& assembly,
+                                        const U2Sequence& reference,
+                                        const U2DbiRef& srcDbiRef,
+                                        const U2DbiRef& dstDbiRef,
+                                        const QVariantMap& hints);
 
     void prepare();
     void run();
@@ -50,10 +49,8 @@ private:
     const U2DbiRef dstDbiRef;
     const QString dstFolder;
 
-    CloneObjectTask *cloneAssemblyTask;
-    CloneObjectTask *cloneReferenceTask;
+    CloneObjectTask* cloneAssemblyTask;
+    CloneObjectTask* cloneReferenceTask;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CLONE_ASSEMBLY_WITH_REFERENCE_TO_DBI_TASK_H_
