@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CONVERT_ACE_TO_SQLITE_TASK_H_
-#define _U2_CONVERT_ACE_TO_SQLITE_TASK_H_
+#pragma once
 
 #include <U2Core/GUrl.h>
 #include <U2Core/Task.h>
@@ -35,7 +34,7 @@ namespace U2 {
 class ConvertAceToSqliteTask : public Task {
     Q_OBJECT
 public:
-    ConvertAceToSqliteTask(const GUrl &sourceUrl, const U2DbiRef &dstDbiRef);
+    ConvertAceToSqliteTask(const GUrl& sourceUrl, const U2DbiRef& dstDbiRef);
 
     virtual void run();
     virtual ReportResult report();
@@ -44,14 +43,14 @@ public:
     QMap<U2Sequence, U2Assembly> getImportedObjects() const;
 
 private:
-    qint64 importAssemblies(IOAdapter &ioAdapter);
+    qint64 importAssemblies(IOAdapter& ioAdapter);
     qint64 packReads();
     void updateAttributeDbi();
 
     const GUrl sourceUrl;
 
     U2DbiRef dstDbiRef;
-    U2Dbi *dbi;
+    U2Dbi* dbi;
 
     bool databaseWasCreated;
     int countImportedAssembly;
@@ -62,5 +61,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_CONVERT_ACE_TO_SQLITE_TASK_H_
