@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SQLITEBLOBINPUTSTREAM_H_
-#define _U2_SQLITEBLOBINPUTSTREAM_H_
+#pragma once
 
 #include <U2Core/InputStream.h>
 #include <U2Core/U2SqlHelpers.h>
@@ -36,11 +35,11 @@ public:
     virtual ~SQLiteBlobStream();
 
 protected:
-    void init(int accessType, DbRef *db, const QByteArray &tableId, const QByteArray &columnId, const U2DataId &rowId, U2OpStatus &os);
+    void init(int accessType, DbRef* db, const QByteArray& tableId, const QByteArray& columnId, const U2DataId& rowId, U2OpStatus& os);
     void releaseHandle();
 
 protected:
-    sqlite3_blob *handle;
+    sqlite3_blob* handle;
     qint64 size;
     qint64 offset;
 
@@ -51,14 +50,12 @@ protected:
 class SQLiteBlobInputStream : public InputStream, public SQLiteBlobStream {
     Q_DISABLE_COPY(SQLiteBlobInputStream)
 public:
-    SQLiteBlobInputStream(DbRef *db, const QByteArray &tableId, const QByteArray &columnId, const U2DataId &rowId, U2OpStatus &os);
+    SQLiteBlobInputStream(DbRef* db, const QByteArray& tableId, const QByteArray& columnId, const U2DataId& rowId, U2OpStatus& os);
 
     qint64 available();
     void close();
-    int read(char *buffer, int length, U2OpStatus &os);
-    qint64 skip(qint64 n, U2OpStatus &os);
+    int read(char* buffer, int length, U2OpStatus& os);
+    qint64 skip(qint64 n, U2OpStatus& os);
 };
 
 }  // namespace U2
-
-#endif  // _U2_SQLITEBLOBINPUTSTREAM_H_
