@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SQLITE_DBI_H_
-#define _U2_SQLITE_DBI_H_
+#pragma once
 
 #include <QStack>
 
@@ -55,9 +54,6 @@ class SQLiteVariantDbi;
 /** Store all reads in N tables sorted by effective read length */
 #define SQLITE_DBI_ASSEMBLY_READ_ELEN_METHOD_MULTITABLE_V1 "multi-table-v1"
 
-/** Uses RTree index to store reads. This method is simple but not very efficient in terms of space/insert time */
-#define SQLITE_DBI_ASSEMBLY_READ_ELEN_METHOD_RTREE "rtree2d"
-
 /** No compression is applied. Best for manual DB browsing  (default)*/
 #define SQLITE_DBI_ASSEMBLY_READ_COMPRESSION_METHOD_NO_COMPRESSION "no-compression"
 
@@ -78,84 +74,84 @@ public:
     special flags
     "assembly-reads-compression=1" - enables reads compression for assembly. Affects new DB only
     */
-    virtual void init(const QHash<QString, QString> &properties, const QVariantMap &persistentData, U2OpStatus &os);
+    virtual void init(const QHash<QString, QString>& properties, const QVariantMap& persistentData, U2OpStatus& os);
 
     /** Stops the database and frees up used resources. */
-    virtual QVariantMap shutdown(U2OpStatus &os);
+    virtual QVariantMap shutdown(U2OpStatus& os);
 
     /**
     Ensures that dbi state is synchronized with storage
     Return 'true' of operation is successful
     */
-    virtual bool flush(U2OpStatus &os);
+    virtual bool flush(U2OpStatus& os);
 
     /** Unique database id. Used for cross-database references. */
     virtual QString getDbiId() const;
 
-    virtual bool isInitialized(U2OpStatus &os);
+    virtual bool isInitialized(U2OpStatus& os);
 
-    virtual void populateDefaultSchema(U2OpStatus &os);
+    virtual void populateDefaultSchema(U2OpStatus& os);
 
     /** Returns database meta-info. Any set of properties to be shown to user */
-    virtual QHash<QString, QString> getDbiMetaInfo(U2OpStatus &os);
+    virtual QHash<QString, QString> getDbiMetaInfo(U2OpStatus& os);
 
     /** Returns type of the entity referenced by the given ID */
-    virtual U2DataType getEntityTypeById(const U2DataId &id) const;
+    virtual U2DataType getEntityTypeById(const U2DataId& id) const;
 
-    virtual U2ObjectDbi *getObjectDbi();
+    virtual U2ObjectDbi* getObjectDbi();
 
-    virtual U2ObjectRelationsDbi *getObjectRelationsDbi();
+    virtual U2ObjectRelationsDbi* getObjectRelationsDbi();
 
-    virtual U2SequenceDbi *getSequenceDbi();
+    virtual U2SequenceDbi* getSequenceDbi();
 
-    virtual U2MsaDbi *getMsaDbi();
+    virtual U2MsaDbi* getMsaDbi();
 
-    virtual U2AssemblyDbi *getAssemblyDbi();
+    virtual U2AssemblyDbi* getAssemblyDbi();
 
-    virtual U2CrossDatabaseReferenceDbi *getCrossDatabaseReferenceDbi();
+    virtual U2CrossDatabaseReferenceDbi* getCrossDatabaseReferenceDbi();
 
-    virtual U2AttributeDbi *getAttributeDbi();
+    virtual U2AttributeDbi* getAttributeDbi();
 
-    virtual U2VariantDbi *getVariantDbi();
+    virtual U2VariantDbi* getVariantDbi();
 
-    virtual U2FeatureDbi *getFeatureDbi();
+    virtual U2FeatureDbi* getFeatureDbi();
 
-    virtual U2ModDbi *getModDbi();
+    virtual U2ModDbi* getModDbi();
 
-    virtual UdrDbi *getUdrDbi();
+    virtual UdrDbi* getUdrDbi();
 
-    DbRef *getDbRef() const {
+    DbRef* getDbRef() const {
         return db;
     }
 
-    SQLiteObjectDbi *getSQLiteObjectDbi() const;
+    SQLiteObjectDbi* getSQLiteObjectDbi() const;
 
-    SQLiteObjectRelationsDbi *getSQLiteObjectRelationsDbi() const;
+    SQLiteObjectRelationsDbi* getSQLiteObjectRelationsDbi() const;
 
-    SQLiteMsaDbi *getSQLiteMsaDbi() const;
+    SQLiteMsaDbi* getSQLiteMsaDbi() const;
 
-    SQLiteSequenceDbi *getSQLiteSequenceDbi() const;
+    SQLiteSequenceDbi* getSQLiteSequenceDbi() const;
 
-    SQLiteModDbi *getSQLiteModDbi() const;
+    SQLiteModDbi* getSQLiteModDbi() const;
 
-    SQLiteUdrDbi *getSQLiteUdrDbi() const;
+    SQLiteUdrDbi* getSQLiteUdrDbi() const;
 
-    SQLiteFeatureDbi *getSQLiteFeatureDbi() const;
+    SQLiteFeatureDbi* getSQLiteFeatureDbi() const;
 
     /** Returns properties used to initialized the database */
     virtual QHash<QString, QString> getInitProperties() const {
         return initProperties;
     }
 
-    virtual QString getProperty(const QString &name, const QString &defaultValue, U2OpStatus &os);
+    virtual QString getProperty(const QString& name, const QString& defaultValue, U2OpStatus& os);
 
-    virtual void setProperty(const QString &name, const QString &value, U2OpStatus &os);
+    virtual void setProperty(const QString& name, const QString& value, U2OpStatus& os);
 
-    virtual void startOperationsBlock(U2OpStatus &os);
+    virtual void startOperationsBlock(U2OpStatus& os);
 
-    virtual void stopOperationBlock(U2OpStatus &os);
+    virtual void stopOperationBlock(U2OpStatus& os);
 
-    QMutex *getDbMutex() const;
+    QMutex* getDbMutex() const;
 
     virtual bool isReadOnly() const;
 
@@ -168,24 +164,24 @@ private:
 
     void setState(U2DbiState state);
 
-    void internalInit(const QHash<QString, QString> &props, U2OpStatus &os);
+    void internalInit(const QHash<QString, QString>& props, U2OpStatus& os);
 
     QString url;
-    DbRef *db;
+    DbRef* db;
 
-    SQLiteObjectDbi *objectDbi;
-    SQLiteObjectRelationsDbi *objectRelationsDbi;
-    SQLiteSequenceDbi *sequenceDbi;
-    SQLiteMsaDbi *msaDbi;
-    SQLiteAssemblyDbi *assemblyDbi;
-    SQLiteCrossDatabaseReferenceDbi *crossDbi;
-    SQLiteAttributeDbi *attributeDbi;
-    SQLiteVariantDbi *variantDbi;
-    SQLiteFeatureDbi *featureDbi;
-    SQLiteModDbi *modDbi;
-    SQLiteUdrDbi *udrDbi;
+    SQLiteObjectDbi* objectDbi;
+    SQLiteObjectRelationsDbi* objectRelationsDbi;
+    SQLiteSequenceDbi* sequenceDbi;
+    SQLiteMsaDbi* msaDbi;
+    SQLiteAssemblyDbi* assemblyDbi;
+    SQLiteCrossDatabaseReferenceDbi* crossDbi;
+    SQLiteAttributeDbi* attributeDbi;
+    SQLiteVariantDbi* variantDbi;
+    SQLiteFeatureDbi* featureDbi;
+    SQLiteModDbi* modDbi;
+    SQLiteUdrDbi* udrDbi;
 
-    QStack<SQLiteTransaction *> operationsBlockTransactions;
+    QStack<SQLiteTransaction*> operationsBlockTransactions;
 
     friend class SQLiteObjectDbi;
     friend class SQLiteCrossDatabaseReferenceDbi;
@@ -200,19 +196,19 @@ public:
     SQLiteDbiFactory();
 
     /** Creates new DBI instance */
-    virtual U2Dbi *createDbi();
+    virtual U2Dbi* createDbi();
 
     /** Returns DBI type ID */
     virtual U2DbiFactoryId getId() const;
 
     /** Checks that data pointed by properties is a valid DBI resource */
-    virtual FormatCheckResult isValidDbi(const QHash<QString, QString> &properties, const QByteArray &rawData, U2OpStatus &os) const;
+    virtual FormatCheckResult isValidDbi(const QHash<QString, QString>& properties, const QByteArray& rawData, U2OpStatus& os) const;
 
-    virtual GUrl id2Url(const U2DbiId &id) const {
+    virtual GUrl id2Url(const U2DbiId& id) const {
         return GUrl(id, GUrl_File);
     }
 
-    virtual bool isDbiExists(const U2DbiId &id) const;
+    virtual bool isDbiExists(const U2DbiId& id) const;
 
 public:
     static const U2DbiFactoryId ID;
@@ -221,21 +217,19 @@ public:
 /** helper class, used as a base for all SQLite<child>Dbis */
 class SQLiteChildDBICommon {
 public:
-    SQLiteChildDBICommon(SQLiteDbi *dbi)
+    SQLiteChildDBICommon(SQLiteDbi* dbi)
         : dbi(dbi), db(dbi->getDbRef()) {
     }
     virtual ~SQLiteChildDBICommon() {
     }
 
-    virtual void initSqlSchema(U2OpStatus &os) = 0;
-    virtual void shutdown(U2OpStatus &) {
+    virtual void initSqlSchema(U2OpStatus& os) = 0;
+    virtual void shutdown(U2OpStatus&) {
     }
 
 protected:
-    SQLiteDbi *dbi;
-    DbRef *db;
+    SQLiteDbi* dbi;
+    DbRef* db;
 };
 
 }  // namespace U2
-
-#endif
