@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SQLITE_OBJECT_RELATIONS_DBI_H_
-#define _U2_SQLITE_OBJECT_RELATIONS_DBI_H_
+#pragma once
 
 #include <U2Core/U2ObjectRelationsDbi.h>
 
@@ -30,18 +29,16 @@ namespace U2 {
 
 class SQLiteObjectRelationsDbi : public U2ObjectRelationsDbi, public SQLiteChildDBICommon {
 public:
-    SQLiteObjectRelationsDbi(SQLiteDbi *dbi);
+    SQLiteObjectRelationsDbi(SQLiteDbi* dbi);
 
-    void initSqlSchema(U2OpStatus &os);
+    void initSqlSchema(U2OpStatus& os);
 
-    void createObjectRelation(U2ObjectRelation &relation, U2OpStatus &os);
-    QList<U2ObjectRelation> getObjectRelations(const U2DataId &object, U2OpStatus &os);
-    QList<U2DataId> getReferenceRelatedObjects(const U2DataId &reference, GObjectRelationRole relationRole, U2OpStatus &os);
-    void removeObjectRelation(U2ObjectRelation &relation, U2OpStatus &os);
-    void removeAllObjectRelations(const U2DataId &object, U2OpStatus &os);
-    void removeReferencesForObject(const U2DataId &object, U2OpStatus &os);
+    void createObjectRelation(U2ObjectRelation& relation, U2OpStatus& os);
+    QList<U2ObjectRelation> getObjectRelations(const U2DataId& object, U2OpStatus& os);
+    QList<U2DataId> getReferenceRelatedObjects(const U2DataId& reference, GObjectRelationRole relationRole, U2OpStatus& os);
+    void removeObjectRelation(U2ObjectRelation& relation, U2OpStatus& os);
+    void removeAllObjectRelations(const U2DataId& object, U2OpStatus& os);
+    void removeReferencesForObject(const U2DataId& object, U2OpStatus& os);
 };
 
 }  // namespace U2
-
-#endif  // _U2_MYSQL_OBJECT_RELATIONS_DBI_H_
