@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@ namespace U2 {
 
 #define DEFAULT_ROWS_PER_TABLE 5000
 
-MultiTableAssemblyAdapter::MultiTableAssemblyAdapter(SQLiteDbi *_dbi, const U2DataId &assemblyId, const AssemblyCompressor *compressor, DbRef *db, U2OpStatus &os)
+MultiTableAssemblyAdapter::MultiTableAssemblyAdapter(SQLiteDbi* _dbi, const U2DataId& assemblyId, const AssemblyCompressor* compressor, DbRef* db, U2OpStatus& os)
     : SQLiteAssemblyAdapter(assemblyId, compressor, db) {
     dbi = _dbi;
     version = -1;
@@ -54,7 +54,7 @@ void MultiTableAssemblyAdapter::clearTableAdaptersInfo() {
     elenRanges.clear();
 }
 
-void MultiTableAssemblyAdapter::syncTables(U2OpStatus &os) {
+void MultiTableAssemblyAdapter::syncTables(U2OpStatus& os) {
     qint64 versionInDb = dbi->getObjectDbi()->getObjectVersion(assemblyId, os);
     if (versionInDb <= version) {
         return;
@@ -70,7 +70,7 @@ void MultiTableAssemblyAdapter::syncTables(U2OpStatus &os) {
     }
 }
 
-static QVector<U2Region> toRange(const QVector<int> &startPos) {
+static QVector<U2Region> toRange(const QVector<int>& startPos) {
     QVector<U2Region> res;
     int prev = 0;
     foreach (int pos, startPos) {
@@ -80,7 +80,7 @@ static QVector<U2Region> toRange(const QVector<int> &startPos) {
     return res;
 }
 
-void MultiTableAssemblyAdapter::initTables(const QList<U2AssemblyRead> &reads, U2OpStatus &os) {
+void MultiTableAssemblyAdapter::initTables(const QList<U2AssemblyRead>& reads, U2OpStatus& os) {
     if (os.hasError()) {
         return;
     }
@@ -109,7 +109,7 @@ void MultiTableAssemblyAdapter::initTables(const QList<U2AssemblyRead> &reads, U
     flushTables(os);
 }
 
-void MultiTableAssemblyAdapter::rereadTables(const QByteArray &idata, U2OpStatus &os) {
+void MultiTableAssemblyAdapter::rereadTables(const QByteArray& idata, U2OpStatus& os) {
     QWriteLocker wl(&tablesSyncLock);
 
     clearTableAdaptersInfo();
@@ -131,7 +131,7 @@ void MultiTableAssemblyAdapter::rereadTables(const QByteArray &idata, U2OpStatus
     QList<QByteArray> elenTokens = elenData.split(',');
     U2Region prev(-1, 1);
     bool parseOk = true;
-    foreach (const QByteArray &elenTok, elenTokens) {
+    foreach (const QByteArray& elenTok, elenTokens) {
         int start = elenTok.toInt(&parseOk);
         if (!parseOk || start < prev.endPos()) {
             os.setError(QString("Failed to parse range: %1, full: %2").arg(elenTok.constData()).arg(elenData.constData()));
@@ -173,7 +173,7 @@ void MultiTableAssemblyAdapter::rereadTables(const QByteArray &idata, U2OpStatus
     }
 }
 
-void MultiTableAssemblyAdapter::flushTables(U2OpStatus &os) {
+void MultiTableAssemblyAdapter::flushTables(U2OpStatus& os) {
     bool empty = adaptersGrid.isEmpty();
     if (empty) {
         // TODO: fetch some reads for analysis. By now not needed, since regions are hard-coded anyway
@@ -208,19 +208,19 @@ void MultiTableAssemblyAdapter::initAdaptersGrid(int nRows, int nElens) {
     assert(adaptersGrid.isEmpty());
     adaptersGrid.resize(nRows);
     for (int i = 0; i < nRows; i++) {
-        adaptersGrid[i] = QVector<MTASingleTableAdapter *>(nElens, nullptr);
+        adaptersGrid[i] = QVector<MTASingleTableAdapter*>(nElens, nullptr);
     }
 }
 
-MTASingleTableAdapter *MultiTableAssemblyAdapter::createAdapter(int rowPos, int elenPos, U2OpStatus &os) {
+MTASingleTableAdapter* MultiTableAssemblyAdapter::createAdapter(int rowPos, int elenPos, U2OpStatus& os) {
     assert(adaptersGrid.at(rowPos).at(elenPos) == nullptr);
 
     QString suffix = getTableSuffix(rowPos, elenPos);
-    SingleTableAssemblyAdapter *sa = new SingleTableAssemblyAdapter(dbi, assemblyId, 'M', suffix, compressor, db, os);
-    const U2Region &elenRange = elenRanges.at(elenPos);
+    SingleTableAssemblyAdapter* sa = new SingleTableAssemblyAdapter(dbi, assemblyId, 'M', suffix, compressor, db, os);
+    const U2Region& elenRange = elenRanges.at(elenPos);
     sa->enableRangeTableMode(elenRange.startPos, elenRange.endPos());
     QByteArray idExtra = getIdExtra(rowPos, elenPos);
-    MTASingleTableAdapter *ma = new MTASingleTableAdapter(sa, rowPos, elenPos, idExtra);
+    MTASingleTableAdapter* ma = new MTASingleTableAdapter(sa, rowPos, elenPos, idExtra);
     ma->singleTableAdapter->createReadsTables(os);
     adapters << ma;
     idExtras << idExtra;
@@ -228,10 +228,10 @@ MTASingleTableAdapter *MultiTableAssemblyAdapter::createAdapter(int rowPos, int
     return ma;
 }
 
-void MultiTableAssemblyAdapter::createReadsIndexes(U2OpStatus &os) {
+void MultiTableAssemblyAdapter::createReadsIndexes(U2OpStatus& os) {
     SQLiteWriteQuery("PRAGMA temp_store = FILE", db, os).execute();
     CHECK_OP(os, );
-    foreach (MTASingleTableAdapter *a, adapters) {
+    foreach (MTASingleTableAdapter* a, adapters) {
         a->singleTableAdapter->createReadsIndexes(os);
         if (os.hasError()) {
             break;
@@ -242,19 +242,19 @@ void MultiTableAssemblyAdapter::createReadsIndexes(U2OpStatus &os) {
 
 QByteArray MultiTableAssemblyAdapter::getIdExtra(int rowPos, int elenPos) {
     QByteArray res(4, 0);
-    qint16 *data = (qint16 *)res.data();
+    qint16* data = (qint16*)res.data();
     data[0] = (qint16)rowPos;
     data[1] = (qint16)elenPos;
     return res;
 }
 
-qint64 MultiTableAssemblyAdapter::countReads(const U2Region &r, U2OpStatus &os) {
+qint64 MultiTableAssemblyAdapter::countReads(const U2Region& r, U2OpStatus& os) {
     bool all = r == U2_REGION_MAX;
     qint64 sum = 0;
     // use more sensitive algorithm for smaller regions with low amount of reads
     // and not-very sensitive for huge regions with a lot of reads
     int nReadsToUseNotPreciseAlgorithms = 1000 / (r.length + 1);
-    foreach (MTASingleTableAdapter *a, adapters) {
+    foreach (MTASingleTableAdapter* a, adapters) {
         int n = a->singleTableAdapter->countReads(r, os);
         if (n != 0 && !all && n < nReadsToUseNotPreciseAlgorithms) {
             n = a->singleTableAdapter->countReadsPrecise(r, os);
@@ -267,14 +267,14 @@ qint64 MultiTableAssemblyAdapter::countReads(const U2Region &r, U2OpStatus &os)
     return sum;
 }
 
-qint64 MultiTableAssemblyAdapter::getMaxPackedRow(const U2Region &r, U2OpStatus &os) {
+qint64 MultiTableAssemblyAdapter::getMaxPackedRow(const U2Region& r, U2OpStatus& os) {
     qint64 max = 0;
     // process only hi row adapters
     int nRows = adaptersGrid.size();
     for (int rowPos = nRows; --rowPos >= 0 && max == 0;) {
-        QVector<MTASingleTableAdapter *> elenAdapters = adaptersGrid.at(rowPos);
+        QVector<MTASingleTableAdapter*> elenAdapters = adaptersGrid.at(rowPos);
         for (int elenPos = 0, nElens = elenAdapters.size(); elenPos < nElens; elenPos++) {
-            MTASingleTableAdapter *a = elenAdapters.at(elenPos);
+            MTASingleTableAdapter* a = elenAdapters.at(elenPos);
             if (a == nullptr) {
                 continue;
             }
@@ -287,10 +287,10 @@ qint64 MultiTableAssemblyAdapter::getMaxPackedRow(const U2Region &r, U2OpStatus
     return max;
 }
 
-qint64 MultiTableAssemblyAdapter::getMaxEndPos(U2OpStatus &os) {
+qint64 MultiTableAssemblyAdapter::getMaxEndPos(U2OpStatus& os) {
     // TODO: optimize by using gstart + maxReadLen for first n-1 tables
     qint64 max = 0;
-    foreach (MTASingleTableAdapter *a, adapters) {
+    foreach (MTASingleTableAdapter* a, adapters) {
         qint64 n = a->singleTableAdapter->getMaxEndPos(os);
         if (os.hasError()) {
             break;
@@ -300,9 +300,9 @@ qint64 MultiTableAssemblyAdapter::getMaxEndPos(U2OpStatus &os) {
     return max;
 }
 
-U2DbiIterator<U2AssemblyRead> *MultiTableAssemblyAdapter::getReads(const U2Region &r, U2OpStatus &os, bool sortedHint) {
-    QVector<U2DbiIterator<U2AssemblyRead> *> iterators;
-    foreach (MTASingleTableAdapter *a, adapters) {
+U2DbiIterator<U2AssemblyRead>* MultiTableAssemblyAdapter::getReads(const U2Region& r, U2OpStatus& os, bool sortedHint) {
+    QVector<U2DbiIterator<U2AssemblyRead>*> iterators;
+    foreach (MTASingleTableAdapter* a, adapters) {
         iterators << a->singleTableAdapter->getReads(r, os, sortedHint);
         if (os.hasError()) {
             break;
@@ -315,11 +315,11 @@ U2DbiIterator<U2AssemblyRead> *MultiTableAssemblyAdapter::getReads(const U2Regio
     return new MTAReadsIterator(iterators, idExtras, sortedHint);
 }
 
-U2DbiIterator<U2AssemblyRead> *MultiTableAssemblyAdapter::getReadsByRow(const U2Region &r, qint64 minRow, qint64 maxRow, U2OpStatus &os) {
-    QVector<U2DbiIterator<U2AssemblyRead> *> iterators;
+U2DbiIterator<U2AssemblyRead>* MultiTableAssemblyAdapter::getReadsByRow(const U2Region& r, qint64 minRow, qint64 maxRow, U2OpStatus& os) {
+    QVector<U2DbiIterator<U2AssemblyRead>*> iterators;
     QVector<QByteArray> selectedIdExtras;
     U2Region targetRowRange(minRow, maxRow - minRow);
-    foreach (MTASingleTableAdapter *a, adapters) {
+    foreach (MTASingleTableAdapter* a, adapters) {
         const U2Region rowRegion(a->rowPos * rowsPerRange, rowsPerRange);
         if (!rowRegion.intersects(targetRowRange)) {
             continue;
@@ -337,9 +337,9 @@ U2DbiIterator<U2AssemblyRead> *MultiTableAssemblyAdapter::getReadsByRow(const U2
     return new MTAReadsIterator(iterators, selectedIdExtras, false);
 }
 
-U2DbiIterator<U2AssemblyRead> *MultiTableAssemblyAdapter::getReadsByName(const QByteArray &name, U2OpStatus &os) {
-    QVector<U2DbiIterator<U2AssemblyRead> *> iterators;
-    foreach (MTASingleTableAdapter *a, adapters) {
+U2DbiIterator<U2AssemblyRead>* MultiTableAssemblyAdapter::getReadsByName(const QByteArray& name, U2OpStatus& os) {
+    QVector<U2DbiIterator<U2AssemblyRead>*> iterators;
+    foreach (MTASingleTableAdapter* a, adapters) {
         iterators << a->singleTableAdapter->getReadsByName(name, os);
         if (os.hasError()) {
             break;
@@ -352,19 +352,19 @@ U2DbiIterator<U2AssemblyRead> *MultiTableAssemblyAdapter::getReadsByName(const Q
     return new MTAReadsIterator(iterators, idExtras, false);
 }
 
-int MultiTableAssemblyAdapter::getElenRangePosById(const U2DataId &id) const {
+int MultiTableAssemblyAdapter::getElenRangePosById(const U2DataId& id) const {
     QByteArray extra = U2DbiUtils::toDbExtra(id);
 
     SAFE_POINT(extra.size() == 4, QString("Illegal assembly read ID extra part! HEX: %1").arg(extra.toHex().constData()), -1);
 
-    const qint16 *data = (const qint16 *)extra.constData();
+    const qint16* data = (const qint16*)extra.constData();
     return int(data[1]);
 }
 
 int MultiTableAssemblyAdapter::getElenRangePosByLength(qint64 readLength) const {
     int nElenRanges = elenRanges.size();
     for (int i = 0; i < nElenRanges; i++) {
-        const U2Region &r = elenRanges[i];
+        const U2Region& r = elenRanges[i];
         if (r.contains(readLength)) {
             return i;
         }
@@ -376,22 +376,22 @@ int MultiTableAssemblyAdapter::getRowRangePosByRow(quint64 row) const {
     return row / rowsPerRange;
 }
 
-int MultiTableAssemblyAdapter::getRowRangePosById(const U2DataId &id) const {
+int MultiTableAssemblyAdapter::getRowRangePosById(const U2DataId& id) const {
     QByteArray extra = U2DbiUtils::toDbExtra(id);
 
     SAFE_POINT(extra.size() == 4, QString("Extra part size of assembly read ID is not correct! HEX(Extra): %1").arg(extra.toHex().constData()), -1);
 
-    const qint16 *data = (const qint16 *)extra.constData();
+    const qint16* data = (const qint16*)extra.constData();
     return int(data[0]);
 }
 
-static U2DataId addTable2Id(const U2DataId &id, const QByteArray &idExtra) {
+static U2DataId addTable2Id(const U2DataId& id, const QByteArray& idExtra) {
     assert(U2DbiUtils::toDbExtra(id).isEmpty());
     U2DataId res = U2DbiUtils::toU2DataId(U2DbiUtils::toDbiId(id), U2Type::AssemblyRead, idExtra);
     return res;
 }
 
-static void ensureGridSize(QVector<QVector<QList<U2AssemblyRead>>> &grid, int rowPos, int nElens) {
+static void ensureGridSize(QVector<QVector<QList<U2AssemblyRead>>>& grid, int rowPos, int nElens) {
     int oldRows = grid.size();
     if (oldRows > rowPos) {
         return;
@@ -406,7 +406,7 @@ static void ensureGridSize(QVector<QVector<QList<U2AssemblyRead>>> &grid, int ro
 #define N_READS_TO_FLUSH_TOTAL 100000
 #define N_READS_TO_FLUSH_PER_RANGE 10000
 
-void MultiTableAssemblyAdapter::addReads(U2DbiIterator<U2AssemblyRead> *it, U2AssemblyReadsImportInfo &ii, U2OpStatus &os) {
+void MultiTableAssemblyAdapter::addReads(U2DbiIterator<U2AssemblyRead>* it, U2AssemblyReadsImportInfo& ii, U2OpStatus& os) {
     bool empty = adaptersGrid.isEmpty();
     if (empty) {
         // TODO: fetch some reads for analysis. By now not needed, since regions are hard-coded anyway
@@ -449,12 +449,12 @@ void MultiTableAssemblyAdapter::addReads(U2DbiIterator<U2AssemblyRead> *it, U2As
         if (lastIteration || readsInGrid > N_READS_TO_FLUSH_TOTAL) {
             for (int rowPos = 0; rowPos < nRows && !os.isCoR(); rowPos++) {
                 for (int elenPos = 0; elenPos < nElens && !os.isCoR(); elenPos++) {
-                    QList<U2AssemblyRead> &rangeReads = readsGrid[rowPos][elenPos];
+                    QList<U2AssemblyRead>& rangeReads = readsGrid[rowPos][elenPos];
                     int nRangeReads = rangeReads.size();
                     if (nRangeReads == 0 || (!lastIteration && nRangeReads < N_READS_TO_FLUSH_PER_RANGE)) {
                         continue;
                     }
-                    MTASingleTableAdapter *adapter = getAdapterByRowAndElenRange(rowPos, elenPos, true, os);
+                    MTASingleTableAdapter* adapter = getAdapterByRowAndElenRange(rowPos, elenPos, true, os);
                     U2AssemblyReadsImportInfo rangeReadsImportInfo;
                     // pass the same coverage info through all adapters to accumulate coverage
                     rangeReadsImportInfo.coverageInfo = ii.coverageInfo;
@@ -479,7 +479,7 @@ void MultiTableAssemblyAdapter::addReads(U2DbiIterator<U2AssemblyRead> *it, U2As
     }
 }
 
-MTASingleTableAdapter *MultiTableAssemblyAdapter::getAdapterByRowAndElenRange(int rowPos, int elenPos, bool createIfNotExits, U2OpStatus &os) {
+MTASingleTableAdapter* MultiTableAssemblyAdapter::getAdapterByRowAndElenRange(int rowPos, int elenPos, bool createIfNotExits, U2OpStatus& os) {
     int nElens = elenRanges.size();
     assert(elenPos < nElens);
     if (rowPos >= adaptersGrid.size()) {
@@ -494,24 +494,24 @@ MTASingleTableAdapter *MultiTableAssemblyAdapter::getAdapterByRowAndElenRange(in
             adaptersGrid[i].resize(nElens);
         }
     }
-    QVector<MTASingleTableAdapter *> elenAdapters = adaptersGrid.at(rowPos);
+    QVector<MTASingleTableAdapter*> elenAdapters = adaptersGrid.at(rowPos);
     assert(elenAdapters.size() == nElens);
-    MTASingleTableAdapter *adapter = elenAdapters.at(elenPos);
+    MTASingleTableAdapter* adapter = elenAdapters.at(elenPos);
     if (adapter == nullptr && createIfNotExits) {
         adapter = createAdapter(rowPos, elenPos, os);
     }
     return adapter;
 }
 
-void MultiTableAssemblyAdapter::removeReads(const QList<U2DataId> &readIds, U2OpStatus &os) {
+void MultiTableAssemblyAdapter::removeReads(const QList<U2DataId>& readIds, U2OpStatus& os) {
     int nReads = readIds.size();
 
-    QHash<MTASingleTableAdapter *, QList<U2DataId>> readsByAdapter;
+    QHash<MTASingleTableAdapter*, QList<U2DataId>> readsByAdapter;
     for (int i = 0; i < nReads; i++) {
-        const U2DataId &readId = readIds[i];
+        const U2DataId& readId = readIds[i];
         int rowPos = getRowRangePosById(readId);
         int elenPos = getElenRangePosById(readId);
-        MTASingleTableAdapter *a = getAdapterByRowAndElenRange(rowPos, elenPos, false, os);
+        MTASingleTableAdapter* a = getAdapterByRowAndElenRange(rowPos, elenPos, false, os);
 
         SAFE_POINT(a != nullptr, QString("No table adapter was found! row: %1, elen: %2").arg(rowPos).arg(elenPos), );
 
@@ -520,19 +520,19 @@ void MultiTableAssemblyAdapter::removeReads(const QList<U2DataId> &readIds, U2Op
         }
         readsByAdapter[a].append(readId);
     }
-    foreach (MTASingleTableAdapter *a, readsByAdapter.keys()) {
-        QList<U2DataId> &rangeReadIds = readsByAdapter[a];
+    foreach (MTASingleTableAdapter* a, readsByAdapter.keys()) {
+        QList<U2DataId>& rangeReadIds = readsByAdapter[a];
         a->singleTableAdapter->removeReads(rangeReadIds, os);
         // TODO: remove adapters for empty tables. And tables as well
     }
 }
 
-void MultiTableAssemblyAdapter::dropReadsTables(U2OpStatus &os) {
+void MultiTableAssemblyAdapter::dropReadsTables(U2OpStatus& os) {
     // remove prepared queries to finalize them and prevent SQLite errors on table drop
     db->preparedQueries.clear();
 
-    for (QVector<MTASingleTableAdapter *> adaptersVector : qAsConst(adaptersGrid)) {
-        for (MTASingleTableAdapter *adapter : qAsConst(adaptersVector)) {
+    for (QVector<MTASingleTableAdapter*> adaptersVector : qAsConst(adaptersGrid)) {
+        for (MTASingleTableAdapter* adapter : qAsConst(adaptersVector)) {
             if (adapter != nullptr) {
                 adapter->singleTableAdapter->dropReadsTables(os);
             }
@@ -540,7 +540,7 @@ void MultiTableAssemblyAdapter::dropReadsTables(U2OpStatus &os) {
     }
 }
 
-void MultiTableAssemblyAdapter::pack(U2AssemblyPackStat &stat, U2OpStatus &os) {
+void MultiTableAssemblyAdapter::pack(U2AssemblyPackStat& stat, U2OpStatus& os) {
     MultiTablePackAlgorithmAdapter packAdapter(this);
 
     AssemblyPackAlgorithm::pack(packAdapter, stat, os);
@@ -553,9 +553,9 @@ void MultiTableAssemblyAdapter::pack(U2AssemblyPackStat &stat, U2OpStatus &os) {
     flushTables(os);
 }
 
-void MultiTableAssemblyAdapter::calculateCoverage(const U2Region &region, U2AssemblyCoverageStat &coverage, U2OpStatus &os) {
+void MultiTableAssemblyAdapter::calculateCoverage(const U2Region& region, U2AssemblyCoverageStat& coverage, U2OpStatus& os) {
     for (int i = 0; i < adapters.size(); ++i) {
-        MTASingleTableAdapter *a = adapters.at(i);
+        MTASingleTableAdapter* a = adapters.at(i);
         a->singleTableAdapter->calculateCoverage(region, coverage, os);
         if (os.isCoR()) {
             break;
@@ -568,13 +568,13 @@ void MultiTableAssemblyAdapter::calculateCoverage(const U2Region &region, U2Asse
 //////////////////////////////////////////////////////////////////////////
 // pack adapter
 
-MultiTablePackAlgorithmAdapter::MultiTablePackAlgorithmAdapter(MultiTableAssemblyAdapter *ma) {
+MultiTablePackAlgorithmAdapter::MultiTablePackAlgorithmAdapter(MultiTableAssemblyAdapter* ma) {
     multiTableAdapter = ma;
-    DbRef *db = multiTableAdapter->getDbRef();
+    DbRef* db = multiTableAdapter->getDbRef();
     int nElens = multiTableAdapter->getNumberOfElenRanges();
     ensureGridSize(nElens);
-    foreach (MTASingleTableAdapter *a, multiTableAdapter->getAdapters()) {
-        SingleTablePackAlgorithmAdapter *sa = new SingleTablePackAlgorithmAdapter(db, a->singleTableAdapter->getReadsTableName());
+    foreach (MTASingleTableAdapter* a, multiTableAdapter->getAdapters()) {
+        SingleTablePackAlgorithmAdapter* sa = new SingleTablePackAlgorithmAdapter(db, a->singleTableAdapter->getReadsTableName());
         packAdapters << sa;
         if (packAdaptersGrid.size() <= a->rowPos) {
             packAdaptersGrid.resize(a->rowPos + 1);
@@ -586,9 +586,9 @@ MultiTablePackAlgorithmAdapter::MultiTablePackAlgorithmAdapter(MultiTableAssembl
     }
 }
 
-U2DbiIterator<PackAlgorithmData> *MultiTablePackAlgorithmAdapter::selectAllReads(U2OpStatus &os) {
-    QVector<U2DbiIterator<PackAlgorithmData> *> iterators;
-    foreach (SingleTablePackAlgorithmAdapter *a, packAdapters) {
+U2DbiIterator<PackAlgorithmData>* MultiTablePackAlgorithmAdapter::selectAllReads(U2OpStatus& os) {
+    QVector<U2DbiIterator<PackAlgorithmData>*> iterators;
+    foreach (SingleTablePackAlgorithmAdapter* a, packAdapters) {
         iterators << a->selectAllReads(os);
     }
     return new MTAPackAlgorithmDataIterator(iterators, multiTableAdapter->getIdExtrasPerRange());
@@ -598,12 +598,12 @@ MultiTablePackAlgorithmAdapter::~MultiTablePackAlgorithmAdapter() {
     qDeleteAll(packAdapters);
 }
 
-void MultiTablePackAlgorithmAdapter::assignProw(const U2DataId &readId, qint64 prow, U2OpStatus &os) {
+void MultiTablePackAlgorithmAdapter::assignProw(const U2DataId& readId, qint64 prow, U2OpStatus& os) {
     int elenPos = multiTableAdapter->getElenRangePosById(readId);
     int oldRowPos = multiTableAdapter->getRowRangePosById(readId);
     int newRowPos = multiTableAdapter->getRowRangePosByRow(prow);
 
-    SingleTablePackAlgorithmAdapter *sa = nullptr;
+    SingleTablePackAlgorithmAdapter* sa = nullptr;
     if (newRowPos == oldRowPos) {
         sa = packAdaptersGrid[oldRowPos][elenPos];
         sa->assignProw(readId, prow, os);
@@ -612,8 +612,8 @@ void MultiTablePackAlgorithmAdapter::assignProw(const U2DataId &readId, qint64 p
     ensureGridSize(newRowPos + 1);
 
     sa = packAdaptersGrid[newRowPos][elenPos];
-    MTASingleTableAdapter *oldA = multiTableAdapter->getAdapterByRowAndElenRange(oldRowPos, elenPos, false, os);
-    MTASingleTableAdapter *newA = multiTableAdapter->getAdapterByRowAndElenRange(newRowPos, elenPos, true, os);
+    MTASingleTableAdapter* oldA = multiTableAdapter->getAdapterByRowAndElenRange(oldRowPos, elenPos, false, os);
+    MTASingleTableAdapter* newA = multiTableAdapter->getAdapterByRowAndElenRange(newRowPos, elenPos, true, os);
 
     SAFE_POINT(oldA != nullptr, QString("Can't find reads table adapter: row: %1, elen: %2").arg(oldRowPos).arg(elenPos), );
     SAFE_POINT(newA != nullptr, QString("Can't find reads table adapter: row: %1, elen: %2").arg(newRowPos).arg(elenPos), );
@@ -625,27 +625,27 @@ void MultiTablePackAlgorithmAdapter::assignProw(const U2DataId &readId, qint64 p
         packAdaptersGrid[newRowPos][elenPos] = sa;
     }
 
-    QVector<SQLiteReadTableMigrationData> &newTableData = migrations[newA];
+    QVector<SQLiteReadTableMigrationData>& newTableData = migrations[newA];
     newTableData.append(SQLiteReadTableMigrationData(U2DbiUtils::toDbiId(readId), oldA, prow));
     // TODO: add mem check here!
 }
 
 void MultiTablePackAlgorithmAdapter::releaseDbResources() {
-    foreach (SingleTablePackAlgorithmAdapter *a, packAdapters) {
+    foreach (SingleTablePackAlgorithmAdapter* a, packAdapters) {
         a->releaseDbResources();
     }
 }
 
-void MultiTablePackAlgorithmAdapter::migrate(MTASingleTableAdapter *newA, const QVector<SQLiteReadTableMigrationData> &data, qint64 migratedBefore, qint64 totalMigrationCount, U2OpStatus &os) {
+void MultiTablePackAlgorithmAdapter::migrate(MTASingleTableAdapter* newA, const QVector<SQLiteReadTableMigrationData>& data, qint64 migratedBefore, qint64 totalMigrationCount, U2OpStatus& os) {
     SAFE_POINT_OP(os, );
     // delete reads from old tables, and insert into new one
-    QHash<MTASingleTableAdapter *, QVector<SQLiteReadTableMigrationData>> readsByOldTable;
-    foreach (const SQLiteReadTableMigrationData &d, data) {
+    QHash<MTASingleTableAdapter*, QVector<SQLiteReadTableMigrationData>> readsByOldTable;
+    foreach (const SQLiteReadTableMigrationData& d, data) {
         readsByOldTable[d.oldTable].append(d);
     }
-    DbRef *db = multiTableAdapter->getDbRef();
-    foreach (MTASingleTableAdapter *oldA, readsByOldTable.keys()) {
-        const QVector<SQLiteReadTableMigrationData> &migData = readsByOldTable[oldA];
+    DbRef* db = multiTableAdapter->getDbRef();
+    foreach (MTASingleTableAdapter* oldA, readsByOldTable.keys()) {
+        const QVector<SQLiteReadTableMigrationData>& migData = readsByOldTable[oldA];
         if (migData.isEmpty()) {
             continue;
         }
@@ -668,7 +668,7 @@ void MultiTablePackAlgorithmAdapter::migrate(MTASingleTableAdapter *newA, const
 
             SQLiteWriteQuery(QString("CREATE TEMPORARY TABLE %1(id INTEGER PRIMARY KEY, prow INTEGER NOT NULL)").arg(idsTable), db, os).execute();
             SQLiteWriteQuery insertIds(QString("INSERT INTO %1(id, prow) VALUES(?1, ?2)").arg(idsTable), db, os);
-            for (const SQLiteReadTableMigrationData &d : qAsConst(migData)) {
+            for (const SQLiteReadTableMigrationData& d : qAsConst(migData)) {
                 insertIds.reset(false);
                 insertIds.bindInt64(1, d.readId);
                 insertIds.bindInt32(2, d.newProw);
@@ -713,12 +713,12 @@ void MultiTablePackAlgorithmAdapter::migrate(MTASingleTableAdapter *newA, const
     }
 }
 
-void MultiTablePackAlgorithmAdapter::migrateAll(U2OpStatus &os) {
+void MultiTablePackAlgorithmAdapter::migrateAll(U2OpStatus& os) {
     SAFE_POINT_OP(os, );
 
     qint64 nReadsToMigrate = 0;
-    foreach (MTASingleTableAdapter *newTable, migrations.keys()) {
-        const QVector<SQLiteReadTableMigrationData> &data = migrations[newTable];
+    foreach (MTASingleTableAdapter* newTable, migrations.keys()) {
+        const QVector<SQLiteReadTableMigrationData>& data = migrations[newTable];
         nReadsToMigrate += data.size();
     }
     if (nReadsToMigrate == 0) {
@@ -732,7 +732,7 @@ void MultiTablePackAlgorithmAdapter::migrateAll(U2OpStatus &os) {
 #define MAX_PERCENT_TO_REINDEX 20
     if (migrationPercent > MAX_PERCENT_TO_REINDEX) {
         perfLog.trace("Assembly: dropping old indexes first");
-        foreach (MTASingleTableAdapter *adapter, multiTableAdapter->getAdapters()) {
+        foreach (MTASingleTableAdapter* adapter, multiTableAdapter->getAdapters()) {
             adapter->singleTableAdapter->dropReadsIndexes(os);
         }
         perfLog.trace("Assembly: indexes are dropped");
@@ -740,8 +740,8 @@ void MultiTablePackAlgorithmAdapter::migrateAll(U2OpStatus &os) {
 
     SAFE_POINT_OP(os, );
     int nMigrated = 0;
-    foreach (MTASingleTableAdapter *newTable, migrations.keys()) {
-        const QVector<SQLiteReadTableMigrationData> &data = migrations[newTable];
+    foreach (MTASingleTableAdapter* newTable, migrations.keys()) {
+        const QVector<SQLiteReadTableMigrationData>& data = migrations[newTable];
         migrate(newTable, data, nMigrated, nReadsToMigrate, os);
         nMigrated += data.size();
     }
@@ -762,7 +762,7 @@ void MultiTablePackAlgorithmAdapter::ensureGridSize(int nRows) {
 //////////////////////////////////////////////////////////////////////////
 // MTAReadsIterator
 
-MTAReadsIterator::MTAReadsIterator(QVector<U2DbiIterator<U2AssemblyRead> *> &i, const QVector<QByteArray> &ie, bool sorted)
+MTAReadsIterator::MTAReadsIterator(QVector<U2DbiIterator<U2AssemblyRead>*>& i, const QVector<QByteArray>& ie, bool sorted)
     : iterators(i), currentRange(0), idExtras(ie), sortedHint(sorted) {
 }
 
@@ -773,7 +773,7 @@ MTAReadsIterator::~MTAReadsIterator() {
 // TODO: remove copy-paste from this code
 bool MTAReadsIterator::hasNext() {
     if (sortedHint) {
-        foreach (U2DbiIterator<U2AssemblyRead> *it, iterators) {
+        foreach (U2DbiIterator<U2AssemblyRead>* it, iterators) {
             if (it->hasNext()) {
                 return true;
             }
@@ -783,7 +783,7 @@ bool MTAReadsIterator::hasNext() {
         bool res = currentRange < iterators.size();
         if (res) {
             do {
-                U2DbiIterator<U2AssemblyRead> *it = iterators[currentRange];
+                U2DbiIterator<U2AssemblyRead>* it = iterators[currentRange];
                 res = it->hasNext();
                 if (res) {
                     break;
@@ -799,33 +799,33 @@ U2AssemblyRead MTAReadsIterator::next() {
     U2AssemblyRead res;
     if (sortedHint) {
         qint64 minPos = LLONG_MAX;
-        U2DbiIterator<U2AssemblyRead> *minIt = nullptr;
-        foreach (U2DbiIterator<U2AssemblyRead> *it, iterators) {
+        U2DbiIterator<U2AssemblyRead>* minIt = nullptr;
+        foreach (U2DbiIterator<U2AssemblyRead>* it, iterators) {
             if (it->hasNext()) {
                 U2AssemblyRead candidate = it->peek();
-                SAFE_POINT(nullptr != candidate.data(), "NULL assembly read", candidate);
+                SAFE_POINT(candidate.data() != nullptr, "NULL assembly read", candidate);
                 if (candidate->leftmostPos < minPos) {
                     minIt = it;
                     minPos = candidate->leftmostPos;
                 }
             }
         }
-        if (nullptr != minIt) {
+        if (minIt != nullptr) {
             res = minIt->next();
-            SAFE_POINT(nullptr != res.data(), "NULL assembly read", res);
+            SAFE_POINT(res.data() != nullptr, "NULL assembly read", res);
             int currentIt = iterators.indexOf(minIt);
-            const QByteArray &idExtra = idExtras.at(currentIt);
+            const QByteArray& idExtra = idExtras.at(currentIt);
             res->id = addTable2Id(res->id, idExtra);
         }
         return res;
     } else {
         if (currentRange < iterators.size()) {
             do {
-                U2DbiIterator<U2AssemblyRead> *it = iterators[currentRange];
+                U2DbiIterator<U2AssemblyRead>* it = iterators[currentRange];
                 if (it->hasNext()) {
                     res = it->next();
-                    SAFE_POINT(nullptr != res.data(), "NULL assembly read", res);
-                    const QByteArray &idExtra = idExtras.at(currentRange);
+                    SAFE_POINT(res.data() != nullptr, "NULL assembly read", res);
+                    const QByteArray& idExtra = idExtras.at(currentRange);
                     res->id = addTable2Id(res->id, idExtra);
                     break;
                 }
@@ -840,33 +840,33 @@ U2AssemblyRead MTAReadsIterator::peek() {
     U2AssemblyRead res;
     if (sortedHint) {
         qint64 minPos = LLONG_MAX;
-        U2DbiIterator<U2AssemblyRead> *minIt = nullptr;
-        foreach (U2DbiIterator<U2AssemblyRead> *it, iterators) {
+        U2DbiIterator<U2AssemblyRead>* minIt = nullptr;
+        foreach (U2DbiIterator<U2AssemblyRead>* it, iterators) {
             if (it->hasNext()) {
                 U2AssemblyRead candidate = it->peek();
-                SAFE_POINT(nullptr != candidate.data(), "NULL assembly read", candidate);
+                SAFE_POINT(candidate.data() != nullptr, "NULL assembly read", candidate);
                 if (candidate->leftmostPos < minPos) {
                     minIt = it;
                     minPos = candidate->leftmostPos;
                 }
             }
         }
-        if (nullptr != minIt) {
+        if (minIt != nullptr) {
             res = minIt->next();
-            SAFE_POINT(nullptr != res.data(), "NULL assembly read", res);
+            SAFE_POINT(res.data() != nullptr, "NULL assembly read", res);
             int currentIt = iterators.indexOf(minIt);
-            const QByteArray &idExtra = idExtras.at(currentIt);
+            const QByteArray& idExtra = idExtras.at(currentIt);
             res->id = addTable2Id(res->id, idExtra);
         }
         return res;
     } else {
         if (currentRange < iterators.size()) {
             do {
-                U2DbiIterator<U2AssemblyRead> *it = iterators[currentRange];
+                U2DbiIterator<U2AssemblyRead>* it = iterators[currentRange];
                 if (it->hasNext()) {
                     res = it->peek();
-                    SAFE_POINT(nullptr != res.data(), "NULL assembly read", res);
-                    const QByteArray &idExtra = idExtras.at(currentRange);
+                    SAFE_POINT(res.data() != nullptr, "NULL assembly read", res);
+                    const QByteArray& idExtra = idExtras.at(currentRange);
                     res->id = addTable2Id(res->id, idExtra);
                     break;
                 }
@@ -880,7 +880,7 @@ U2AssemblyRead MTAReadsIterator::peek() {
 //////////////////////////////////////////////////////////////////////////
 // MTAPackAlgorithmDataIterator
 
-MTAPackAlgorithmDataIterator::MTAPackAlgorithmDataIterator(QVector<U2DbiIterator<PackAlgorithmData> *> &i, const QVector<QByteArray> &ie)
+MTAPackAlgorithmDataIterator::MTAPackAlgorithmDataIterator(QVector<U2DbiIterator<PackAlgorithmData>*>& i, const QVector<QByteArray>& ie)
     : iterators(i), idExtras(ie) {
     fetchNextData();
 }
@@ -907,7 +907,7 @@ void MTAPackAlgorithmDataIterator::fetchNextData() {
     PackAlgorithmData bestCandidate;
     int bestRange = 0;
     for (int i = 0; i < iterators.size(); i++) {
-        U2DbiIterator<PackAlgorithmData> *it = iterators[i];
+        U2DbiIterator<PackAlgorithmData>* it = iterators[i];
         if (!it->hasNext()) {
             continue;
         }
@@ -920,7 +920,7 @@ void MTAPackAlgorithmDataIterator::fetchNextData() {
     nextData = bestCandidate;
     if (!nextData.readId.isEmpty()) {
         iterators[bestRange]->next();
-        const QByteArray &idExtra = idExtras.at(bestRange);
+        const QByteArray& idExtra = idExtras.at(bestRange);
         nextData.readId = addTable2Id(nextData.readId, idExtra);
     }
 }
