@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SQLITE_UPGRADER_H_
-#define _U2_SQLITE_UPGRADER_H_
+#pragma once
 
 #include <U2Core/U2DbiUpgrader.h>
 
@@ -30,12 +29,10 @@ class SQLiteDbi;
 
 class SqliteUpgrader : public U2DbiUpgrader {
 public:
-    SqliteUpgrader(const Version &versionFrom, const Version &versionTo, SQLiteDbi *dbi);
+    SqliteUpgrader(const Version& versionFrom, const Version& versionTo, SQLiteDbi* dbi);
 
 protected:
-    SQLiteDbi *dbi;
+    SQLiteDbi* dbi;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SQLITE_UPGRADER_H_
