@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SQLITE_UPGRADER_FROM_1_13_TO_1_25_H_
-#define _U2_SQLITE_UPGRADER_FROM_1_13_TO_1_25_H_
+#pragma once
 
 #include "SqliteUpgrader.h"
 
@@ -28,14 +27,12 @@ namespace U2 {
 
 class SqliteUpgraderFrom_1_13_To_1_25 : public SqliteUpgrader {
 public:
-    SqliteUpgraderFrom_1_13_To_1_25(SQLiteDbi *dbi);
+    SqliteUpgraderFrom_1_13_To_1_25(SQLiteDbi* dbi);
 
-    void upgrade(U2OpStatus &os) const;
+    void upgrade(U2OpStatus& os) const;
 
 private:
-    void upgradeCoverageAttribute(U2OpStatus &os) const;
+    void upgradeCoverageAttribute(U2OpStatus& os) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SQLITE_UPGRADER_FROM_0_TO_1_13_H_
