@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CALCULATE_SEQUENCES_NUMBER_TASK_H_
-#define _U2_CALCULATE_SEQUENCES_NUMBER_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 #include <U2Core/global.h>
@@ -30,7 +29,7 @@ namespace U2 {
 class U2FORMATS_EXPORT CalculateSequencesNumberTask : public Task {
     Q_OBJECT
 public:
-    CalculateSequencesNumberTask(const QString &url);
+    CalculateSequencesNumberTask(const QString& url);
 
     int getSequencesNumber() const;
 
@@ -42,4 +41,3 @@ private:
 };
 
 }  // namespace U2
-#endif
