@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CONVERT_ASSEMBLY_TO_SAM_TASK_H_
-#define _U2_CONVERT_ASSEMBLY_TO_SAM_TASK_H_
+#pragma once
 
 #include <U2Core/AssemblyObject.h>
 #include <U2Core/GUrl.h>
@@ -34,10 +33,10 @@ class U2FORMATS_EXPORT ConvertAssemblyToSamTask : public Task {
     Q_OBJECT
 public:
     ConvertAssemblyToSamTask(GUrl dbFileUrl, GUrl samFileUrl);
-    ConvertAssemblyToSamTask(const DbiConnection *handle, GUrl samFileUrl);
+    ConvertAssemblyToSamTask(const DbiConnection* handle, GUrl samFileUrl);
 
     /** Converts only one assembly object to a SAM file */
-    ConvertAssemblyToSamTask(const U2EntityRef &entityRef, GUrl samFileUrl);
+    ConvertAssemblyToSamTask(const U2EntityRef& entityRef, GUrl samFileUrl);
 
     void run();
     QString generateReport() const;
@@ -48,9 +47,7 @@ private:
 
     U2EntityRef assemblyEntityRef;
 
-    const DbiConnection *handle;
+    const DbiConnection* handle;
 };
 
 }  // namespace U2
-
-#endif  //_U2_CONVERT_ASSEMBLY_TO_SAM_TASK_H_
