@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@ namespace U2 {
 
 //////////////////////////////////////////////////////////////////////////
 // MergeBamTask
-MergeBamTask::MergeBamTask(const QStringList &urls, const QString &dir, const QString &outName, bool sortInputBams)
+MergeBamTask::MergeBamTask(const QStringList& urls, const QString& dir, const QString& outName, bool sortInputBams)
     : Task(DocumentFormatUtils::tr("Merge BAM files with SAMTools merge"), TaskFlags_FOSCOE), outputName(outName), workingDir(dir), targetUrl(""), bamUrls(urls), sortInputBams(sortInputBams) {
     if (!workingDir.endsWith("/") && !workingDir.endsWith("\\")) {
         this->workingDir += "/";
@@ -55,8 +55,8 @@ QString MergeBamTask::getResult() const {
     return targetUrl;
 }
 
-void cleanupTempDir(const QStringList &tempDirFiles) {
-    foreach (const QString &url, tempDirFiles) {
+void cleanupTempDir(const QStringList& tempDirFiles) {
+    foreach (const QString& url, tempDirFiles) {
         QFile toDelete(url);
         if (toDelete.exists(url)) {
             toDelete.remove(url);
@@ -73,11 +73,11 @@ void MergeBamTask::run() {
     QString tmpDirPath = AppContext::getAppSettings()->getUserAppsSettings()->getCurrentProcessTemporaryDirPath();
     if (sortInputBams) {
         QStringList sortedNamesList;
-        foreach (const QString &url, bamUrls) {
+        for (const QString& url : qAsConst(bamUrls)) {
             QFileInfo fi(url);
-            QString sortedName = tmpDirPath + "/" + fi.completeBaseName() + "_sorted.bam";
-            sortedNamesList.append(sortedName);
-            BAMUtils::sortBam(url, sortedName, stateInfo);
+            QString sortedFilePath = tmpDirPath + "/" + fi.completeBaseName() + "_sorted.bam";
+            sortedNamesList.append(sortedFilePath);
+            BAMUtils::sortBam(url, sortedFilePath, stateInfo);
             if (stateInfo.isCoR()) {
                 cleanupTempDir(sortedNamesList);
                 return;
