@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MERGE_BAM_TASK_H_
-#define _U2_MERGE_BAM_TASK_H_
+#pragma once
 
 #include <U2Core/GUrl.h>
 #include <U2Core/Task.h>
@@ -29,19 +28,17 @@ namespace U2 {
 
 class U2FORMATS_EXPORT MergeBamTask : public Task {
 public:
-    MergeBamTask(const QStringList &urls, const QString &dir, const QString &outName, bool sortInputBams = false);
+    MergeBamTask(const QStringList& urls, const QString& dir, const QString& outName, bool sortInputBams = false);
 
     QString getResult() const;
-    void run();
+    void run() override;
 
 protected:
     QString outputName;
     QString workingDir;
     QString targetUrl;
     QStringList bamUrls;
-    bool sortInputBams;
+    bool sortInputBams = false;
 };  // MergeBamTask
 
 }  // namespace U2
-
-#endif  // _U2_MERGE_BAM_TASK_H_
