@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PAIRED_FASTQ_COMPARATOR_H_
-#define _U2_PAIRED_FASTQ_COMPARATOR_H_
+#pragma once
 
 #include <QFile>
 
@@ -41,17 +40,17 @@ class FastqSequenceInfo {
 public:
     FastqSequenceInfo() {
     }
-    FastqSequenceInfo(const DNASequence &seq);
+    FastqSequenceInfo(const DNASequence& seq);
 
     bool isValid() const;
 
     QString getSeqName() const;
-    const DNASequence &getDNASeq() const {
+    const DNASequence& getDNASeq() const {
         return seq;
     }
 
-    bool operator==(const FastqSequenceInfo &other) const;
-    bool operator!=(const FastqSequenceInfo &other) const;
+    bool operator==(const FastqSequenceInfo& other) const;
+    bool operator!=(const FastqSequenceInfo& other) const;
 
 private:
     DNASequence seq;
@@ -63,8 +62,8 @@ private:
 class U2FORMATS_EXPORT PairedFastqComparator : public QObject {
     Q_OBJECT
 public:
-    PairedFastqComparator(const QString &inputFile_1, const QString &inputFile_2, const QString &outputFile_1, const QString &outputFile_2, U2OpStatus &os);
-    void compare(U2OpStatus &os);
+    PairedFastqComparator(const QString& inputFile_1, const QString& inputFile_2, const QString& outputFile_1, const QString& outputFile_2, U2OpStatus& os);
+    void compare(U2OpStatus& os);
 
     int getPairsCount() const {
         return pairsCounter;
@@ -74,13 +73,13 @@ public:
     }
 
 private:
-    void dropUntilItem(U2OpStatus &os, QList<FastqSequenceInfo> &list, const FastqSequenceInfo &untilItem);
+    void dropUntilItem(U2OpStatus& os, QList<FastqSequenceInfo>& list, const FastqSequenceInfo& untilItem);
 
-    const FastqSequenceInfo tryToFindPair(U2OpStatus &os, QList<FastqSequenceInfo> &initializer, const FastqSequenceInfo &info, QList<FastqSequenceInfo> &searchIn);
+    const FastqSequenceInfo tryToFindPair(U2OpStatus& os, QList<FastqSequenceInfo>& initializer, const FastqSequenceInfo& info, QList<FastqSequenceInfo>& searchIn);
 
-    void tryToFindPairInTail(U2OpStatus &os, FASTQIterator &reads, QList<FastqSequenceInfo> &unpaired, bool iteratorContentIsFirst);
+    void tryToFindPairInTail(U2OpStatus& os, FASTQIterator& reads, QList<FastqSequenceInfo>& unpaired, bool iteratorContentIsFirst);
 
-    void writePair(U2OpStatus &os, const FastqSequenceInfo &seqInfo_1, const FastqSequenceInfo &seqInfo_2);
+    void writePair(U2OpStatus& os, const FastqSequenceInfo& seqInfo_1, const FastqSequenceInfo& seqInfo_2);
 
 private:
     FASTQIterator it_1;
@@ -94,5 +93,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_PAIRED_FASTQ_COMPARATOR_H_
