@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,10 +28,10 @@
 
 namespace U2 {
 
-TabulatedFormatReader::TabulatedFormatReader(U2OpStatus &os, IOAdapter *ioAdapter)
+TabulatedFormatReader::TabulatedFormatReader(U2OpStatus& os, IOAdapter* ioAdapter)
     : ioAdapter(ioAdapter),
       currentLine(0) {
-    CHECK_EXT(nullptr != ioAdapter, os.setError(L10N::nullPointerError("IO adapter")), );
+    CHECK_EXT(ioAdapter != nullptr, os.setError(L10N::nullPointerError("IO adapter")), );
     CHECK_EXT(ioAdapter->isOpen(), os.setError(tr("IO adapter is not opened")), );
 
     readNextLine();
@@ -51,7 +51,7 @@ qint64 TabulatedFormatReader::getCurrentLineNumber() const {
     return currentLine;
 }
 
-const QStringList &TabulatedFormatReader::getComments() const {
+const QStringList& TabulatedFormatReader::getComments() const {
     return comments;
 }
 
@@ -77,11 +77,11 @@ QString TabulatedFormatReader::read() {
     return line;
 }
 
-bool TabulatedFormatReader::isComment(const QString &line) {
+bool TabulatedFormatReader::isComment(const QString& line) {
     return line.startsWith('#');
 }
 
-void TabulatedFormatReader::storeLine(const QString &line) {
+void TabulatedFormatReader::storeLine(const QString& line) {
     if (isComment(line)) {
         comments << line;
     } else {
