@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_NOTIFICATIONS_TYPES_H_
-#define _U2_NOTIFICATIONS_TYPES_H_
+#pragma once
 
 namespace U2 {
 
@@ -32,5 +31,3 @@ enum NotificationType {
 };
 
 }  // namespace U2
-
-#endif
