@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -42,6 +42,7 @@
 #include <U2Core/Log.h>
 #include <U2Core/ProjectModel.h>
 #include <U2Core/ResourceTracker.h>
+#include <U2Core/Settings.h>
 #include <U2Core/U2SafePoints.h>
 
 #include <U2Gui/ObjectViewModel.h>
@@ -55,7 +56,7 @@ const int OpenViewTask::MAX_DOC_NUMBER_TO_OPEN_VIEWS = 5;
 //////////////////////////////////////////////////////////////////////////
 // LoadUnloadedDocumentAndOpenViewTask
 
-LoadUnloadedDocumentAndOpenViewTask::LoadUnloadedDocumentAndOpenViewTask(Document *d)
+LoadUnloadedDocumentAndOpenViewTask::LoadUnloadedDocumentAndOpenViewTask(Document* d)
     : Task("", TaskFlags_NR_FOSCOE | TaskFlag_MinimizeSubtaskErrorText | TaskFlag_CollectChildrenWarnings) {
     loadUnloadedTask = new LoadUnloadedDocumentTask(d);
     setUseDescriptionFromSubtask(true);
@@ -66,11 +67,11 @@ LoadUnloadedDocumentAndOpenViewTask::LoadUnloadedDocumentAndOpenViewTask(Documen
     addSubTask(loadUnloadedTask);
 }
 
-static Task *createOpenViewTask(const MultiGSelection &ms) {
-    QList<GObjectViewFactory *> fs = AppContext::getObjectViewFactoryRegistry()->getAllFactories();
-    QList<GObjectViewFactory *> ls;
+static Task* createOpenViewTask(const MultiGSelection& ms) {
+    QList<GObjectViewFactory*> fs = AppContext::getObjectViewFactoryRegistry()->getAllFactories();
+    QList<GObjectViewFactory*> ls;
 
-    foreach (GObjectViewFactory *f, fs) {
+    foreach (GObjectViewFactory* f, fs) {
         // check if new view can be created
         if (f->canCreateView(ms)) {
             ls.append(f);
@@ -78,33 +79,27 @@ static Task *createOpenViewTask(const MultiGSelection &ms) {
     }
 
     if (ls.size() > 1) {
-        GObjectViewFactory *f = AppContext::getObjectViewFactoryRegistry()->getFactoryById(GObjectViewFactory::SIMPLE_TEXT_FACTORY);
+        GObjectViewFactory* f = AppContext::getObjectViewFactoryRegistry()->getFactoryById(GObjectViewFactory::SIMPLE_TEXT_FACTORY);
         if (ls.contains(f)) {
             // ignore auxiliary text data
             ls.removeAll(f);
         }
     }
-
-    if (ls.size() == 1) {
-        GObjectViewFactory *f = ls.first();
-        Task *t = f->createViewTask(ms, true);
-        return t;
-    }
-    return nullptr;
+    return ls.size() == 1 ? ls[0]->createViewTask(ms, true) : nullptr;
 }
 
-Document *LoadUnloadedDocumentAndOpenViewTask::getDocument() {
+Document* LoadUnloadedDocumentAndOpenViewTask::getDocument() {
     return loadUnloadedTask->getDocument();
 }
 
-QList<Task *> LoadUnloadedDocumentAndOpenViewTask::onSubTaskFinished(Task *subTask) {
-    QList<Task *> res;
+QList<Task*> LoadUnloadedDocumentAndOpenViewTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> res;
     if (subTask != loadUnloadedTask || hasError() || isCanceled()) {
         return res;
     }
 
     // look if saved state can be loaded
-    Document *doc = loadUnloadedTask->getDocument();
+    Document* doc = loadUnloadedTask->getDocument();
     assert(doc->isLoaded());
 
     res.append(new OpenViewTask(doc));
@@ -114,17 +109,17 @@ QList<Task *> LoadUnloadedDocumentAndOpenViewTask::onSubTaskFinished(Task *subTa
 //////////////////////////////////////////////////////////////////////////
 // OpenViewTask
 
-OpenViewTask::OpenViewTask(Document *d)
+OpenViewTask::OpenViewTask(Document* d)
     : Task("Open view", TaskFlags_NR_FOSCOE | TaskFlag_MinimizeSubtaskErrorText), doc(d) {
     assert(doc != nullptr);
     assert(doc->isLoaded());
 }
 
 void OpenViewTask::prepare() {
-    QList<Task *> res;
+    QList<Task*> res;
 
     // if any of existing views has added an object from the document -> do not open new view
-    const QList<GObject *> &docObjects = doc->getObjects();
+    const QList<GObject*>& docObjects = doc->getObjects();
     if (!GObjectViewUtils::findViewsWithAnyOfObjects(docObjects).isEmpty()) {
         return;
     }
@@ -135,15 +130,15 @@ void OpenViewTask::prepare() {
     MultiGSelection ms;
     ms.addSelection(&os);
 
-    QList<GObjectViewState *> sl = GObjectViewUtils::selectStates(ms, AppContext::getProject()->getGObjectViewStates());
+    QList<GObjectViewState*> sl = GObjectViewUtils::selectStates(ms, AppContext::getProject()->getGObjectViewStates());
     if (sl.size() == 1) {
-        GObjectViewState *state = sl.first();
+        GObjectViewState* state = sl.first();
         SAFE_POINT_EXT(state, setError(tr("State is NULL")), );
-        GObjectViewFactory *f = AppContext::getObjectViewFactoryRegistry()->getFactoryById(state->getViewFactoryId());
+        GObjectViewFactory* f = AppContext::getObjectViewFactoryRegistry()->getFactoryById(state->getViewFactoryId());
         SAFE_POINT_EXT(f, setError(tr("GObject factory is NULL")), );
         res.append(f->createViewTask(state->getViewName(), state->getStateData()));
     } else {
-        Task *openViewTask = createOpenViewTask(ms);
+        Task* openViewTask = createOpenViewTask(ms);
         if (openViewTask != nullptr) {
             openViewTask->setSubtaskProgressWeight(0);
             res.append(openViewTask);
@@ -153,22 +148,22 @@ void OpenViewTask::prepare() {
     if (res.isEmpty()) {
         // no view can be opened -> check special case: loaded object contains annotations associated with sequence
         // -> load sequence and open view for it;
-        foreach (GObject *obj, doc->findGObjectByType(GObjectTypes::ANNOTATION_TABLE)) {
+        foreach (GObject* obj, doc->findGObjectByType(GObjectTypes::ANNOTATION_TABLE)) {
             QList<GObjectRelation> rels = obj->findRelatedObjectsByRole(ObjectRole_Sequence);
             if (rels.isEmpty()) {
                 continue;
             }
-            const GObjectRelation &rel = rels.first();
-            Document *seqDoc = AppContext::getProject()->findDocumentByURL(rel.ref.docUrl);
+            const GObjectRelation& rel = rels.first();
+            Document* seqDoc = AppContext::getProject()->findDocumentByURL(rel.ref.docUrl);
             if (seqDoc != nullptr) {
                 if (seqDoc->isLoaded()) {  // try open sequence view
-                    GObject *seqObj = seqDoc->findGObjectByName(rel.ref.objName);
+                    GObject* seqObj = seqDoc->findGObjectByName(rel.ref.objName);
                     if (seqObj != nullptr && seqObj->getGObjectType() == GObjectTypes::SEQUENCE) {
                         GObjectSelection os2;
                         os2.addToSelection(seqObj);
                         MultiGSelection ms2;
                         ms2.addSelection(&os2);
-                        Task *openViewTask = createOpenViewTask(ms2);
+                        Task* openViewTask = createOpenViewTask(ms2);
                         if (openViewTask != nullptr) {
                             openViewTask->setSubtaskProgressWeight(0);
                             res.append(openViewTask);
@@ -188,7 +183,7 @@ void OpenViewTask::prepare() {
             // 1. assemblies with their references
             // 2. multiple chromatogram alignment with a reference
             // -> load assemblies/mca and their references and open view for the first object;
-            QList<GObject *> objectsToOpen;
+            QList<GObject*> objectsToOpen;
 
             objectsToOpen << doc->findGObjectByType(GObjectTypes::ASSEMBLY);
             if (objectsToOpen.isEmpty()) {
@@ -201,7 +196,7 @@ void OpenViewTask::prepare() {
                 MultiGSelection ms2;
                 ms2.addSelection(&os2);
 
-                Task *openViewTask = createOpenViewTask(ms2);
+                Task* openViewTask = createOpenViewTask(ms2);
                 if (openViewTask != nullptr) {
                     openViewTask->setSubtaskProgressWeight(0);
                     res.append(openViewTask);
@@ -210,34 +205,34 @@ void OpenViewTask::prepare() {
         }
     }
 
-    foreach (Task *task, res) {
+    foreach (Task* task, res) {
         addSubTask(task);
     }
 }
 
 //////////////////////////////////////////////////////////////////////////
 
-LoadRemoteDocumentAndAddToProjectTask::LoadRemoteDocumentAndAddToProjectTask(const QString &accId, const QString &dbName)
-    : Task(tr("Load remote document and add to project"), TaskFlags_NR_FOSCOE | TaskFlag_MinimizeSubtaskErrorText),
-      mode(LoadRemoteDocumentMode_OpenView), loadRemoteDocTask(nullptr) {
-    accNumber = accId;
-    databaseName = dbName;
-}
-
-LoadRemoteDocumentAndAddToProjectTask::LoadRemoteDocumentAndAddToProjectTask(const GUrl &url)
-    : Task(tr("Load remote document and add to project"), TaskFlags_NR_FOSCOE | TaskFlag_MinimizeSubtaskErrorText),
-      mode(LoadRemoteDocumentMode_OpenView), loadRemoteDocTask(nullptr) {
+LoadRemoteDocumentAndAddToProjectTask::LoadRemoteDocumentAndAddToProjectTask(const GUrl& url)
+    : Task(tr("Load remote document and add to project"), TaskFlags_NR_FOSCOE |
+                                                          TaskFlag_MinimizeSubtaskErrorText |
+                                                          TaskFlag_ReportingIsSupported |
+                                                          TaskFlag_ReportingIsEnabled) {
     docUrl = url;
 }
 
-LoadRemoteDocumentAndAddToProjectTask::LoadRemoteDocumentAndAddToProjectTask(const QString &accId, const QString &dbName, const QString &fp, const QString &format, const QVariantMap &hints, LoadRemoteDocumentMode mode)
-    : Task(tr("Load remote document and add to project"), TaskFlags_NR_FOSCOE | TaskFlag_MinimizeSubtaskErrorText),
-      accNumber(accId), databaseName(dbName), fileFormat(format), fullpath(fp), hints(hints), mode(mode), loadRemoteDocTask(nullptr) {
-    if (mode == LoadRemoteDocumentMode_LoadOnly) {
-        setReportingSupported(true);
-        setReportingEnabled(true);
-        setTaskName(tr("Load remote document"));
-    }
+LoadRemoteDocumentAndAddToProjectTask::LoadRemoteDocumentAndAddToProjectTask(const QString& _accId, const QString& _dbName,
+                                                                             const QString& _fp, const QString& _format,
+                                                                             const QVariantMap& _hints, bool _openView)
+    : Task(tr("Load remote document and add to project"), TaskFlags_NR_FOSCOE |
+                                                          TaskFlag_MinimizeSubtaskErrorText |
+                                                          TaskFlag_ReportingIsSupported |
+                                                          TaskFlag_ReportingIsEnabled),
+      accNumber(_accId),
+      databaseName(_dbName),
+      fileFormat(_format),
+      fullpath(_fp),
+      hints(_hints),
+      openView(_openView) {
 }
 
 void LoadRemoteDocumentAndAddToProjectTask::prepare() {
@@ -246,11 +241,13 @@ void LoadRemoteDocumentAndAddToProjectTask::prepare() {
     } else {
         loadRemoteDocTask = new LoadRemoteDocumentTask(docUrl);
     }
+    loadRemoteDocTask->setReportingSupported(true);
+    loadRemoteDocTask->setReportingEnabled(true);
     addSubTask(loadRemoteDocTask);
 }
 
 namespace {
-Task *createLoadedDocTask(Document *loadedDoc, bool openView) {
+Task* createLoadedDocTask(Document* loadedDoc, bool openView) {
     if (loadedDoc->isLoaded() && openView) {
         return new OpenViewTask(loadedDoc);
     }
@@ -264,8 +261,8 @@ Task *createLoadedDocTask(Document *loadedDoc, bool openView) {
 }
 }  // namespace
 
-QList<Task *> LoadRemoteDocumentAndAddToProjectTask::onSubTaskFinished(Task *subTask) {
-    QList<Task *> subTasks;
+QList<Task*> LoadRemoteDocumentAndAddToProjectTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> subTasks;
     if (subTask->hasError()) {
         return subTasks;
     }
@@ -275,17 +272,14 @@ QList<Task *> LoadRemoteDocumentAndAddToProjectTask::onSubTaskFinished(Task *sub
     }
 
     if (subTask == loadRemoteDocTask) {
-        if (mode == LoadRemoteDocumentMode_LoadOnly) {
-            return subTasks;
-        }
         // hack for handling errors with http requests with bad resource id
-        Document *d = loadRemoteDocTask->getDocument();
+        Document* d = loadRemoteDocTask->getDocument();
         if (d->getDocumentFormatId() == BaseDocumentFormats::PLAIN_TEXT) {
             setError(tr("Cannot find %1 in %2 database").arg(accNumber).arg(databaseName));
             // try to delete file with response that was created
             QFile::remove(d->getURLString());
             // and remove it from downloaded cache
-            RecentlyDownloadedCache *cache = AppContext::getRecentlyDownloadedCache();
+            RecentlyDownloadedCache* cache = AppContext::getRecentlyDownloadedCache();
             if (cache != nullptr) {
                 cache->remove(d->getURLString());
             }
@@ -293,22 +287,22 @@ QList<Task *> LoadRemoteDocumentAndAddToProjectTask::onSubTaskFinished(Task *sub
         }
 
         QString fullPath = loadRemoteDocTask->getLocalUrl();
-        Project *proj = AppContext::getProject();
+        Project* proj = AppContext::getProject();
         if (proj == nullptr) {
             QVariantMap hints;
-            hints[ProjectLoaderHint_LoadWithoutView] = mode != LoadRemoteDocumentMode_OpenView;
-            Task *openWithProjectTask = AppContext::getProjectLoader()->openWithProjectTask(fullPath, hints);
+            hints[ProjectLoaderHint_LoadWithoutView] = !openView;
+            Task* openWithProjectTask = AppContext::getProjectLoader()->openWithProjectTask(fullPath, hints);
             if (openWithProjectTask != nullptr) {
                 subTasks.append(openWithProjectTask);
             }
         } else {
-            Document *doc = loadRemoteDocTask->getDocument();
+            Document* doc = loadRemoteDocTask->getDocument();
             SAFE_POINT(doc != nullptr, "loadRemoteDocTask->takeDocument() returns NULL!", subTasks);
             QString url = doc->getURLString();
-            Document *loadedDoc = proj->findDocumentByURL(url);
+            Document* loadedDoc = proj->findDocumentByURL(url);
             if (loadedDoc != nullptr) {
-                Task *task = createLoadedDocTask(loadedDoc, mode == LoadRemoteDocumentMode_OpenView);
-                if (nullptr != task) {
+                Task* task = createLoadedDocTask(loadedDoc, openView);
+                if (task != nullptr) {
                     subTasks.append(task);
                 }
             } else {
@@ -316,7 +310,7 @@ QList<Task *> LoadRemoteDocumentAndAddToProjectTask::onSubTaskFinished(Task *sub
                 doc = loadRemoteDocTask->takeDocument();
                 SAFE_POINT(doc != nullptr, "loadRemoteDocTask->takeDocument() returns NULL!", subTasks);
                 subTasks.append(new AddDocumentTask(doc));
-                if (mode == LoadRemoteDocumentMode_OpenView) {
+                if (openView) {
                     subTasks.append(new LoadUnloadedDocumentAndOpenViewTask(doc));
                 } else {
                     subTasks.append(new LoadUnloadedDocumentTask(doc));
@@ -329,22 +323,12 @@ QList<Task *> LoadRemoteDocumentAndAddToProjectTask::onSubTaskFinished(Task *sub
 }
 
 QString LoadRemoteDocumentAndAddToProjectTask::generateReport() const {
-    // Note: reporting is enabled only for db + accession mode.
-    if (hasError()) {
-        return tr("Failed to download %1 from %2. Error: %3").arg(accNumber).arg(databaseName).arg(getError());
-    }
-    if (isCanceled()) {
-        return QString();
-    }
-    QString url = loadRemoteDocTask->getLocalUrl();
-    return tr("Document was successfully downloaded: [%1, %2] -> <a href='%3'>%4</a>")
-        .arg(databaseName)
-        .arg(accNumber)
-        .arg(url)
-        .arg(url);
+    SAFE_POINT_NN(loadRemoteDocTask, {});
+
+    return loadRemoteDocTask->generateReport();
 }
 
-AddDocumentAndOpenViewTask::AddDocumentAndOpenViewTask(Document *doc, const AddDocumentTaskConfig &conf)
+AddDocumentAndOpenViewTask::AddDocumentAndOpenViewTask(Document* doc, const AddDocumentTaskConfig& conf)
     : Task(tr("Opening view for document: 'NONAME'"), TaskFlags_NR_FOSE_COSC | TaskFlag_CollectChildrenWarnings) {
     if (doc != nullptr) {
         GUrl url = doc->getURL();
@@ -357,7 +341,7 @@ AddDocumentAndOpenViewTask::AddDocumentAndOpenViewTask(Document *doc, const AddD
     addSubTask(new AddDocumentTask(doc, conf));
 }
 
-AddDocumentAndOpenViewTask::AddDocumentAndOpenViewTask(DocumentProviderTask *dp, const AddDocumentTaskConfig &conf)
+AddDocumentAndOpenViewTask::AddDocumentAndOpenViewTask(DocumentProviderTask* dp, const AddDocumentTaskConfig& conf)
     : Task(tr("Opening view for document: 'NONAME'"), TaskFlags_NR_FOSE_COSC | TaskFlag_CollectChildrenWarnings) {
     if (dp != nullptr) {
         setTaskName(tr("Opening view for document: %1").arg(dp->getDocumentDescription()));
@@ -369,11 +353,11 @@ AddDocumentAndOpenViewTask::AddDocumentAndOpenViewTask(DocumentProviderTask *dp,
     addSubTask(new AddDocumentTask(dp, conf));
 }
 
-QList<Task *> AddDocumentAndOpenViewTask::onSubTaskFinished(Task *t) {
-    QList<Task *> res;
-    AddDocumentTask *addTask = qobject_cast<AddDocumentTask *>(t);
+QList<Task*> AddDocumentAndOpenViewTask::onSubTaskFinished(Task* t) {
+    QList<Task*> res;
+    auto addTask = qobject_cast<AddDocumentTask*>(t);
     if (addTask != nullptr && !addTask->getStateInfo().isCoR()) {
-        Document *doc = addTask->getDocument();
+        Document* doc = addTask->getDocument();
         assert(doc != nullptr);
         res << new LoadUnloadedDocumentAndOpenViewTask(doc);
     }
