@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OPEN_DOCUMENT_TASK_H_
-#define _U2_OPEN_DOCUMENT_TASK_H_
+#pragma once
 
 #include <U2Core/AddDocumentTask.h>
 #include <U2Core/GUrl.h>
@@ -36,41 +35,35 @@ class DocumentProviderTask;
 class U2GUI_EXPORT LoadUnloadedDocumentAndOpenViewTask : public Task {
     Q_OBJECT
 public:
-    LoadUnloadedDocumentAndOpenViewTask(Document *d);
+    LoadUnloadedDocumentAndOpenViewTask(Document* d);
 
-    Document *getDocument();
+    Document* getDocument();
 
 protected:
-    virtual QList<Task *> onSubTaskFinished(Task *subTask);
+    virtual QList<Task*> onSubTaskFinished(Task* subTask);
 
 private:
     void clearResourceUse();
 
-    LoadUnloadedDocumentTask *loadUnloadedTask;
-};
-
-enum LoadRemoteDocumentMode {
-    LoadRemoteDocumentMode_LoadOnly = 1,
-    LoadRemoteDocumentMode_AddToProject = 2,
-    LoadRemoteDocumentMode_OpenView = 3
+    LoadUnloadedDocumentTask* loadUnloadedTask;
 };
 
 class U2GUI_EXPORT LoadRemoteDocumentAndAddToProjectTask : public Task {
     Q_OBJECT
 public:
-    LoadRemoteDocumentAndAddToProjectTask(const QString &accId, const QString &dbName);
-    LoadRemoteDocumentAndAddToProjectTask(const QString &accId,
-                                          const QString &dbName,
-                                          const QString &fullpath,
-                                          const QString &format = QString(),
-                                          const QVariantMap &hints = QVariantMap(),
-                                          LoadRemoteDocumentMode mode = LoadRemoteDocumentMode_OpenView);
-    LoadRemoteDocumentAndAddToProjectTask(const GUrl &url);
-    virtual void prepare();
-    virtual QString generateReport() const;
+    LoadRemoteDocumentAndAddToProjectTask(const QString& accId,
+                                          const QString& dbName,
+                                          const QString& fullpath,
+                                          const QString& format = QString(),
+                                          const QVariantMap& hints = QVariantMap(),
+                                          bool openView = true);
+    LoadRemoteDocumentAndAddToProjectTask(const GUrl& url);
+
+    void prepare() override;
+    QString generateReport() const override;
 
 protected:
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
 
 private:
     QString accNumber;
@@ -79,14 +72,14 @@ private:
     QString fullpath;
     GUrl docUrl;
     QVariantMap hints;
-    LoadRemoteDocumentMode mode;
-    LoadRemoteDocumentTask *loadRemoteDocTask;
+    bool openView = true;
+    LoadRemoteDocumentTask* loadRemoteDocTask = nullptr;
 };
 
 class U2GUI_EXPORT OpenViewTask : public Task {
     Q_OBJECT
 public:
-    OpenViewTask(Document *d);
+    OpenViewTask(Document* d);
 
     static const int MAX_DOC_NUMBER_TO_OPEN_VIEWS;
 
@@ -94,19 +87,17 @@ protected:
     void prepare();
 
 private:
-    Document *doc;
+    Document* doc;
 };
 
 class U2GUI_EXPORT AddDocumentAndOpenViewTask : public Task {
     Q_OBJECT
 public:
-    AddDocumentAndOpenViewTask(Document *d, const AddDocumentTaskConfig &conf = AddDocumentTaskConfig());
-    AddDocumentAndOpenViewTask(DocumentProviderTask *d, const AddDocumentTaskConfig &conf = AddDocumentTaskConfig());
+    AddDocumentAndOpenViewTask(Document* d, const AddDocumentTaskConfig& conf = AddDocumentTaskConfig());
+    AddDocumentAndOpenViewTask(DocumentProviderTask* d, const AddDocumentTaskConfig& conf = AddDocumentTaskConfig());
 
 protected:
-    QList<Task *> onSubTaskFinished(Task *t);
+    QList<Task*> onSubTaskFinished(Task* t);
 };
 
 }  // namespace U2
-
-#endif
