@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PLUGIN_VIEWER_H_
-#define _U2_PLUGIN_VIEWER_H_
+#pragma once
 
 #include <U2Core/PluginModel.h>
 #include <U2Core/ServiceTypes.h>
@@ -33,11 +32,9 @@ namespace U2 {
 class U2GUI_EXPORT PluginViewer : public Service {
     Q_OBJECT
 public:
-    PluginViewer(const QString &name, const QString &desc)
+    PluginViewer(const QString& name, const QString& desc)
         : Service(Service_PluginViewer, name, desc) {
     }
 };
 
 }  // namespace U2
-
-#endif
