@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PROJECT_UTILS__H_
-#define _U2_PROJECT_UTILS__H_
+#pragma once
 
 #include <U2Core/GAutoDeleteList.h>
 #include <U2Core/ProjectModel.h>
@@ -36,7 +35,7 @@ namespace U2 {
 class U2GUI_EXPORT ProjectParser : public QObject {
     Q_OBJECT
 public:
-    virtual Project *createProjectFromXMLModel(const QString &url, const QDomDocument &xmlDoc, U2OpStatus &si) = 0;
+    virtual Project* createProjectFromXMLModel(const QString& url, const QDomDocument& xmlDoc, U2OpStatus& si) = 0;
     virtual QString getVersion() {
         assert(false);
         return QString();
@@ -45,11 +44,11 @@ public:
 
 class U2GUI_EXPORT ProjectParserRegistry {
 public:
-    ProjectParser *getProjectParserByVersion(const QString &id);
-    static ProjectParserRegistry *instance();
+    ProjectParser* getProjectParserByVersion(const QString& id);
+    static ProjectParserRegistry* instance();
 
 private:
-    ProjectParserRegistry(ProjectParserRegistry &ppr) {
+    ProjectParserRegistry(ProjectParserRegistry& ppr) {
         Q_UNUSED(ppr);
         assert(0);
     };
@@ -64,7 +63,7 @@ class ProjectParser10 : public ProjectParser {
     Q_OBJECT
 public:
     ProjectParser10() {};
-    Project *createProjectFromXMLModel(const QString &url, const QDomDocument &xmlDoc, U2OpStatus &si);
+    Project* createProjectFromXMLModel(const QString& url, const QDomDocument& xmlDoc, U2OpStatus& si);
     QString getVersion() {
         return QString("1.0");
     };
@@ -74,11 +73,9 @@ class U2GUI_EXPORT ProjectFileUtils : public QObject {
     Q_OBJECT
 
 public:
-    static void saveProjectFile(U2OpStatus &ts, Project *p, const QString &projectUrl, const StrMap &docUrlRemap = StrMap());
+    static void saveProjectFile(U2OpStatus& ts, Project* p, const QString& projectUrl, const StrMap& docUrlRemap = StrMap());
 
-    static void loadXMLProjectModel(const QString &url, U2OpStatus &si, QDomDocument &doc, QString &version);
+    static void loadXMLProjectModel(const QString& url, U2OpStatus& si, QDomDocument& doc, QString& version);
 };
 
 }  // namespace U2
-
-#endif
