@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -36,15 +36,15 @@ namespace U2 {
 //// WidgetParamSnapshot
 //////////////////////////////////////////////////////////////////////////
 
-WidgetParamSnapshot::WidgetParamSnapshot(const QString &widgetId)
+WidgetParamSnapshot::WidgetParamSnapshot(const QString& widgetId)
     : widgetId(widgetId) {
 }
 
-const QString &WidgetParamSnapshot::getWidgetId() const {
+const QString& WidgetParamSnapshot::getWidgetId() const {
     return widgetId;
 }
 
-void WidgetParamSnapshot::setParameter(const QString &name, const QVariant &value) {
+void WidgetParamSnapshot::setParameter(const QString& name, const QVariant& value) {
     params[name] = value;
 }
 
@@ -60,48 +60,48 @@ bool WidgetParamSnapshot::isValid() const {
 //// U2WidgetStateStorage
 //////////////////////////////////////////////////////////////////////////
 
-QMultiMap<MWMDIWindow *, WidgetParamSnapshot> U2WidgetStateStorage::window2widgetSnapshots;
+QMultiMap<MWMDIWindow*, WidgetParamSnapshot> U2WidgetStateStorage::window2widgetSnapshots;
 
-void U2WidgetStateStorage::saveWidgetState(const U2SavableWidget &widget) {
-    MWMDIWindow *contextWindow = widget.getContextWindow();
+void U2WidgetStateStorage::saveWidgetState(const U2SavableWidget& widget) {
+    MWMDIWindow* contextWindow = widget.getContextWindow();
     CHECK(windowExists(contextWindow), );
 
     const QString widgetId = widget.getWidgetId();
     WidgetParamSnapshot snapshot(widgetId);
-    foreach (const QString &childId, widget.getChildIds()) {
+    foreach (const QString& childId, widget.getChildIds()) {
         snapshot.setParameter(childId, widget.getChildValue(childId));
     }
     window2widgetSnapshots.insert(contextWindow, snapshot);
 }
 
-void U2WidgetStateStorage::restoreWidgetState(U2SavableWidget &widget) {
+void U2WidgetStateStorage::restoreWidgetState(U2SavableWidget& widget) {
     const WidgetParamSnapshot snapshot = findWidgetParams(widget);
     CHECK(snapshot.isValid(), );
 
     const QVariantMap params = snapshot.getParameters();
-    foreach (const QString &paramName, params.keys()) {
+    foreach (const QString& paramName, params.keys()) {
         if (widget.childValueIsAcceptable(paramName, params[paramName])) {
             widget.setChildValue(paramName, params[paramName]);
         }
     }
 }
 
-void U2WidgetStateStorage::onWindowClose(MWMDIWindow *closedWindow) {
+void U2WidgetStateStorage::onWindowClose(MWMDIWindow* closedWindow) {
     window2widgetSnapshots.remove(closedWindow);
 }
 
-bool U2WidgetStateStorage::windowExists(MWMDIWindow *window) {
-    CHECK(nullptr != window, true);
+bool U2WidgetStateStorage::windowExists(MWMDIWindow* window) {
+    CHECK(window != nullptr, true);
 
-    MWMDIManager *mdiManager = AppContext::getMainWindow()->getMDIManager();
-    SAFE_POINT(nullptr != mdiManager, "Invalid MDI manager", false);
+    MWMDIManager* mdiManager = AppContext::getMainWindow()->getMDIManager();
+    SAFE_POINT(mdiManager != nullptr, "Invalid MDI manager", false);
     return mdiManager->getWindows().contains(window);
 }
 
-WidgetParamSnapshot U2WidgetStateStorage::findWidgetParams(const U2SavableWidget &widget) {
-    MWMDIWindow *contextWindow = widget.getContextWindow();
+WidgetParamSnapshot U2WidgetStateStorage::findWidgetParams(const U2SavableWidget& widget) {
+    MWMDIWindow* contextWindow = widget.getContextWindow();
     CHECK(window2widgetSnapshots.contains(contextWindow), WidgetParamSnapshot());
-    foreach (const WidgetParamSnapshot &snapshot, window2widgetSnapshots.values(contextWindow)) {
+    foreach (const WidgetParamSnapshot& snapshot, window2widgetSnapshots.values(contextWindow)) {
         if (snapshot.getWidgetId() == widget.getWidgetId()) {
             return snapshot;
         }
