@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WIDGET_STATE_STORAGE_H_
-#define _U2_WIDGET_STATE_STORAGE_H_
+#pragma once
 
 #include <QMultiMap>
 #include <QVariantMap>
@@ -34,10 +33,10 @@ class U2SavableWidget;
 
 class WidgetParamSnapshot {
 public:
-    explicit WidgetParamSnapshot(const QString &widgetId = QString());
+    explicit WidgetParamSnapshot(const QString& widgetId = QString());
 
-    const QString &getWidgetId() const;
-    void setParameter(const QString &name, const QVariant &value);
+    const QString& getWidgetId() const;
+    void setParameter(const QString& name, const QVariant& value);
     QVariantMap getParameters() const;
     bool isValid() const;
 
@@ -48,17 +47,15 @@ private:
 
 class U2GUI_EXPORT U2WidgetStateStorage {
 public:
-    static void saveWidgetState(const U2SavableWidget &widget);
-    static void restoreWidgetState(U2SavableWidget &widget);
-    static void onWindowClose(MWMDIWindow *closedWindow);
+    static void saveWidgetState(const U2SavableWidget& widget);
+    static void restoreWidgetState(U2SavableWidget& widget);
+    static void onWindowClose(MWMDIWindow* closedWindow);
 
 private:
-    static WidgetParamSnapshot findWidgetParams(const U2SavableWidget &widget);
-    static bool windowExists(MWMDIWindow *window);
+    static WidgetParamSnapshot findWidgetParams(const U2SavableWidget& widget);
+    static bool windowExists(MWMDIWindow* window);
 
-    static QMultiMap<MWMDIWindow *, WidgetParamSnapshot> window2widgetSnapshots;
+    static QMultiMap<MWMDIWindow*, WidgetParamSnapshot> window2widgetSnapshots;
 };
 
 }  // namespace U2
-
-#endif  // _U2_WIDGET_STATE_STORAGE_H_
