@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_UNLOAD_DOCUMENT_TASK_H_
-#define _U2_UNLOAD_DOCUMENT_TASK_H_
+#pragma once
 
 #include <QPointer>
 
@@ -42,39 +41,37 @@ enum UnloadDocumentTask_SaveMode {
 class U2GUI_EXPORT UnloadDocumentTask : public Task {
     Q_OBJECT
 public:
-    UnloadDocumentTask(Document *doc, bool save);
+    UnloadDocumentTask(Document* doc, bool save);
     ReportResult report();
 
-    static QList<Task *> runUnloadTaskHelper(const QList<Document *> &docs, UnloadDocumentTask_SaveMode sm);
-    static QString checkSafeUnload(Document *d);
+    static QList<Task*> runUnloadTaskHelper(const QList<Document*>& docs, UnloadDocumentTask_SaveMode sm);
+    static QString checkSafeUnload(Document* d);
 
 private:
     QPointer<Document> doc;
-    SaveDocumentTask *saveTask;
-    StateLock *lock;
+    SaveDocumentTask* saveTask;
+    StateLock* lock;
     static const QString ACTIVE_VIEW_ERROR;
 };
 
 class U2GUI_EXPORT ReloadDocumentTask : public Task {
     Q_OBJECT
 public:
-    ReloadDocumentTask(Document *d);
+    ReloadDocumentTask(Document* d);
     virtual void prepare();
-    virtual QList<Task *> onSubTaskFinished(Task *subTask);
+    virtual QList<Task*> onSubTaskFinished(Task* subTask);
 
 private:
     void saveObjectRelationsFromDoc();
     void restoreObjectRelationsForDoc();
-    static void restoreObjectRelationsForObject(GObject *obj,
-                                                const QList<GObjectRelation> &relations);
+    static void restoreObjectRelationsForObject(GObject* obj,
+                                                const QList<GObjectRelation>& relations);
 
-    Document *doc;
+    Document* doc;
     GUrl url;
-    Task *removeDocTask;
-    Task *openDocTask;
+    Task* removeDocTask;
+    Task* openDocTask;
     QMultiMap<QString, GObjectRelation> savedObjectRelations;
 };
 
 }  // namespace U2
-
-#endif
