@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WELCOME_PAGE_ACTION_H_
-#define _U2_WELCOME_PAGE_ACTION_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -28,12 +27,12 @@ namespace U2 {
 
 class U2GUI_EXPORT WelcomePageAction {
 public:
-    WelcomePageAction(const QString &id);
+    WelcomePageAction(const QString& id);
 
     virtual ~WelcomePageAction();
     virtual void perform() = 0;
 
-    const QString &getId() const;
+    const QString& getId() const;
 
 private:
     QString id;
@@ -48,5 +47,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // _U2_WELCOME_PAGE_ACTION_H_
