@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@ const QString GroupHeaderImageWidget::HEADER_COMMON_STYLE = "border-style: solid
                                                             "margin-top: 4px;"
                                                             "margin-right: 3px;";
 
-GroupHeaderImageWidget::GroupHeaderImageWidget(const QString &_groupId, const QPixmap &image)
+GroupHeaderImageWidget::GroupHeaderImageWidget(const QString& _groupId, const QPixmap& image)
     : groupId(_groupId) {
     this->setPixmap(image);
 
@@ -50,8 +50,8 @@ GroupHeaderImageWidget::GroupHeaderImageWidget(const QString &_groupId, const QP
     this->setObjectName(groupId);
 }
 
-void GroupHeaderImageWidget::mousePressEvent(QMouseEvent * /*event*/) {
-    SAFE_POINT(nullptr != groupId, "Internal error: group header with NULL group ID was pressed.", );
+void GroupHeaderImageWidget::mousePressEvent(QMouseEvent* /*event*/) {
+    SAFE_POINT(groupId != nullptr, "Internal error: group header with NULL group ID was pressed.", );
 
     emit si_groupHeaderPressed(groupId);
 }
