@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GROUP_HEADER_IMAGE_WIDGET_H_
-#define _U2_GROUP_HEADER_IMAGE_WIDGET_H_
+#pragma once
 
 #include <QLabel>
 
@@ -34,9 +33,9 @@ namespace U2 {
 class U2GUI_EXPORT GroupHeaderImageWidget : public QLabel {
     Q_OBJECT
 public:
-    GroupHeaderImageWidget(const QString &groupId, const QPixmap &image);
+    GroupHeaderImageWidget(const QString& groupId, const QPixmap& image);
 
-    inline const QString &getGroupId() {
+    inline const QString& getGroupId() {
         return groupId;
     }
 
@@ -52,7 +51,7 @@ signals:
     void si_groupHeaderPressed(QString groupId);
 
 protected:
-    virtual void mousePressEvent(QMouseEvent *);
+    virtual void mousePressEvent(QMouseEvent*);
 
 private:
     QString groupId;
@@ -61,5 +60,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
