@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GROUP_OPTIONS_WIDGET_H_
-#define _U2_GROUP_OPTIONS_WIDGET_H_
+#pragma once
 
 #include <QWidget>
 
@@ -37,9 +36,9 @@ namespace U2 {
 class U2GUI_EXPORT GroupOptionsWidget : public QWidget {
     Q_OBJECT
 public:
-    GroupOptionsWidget(const QString &groupId, const QString &title, const QString &documentationPage, QWidget *widget, QWidget *mainWidget);
+    GroupOptionsWidget(const QString& groupId, const QString& title, const QString& documentationPage, QWidget* widget, QWidget* mainWidget);
 
-    const QString &getGroupId() const {
+    const QString& getGroupId() const {
         return groupId;
     }
 
@@ -51,22 +50,22 @@ public:
         return MAX_WIDGET_WIDTH;
     }
 
-    const QString &getTitle() const {
+    const QString& getTitle() const {
         return title;
     }
 
-    QWidget *getMainWidget() const {
+    QWidget* getMainWidget() const {
         return mainWidget;
     }
 
 private:
     QString groupId;
-    QWidget *widget;
-    QWidget *mainWidget;
-    QLabel *titleWidget;
+    QWidget* widget;
+    QWidget* mainWidget;
+    QLabel* titleWidget;
     QString title;
 
-    QVBoxLayout *mainLayout;
+    QVBoxLayout* mainLayout;
 
     static const int TITLE_HEIGHT = 30;
     static const int MIN_WIDGET_WIDTH = 300;
@@ -74,5 +73,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
