@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OP_WIDGET_FACTORY_REGISTRY_H_
-#define _U2_OP_WIDGET_FACTORY_REGISTRY_H_
+#pragma once
 
 #include <QMutex>
 
@@ -34,15 +33,15 @@ class U2GUI_EXPORT OPWidgetFactoryRegistry : public QObject {
     Q_OBJECT
 
 public:
-    OPWidgetFactoryRegistry(QObject *parent = nullptr);
+    OPWidgetFactoryRegistry(QObject* parent = nullptr);
     ~OPWidgetFactoryRegistry();
 
-    bool registerFactory(OPWidgetFactory *factory);
+    bool registerFactory(OPWidgetFactory* factory);
 
-    QList<OPWidgetFactory *> getRegisteredFactories(const QList<OPFactoryFilterVisitorInterface *> &filters);
+    QList<OPWidgetFactory*> getRegisteredFactories(const QList<OPFactoryFilterVisitorInterface*>& filters);
 
 private:
-    QList<OPWidgetFactory *> opWidgetFactories;
+    QList<OPWidgetFactory*> opWidgetFactories;
     QMutex mutex;
 };
 
@@ -50,18 +49,16 @@ class U2GUI_EXPORT OPCommonWidgetFactoryRegistry : public QObject {
     Q_OBJECT
 
 public:
-    OPCommonWidgetFactoryRegistry(QObject *parent = nullptr);
+    OPCommonWidgetFactoryRegistry(QObject* parent = nullptr);
     ~OPCommonWidgetFactoryRegistry();
 
-    bool registerFactory(OPCommonWidgetFactory *factory);
+    bool registerFactory(OPCommonWidgetFactory* factory);
 
-    QList<OPCommonWidgetFactory *> getRegisteredFactories(QString groupId);
+    QList<OPCommonWidgetFactory*> getRegisteredFactories(QString groupId);
 
 private:
-    QList<OPCommonWidgetFactory *> factories;
+    QList<OPCommonWidgetFactory*> factories;
     QMutex mutex;
 };
 
 }  // namespace U2
-
-#endif
