@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OPTIONS_PANEL_H_
-#define _U2_OPTIONS_PANEL_H_
+#pragma once
 
 #include <QObject>
 
@@ -28,7 +27,7 @@
 
 namespace U2 {
 
-class GObjectView;
+class GObjectViewController;
 class OptionsPanelWidget;
 class OPWidgetFactory;
 
@@ -37,60 +36,58 @@ class OPWidgetFactory;
  * low-level implementation of the panel (including widgets, their styles, etc.)
  * To use this class add the Options Panel's main widget to a layout and add the required groups.
  */
-class U2GUI_EXPORT OptionsPanel : public QObject {
+class U2GUI_EXPORT OptionsPanelController : public QObject {
     Q_OBJECT
 public:
     /** Creates a new OptionsPanelWidget */
-    OptionsPanel(GObjectView *);
+    OptionsPanelController(GObjectViewController*);
+
+    /** Add a new options panel group instance and corresponding widgets. */
+    void addGroup(OPWidgetFactory* factory);
+
+    /** Creates main (a panel with buttons) widget of the options panel.  */
+    OptionsPanelWidget* createWidget(QWidget* parent);
 
     /**
-     * Normally, the OptionsPanelWidget is added to another widget and should be deleted
-     * when this widget is deleted, but if this hasn't happened by some reason, then
-     * the destructor deletes the object.
+     * Returns inner (content) widget of the options panel.
+     * The widget is always defined (after createWidget call) but may be hidden if the options panel is collapsed.
      */
-    ~OptionsPanel();
-
-    /** Add a new options panel group instance and corresponding widgets*/
-    void addGroup(OPWidgetFactory *factory);
-
-    /** Returns the main Options Panel widget */
-    OptionsPanelWidget *getMainWidget();
+    QWidget* getContentWidget() const;
 
     /** Opens a group with the specified group id. */
-    void openGroupById(const QString &groupId, const QVariantMap &options = QVariantMap());
+    void openGroupById(const QString& groupId, const QVariantMap& options = QVariantMap());
 
     /** Returns id for currently opened tab. **/
-    QString getActiveGroupId() {
-        return activeGroupId;
-    }
+    const QString& getActiveGroupId() const;
 
 public slots:
     /** Catches signals that a group header has been pressed
         and implements the behavior of groups selection (only one group at a time can be opened) */
-    void sl_groupHeaderPressed(QString groupId);
+    void sl_groupHeaderPressed(const QString& groupId);
 
 private:
-    GObjectView *objView;
+    /** Instantiates group widgets. Used during createWidget() call. */
+    void instantiateGroups();
+
+    GObjectViewController* objView;
 
     /** Shows the options widget */
-    void openOptionsGroup(const QString &groupId, const QVariantMap &options = QVariantMap());
+    void openOptionsGroup(const QString& groupId, const QVariantMap& options = QVariantMap());
 
     /** Hides the options widget  */
-    void closeOptionsGroup(const QString &groupId);
+    void closeOptionsGroup(const QString& groupId);
 
     /** Returns the Options Panel widget factory by the specified groupId, or NULL. */
-    OPWidgetFactory *findFactoryByGroupId(const QString &groupId);
+    OPWidgetFactory* findFactoryByGroupId(const QString& groupId);
 
     /** All added groups */
-    QList<OPWidgetFactory *> opWidgetFactories;
+    QList<OPWidgetFactory*> opWidgetFactories;
 
     /** The widget that displays options groups */
-    OptionsPanelWidget *widget;
+    OptionsPanelWidget* widget = nullptr;
 
     /** IDs of the opened group */
     QString activeGroupId;
 };
 
 }  // namespace U2
-
-#endif
