@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OPTIONS_PANEL_GROUP_H_
-#define _U2_OPTIONS_PANEL_GROUP_H_
+#pragma once
 
 namespace U2 {
 
@@ -32,20 +31,18 @@ class GroupOptionsWidget;
  */
 class OptionsPanelGroup {
 public:
-    OptionsPanelGroup(GroupHeaderImageWidget *, GroupOptionsWidget *);
+    OptionsPanelGroup(GroupHeaderImageWidget*, GroupOptionsWidget*);
 
-    inline GroupHeaderImageWidget *getHeaderImageWidget() const {
+    inline GroupHeaderImageWidget* getHeaderImageWidget() const {
         return headerImageWidget;
     }
-    inline GroupOptionsWidget *getOptionsWidget() const {
+    inline GroupOptionsWidget* getOptionsWidget() const {
         return optionsWidget;
     }
 
 private:
-    GroupHeaderImageWidget *headerImageWidget;
-    GroupOptionsWidget *optionsWidget;
+    GroupHeaderImageWidget* headerImageWidget;
+    GroupOptionsWidget* optionsWidget;
 };
 
 }  // namespace U2
-
-#endif
