@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADD_NEW_DOCUMENT_DIALOG_CTRL_H_
-#define _U2_ADD_NEW_DOCUMENT_DIALOG_CTRL_H_
+#pragma once
 
 #include <U2Core/DocumentModel.h>
 #include <U2Core/global.h>
@@ -29,7 +28,7 @@ namespace U2 {
 
 class U2GUI_EXPORT AddNewDocumentDialogModel {
 public:
-    AddNewDocumentDialogModel(const QString &_url = QString(), const DocumentFormatId &_format = DocumentFormatId())
+    AddNewDocumentDialogModel(const QString& _url = QString(), const DocumentFormatId& _format = DocumentFormatId())
         : url(_url), format(_format), successful(false) {
     }
 
@@ -41,9 +40,7 @@ public:
 
 class U2GUI_EXPORT AddNewDocumentDialogController {
 public:
-    static void run(QWidget *p, AddNewDocumentDialogModel &m, const DocumentFormatConstraints &c);
+    static void run(QWidget* p, AddNewDocumentDialogModel& m, const DocumentFormatConstraints& c);
 };
 
 }  // namespace U2
-
-#endif
