@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADD_NEW_DOCUMENT_DIALOG_IMPL_H_
-#define _U2_ADD_NEW_DOCUMENT_DIALOG_IMPL_H_
+#pragma once
 
 #include "AddNewDocumentDialogController.h"
 #include "ui_AddNewDocumentDialog.h"
@@ -32,18 +31,16 @@ class SaveDocumentController;
 
 class AddNewDocumentDialogImpl : public QDialog, public Ui_AddNewDocumentDialog {
     Q_OBJECT
-    AddNewDocumentDialogImpl(QWidget *p, AddNewDocumentDialogModel &m, const DocumentFormatConstraints &c);
+    AddNewDocumentDialogImpl(QWidget* p, AddNewDocumentDialogModel& m, const DocumentFormatConstraints& c);
     friend class AddNewDocumentDialogController;
 
 public slots:
     void accept();
 
 private:
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
     AddNewDocumentDialogModel model;
-    DocumentFormatComboboxController *formatController;
+    DocumentFormatComboboxController* formatController;
 };
 
 }  // namespace U2
-
-#endif
