@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_AUTHENTICATION_WIDGET_H_
-#define _U2_AUTHENTICATION_WIDGET_H_
+#pragma once
 
 #include <QWidget>
 
@@ -33,10 +32,10 @@ namespace U2 {
 class U2GUI_EXPORT AuthenticationWidget : public QWidget, public Ui_AuthenticationWidget {
     Q_OBJECT
 public:
-    AuthenticationWidget(QWidget *parent = nullptr);
+    AuthenticationWidget(QWidget* parent = nullptr);
 
-    void setLogin(const QString &login);
-    void setPassword(const QString &password);
+    void setLogin(const QString& login);
+    void setPassword(const QString& password);
     void setRemembered(bool isChecked);
 
     QString getLogin() const;
@@ -45,5 +44,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // _U2_AUTHENTICATION_WIDGET_H_
