@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -39,14 +39,14 @@
 
 namespace U2 {
 
-CreateAnnotationDialog::CreateAnnotationDialog(QWidget *p, CreateAnnotationModel &m)
+CreateAnnotationDialog::CreateAnnotationDialog(QWidget* p, CreateAnnotationModel& m, const QString& helpButtonCode)
     : QDialog(p),
       model(m),
       ui(new Ui_CreateAnnotationDialog) {
     ui->setupUi(this);
     annWidgetController = new CreateAnnotationWidgetController(m, this, CreateAnnotationWidgetController::Full);
 
-    helpButton = new HelpButton(this, ui->buttonBox, "65929465");
+    helpButton = new HelpButton(this, ui->buttonBox, helpButtonCode.isEmpty() ? QString("65929465") : helpButtonCode);
     ui->buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Create"));
 
     ui->mainLayout->insertWidget(0, annWidgetController->getWidget());
@@ -58,7 +58,7 @@ CreateAnnotationDialog::~CreateAnnotationDialog() {
     delete ui;
 }
 
-void CreateAnnotationDialog::updateAppearance(const QString &newTitle, const QString &newHelpPage, const QString &newOkButtonName) {
+void CreateAnnotationDialog::updateAppearance(const QString& newTitle, const QString& newHelpPage, const QString& newOkButtonName) {
     setWindowTitle(newTitle);
     ui->buttonBox->button(QDialogButtonBox::Ok)->setText(newOkButtonName);
     ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
