@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -33,7 +33,7 @@
 
 namespace U2 {
 
-CreateAnnotationFullWidget::CreateAnnotationFullWidget(const qint64 seqLen, QWidget *parent)
+CreateAnnotationFullWidget::CreateAnnotationFullWidget(const qint64 seqLen, QWidget* parent)
     : CreateAnnotationWidget(parent),
       formatType(Simple),
       seqLen(seqLen),
@@ -101,8 +101,10 @@ void CreateAnnotationFullWidget::useAminoAnnotationTypes(bool useAmino) {
     lwAnnotationType->clear();
     lwAnnotationType->addItems(featureTypes);
 
-    const int index = featureTypes.indexOf(U2FeatureTypes::getVisualName(U2FeatureTypes::MiscFeature));
+    int index = featureTypes.indexOf(U2FeatureTypes::getVisualName(U2FeatureTypes::MiscFeature));
     lwAnnotationType->setCurrentRow(index);
+    chbComplement->setVisible(!useAmino);
+    tbDoComplement->setVisible(!useAmino);
 }
 
 void CreateAnnotationFullWidget::focusGroupName() {
@@ -125,16 +127,16 @@ void CreateAnnotationFullWidget::focusLocation() {
     }
 }
 
-void CreateAnnotationFullWidget::setNewTablePath(const QString &path) {
+void CreateAnnotationFullWidget::setNewTablePath(const QString& path) {
     leNewTablePath->setText(path);
 }
 
-void CreateAnnotationFullWidget::setGroupName(const QString &name) {
+void CreateAnnotationFullWidget::setGroupName(const QString& name) {
     leGroupName->setText(name);
 }
 
 void CreateAnnotationFullWidget::setAnnotationType(U2FeatureType type) {
-    QList<QListWidgetItem *> items = lwAnnotationType->findItems(U2FeatureTypes::getVisualName(type), Qt::MatchExactly);
+    QList<QListWidgetItem*> items = lwAnnotationType->findItems(U2FeatureTypes::getVisualName(type), Qt::MatchExactly);
     if (Q_LIKELY(!items.isEmpty())) {
         lwAnnotationType->setCurrentItem(items.first());
         return;
@@ -150,11 +152,11 @@ void CreateAnnotationFullWidget::setAnnotationType(U2FeatureType type) {
     lwAnnotationType->setCurrentRow(0);
 }
 
-void CreateAnnotationFullWidget::setAnnotationName(const QString &name) {
+void CreateAnnotationFullWidget::setAnnotationName(const QString& name) {
     leAnnotationName->setText(name);
 }
 
-void CreateAnnotationFullWidget::setLocation(const U2Location &location) {
+void CreateAnnotationFullWidget::setLocation(const U2Location& location) {
     // Example: (200..len,1..100)=(200..100), lambda returns true
     auto isSimpleSplitLocation = [&location](qint64 seqLen) {
         if (location->regions.size() < 2) {
@@ -163,8 +165,6 @@ void CreateAnnotationFullWidget::setLocation(const U2Location &location) {
         return location->regions[0].endPos() == seqLen && location->regions[1].startPos == 0;
     };
 
-    const bool firstLocationSetting = leRegionStart->text().isEmpty() && leRegionEnd->text().isEmpty();
-
     isValidLocation = false;
 
     QString startPos;
@@ -190,24 +190,17 @@ void CreateAnnotationFullWidget::setLocation(const U2Location &location) {
 
     leRegionStart->setText(startPos);
     leRegionEnd->setText(endPos);
-    chbComplement->setChecked(location->strand.isCompementary());
+    chbComplement->setChecked(location->strand.isComplementary());
     leLocation->setText(getGenbankLocationString(location));
-
-    // Examples: (200..len,1..100,5..10), (200..300,400..500) are not representable in simple format
-    const bool needToShowInGenbank = location->regions.size() > 2 ||
-                                     (location->regions.size() == 2 && !isSimpleSplitLocation(seqLen));
-    if (firstLocationSetting && needToShowInGenbank) {
-        rbGenbankFormat->setChecked(true);
-    }
 }
 
-void CreateAnnotationFullWidget::setDescription(const QString &description) {
+void CreateAnnotationFullWidget::setDescription(const QString& description) {
     leDescription->setText(description);
 }
 
 QString CreateAnnotationFullWidget::getAnnotationTypeString() const {
-    QListWidgetItem *currentItem = lwAnnotationType->currentItem();
-    SAFE_POINT(nullptr != currentItem, "Annotation type is not selected", "");
+    QListWidgetItem* currentItem = lwAnnotationType->currentItem();
+    SAFE_POINT(currentItem != nullptr, "Annotation type is not selected", "");
     return currentItem->text();
 }
 
@@ -224,14 +217,7 @@ QString CreateAnnotationFullWidget::getDescription() const {
 }
 
 QString CreateAnnotationFullWidget::getLocationString() const {
-    const QString location = leLocation->text();
-    if (isValidLocation) {
-        return location;
-    }
-    if (location.startsWith("complement(") && location.endsWith(")")) {
-        return "complement()";
-    }
-    return QString();
+    return leLocation->text();
 }
 
 bool CreateAnnotationFullWidget::isUsePatternNamesChecked() const {
@@ -269,7 +255,7 @@ bool CreateAnnotationFullWidget::isAutoTableOptionSelected() const {
     return rbUseAutoTable->isChecked();
 }
 
-void CreateAnnotationFullWidget::showSelectGroupMenu(QMenu &menu) {
+void CreateAnnotationFullWidget::showSelectGroupMenu(QMenu& menu) {
     const QPoint menuPos = tbSelectGroupName->mapToGlobal(tbSelectGroupName->rect().bottomLeft());
     menu.exec(menuPos);
 }
@@ -281,7 +267,11 @@ void CreateAnnotationFullWidget::sl_regionChanged() {
     CHECK(ok, );
     qint64 endPos = leRegionEnd->text().toLongLong(&ok);
     CHECK(ok, );
-    isValidLocation = (startPos >= 1 && startPos <= seqLen && endPos >= 1 && endPos <= seqLen);
+    isValidLocation = startPos >= 1 && startPos <= seqLen && endPos >= 1 && endPos <= seqLen;
+    if (!isValidLocation) {
+        leLocation->setText("");
+        return;
+    }
 
     U2Location location;
     if (startPos > endPos) {  // split (200..100) to (200..len,1..100)
@@ -330,19 +320,19 @@ void CreateAnnotationFullWidget::initOsDependingLayoutSettings() {
 
 void CreateAnnotationFullWidget::connectSignals() {
     connect(tbBrowseExistingTable, SIGNAL(clicked()), SLOT(sl_selectExistingTableRequest()));
-    connect(leGroupName, SIGNAL(textEdited(const QString &)), SLOT(sl_groupNameEdited()));
-    connect(leGroupName, SIGNAL(textChanged(const QString &)), SLOT(sl_groupNameEdited()));
-    connect(leAnnotationName, SIGNAL(textEdited(const QString &)), SLOT(sl_annotationNameEdited()));
-    connect(leAnnotationName, SIGNAL(textChanged(const QString &)), SLOT(sl_annotationNameEdited()));
-    connect(leRegionStart, SIGNAL(textEdited(const QString &)), SLOT(sl_regionChanged()));
-    connect(leRegionEnd, SIGNAL(textEdited(const QString &)), SLOT(sl_regionChanged()));
+    connect(leGroupName, SIGNAL(textEdited(const QString&)), SLOT(sl_groupNameEdited()));
+    connect(leGroupName, SIGNAL(textChanged(const QString&)), SLOT(sl_groupNameEdited()));
+    connect(leAnnotationName, SIGNAL(textEdited(const QString&)), SLOT(sl_annotationNameEdited()));
+    connect(leAnnotationName, SIGNAL(textChanged(const QString&)), SLOT(sl_annotationNameEdited()));
+    connect(leRegionStart, SIGNAL(textEdited(const QString&)), SLOT(sl_regionChanged()));
+    connect(leRegionEnd, SIGNAL(textEdited(const QString&)), SLOT(sl_regionChanged()));
     connect(leLocation, SIGNAL(editingFinished()), SLOT(sl_locationChanged()));
     connect(tbDoComplement, SIGNAL(clicked()), SLOT(sl_complementLocation()));
     connect(chbComplement, SIGNAL(clicked()), SLOT(sl_complementLocation()));
     connect(tbSelectGroupName, SIGNAL(clicked()), SLOT(sl_selectGroupNameMenuRequest()));
 }
 
-GObjectComboBoxController *CreateAnnotationFullWidget::createGObjectComboBoxController(const GObjectComboBoxControllerConstraints &constraints) {
+GObjectComboBoxController* CreateAnnotationFullWidget::createGObjectComboBoxController(const GObjectComboBoxControllerConstraints& constraints) {
     return new GObjectComboBoxController(this, constraints, cbExistingTable);
 }
 
@@ -352,7 +342,7 @@ void CreateAnnotationFullWidget::countDescriptionUsage() const {
     }
 }
 
-void CreateAnnotationFullWidget::fillSaveDocumentControllerConfig(SaveDocumentControllerConfig &config) const {
+void CreateAnnotationFullWidget::fillSaveDocumentControllerConfig(SaveDocumentControllerConfig& config) const {
     config.fileNameEdit = leNewTablePath;
     config.fileDialogButton = tbBrowseNewTable;
 }
