@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,16 +21,9 @@
 
 #include "CreateAnnotationWidgetController.h"
 
-#include <QCheckBox>
-#include <QComboBox>
-#include <QGridLayout>
 #include <QLabel>
-#include <QLineEdit>
 #include <QMainWindow>
 #include <QMenu>
-#include <QRadioButton>
-#include <QToolButton>
-#include <QVBoxLayout>
 
 #include <U2Core/Annotation.h>
 #include <U2Core/AnnotationGroup.h>
@@ -38,7 +31,6 @@
 #include <U2Core/AppContext.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/GObjectReference.h>
-#include <U2Core/GObjectRelationRoles.h>
 #include <U2Core/GObjectTypes.h>
 #include <U2Core/GObjectUtils.h>
 #include <U2Core/GUrlUtils.h>
@@ -56,13 +48,11 @@
 
 #include <U2Formats/GenbankLocationParser.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/GUIUtils.h>
 #include <U2Gui/MainWindow.h>
 #include <U2Gui/ProjectTreeController.h>
 #include <U2Gui/ProjectTreeItemSelectorDialog.h>
 #include <U2Gui/SaveDocumentController.h>
-#include <U2Gui/ShowHideSubgroupWidget.h>
 
 #include "CreateAnnotationFullWidget.h"
 #include "CreateAnnotationNormalWidget.h"
@@ -72,33 +62,20 @@
 namespace U2 {
 
 CreateAnnotationModel::CreateAnnotationModel()
-    : defaultIsNewDoc(false),
-      hideGroupName(false),
-      hideLocation(false),
-      hideAnnotationType(false),
-      hideAnnotationName(false),
-      hideDescription(false),
-      hideUsePatternNames(true),
-      useUnloadedObjects(false),
-      useAminoAnnotationTypes(false),
-      data(new AnnotationData),
-      hideAnnotationTableOption(false),
-      hideAutoAnnotationsOption(true),
-      hideAnnotationParameters(false) {
+    : data(new AnnotationData()) {
 }
 
-AnnotationTableObject *CreateAnnotationModel::getAnnotationObject() const {
-    GObject *res = GObjectUtils::selectObjectByReference(annotationObjectRef, UOF_LoadedOnly);
-    AnnotationTableObject *aobj = qobject_cast<AnnotationTableObject *>(res);
-    SAFE_POINT(nullptr != aobj, "Invalid annotation table detected!", nullptr);
+AnnotationTableObject* CreateAnnotationModel::getAnnotationObject() const {
+    GObject* res = GObjectUtils::selectObjectByReference(annotationObjectRef, UOF_LoadedOnly);
+    auto aobj = qobject_cast<AnnotationTableObject*>(res);
+    SAFE_POINT(aobj != nullptr, "Invalid annotation table detected!", nullptr);
     return aobj;
 }
 
-const QString CreateAnnotationWidgetController::DESCRIPTION_QUALIFIER_KEY = "note";
 const QString CreateAnnotationWidgetController::SETTINGS_LASTDIR = "create_annotation/last_dir";
 
-CreateAnnotationWidgetController::CreateAnnotationWidgetController(const CreateAnnotationModel &m,
-                                                                   QObject *p,
+CreateAnnotationWidgetController::CreateAnnotationWidgetController(const CreateAnnotationModel& m,
+                                                                   QObject* p,
                                                                    AnnotationWidgetMode layoutMode)
     : QObject(p),
       model(m),
@@ -119,7 +96,7 @@ CreateAnnotationWidgetController::CreateAnnotationWidgetController(const CreateA
     occc.uof = model.useUnloadedObjects ? UOF_LoadedAndUnloaded : UOF_LoadedOnly;
     occ = w->createGObjectComboBoxController(occc);
 
-    commonWidgetUpdate(model);
+    commonWidgetUpdate();
 
     connect(w, SIGNAL(si_selectExistingTableRequest()), SLOT(sl_onLoadObjectsClicked()));
     connect(w, SIGNAL(si_selectGroupNameMenuRequest()), SLOT(sl_groupName()));
@@ -133,7 +110,7 @@ CreateAnnotationWidgetController::~CreateAnnotationWidgetController() {
     // Do not remove the empty destructor because https://doc.qt.io/qt-5/qscopedpointer.html#forward-declared-pointers
 }
 
-void CreateAnnotationWidgetController::updateWidgetForAnnotationModel(const CreateAnnotationModel &newModel) {
+void CreateAnnotationWidgetController::updateWidgetForAnnotationModel(const CreateAnnotationModel& newModel) {
     SAFE_POINT(newModel.sequenceObjectRef.isValid(),
                "Internal error: incorrect sequence object reference was supplied"
                "to the annotation widget controller.", );
@@ -149,10 +126,10 @@ void CreateAnnotationWidgetController::updateWidgetForAnnotationModel(const Crea
 
     occ->updateConstrains(occc);
 
-    commonWidgetUpdate(newModel);
+    commonWidgetUpdate();
 }
 
-void CreateAnnotationWidgetController::commonWidgetUpdate(const CreateAnnotationModel &model) {
+void CreateAnnotationWidgetController::commonWidgetUpdate() {
     w->setLocationVisible(!model.hideLocation);
     w->setAnnotationNameVisible(!model.hideAnnotationName);
 
@@ -195,25 +172,25 @@ void CreateAnnotationWidgetController::commonWidgetUpdate(const CreateAnnotation
     w->setUsePatternNamesVisible(!model.hideUsePatternNames);
 
     w->useAminoAnnotationTypes(model.useAminoAnnotationTypes);
-    if (U2FeatureTypes::Invalid != model.data->type) {
+    if (model.data->type != U2FeatureTypes::Invalid) {
         w->setAnnotationType(model.data->type);
     }
 }
 
 class PTCAnnotationObjectFilter : public PTCObjectRelationFilter {
 public:
-    PTCAnnotationObjectFilter(const GObjectRelation &_rel, bool _allowUnloaded, QObject *p = nullptr)
+    PTCAnnotationObjectFilter(const GObjectRelation& _rel, bool _allowUnloaded, QObject* p = nullptr)
         : PTCObjectRelationFilter(_rel, p), allowUnloaded(_allowUnloaded) {
     }
 
-    bool filter(GObject *obj) const {
+    bool filter(GObject* obj) const override {
         if (PTCObjectRelationFilter::filter(obj)) {
             return true;
         }
         if (obj->isUnloaded()) {
             return !allowUnloaded;
         }
-        SAFE_POINT(nullptr != qobject_cast<AnnotationTableObject *>(obj), "Invalid annotation table object!", false);
+        SAFE_POINT(qobject_cast<AnnotationTableObject*>(obj) != nullptr, "Invalid annotation table object!", false);
         return obj->isStateLocked();
     }
     bool allowUnloaded;
@@ -227,12 +204,12 @@ void CreateAnnotationWidgetController::sl_onLoadObjectsClicked() {
     GObjectRelation rel(model.sequenceObjectRef, ObjectRole_Sequence);
     QScopedPointer<PTCAnnotationObjectFilter> filter(new PTCAnnotationObjectFilter(rel, model.useUnloadedObjects));
     s.objectFilter = filter.data();
-    QList<GObject *> objs = ProjectTreeItemSelectorDialog::selectObjects(s, AppContext::getMainWindow()->getQMainWindow());
+    QList<GObject*> objs = ProjectTreeItemSelectorDialog::selectObjects(s, AppContext::getMainWindow()->getQMainWindow());
     if (objs.isEmpty()) {
         return;
     }
     assert(objs.size() == 1);
-    GObject *obj = objs.first();
+    GObject* obj = objs.first();
     occ->setSelectedObject(obj);
 }
 
@@ -266,14 +243,17 @@ QString CreateAnnotationWidgetController::validate() {
         return tr("Invalid location! Location must be in GenBank format.\nSimple examples:\n1..10\njoin(1..10,15..45)\ncomplement(5..15)");
     }
     if (!model.hideLocation) {
-        foreach (const U2Region &reg, model.data->getRegions()) {
+        foreach (const U2Region& reg, model.data->getRegions()) {
             if (reg.endPos() > model.sequenceLen || reg.startPos < 0 || reg.endPos() < reg.startPos) {
                 return tr("Invalid location! Location must be in GenBank format.\nSimple examples:\n1..10\njoin(1..10,15..45)\ncomplement(5..15)");
             }
         }
+        if (model.useAminoAnnotationTypes && model.data->location->strand != U2Strand::Direct) {
+            return tr("The 'complement' keyword cannot be present in the location of an amino acid sequence annotation.");
+        }
     }
 
-    return QString();
+    return "";
 }
 
 void CreateAnnotationWidgetController::updateModel(bool forValidation) {
@@ -336,12 +316,12 @@ QString CreateAnnotationWidgetController::defaultDir() {
     QString dir = AppContext::getSettings()->getValue(SETTINGS_LASTDIR, QString(""), true).toString();
     if (dir.isEmpty() || !QDir(dir).exists()) {
         dir = GUrlUtils::getDefaultDataPath();
-        Project *prj = AppContext::getProject();
+        Project* prj = AppContext::getProject();
         if (prj != nullptr) {
-            const QString &prjUrl = prj->getProjectURL();
+            const QString& prjUrl = prj->getProjectURL();
             if (!prjUrl.isEmpty()) {
                 QFileInfo fi(prjUrl);
-                const QDir &prjDir = fi.absoluteDir();
+                const QDir& prjDir = fi.absoluteDir();
                 dir = prjDir.absolutePath();
             }
         }
@@ -373,45 +353,44 @@ bool CreateAnnotationWidgetController::isAnnotationsTableVirtual() {
 bool CreateAnnotationWidgetController::prepareAnnotationObject() {
     updateModel(false);
     QString v = validate();
-    if ((w->isExistingTableOptionSelected()) && isAnnotationsTableVirtual()) {
-        Document *d = AppContext::getProject()->findDocumentByURL(model.sequenceObjectRef.docUrl);
+    if (w->isExistingTableOptionSelected() && isAnnotationsTableVirtual()) {
+        Document* d = AppContext::getProject()->findDocumentByURL(model.sequenceObjectRef.docUrl);
         SAFE_POINT(d != nullptr, "cannot create a annotation table in same document", false);
         U2OpStatusImpl os;
         const U2DbiRef localDbiRef = AppContext::getDbiRegistry()->getSessionTmpDbiRef(os);
         SAFE_POINT_OP(os, false);
-        AnnotationTableObject *ann = new AnnotationTableObject(model.sequenceObjectRef.objName + FEATURES_TAG, localDbiRef);
+        AnnotationTableObject* ann = new AnnotationTableObject(model.sequenceObjectRef.objName + FEATURES_TAG, localDbiRef);
         ann->addObjectRelation(GObjectRelation(model.sequenceObjectRef, ObjectRole_Sequence));
         d->addObject(ann);
         occ->setSelectedObject(ann);
-        model.annotationObjectRef = ann;
+        model.annotationObjectRef = ann->getReference();
     }
     SAFE_POINT(v.isEmpty(), "Annotation model is not valid", false);
     if (!model.annotationObjectRef.isValid() && w->isNewTableOptionSelected()) {
         SAFE_POINT(!model.newDocUrl.isEmpty(), "newDocUrl is empty", false);
         SAFE_POINT(AppContext::getProject()->findDocumentByURL(model.newDocUrl) == nullptr, "cannot create a document that is already in the project", false);
-        IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
-        DocumentFormat *df = AppContext::getDocumentFormatRegistry()->getFormatById(BaseDocumentFormats::PLAIN_GENBANK);
+        IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
+        DocumentFormat* df = AppContext::getDocumentFormatRegistry()->getFormatById(BaseDocumentFormats::PLAIN_GENBANK);
         U2OpStatus2Log os;
-        Document *d = df->createNewLoadedDocument(iof, model.newDocUrl, os);
+        Document* d = df->createNewLoadedDocument(iof, model.newDocUrl, os);
         CHECK_OP(os, false);
         const U2DbiRef dbiRef = AppContext::getDbiRegistry()->getSessionTmpDbiRef(os);
         SAFE_POINT_OP(os, false);
-        AnnotationTableObject *aobj = new AnnotationTableObject("Annotations", dbiRef);
+        AnnotationTableObject* aobj = new AnnotationTableObject("Annotations", dbiRef);
         aobj->addObjectRelation(GObjectRelation(model.sequenceObjectRef, ObjectRole_Sequence));
         d->addObject(aobj);
         AppContext::getProject()->addDocument(d);
-        model.annotationObjectRef = aobj;
+        model.annotationObjectRef = aobj->getReference();
     }
 
     return true;
 }
 
 void CreateAnnotationWidgetController::sl_groupName() {
-    GObject *obj = occ->getSelectedObject();
-    QStringList groupNames;
-    groupNames << GROUP_NAME_AUTO;
-    if (nullptr != obj && !obj->isUnloaded() && !isAnnotationsTableVirtual()) {
-        AnnotationTableObject *ao = qobject_cast<AnnotationTableObject *>(obj);
+    GObject* obj = occ->getSelectedObject();
+    QStringList groupNames = {GROUP_NAME_AUTO};
+    if (obj != nullptr && !obj->isUnloaded() && !isAnnotationsTableVirtual()) {
+        auto ao = qobject_cast<AnnotationTableObject*>(obj);
         ao->getRootGroup()->getSubgroupPaths(groupNames);
     }
     SAFE_POINT(!groupNames.isEmpty(), "Unable to find annotation groups!", );
@@ -422,8 +401,8 @@ void CreateAnnotationWidgetController::sl_groupName() {
     std::sort(groupNames.begin(), groupNames.end());
 
     QMenu menu(w);
-    foreach (const QString &str, groupNames) {
-        QAction *a = new QAction(str, &menu);
+    for (const QString& str : qAsConst(groupNames)) {
+        QAction* a = new QAction(str, &menu);
         connect(a, SIGNAL(triggered()), SLOT(sl_setPredefinedGroupName()));
         menu.addAction(a);
     }
@@ -431,7 +410,7 @@ void CreateAnnotationWidgetController::sl_groupName() {
 }
 
 void CreateAnnotationWidgetController::sl_setPredefinedGroupName() {
-    QAction *a = qobject_cast<QAction *>(sender());
+    auto a = qobject_cast<QAction*>(sender());
     QString name = a->text();
     w->setGroupName(name);
 }
@@ -457,7 +436,7 @@ void CreateAnnotationWidgetController::setFocusToAnnotationType() {
 }
 
 void CreateAnnotationWidgetController::sl_documentsComboUpdated() {
-    commonWidgetUpdate(model);
+    commonWidgetUpdate();
 }
 
 void CreateAnnotationWidgetController::sl_annotationNameEdited() {
@@ -472,7 +451,7 @@ void CreateAnnotationWidgetController::sl_usePatternNamesStateChanged() {
     emit si_usePatternNamesStateChanged();
 }
 
-QWidget *CreateAnnotationWidgetController::getWidget() const {
+QWidget* CreateAnnotationWidgetController::getWidget() const {
     return w;
 }
 
@@ -485,7 +464,7 @@ AnnotationCreationPattern CreateAnnotationWidgetController::getAnnotationPattern
     return pattern;
 }
 
-QPair<QWidget *, QWidget *> CreateAnnotationWidgetController::getTaborderEntryAndExitPoints() const {
+QPair<QWidget*, QWidget*> CreateAnnotationWidgetController::getTaborderEntryAndExitPoints() const {
     return w->getTabOrderEntryAndExitPoints();
 }
 
