@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CREATE_OBJECT_RELATION_DIALOG_CONTROLLER_H_
-#define _U2_CREATE_OBJECT_RELATION_DIALOG_CONTROLLER_H_
+#pragma once
 
 #include <QDialog>
 
@@ -36,12 +35,12 @@ class GObject;
 class U2GUI_EXPORT CreateObjectRelationDialogController : public QDialog {
     Q_OBJECT
 public:
-    CreateObjectRelationDialogController(GObject *obj, const QList<GObject *> &objects, GObjectRelationRole role, bool removeDuplicates, const QString &relationHint, QWidget *p = nullptr);
+    CreateObjectRelationDialogController(GObject* obj, const QList<GObject*>& objects, GObjectRelationRole role, bool removeDuplicates, const QString& relationHint, QWidget* p = nullptr);
     ~CreateObjectRelationDialogController();
 
-    GObject *selectedObject;
-    GObject *assObj;
-    QList<GObject *> objects;
+    GObject* selectedObject;
+    GObject* assObj;
+    QList<GObject*> objects;
     GObjectRelationRole role;
     bool removeDuplicates;
     bool relationIsSet;
@@ -50,9 +49,7 @@ public slots:
     virtual void accept();
 
 private:
-    Ui_CreateObjectRelationDialog *ui;
+    Ui_CreateObjectRelationDialog* ui;
 };
 
 }  // namespace U2
-
-#endif
