@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CREATE_SEQUENCE_FROM_TEXT_AND_OPEN_VIEW_TASK_H_
-#define _U2_CREATE_SEQUENCE_FROM_TEXT_AND_OPEN_VIEW_TASK_H_
+#pragma once
 
 #include <U2Core/DNASequence.h>
 #include <U2Core/GUrl.h>
@@ -35,26 +34,24 @@ class ImportSequenceFromRawDataTask;
 class CreateSequenceFromTextAndOpenViewTask : public Task {
     Q_OBJECT
 public:
-    CreateSequenceFromTextAndOpenViewTask(const QList<DNASequence> &sequences, const QString &formatId, const GUrl &saveToPath, bool saveImmediately);
+    CreateSequenceFromTextAndOpenViewTask(const QList<DNASequence>& sequences, const QString& formatId, const GUrl& saveToPath, bool saveImmediately);
 
 private:
     void prepare();
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
 
-    QList<Task *> prepareImportSequenceTasks();
-    Document *createEmptyDocument();
+    QList<Task*> prepareImportSequenceTasks();
+    Document* createEmptyDocument();
     void addDocument();
 
     const QList<DNASequence> sequences;
-    DocumentFormat *format;
+    DocumentFormat* format;
     const GUrl saveToPath;
     const bool saveImmediately;
-    Task *openProjectTask;
-    QList<Task *> importTasks;
+    Task* openProjectTask;
+    QList<Task*> importTasks;
     int importedSequences;
-    Document *document;
+    Document* document;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CREATE_SEQUENCE_FROM_TEXT_AND_OPEN_VIEW_TASK_H_
