@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,10 +34,10 @@
 
 namespace U2 {
 
-bool CredentialsAskerGui::askWithFixedLogin(const QString &resourceUrl) const {
+bool CredentialsAskerGui::askWithFixedLogin(const QString& resourceUrl) const {
     SAFE_POINT(AppContext::isGUIMode(), "Unexpected application run mode", false);
 
-    QWidget *mainWindow = qobject_cast<QWidget *>(AppContext::getMainWindow()->getQMainWindow());
+    auto mainWindow = qobject_cast<QWidget*>(AppContext::getMainWindow()->getQMainWindow());
 
     QString userName;
     const QString shortDbiUrl = U2DbiUtils::full2shortDbiUrl(resourceUrl, userName);
@@ -58,10 +58,10 @@ bool CredentialsAskerGui::askWithFixedLogin(const QString &resourceUrl) const {
     return true;
 }
 
-bool CredentialsAskerGui::askWithModifiableLogin(QString &resourceUrl) const {
+bool CredentialsAskerGui::askWithModifiableLogin(QString& resourceUrl) const {
     SAFE_POINT(AppContext::isGUIMode(), "Unexpected application run mode", false);
 
-    QWidget *mainWindow = qobject_cast<QWidget *>(AppContext::getMainWindow()->getQMainWindow());
+    auto mainWindow = qobject_cast<QWidget*>(AppContext::getMainWindow()->getQMainWindow());
 
     QString userName;
     const QString shortDbiUrl = U2DbiUtils::full2shortDbiUrl(resourceUrl, userName);
