@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CREDENTIALS_ASKER_GUI_H_
-#define _U2_CREDENTIALS_ASKER_GUI_H_
+#pragma once
 
 #include <U2Core/CredentialsAsker.h>
 
@@ -28,10 +27,8 @@ namespace U2 {
 
 class U2GUI_EXPORT CredentialsAskerGui : public CredentialsAsker {
 public:
-    bool askWithFixedLogin(const QString &resourceUrl) const;
-    bool askWithModifiableLogin(QString &resourceUrl) const;
+    bool askWithFixedLogin(const QString& resourceUrl) const;
+    bool askWithModifiableLogin(QString& resourceUrl) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CREDENTIALS_ASKER_GUI_H_
