@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,15 +22,11 @@
 #include "DialogUtils.h"
 
 #include <QCoreApplication>
-#include <QDir>
 #include <QMessageBox>
 #include <QWizard>
 
-#include <U2Core/AppContext.h>
-#include <U2Core/DocumentImport.h>
 #include <U2Core/DocumentModel.h>
 #include <U2Core/FormatUtils.h>
-#include <U2Core/Settings.h>
 #include <U2Core/Task.h>
 
 #include <U2Gui/LastUsedDirHelper.h>
@@ -38,34 +34,14 @@
 
 namespace U2 {
 
-void DialogUtils::showProjectIsLockedWarning(QWidget *p) {
-    QMessageBox::critical(p, tr("Error"), tr("Project is locked"), QMessageBox::Ok, QMessageBox::NoButton);
+static bool getDontUseNativeDialogFlag() {
+    return qgetenv(ENV_USE_NATIVE_DIALOGS) == "0";
 }
 
-QString DialogUtils::prepareFileFilter(const QString &name, const QStringList &exts, bool any, const QStringList &extra) {
-    return FormatUtils::prepareFileFilter(name, exts, any, extra);
-}
-
-QString DialogUtils::prepareDocumentsFileFilter(const DocumentFormatId &fid, bool any, const QStringList &extra) {
-    return FormatUtils::prepareDocumentsFileFilter(fid, any, extra);
-}
-
-QString DialogUtils::prepareDocumentsFileFilter(bool any, const QStringList &extra) {
-    return FormatUtils::prepareDocumentsFileFilter(any, extra);
-}
-
-QString DialogUtils::prepareDocumentsFileFilter(const DocumentFormatConstraints &c, bool any) {
-    return FormatUtils::prepareDocumentsFileFilter(c, any);
-}
-
-QString DialogUtils::prepareDocumentsFileFilterByObjType(const GObjectType &t, bool any) {
-    return FormatUtils::prepareDocumentsFileFilterByObjType(t, any);
-}
-
-void DialogUtils::setWizardMinimumSize(QWizard *wizard, const QSize &minimumSize) {
+void WizardUtils::setWizardMinimumSize(QWizard* wizard, const QSize& minimumSize) {
     QSize bestSize = minimumSize;
     foreach (int pageId, wizard->pageIds()) {
-        QWizardPage *page = wizard->page(pageId);
+        QWizardPage* page = wizard->page(pageId);
         page->adjustSize();
         bestSize = bestSize.expandedTo(page->size());
     }
@@ -100,4 +76,32 @@ void FileLineEdit::sl_onBrowse() {
     setFocus();
 }
 
+/** Adds 'DontUseNativeDialog' option the the options when needed in-place. */
+static void adjustColorDialogOptions(QColorDialog::ColorDialogOptions& options) {
+    if (getDontUseNativeDialogFlag()) {
+        options |= QColorDialog::DontUseNativeDialog;
+    }
+}
+
+U2ColorDialog::U2ColorDialog(QWidget* parent)
+    : QColorDialog(parent) {
+    QColorDialog::ColorDialogOptions adjustedOptions = options();
+    adjustColorDialogOptions(adjustedOptions);
+    setOptions(adjustedOptions);
+}
+
+U2ColorDialog::U2ColorDialog(const QColor& initial, QWidget* parent)
+    : QColorDialog(initial, parent) {
+    QColorDialog::ColorDialogOptions adjustedOptions = options();
+    adjustColorDialogOptions(adjustedOptions);
+    setOptions(adjustedOptions);
+}
+
+QColor U2ColorDialog::getColor(const QColor& initial,
+                               QWidget* parent,
+                               const QString& title,
+                               QColorDialog::ColorDialogOptions options) {
+    adjustColorDialogOptions(options);
+    return QColorDialog::getColor(initial, parent, title, options);
+}
 }  // namespace U2
