@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,9 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DIALOG_UTILS_H_
-#define _U2_DIALOG_UTILS_H_
+#pragma once
 
+#include <QColorDialog>
 #include <QLineEdit>
 #include <QWidget>
 
@@ -35,32 +35,20 @@ class DocumentFormatConstraints;
 class Logger;
 class TaskStateInfo;
 
-class U2GUI_EXPORT DialogUtils : public QObject {
+class U2GUI_EXPORT WizardUtils : public QObject {
     Q_OBJECT
 public:
-    static void showProjectIsLockedWarning(QWidget *p = nullptr);
-
-    static QString prepareFileFilter(const QString &name, const QStringList &exts, bool any = true, const QStringList &extraExts = QStringList(".gz"));
-
-    static QString prepareDocumentsFileFilter(const DocumentFormatId &fid, bool any, const QStringList &extraExts = QStringList(".gz"));
-
-    // returns filter for all formats supported. All-docs filter is returned first if any==true
-    static QString prepareDocumentsFileFilter(bool any, const QStringList &extraExts = QStringList(".gz"));
-
-    static QString prepareDocumentsFileFilter(const DocumentFormatConstraints &c, bool any);
-
-    static QString prepareDocumentsFileFilterByObjType(const GObjectType &t, bool any);
-
-    static void setWizardMinimumSize(QWizard *wizard, const QSize &minimumSize = QSize());
+    static void setWizardMinimumSize(QWizard* wizard, const QSize& minimumSize = QSize());
 };
 
 class U2GUI_EXPORT FileLineEdit : public QLineEdit {
     Q_OBJECT
 public:
-    FileLineEdit(const QString &filter, const QString &type, bool multi, QWidget *parent)
+    FileLineEdit(const QString& filter, const QString& type, bool multi, QWidget* parent)
         : QLineEdit(parent), FileFilter(filter), type(type), multi(multi) {
     }
-private slots:
+
+public slots:
     void sl_onBrowse();
 
 private:
@@ -69,6 +57,19 @@ private:
     bool multi;
 };
 
-}  // namespace U2
+class U2GUI_EXPORT U2ColorDialog : public QColorDialog {
+public:
+    explicit U2ColorDialog(QWidget* parent = nullptr);
+    explicit U2ColorDialog(const QColor& initial, QWidget* parent = nullptr);
 
-#endif
+    /**
+     * Runs a dialog and returns a color.
+     * Same as QColorDialog::getColor() but checks 'UGENE_USE_NATIVE_DIALOGS' environment variable and adjust 'options' accordingly.
+     */
+    static QColor getColor(const QColor& initial = Qt::white,
+                           QWidget* parent = nullptr,
+                           const QString& title = QString(),
+                           QColorDialog::ColorDialogOptions options = QColorDialog::ColorDialogOptions());
+};
+
+}  // namespace U2
