@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOCUMENT_FORMAT_COMBOBOX_CONTROLLER_H_
-#define _U2_DOCUMENT_FORMAT_COMBOBOX_CONTROLLER_H_
+#pragma once
 
 #include <QComboBox>
 
@@ -31,9 +30,9 @@ namespace U2 {
 class U2GUI_EXPORT DocumentFormatComboboxController : public QObject {
     Q_OBJECT
 public:
-    DocumentFormatComboboxController(QObject *p, QComboBox *combo, const DocumentFormatConstraints &c, const DocumentFormatId &active = DocumentFormatId());
+    DocumentFormatComboboxController(QObject* p, QComboBox* combo, const DocumentFormatConstraints& c, const DocumentFormatId& active = DocumentFormatId());
 
-    void updateConstraints(const DocumentFormatConstraints &c);
+    void updateConstraints(const DocumentFormatConstraints& c);
 
     DocumentFormatId getActiveFormatId() const;
     void setActiveFormatId(DocumentFormatId);
@@ -41,25 +40,23 @@ public:
         return !getActiveFormatId().isNull();
     }
     QList<DocumentFormatId> getFormatsInCombo();
-    QComboBox *comboBox() {
+    QComboBox* comboBox() {
         return combo;
     }
 
-    static void fill(QComboBox *combo, QList<DocumentFormatId> &ids, DocumentFormatId active);
-    static DocumentFormatId getActiveFormatId(QComboBox *combo);
-    static QList<DocumentFormatId> getFormatsInCombo(QComboBox *combo);
+    static void fill(QComboBox* combo, QList<DocumentFormatId>& ids, DocumentFormatId active);
+    static DocumentFormatId getActiveFormatId(QComboBox* combo);
+    static QList<DocumentFormatId> getFormatsInCombo(QComboBox* combo);
 
 private slots:
-    void sl_onDocumentFormatRegistered(DocumentFormat *);
-    void sl_onDocumentFormatUnregistered(DocumentFormat *);
+    void sl_onDocumentFormatRegistered(DocumentFormat*);
+    void sl_onDocumentFormatUnregistered(DocumentFormat*);
 
 private:
     void updateCombo(DocumentFormatId active);
 
-    QComboBox *combo;
+    QComboBox* combo;
     DocumentFormatConstraints c;
 };
 
 }  // namespace U2
-
-#endif
