@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -47,12 +47,13 @@
 
 static const QString SAVE_DIR("downloadremotefiledialog/savedir");
 static const QString HINT_STYLE_SHEET = "color:green; font:bold";
+static const QString DB_EXTERNAL_LINK = QString(R"(<a href="%1"><img src=":core/images/external_link.png" width="22" height="22"></a>)");
 
 namespace U2 {
 
 QString DownloadRemoteFileDialog::defaultDB("");
 
-DownloadRemoteFileDialog::DownloadRemoteFileDialog(QWidget *p)
+DownloadRemoteFileDialog::DownloadRemoteFileDialog(QWidget* p)
     : QDialog(p), isQueryDB(false) {
     ui = new Ui_DownloadRemoteFileDialog;
     ui->setupUi(this);
@@ -64,9 +65,17 @@ DownloadRemoteFileDialog::DownloadRemoteFileDialog(QWidget *p)
     ui->formatLabel->hide();
     adjustSize();
 
-    RemoteDBRegistry &registry = RemoteDBRegistry::getRemoteDBRegistry();
+    RemoteDBRegistry& registry = RemoteDBRegistry::getRemoteDBRegistry();
+    connect(ui->databasesBox, &QComboBox::currentTextChanged, this, [this](const QString& text) {
+        auto link = RemoteDBRegistry::EXTERNAL_LINKS.value(text);
+        SAFE_POINT(!link.isEmpty(), QString("No database found: %1").arg(text), );
+
+        auto sign = DB_EXTERNAL_LINK.arg(link);
+        ui->lbExternalLink->setText(sign);
+    });
+
     const QList<QString> dataBases = registry.getDBs();
-    foreach (const QString &dbName, dataBases) {
+    foreach (const QString& dbName, dataBases) {
         ui->databasesBox->addItem(dbName, dbName);
     }
 
@@ -81,14 +90,14 @@ DownloadRemoteFileDialog::DownloadRemoteFileDialog(QWidget *p)
 
     connect(ui->databasesBox, SIGNAL(currentIndexChanged(int)), SLOT(sl_onDbChanged()));
     connect(ui->saveFilenameToolButton, SIGNAL(clicked()), SLOT(sl_saveFilenameButtonClicked()));
-    connect(ui->hintLabel, SIGNAL(linkActivated(const QString &)), SLOT(sl_linkActivated(const QString &)));
+    connect(ui->hintLabel, SIGNAL(linkActivated(const QString&)), SLOT(sl_linkActivated(const QString&)));
 
     sl_onDbChanged();
 
     setSaveFilename();
 }
 
-DownloadRemoteFileDialog::DownloadRemoteFileDialog(const QString &id, const QString &dbId, QWidget *p /* = NULL*/)
+DownloadRemoteFileDialog::DownloadRemoteFileDialog(const QString& id, const QString& dbId, QWidget* p /* = NULL*/)
     : QDialog(p), isQueryDB(false) {
     ui = new Ui_DownloadRemoteFileDialog;
     ui->setupUi(this);
@@ -96,7 +105,7 @@ DownloadRemoteFileDialog::DownloadRemoteFileDialog(const QString &id, const QStr
 
     ui->formatBox->addItem(GENBANK_FORMAT);
     ui->formatBox->addItem(FASTA_FORMAT);
-    connect(ui->formatBox, SIGNAL(currentIndexChanged(const QString &)), SLOT(sl_formatChanged(const QString &)));
+    connect(ui->formatBox, SIGNAL(currentIndexChanged(const QString&)), SLOT(sl_formatChanged(const QString&)));
     adjustSize();
 
     ui->databasesBox->clear();
@@ -179,7 +188,7 @@ void DownloadRemoteFileDialog::accept() {
 
     QString dbId = getDBId();
     QStringList resIds = resourceId.split(QRegExp("[\\s,;]+"));
-    QList<Task *> tasks;
+    QList<Task*> tasks;
 
     QString fileFormat;
     if (ui->formatBox->count() > 0) {
@@ -189,7 +198,6 @@ void DownloadRemoteFileDialog::accept() {
     QVariantMap hints;
     hints.insert(FORCE_DOWNLOAD_SEQUENCE_HINT, ui->chbForceDownloadSequence->isVisible() && ui->chbForceDownloadSequence->isChecked());
 
-    int taskCount = 0;
     bool addToProject = ui->chbAddToProjectCheck->isChecked();
     if (addToProject && resIds.size() >= 100) {
         QString message = tr("There are more than 100 files found for download.\nAre you sure you want to open all of them?");
@@ -200,22 +208,20 @@ void DownloadRemoteFileDialog::accept() {
             addToProject = false;
         }
     }
-    bool hasLoadOnlyDocuments = false;
-    foreach (const QString &resId, resIds) {
-        LoadRemoteDocumentMode mode = LoadRemoteDocumentMode_LoadOnly;
-        if (addToProject) {
-            mode = taskCount < OpenViewTask::MAX_DOC_NUMBER_TO_OPEN_VIEWS ? LoadRemoteDocumentMode_OpenView : LoadRemoteDocumentMode_AddToProject;
+    for (int i = 0; i < resIds.size(); i++) {
+        if (!addToProject) {
+            auto task = new LoadRemoteDocumentTask(resIds[i], dbId, fullPath, fileFormat, hints);
+            task->setReportingSupported(true);
+            task->setReportingEnabled(true);
+            tasks << task;
+        } else {
+            bool openView = i < OpenViewTask::MAX_DOC_NUMBER_TO_OPEN_VIEWS ? true : false;
+            tasks << new LoadRemoteDocumentAndAddToProjectTask(resIds[i], dbId, fullPath, fileFormat, hints, openView);
         }
-        hasLoadOnlyDocuments = hasLoadOnlyDocuments || mode == LoadRemoteDocumentMode_LoadOnly;
-        tasks.append(new LoadRemoteDocumentAndAddToProjectTask(resId, dbId, fullPath, fileFormat, hints, mode));
-        taskCount++;
     }
 
-    TaskFlags flags = TaskFlags_NR_FOSCOE | TaskFlag_ReportingIsSupported;
-    if (hasLoadOnlyDocuments) {
-        flags = flags | TaskFlag_ReportingIsEnabled;
-    }
-    Task *topLevelTask = new MultiTask(tr("Download remote documents"), tasks, false, flags);
+    TaskFlags flags = TaskFlag_NoRun | TaskFlag_ReportingIsSupported | TaskFlag_ReportingIsEnabled;
+    Task* topLevelTask = new MultiTask(tr("Download remote documents"), tasks, false, flags);
     AppContext::getTaskScheduler()->registerTopLevelTask(topLevelTask);
 
     QDialog::accept();
@@ -226,7 +232,7 @@ DownloadRemoteFileDialog::~DownloadRemoteFileDialog() {
     delete ui;
 }
 
-bool DownloadRemoteFileDialog::isNcbiDb(const QString &dbId) const {
+bool DownloadRemoteFileDialog::isNcbiDb(const QString& dbId) const {
     return dbId == RemoteDBRegistry::GENBANK_DNA || dbId == RemoteDBRegistry::GENBANK_PROTEIN;
 }
 
@@ -237,25 +243,25 @@ void DownloadRemoteFileDialog::sl_onDbChanged() {
 
     ui->chbForceDownloadSequence->setVisible(isNcbiDb(dbId));
 
-    RemoteDBRegistry &registry = RemoteDBRegistry::getRemoteDBRegistry();
+    RemoteDBRegistry& registry = RemoteDBRegistry::getRemoteDBRegistry();
     hint = description = registry.getHint(dbId);
 
     setupHintText(hint);
     ui->idLineEdit->setToolTip(description);
 }
 
-void DownloadRemoteFileDialog::sl_formatChanged(const QString &format) {
+void DownloadRemoteFileDialog::sl_formatChanged(const QString& format) {
     ui->chbForceDownloadSequence->setVisible(GENBANK_FORMAT == format);
 }
 
-void DownloadRemoteFileDialog::sl_linkActivated(const QString &link) {
+void DownloadRemoteFileDialog::sl_linkActivated(const QString& link) {
     if (!link.isEmpty()) {
         ui->idLineEdit->setText(link);
     }
 }
 
-void DownloadRemoteFileDialog::setupHintText(const QString &text) {
-    SAFE_POINT(nullptr != ui && nullptr != ui->hintLabel, "Invalid dialog content!", );
+void DownloadRemoteFileDialog::setupHintText(const QString& text) {
+    SAFE_POINT(ui != nullptr && ui->hintLabel != nullptr, "Invalid dialog content!", );
     const QString hintStart(tr("Hint: "));
     const QString hintSample = (text.isEmpty() ? tr("Use database unique identifier.") : text) + "<br>";
     const QString hintEnd(tr("You can download multiple items by separating IDs with space "
