@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOWNLOAD_REMOTE_FILE_DIALOG_H_
-#define _U2_DOWNLOAD_REMOTE_FILE_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 #include <QList>
@@ -45,13 +44,13 @@ class U2GUI_EXPORT DownloadRemoteFileDialog : public QDialog {
 
 public slots:
     void sl_onDbChanged();
-    void sl_formatChanged(const QString &format);
+    void sl_formatChanged(const QString& format);
     void sl_saveFilenameButtonClicked();
-    void sl_linkActivated(const QString &link);
+    void sl_linkActivated(const QString& link);
 
 public:
-    DownloadRemoteFileDialog(QWidget *p = nullptr);
-    DownloadRemoteFileDialog(const QString &ids, const QString &dbId, QWidget *p = nullptr);
+    DownloadRemoteFileDialog(QWidget* p = nullptr);
+    DownloadRemoteFileDialog(const QString& ids, const QString& dbId, QWidget* p = nullptr);
     ~DownloadRemoteFileDialog();
     QString getDBId() const;
     QString getResourceId() const;
@@ -60,12 +59,10 @@ public:
 
 private:
     void setSaveFilename();
-    bool isNcbiDb(const QString &dbId) const;
-    void setupHintText(const QString &sampleText = QString());
+    bool isNcbiDb(const QString& dbId) const;
+    void setupHintText(const QString& sampleText = QString());
 
-    Ui_DownloadRemoteFileDialog *ui;
+    Ui_DownloadRemoteFileDialog* ui;
 };
 
 }  // namespace U2
-
-#endif  //_U2_DOWNLOAD_REMOTE_FILE_DIALOG_H_
