@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EDIT_QUALIFIER_DIALOG_H_
-#define _U2_EDIT_QUALIFIER_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -34,22 +33,21 @@ namespace U2 {
 class U2GUI_EXPORT EditQualifierDialog : public QDialog {
     Q_OBJECT
 public:
-    EditQualifierDialog(QWidget *p, const U2Qualifier &q, bool ro, bool existingQualifier);
+    EditQualifierDialog(QWidget* p, const U2Qualifier& q, bool ro, bool existingQualifier);
     ~EditQualifierDialog();
 
     virtual void accept();
 
-    const U2Qualifier &getModifiedQualifier() const {
+    const U2Qualifier& getModifiedQualifier() const {
         return q;
     }
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *e);
+    bool eventFilter(QObject* obj, QEvent* e);
 
 private:
     U2Qualifier q;
-    Ui_EditQualifierDialog *ui;
+    Ui_EditQualifierDialog* ui;
 };
 
 }  // namespace U2
-#endif
