@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EDIT_SETTINGS_DIALOG_H_
-#define _U2_EDIT_SETTINGS_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -45,15 +44,13 @@ public:
 class U2GUI_EXPORT EditSettingsDialog : public QDialog {
     Q_OBJECT
 public:
-    EditSettingsDialog(const EditSettings &settings, QWidget *parent);
+    EditSettingsDialog(const EditSettings& settings, QWidget* parent);
     ~EditSettingsDialog();
 
     EditSettings getSettings() const;
 
 private:
-    Ui_EditSettingDialogForm *ui;
+    Ui_EditSettingDialogForm* ui;
 };
 
 }  // namespace U2
-
-#endif  // _U2_EDIT_SETTINGS_DIALOG_H_
