@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,9 +27,6 @@
 #include <U2Core/AppContext.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentModel.h>
-#include <U2Core/FormatUtils.h>
-#include <U2Core/U2SafePoints.h>
-#include <U2Core/global.h>
 
 #include <U2Gui/HelpButton.h>
 #include <U2Gui/SaveDocumentController.h>
@@ -40,7 +37,7 @@ namespace U2 {
 
 const QString ExportAnnotationsDialog::CSV_FORMAT_ID("csv");
 
-ExportAnnotationsDialog::ExportAnnotationsDialog(const QString &filename, QWidget *parent)
+ExportAnnotationsDialog::ExportAnnotationsDialog(const QString& filename, QWidget* parent)
     : QDialog(parent), ui(new Ui_ExportAnnotationsDialog()) {
     ui->setupUi(this);
     lastAddToProjectState = ui->addToProjectCheck->isChecked();
@@ -57,7 +54,7 @@ ExportAnnotationsDialog::~ExportAnnotationsDialog() {
     delete ui;
 }
 
-void ExportAnnotationsDialog::initSaveController(const QString &filename) {
+void ExportAnnotationsDialog::initSaveController(const QString& filename) {
     SaveDocumentControllerConfig config;
     config.defaultDomain = "ExportAnnotationsDialogHelperDomain";
     config.defaultFileName = filename;
@@ -78,7 +75,7 @@ void ExportAnnotationsDialog::initSaveController(const QString &filename) {
     saveController = new SaveDocumentController(config, formatConstraints, this);
     saveController->addFormat(CSV_FORMAT_ID, QString(CSV_FORMAT_ID).toUpper(), QStringList() << CSV_FORMAT_ID);
 
-    connect(saveController, SIGNAL(si_formatChanged(const QString &)), SLOT(sl_formatChanged(const QString &)));
+    connect(saveController, SIGNAL(si_formatChanged(const QString&)), SLOT(sl_formatChanged(const QString&)));
     connect(ui->addToProjectCheck, SIGNAL(clicked(bool)), SLOT(sl_addToProjectStateChanged(bool)));
 }
 
@@ -98,7 +95,7 @@ bool ExportAnnotationsDialog::addToProject() const {
     return ui->addToProjectCheck->isChecked();
 }
 
-void ExportAnnotationsDialog::sl_formatChanged(const QString &newFormatId) {
+void ExportAnnotationsDialog::sl_formatChanged(const QString& newFormatId) {
     const bool isCsvFormat = (CSV_FORMAT_ID == newFormatId);
     ui->exportSequenceCheck->setEnabled(isCsvFormat);
     ui->exportSequenceNameCheck->setEnabled(isCsvFormat);
