@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,15 +21,12 @@
 
 #include "ExportDocumentDialogController.h"
 
-#include <QDir>
 #include <QPushButton>
 
 #include <U2Core/AppContext.h>
-#include <U2Core/DocumentUtils.h>
 #include <U2Core/GObject.h>
 #include <U2Core/GUrlUtils.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/HelpButton.h>
 
 #include "SaveDocumentController.h"
@@ -37,7 +34,7 @@
 
 namespace U2 {
 
-ExportDocumentDialogController::ExportDocumentDialogController(Document *d, QWidget *p)
+ExportDocumentDialogController::ExportDocumentDialogController(Document* d, QWidget* p)
     : QDialog(p),
       saveController(nullptr),
       sourceDoc(d),
@@ -51,14 +48,14 @@ ExportDocumentDialogController::ExportDocumentDialogController(Document *d, QWid
     initSaveController(sourceDoc->getObjects(), sourceDoc->getURLString());
 }
 
-ExportDocumentDialogController::ExportDocumentDialogController(GObject *object, QWidget *parent, const QString &initUrl)
+ExportDocumentDialogController::ExportDocumentDialogController(GObject* object, QWidget* parent, const QString& initUrl)
     : QDialog(parent),
       ui(new Ui_ExportDocumentDialog()),
       sourceDoc(nullptr),
       sourceObject(object) {
     ui->setupUi(this);
 
-    QList<GObject *> objectList = QList<GObject *>() << sourceObject;
+    QList<GObject*> objectList = QList<GObject*>() << sourceObject;
     initSaveController(objectList, initUrl);
 
     new HelpButton(this, ui->buttonBox, "65929295");
@@ -66,7 +63,7 @@ ExportDocumentDialogController::ExportDocumentDialogController(GObject *object,
     ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
 }
 
-void ExportDocumentDialogController::initSaveController(const QList<GObject *> &objects, const QString &fileUrl) {
+void ExportDocumentDialogController::initSaveController(const QList<GObject*>& objects, const QString& fileUrl) {
     SaveDocumentControllerConfig config;
     config.defaultFileName = fileUrl;
     config.fileDialogButton = ui->browseButton;
@@ -81,11 +78,11 @@ void ExportDocumentDialogController::initSaveController(const QList<GObject *> &
     saveController = new SaveDocumentController(config, formatConstraints, this);
 }
 
-DocumentFormatConstraints ExportDocumentDialogController::getAcceptableConstraints(const QList<GObject *> &objects) {
+DocumentFormatConstraints ExportDocumentDialogController::getAcceptableConstraints(const QList<GObject*>& objects) {
     DocumentFormatConstraints formatConstraints;
 
     QMap<GObjectType, int> objPerTypeMap;
-    foreach (GObject *obj, objects) {
+    foreach (GObject* obj, objects) {
         GObjectType objectType = obj->getGObjectType();
         formatConstraints.supportedObjectTypes += objectType;
         if (objPerTypeMap.contains(objectType)) {
@@ -135,11 +132,11 @@ void ExportDocumentDialogController::setAddToProjectFlag(bool checked) {
     ui->addToProjCheck->setChecked(checked);
 }
 
-Document *ExportDocumentDialogController::getSourceDoc() const {
+Document* ExportDocumentDialogController::getSourceDoc() const {
     return sourceDoc;
 }
 
-GObject *ExportDocumentDialogController::getSourceObject() const {
+GObject* ExportDocumentDialogController::getSourceObject() const {
     return sourceObject;
 }
 
