@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,6 @@
 
 #include <QImageWriter>
 #include <QMessageBox>
-#include <QPushButton>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/GUrlUtils.h>
@@ -39,15 +38,15 @@
 #include "ui_ExportImageDialog.h"
 
 static const QString IMAGE_DIR = "image";
-static const char *DIALOG_ACCEPT_ERROR_TITLE = "Unable to save file";
+static const char* DIALOG_ACCEPT_ERROR_TITLE = "Unable to save file";
 
 namespace U2 {
 
-ExportImageDialog::ExportImageDialog(QWidget *screenShotWidget,
+ExportImageDialog::ExportImageDialog(QWidget* screenShotWidget,
                                      InvokedFrom invoSource,
-                                     const QString &file,
+                                     const QString& file,
                                      ImageScalingPolicy scalingPolicy,
-                                     QWidget *parent)
+                                     QWidget* parent)
     : QDialog(parent),
       scalingPolicy(scalingPolicy),
       filename(file),
@@ -57,11 +56,11 @@ ExportImageDialog::ExportImageDialog(QWidget *screenShotWidget,
     init();
 }
 
-ExportImageDialog::ExportImageDialog(ImageExportController *factory,
+ExportImageDialog::ExportImageDialog(ImageExportController* factory,
                                      InvokedFrom invoSource,
-                                     const QString &file,
+                                     const QString& file,
                                      ImageScalingPolicy scalingPolicy,
-                                     QWidget *parent)
+                                     QWidget* parent)
     : QDialog(parent),
       exportController(factory),
       scalingPolicy(scalingPolicy),
@@ -113,22 +112,22 @@ void ExportImageDialog::accept() {
     ioLog.info(tr("Saving image to '%1'...").arg(filename));
 
     ImageExportTaskSettings settings(filename, format, QSize(getWidth(), getHeight()), (hasQuality() ? getQuality() : -1), ui->dpiSpinBox->value());
-    Task *task = exportController->getTaskInstance(settings);
+    Task* task = exportController->getTaskInstance(settings);
     AppContext::getTaskScheduler()->registerTopLevelTask(task);
 
     QDialog::accept();
 }
 
-void ExportImageDialog::sl_onFormatsBoxItemChanged(const QString &format) {
-    setSizeControlsEnabled(!isVectorGraphicFormat(format));
+void ExportImageDialog::sl_onFormatsBoxItemChanged(const QString& newFormat) {
+    setSizeControlsEnabled(!isVectorGraphicFormat(newFormat));
 
-    const bool areQualityWidgetsVisible = isLossyFormat(format);
+    bool areQualityWidgetsVisible = isLossyFormat(newFormat);
     ui->qualityLabel->setVisible(areQualityWidgetsVisible);
     ui->qualityHorizontalSlider->setVisible(areQualityWidgetsVisible);
     ui->qualitySpinBox->setVisible(areQualityWidgetsVisible);
 }
 
-void ExportImageDialog::sl_showMessage(const QString &message) {
+void ExportImageDialog::sl_showMessage(const QString& message) {
     ui->hintLabel->setText(message);
     if (!message.isEmpty()) {
         ui->hintLabel->show();
@@ -196,8 +195,8 @@ void ExportImageDialog::init() {
 
     setSizeControlsEnabled(!isVectorGraphicFormat(saveController->getFormatIdToSave()));
 
-    connect(ui->formatsBox, SIGNAL(currentIndexChanged(const QString &)), exportController, SLOT(sl_onFormatChanged(const QString &)));
-    connect(ui->formatsBox, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(sl_onFormatsBoxItemChanged(const QString &)));
+    connect(ui->formatsBox, SIGNAL(currentIndexChanged(const QString&)), exportController, SLOT(sl_onFormatChanged(const QString&)));
+    connect(ui->formatsBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(sl_onFormatsBoxItemChanged(const QString&)));
 
     connect(exportController, SIGNAL(si_disableExport(bool)), SLOT(sl_disableExport(bool)));
     connect(exportController, SIGNAL(si_showMessage(QString)), SLOT(sl_showMessage(QString)));
@@ -207,7 +206,7 @@ void ExportImageDialog::init() {
         sl_showMessage(exportController->getDisableMessage());
     }
 
-    QWidget *settingsWidget = exportController->getSettingsWidget();
+    QWidget* settingsWidget = exportController->getSettingsWidget();
     if (settingsWidget == nullptr) {
         ui->settingsGroupBox->hide();
     } else {
@@ -216,7 +215,7 @@ void ExportImageDialog::init() {
     sl_onFormatsBoxItemChanged(defaultFormat);
 }
 
-void ExportImageDialog::initSaveController(const QString &defaultFormat) {
+void ExportImageDialog::initSaveController(const QString& defaultFormat) {
     LastUsedDirHelper dirHelper(IMAGE_DIR, GUrlUtils::getDefaultDataPath());
 
     SaveDocumentControllerConfig config;
@@ -231,9 +230,10 @@ void ExportImageDialog::initSaveController(const QString &defaultFormat) {
     config.rollSuffix = "_copy";
 
     SaveDocumentController::SimpleFormatsInfo formatsInfo;
-    QStringList formats = getFormats();
-    foreach (const QString &format, formats) {
-        formatsInfo.addFormat(format, QStringList() << format.toLower());
+    QStringList formatComboTexts = getFormats();
+    for (const auto& formatComboText : qAsConst(formatComboTexts)) {
+        QString fileExtension = formatComboText.toLower();
+        formatsInfo.addFormat(formatComboText, {fileExtension});
     }
 
     saveController = new SaveDocumentController(config, formatsInfo, this);
@@ -288,11 +288,11 @@ QStringList ExportImageDialog::getSvgAndPdfFormats() {
     return result;
 }
 
-bool ExportImageDialog::isVectorGraphicFormat(const QString &formatName) {
+bool ExportImageDialog::isVectorGraphicFormat(const QString& formatName) {
     return (ImageExportTaskSettings::SVG_FORMAT == formatName) || (ImageExportTaskSettings::PS_FORMAT == formatName) || (ImageExportTaskSettings::PDF_FORMAT == formatName);
 }
 
-bool ExportImageDialog::isLossyFormat(const QString &formatName) {
+bool ExportImageDialog::isLossyFormat(const QString& formatName) {
     QString lcFormat = formatName.toLower();
     return lcFormat == "jpeg" || lcFormat == "jpg";
 }
