@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,35 +34,35 @@
 
 namespace U2 {
 
-GObjectComboBoxController::GObjectComboBoxController(QObject *p, const GObjectComboBoxControllerConstraints &_c, QComboBox *_cb)
+GObjectComboBoxController::GObjectComboBoxController(QObject* p, const GObjectComboBoxControllerConstraints& _c, QComboBox* _cb)
     : QObject(p), settings(_c), combo(_cb) {
-    connect(AppContext::getProject(), SIGNAL(si_documentAdded(Document *)), SLOT(sl_onDocumentAdded(Document *)));
-    connect(AppContext::getProject(), SIGNAL(si_documentRemoved(Document *)), SLOT(sl_onDocumentRemoved(Document *)));
+    connect(AppContext::getProject(), SIGNAL(si_documentAdded(Document*)), SLOT(sl_onDocumentAdded(Document*)));
+    connect(AppContext::getProject(), SIGNAL(si_documentRemoved(Document*)), SLOT(sl_onDocumentRemoved(Document*)));
     objectIcon = QIcon(":core/images/gobject.png");
     unloadedObjectIcon = objectIcon.pixmap(QSize(16, 16), QIcon::Disabled);
     combo->setInsertPolicy(QComboBox::InsertAlphabetically);
 
-    foreach (Document *d, AppContext::getProject()->getDocuments()) {
+    foreach (Document* d, AppContext::getProject()->getDocuments()) {
         connectDocument(d);
     }
     updateCombo();
 }
 
-void GObjectComboBoxController::updateConstrains(const GObjectComboBoxControllerConstraints &c) {
+void GObjectComboBoxController::updateConstrains(const GObjectComboBoxControllerConstraints& c) {
     settings = c;
     updateCombo();
 }
 
 void GObjectComboBoxController::updateCombo() {
     combo->clear();
-    foreach (Document *d, AppContext::getProject()->getDocuments()) {
+    foreach (Document* d, AppContext::getProject()->getDocuments()) {
         addDocumentObjects(d);
     }
 
-    QList<GObject *> allObjs = GObjectUtils::findAllObjects(UOF_LoadedAndUnloaded);
+    QList<GObject*> allObjs = GObjectUtils::findAllObjects(UOF_LoadedAndUnloaded);
     for (int i = 0, n = combo->count(); i < n; i++) {  // prefocus on loaded object if possible
         GObjectReference ref = combo->itemData(i).value<GObjectReference>();
-        GObject *obj = GObjectUtils::selectObjectByReference(ref, allObjs, UOF_LoadedAndUnloaded);
+        GObject* obj = GObjectUtils::selectObjectByReference(ref, allObjs, UOF_LoadedAndUnloaded);
         if (!obj->isUnloaded()) {
             combo->setCurrentIndex(i);
             break;
@@ -70,26 +70,24 @@ void GObjectComboBoxController::updateCombo() {
     }
 }
 
-void GObjectComboBoxController::connectDocument(Document *document) {
-    if (document->isDatabaseConnection()) {
-        return;
-    }
-    connect(document, SIGNAL(si_objectAdded(GObject *)), SLOT(sl_onObjectAdded(GObject *)));
-    connect(document, SIGNAL(si_objectRemoved(GObject *)), SLOT(sl_onObjectRemoved(GObject *)));
+void GObjectComboBoxController::connectDocument(Document* document) {
+    connect(document, SIGNAL(si_objectAdded(GObject*)), SLOT(sl_onObjectAdded(GObject*)));
+    connect(document, SIGNAL(si_objectRemoved(GObject*)), SLOT(sl_onObjectRemoved(GObject*)));
 }
 
-void GObjectComboBoxController::addDocumentObjects(Document *d) {
-    if (d->isDatabaseConnection()) {
-        return;
-    }
+void GObjectComboBoxController::addDocumentObjects(Document* d) {
     // checks whether you need to add a new annotations table
     QString docUrl = settings.relationFilter.ref.docUrl;
     if (d->getURLString() == docUrl) {
-        connect(d->getObjectById(settings.relationFilter.ref.entityRef.entityId), SIGNAL(si_lockedStateChanged()), SLOT(sl_lockedStateChanged()));
+        GObject* seqObj = d->getObjectById(settings.relationFilter.ref.entityRef.entityId);
+        if (seqObj != nullptr) {
+            connect(seqObj, &GObject::si_lockedStateChanged, this, &GObjectComboBoxController::sl_lockedStateChanged);
+        }
+
         bool hasAnnotationTable = false;
-        QList<GObject *> listAnnotations = d->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
+        QList<GObject*> listAnnotations = d->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
         if (listAnnotations.size() != 0) {
-            foreach (GObject *obj, listAnnotations) {
+            foreach (GObject* obj, listAnnotations) {
                 if (obj->hasObjectRelation(settings.relationFilter)) {
                     hasAnnotationTable = true;
                     break;
@@ -98,7 +96,8 @@ void GObjectComboBoxController::addDocumentObjects(Document *d) {
         }
         if ((!hasAnnotationTable) && (!d->isStateLocked()) && (d->getDocumentFormat()->checkFlags(DocumentFormatFlag_SupportWriting)) && (d->getDocumentFormat()->getSupportedObjectTypes().contains(GObjectTypes::ANNOTATION_TABLE))) {
             QString virtualItemText = d->getName() + " [";
-            GObject *seqObj = d->getObjectById(settings.relationFilter.ref.entityRef.entityId);
+            CHECK(seqObj != nullptr, );
+
             virtualItemText.append(seqObj->getGObjectName() + FEATURES_TAG + "] *");
             combo->addItem(objectIcon, virtualItemText, QVariant::fromValue<GObjectReference>(GObjectReference(seqObj)));
 
@@ -106,26 +105,23 @@ void GObjectComboBoxController::addDocumentObjects(Document *d) {
             return;
         }
     }
-    foreach (GObject *obj, d->getObjects()) {
+    foreach (GObject* obj, d->getObjects()) {
         addObject(obj);
     }
 }
 
-void GObjectComboBoxController::removeDocumentObjects(Document *d) {
-    if (d->isDatabaseConnection()) {
-        return;
-    }
-    foreach (GObject *obj, d->getObjects()) {
-        removeObject(obj);
+void GObjectComboBoxController::removeDocumentObjects(Document* d) {
+    foreach (GObject* obj, d->getObjects()) {
+        removeObject(obj->getReference());
     }
 }
 
-QString GObjectComboBoxController::itemText(GObject *o) {
+QString GObjectComboBoxController::itemText(GObject* o) {
     QString res = o->getDocument()->getName() + " [" + o->getGObjectName() + "]";
     return res;
 }
 
-static int findItem(QComboBox *cb, const GObjectReference &objRef) {
+static int findItem(QComboBox* cb, const GObjectReference& objRef) {
     for (int i = 0; i < cb->count(); i++) {
         GObjectReference ref = cb->itemData(i).value<GObjectReference>();
         if (ref == objRef) {
@@ -135,14 +131,14 @@ static int findItem(QComboBox *cb, const GObjectReference &objRef) {
     return -1;
 }
 
-void GObjectComboBoxController::addObject(GObject *obj) {
+void GObjectComboBoxController::addObject(GObject* obj) {
     GObjectType t = obj->getGObjectType();
     if (settings.uof == UOF_LoadedOnly && t == GObjectTypes::UNLOADED) {
         return;
     }
     if (!settings.typeFilter.isEmpty()) {
         if (t == GObjectTypes::UNLOADED && settings.uof == UOF_LoadedAndUnloaded) {
-            t = qobject_cast<UnloadedObject *>(obj)->getLoadedObjectType();
+            t = qobject_cast<UnloadedObject*>(obj)->getLoadedObjectType();
         }
         if (t != settings.typeFilter) {
             return;
@@ -161,7 +157,7 @@ void GObjectComboBoxController::addObject(GObject *obj) {
     }
 
 #ifdef _DEBUG
-    int n = findItem(combo, obj);
+    int n = findItem(combo, obj->getReference());
     assert(n == -1);
 #endif
     connect(obj, SIGNAL(si_lockedStateChanged()), SLOT(sl_lockedStateChanged()));
@@ -170,7 +166,7 @@ void GObjectComboBoxController::addObject(GObject *obj) {
     emit si_comboBoxChanged();
 }
 
-void GObjectComboBoxController::removeObject(const GObjectReference &ref) {
+void GObjectComboBoxController::removeObject(const GObjectReference& ref) {
     int n = findItem(combo, ref);
     if (n >= 0) {
         combo->removeItem(n);
@@ -181,7 +177,7 @@ void GObjectComboBoxController::removeObject(const GObjectReference &ref) {
     }
 }
 
-bool GObjectComboBoxController::setSelectedObject(const GObjectReference &objRef) {
+bool GObjectComboBoxController::setSelectedObject(const GObjectReference& objRef) {
     int n = findItem(combo, objRef);
     if (n < 0) {
         return false;
@@ -191,50 +187,50 @@ bool GObjectComboBoxController::setSelectedObject(const GObjectReference &objRef
 }
 
 GObjectReference GObjectComboBoxController::getSelectedObjectReference() const {
-    GObject *object = getSelectedObject();
-    if (nullptr != object) {
+    GObject* object = getSelectedObject();
+    if (object != nullptr) {
         return GObjectReference(object);
     } else {
         return GObjectReference();
     }
 }
 
-GObject *GObjectComboBoxController::getSelectedObject() const {
+GObject* GObjectComboBoxController::getSelectedObject() const {
     int n = combo->currentIndex();
     if (n == -1) {
         return nullptr;
     }
     GObjectReference r = combo->itemData(n).value<GObjectReference>();
     SAFE_POINT(r.isValid(), "GObjectReverence is invalid", nullptr);
-    GObject *obj = GObjectUtils::selectObjectByReference(r, GObjectUtils::findAllObjects(UOF_LoadedAndUnloaded), UOF_LoadedAndUnloaded);
+    GObject* obj = GObjectUtils::selectObjectByReference(r, GObjectUtils::findAllObjects(UOF_LoadedAndUnloaded), UOF_LoadedAndUnloaded);
     assert(obj != nullptr);
     return obj;
 }
 
-void GObjectComboBoxController::sl_onDocumentAdded(Document *d) {
+void GObjectComboBoxController::sl_onDocumentAdded(Document* d) {
     connectDocument(d);
     if (d->isLoaded()) {
         addDocumentObjects(d);
     }
 }
 
-void GObjectComboBoxController::sl_onDocumentRemoved(Document *d) {
+void GObjectComboBoxController::sl_onDocumentRemoved(Document* d) {
     if (d->isLoaded()) {
         removeDocumentObjects(d);
     }
 }
 
-void GObjectComboBoxController::sl_onObjectAdded(GObject *obj) {
+void GObjectComboBoxController::sl_onObjectAdded(GObject* obj) {
     Q_UNUSED(obj);
     updateCombo();
 }
 
-void GObjectComboBoxController::sl_onObjectRemoved(GObject *obj) {
-    Document *doc = qobject_cast<Document *>(sender());
+void GObjectComboBoxController::sl_onObjectRemoved(GObject* obj) {
+    auto doc = qobject_cast<Document*>(sender());
     assert(doc != nullptr);
     QString t = obj->getGObjectType();
     if (t == GObjectTypes::UNLOADED && settings.uof == UOF_LoadedAndUnloaded) {
-        t = qobject_cast<UnloadedObject *>(obj)->getLoadedObjectType();
+        t = qobject_cast<UnloadedObject*>(obj)->getLoadedObjectType();
     }
     removeObject(GObjectReference(doc->getURLString(), obj->getGObjectName(), t));
     obj->disconnect(this);
@@ -244,11 +240,11 @@ void GObjectComboBoxController::sl_lockedStateChanged() {
     if (!settings.onlyWritable) {
         return;
     }
-    GObject *obj = qobject_cast<GObject *>(sender());
+    auto obj = qobject_cast<GObject*>(sender());
     if (obj->isStateLocked()) {
-        removeObject(obj);
+        removeObject(obj->getReference());
     } else {
-        if (findItem(combo, obj) == -1) {
+        if (findItem(combo, obj->getReference()) == -1) {
             updateCombo();
         }
     }
