@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GSCROLL_BAR_H_
-#define _U2_GSCROLL_BAR_H_
+#pragma once
 
 #include <QScrollBar>
 
@@ -31,7 +30,7 @@ namespace U2 {
 class U2GUI_EXPORT GScrollBar : public QScrollBar {
     Q_OBJECT
 public:
-    GScrollBar(Qt::Orientation o, QWidget *p = 0)
+    GScrollBar(Qt::Orientation o, QWidget* p = 0)
         : QScrollBar(o, p) {
     }
 
@@ -45,5 +44,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
