@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GENBANK_LOCATION_VALIDATOR_PARSER_H
-#define _U2_GENBANK_LOCATION_VALIDATOR_PARSER_H
+#pragma once
 
 #include <QValidator>
 
@@ -31,19 +30,18 @@ namespace U2 {
 
 class GenbankLocationValidator : public QValidator {
 public:
-    GenbankLocationValidator(QPushButton *okButton, int length, bool isCircular, QLineEdit *le);
+    GenbankLocationValidator(QPushButton* okButton, int length, bool isCircular, QLineEdit* le);
     ~GenbankLocationValidator();
 
-    State validate(QString &str, int &ii) const;
+    State validate(QString& str, int& ii) const;
 
 private:
     State failValidate() const;
 
-    QPushButton *okButton;
+    QPushButton* okButton;
     bool isCircular;
     int seqLen;
-    QLineEdit *le;
+    QLineEdit* le;
 };
 
 }  // namespace U2
-#endif
