@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,6 @@
  * MA 02110-1301, USA.
  */
 
-#include <math.h>
-
 #include <QPainter>
 #include <QVector>
 
@@ -39,22 +37,20 @@ GraphUtils::ArrowConfig::ArrowConfig()
       direction(LeftToRight) {
 }
 
-static void drawNum(QPainter &p, int x1, int x2, const QString &num, int lBorder, int rBorder, int y1, int y2) {
-    if (x1 < lBorder || x2 > rBorder) {
-        return;
-    }
+static void drawNum(QPainter& p, int x1, int x2, const QString& num, int lBorder, int rBorder, int y1, int y2) {
+    CHECK(x1 >= lBorder && x2 <= rBorder, );
     QRect rect(x1, y1, x2 - x1 + 1, y2 - y1 + 1);
     p.drawText(rect, Qt::AlignVCenter | Qt::AlignHCenter, num);
 }
 
 #define MIN_RULER_LEN 10
-void GraphUtils::drawRuler(QPainter &p, const QPoint &pos, qint64 len, qint64 start, qint64 end, const QFont &font, const RulerConfig &c) {
+void GraphUtils::drawRuler(QPainter& p, const QPoint& pos, qint64 len, qint64 start, qint64 end, const QFont& font, const RulerConfig& c) {
     if (start == end || len < MIN_RULER_LEN) {
         return;
     }
     p.save();
 
-    assert(c.drawArrow ? c.drawAxis : true);
+    SAFE_POINT(c.drawArrow ? c.drawAxis : true, "drawAxis must be enabled when drawArrow is true", );
 
     p.setFont(font);
     QFontMetrics fm(font);
@@ -73,6 +69,7 @@ void GraphUtils::drawRuler(QPainter &p, const QPoint &pos, qint64 len, qint64 st
         chunk /= 2;
     }
     float scale = len / (float)span;
+    int minXSpaceBetweenNumbers = 5;  // Minimum horizontal space between sibling numbers in pixels.
     if (c.direction == BottomToTop) {
         if (c.drawAxis) {
             p.drawLine(pos.x(), pos.y() - c.extraAxisLenBefore, pos.x(), pos.y() + len + c.extraAxisLenAfter);
@@ -208,7 +205,7 @@ void GraphUtils::drawRuler(QPainter &p, const QPoint &pos, qint64 len, qint64 st
                         QString snum = FormatUtils::formatNumber(currnotch);
                         int notchleft = pos.x() + x - snum.length() * cw / 2;
                         int notchright = notchleft + snum.length() * cw;
-                        drawNum(p, notchleft, notchright, snum, leftborder, rightborder, yt1, yt2);
+                        drawNum(p, notchleft, notchright, snum, leftborder + minXSpaceBetweenNumbers, rightborder - minXSpaceBetweenNumbers, yt1, yt2);
                     }
                 }
             }
@@ -235,7 +232,7 @@ void GraphUtils::drawRuler(QPainter &p, const QPoint &pos, qint64 len, qint64 st
                         QString snum = FormatUtils::formatNumber(currnotch);
                         int notchleft = pos.x() + len - x - snum.length() * cw / 2;
                         int notchright = notchleft + snum.length() * cw;
-                        drawNum(p, notchleft, notchright, snum, leftborder, rightborder, yt1, yt2);
+                        drawNum(p, notchleft, notchright, snum, leftborder + minXSpaceBetweenNumbers, rightborder - minXSpaceBetweenNumbers, yt1, yt2);
                     }
                 }
             }
@@ -299,7 +296,7 @@ static QVector<QColor> prepareColors() {
     return colors;
 }
 
-QColor GraphUtils::proposeLightColorByKey(const QString &key) {
+QColor GraphUtils::proposeLightColorByKey(const QString& key) {
     // TODO: make thread safe!
     static QVector<QColor> colors = prepareColors();
 
@@ -311,7 +308,7 @@ QColor GraphUtils::proposeLightColorByKey(const QString &key) {
     return colors.at((hash * hash) % colors.size());
 }
 
-int GraphUtils::calculateChunk(qint64 start, qint64 end, qint64 len, const QPainter &p) {
+int GraphUtils::calculateChunk(qint64 start, qint64 end, qint64 len, const QPainter& p) {
     QFontMetrics fm = p.fontMetrics();
     int cw = fm.size(Qt::TextSingleLine, "0").width();
     // the width of the bigger number
@@ -372,7 +369,7 @@ qint64 GraphUtils::pickRoundedNumberBelow(qint64 maxVal) {
     return res;
 }
 
-void GraphUtils::drawArrow(QPainter &painter, const QRectF &rect, const ArrowConfig &config) {
+void GraphUtils::drawArrow(QPainter& painter, const QRectF& rect, const ArrowConfig& config) {
     SAFE_POINT(LeftToRight == config.direction || RightToLeft == config.direction, "Vertical arrows drawing is not implemented", );
     painter.save();
 
