@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GRAPH_UTILS_H_
-#define _U2_GRAPH_UTILS_H_
+#pragma once
 
 #include <QColor>
 
@@ -96,11 +95,11 @@ public:
         Direction direction;
     };
 
-    static void drawRuler(QPainter &p, const QPoint &pos, qint64 len, qint64 start, qint64 end, const QFont &f, const RulerConfig &config);
-    static int calculateChunk(qint64 start, qint64 end, qint64 len, const QPainter &p);
+    static void drawRuler(QPainter& p, const QPoint& pos, qint64 len, qint64 start, qint64 end, const QFont& f, const RulerConfig& config);
+    static int calculateChunk(qint64 start, qint64 end, qint64 len, const QPainter& p);
     static int findChunk(qint64 len, qint64 span, int N);
 
-    static QColor proposeLightColorByKey(const QString &key);
+    static QColor proposeLightColorByKey(const QString& key);
 
     /*
        The method is designed to be used by different algorithms that needs to
@@ -112,9 +111,7 @@ public:
     */
     static qint64 pickRoundedNumberBelow(qint64 maxVal);
 
-    static void drawArrow(QPainter &painter, const QRectF &rect, const ArrowConfig &config);
+    static void drawArrow(QPainter& painter, const QRectF& rect, const ArrowConfig& config);
 };
 
 }  // namespace U2
-
-#endif  // _U2_GRAPH_UTILS_H_
