@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -18,8 +18,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA 02110-1301, USA.
  */
-#ifndef _U2_HELP_BUTTON_H_
-#define _U2_HELP_BUTTON_H_
+#pragma once
 
 #include <QAbstractButton>
 #include <QButtonGroup>
@@ -38,32 +37,31 @@ namespace U2 {
 class U2GUI_EXPORT HelpButton : public QObject {
     Q_OBJECT
 public:
-    HelpButton(QObject *parent, QDialogButtonBox *b, const QString &pageId);
-    HelpButton(QObject *parent, QAbstractButton *b, const QString &pageId);
+    HelpButton(QObject* parent, QDialogButtonBox* b, const QString& pageId);
+    HelpButton(QObject* parent, QAbstractButton* b, const QString& pageId);
 
-    void updatePageId(const QString &pageId);
+    void updatePageId(const QString& pageId);
 
 protected slots:
     virtual void sl_buttonClicked();
 
 protected:
     QString pageId;
-    QPushButton *helpButton;
-    QDialogButtonBox *dialogBox;
+    QPushButton* helpButton;
+    QDialogButtonBox* dialogBox;
 };
 
 class U2GUI_EXPORT ComboboxDependentHelpButton : public HelpButton {
     Q_OBJECT
 public:
-    ComboboxDependentHelpButton(QObject *parent, QDialogButtonBox *b, QComboBox *cb, const QMap<QString, QString> &pageMap);
+    ComboboxDependentHelpButton(QObject* parent, QDialogButtonBox* b, QComboBox* cb, const QMap<QString, QString>& pageMap);
 
 protected slots:
     void sl_buttonClicked() override;
 
 private:
     const QMap<QString, QString> pageMap;
-    const QComboBox *cb;
+    const QComboBox* cb;
 };
 
 }  // namespace U2
-#endif
