@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -18,8 +18,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA 02110-1301, USA.
  */
-#ifndef _U2_HOVER_QLABEL_H_
-#define _U2_HOVER_QLABEL_H_
+#pragma once
 
 #include <QLabel>
 
@@ -30,16 +29,16 @@ namespace U2 {
 class U2GUI_EXPORT HoverQLabel : public QLabel {
     Q_OBJECT
 public:
-    HoverQLabel(const QString &html, const QString &normalStyle, const QString &hoveredStyle, const QString &objectName = QString());
-    void updateStyles(const QString &newNormalStyle, const QString &newHoveredStyle);
+    HoverQLabel(const QString& html, const QString& normalStyle, const QString& hoveredStyle, const QString& objectName = QString());
+    void updateStyles(const QString& newNormalStyle, const QString& newHoveredStyle);
 
 signals:
     void clicked();
 
 protected:
-    void enterEvent(QEvent *event);
-    void leaveEvent(QEvent *event);
-    void mousePressEvent(QMouseEvent *event);
+    void enterEvent(QEvent* event);
+    void leaveEvent(QEvent* event);
+    void mousePressEvent(QMouseEvent* event);
 
 public:
     QString normalStyle;
@@ -48,4 +47,3 @@ public:
 };
 
 }  // namespace U2
-#endif
