@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_SEQUENCE_FROM_RAW_DATA_TASK_H_
-#define _U2_IMPORT_SEQUENCE_FROM_RAW_DATA_TASK_H_
+#pragma once
 
 #include <U2Core/DNASequence.h>
 #include <U2Core/Task.h>
@@ -31,10 +30,10 @@ namespace U2 {
 class ImportSequenceFromRawDataTask : public Task {
     Q_OBJECT
 public:
-    ImportSequenceFromRawDataTask(const U2DbiRef &dbiRef, const QString &folder, const DNASequence &sequence);
+    ImportSequenceFromRawDataTask(const U2DbiRef& dbiRef, const QString& folder, const DNASequence& sequence);
 
     QString getSequenceName() const;
-    const U2EntityRef &getEntityRef() const;
+    const U2EntityRef& getEntityRef() const;
 
 private:
     void run();
@@ -47,5 +46,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_SEQUENCE_FROM_RAW_DATA_TASK_H_
