@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_APR_IMPORT_WIDGET_H_
-#define _U2_APR_IMPORT_WIDGET_H_
+#pragma once
 
 #include <U2Formats/AprImporter.h>
 
@@ -34,16 +33,14 @@ class SaveDocumentController;
 class AprImportWidget : public ImportWidget, public Ui_AprImportWidget {
     Q_OBJECT
 public:
-    AprImportWidget(const GUrl &url, const QVariantMap &settings);
+    AprImportWidget(const GUrl& url, const QVariantMap& settings);
     virtual QVariantMap getSettings() const;
 
-    void initSaveController(const QString &url, const DocumentFormatId defaultFormatId);
+    void initSaveController(const QString& url, const DocumentFormatId defaultFormatId);
 
 private:
-    DocumentFormatId getFormatId(const QVariantMap &settings);
+    DocumentFormatId getFormatId(const QVariantMap& settings);
     static QString getDefaultValues();
 };
 
 }  // namespace U2
-
-#endif  // _U2_APR_IMPORT_WIDGET_H_
