@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,15 +19,13 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_WIDGET_H_
-#define _U2_IMPORT_WIDGET_H_
+#pragma once
 
 #include <QWidget>
 
 namespace U2 {
 
 #define ImportHint_FormatId "import-hint-format-id"
-#define ImportHint_DestinationUrl "import-hint-destination-url"
 
 class SaveDocumentController;
 
@@ -39,9 +37,7 @@ public:
     virtual QVariantMap getSettings() const = 0;
 
 protected:
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_WIDGET_H_
