@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_WIDGETS_H_
-#define _U2_IMPORT_WIDGETS_H_
+#pragma once
 
 #include <U2Core/DocumentImport.h>
 
@@ -42,14 +41,12 @@ public:
 
 class AceImportWidgetFactory : public ImportWidgetFactory {
 public:
-    virtual ImportWidget *getWidget(const GUrl &url, const QVariantMap &settings) const;
+    virtual ImportWidget* getWidget(const GUrl& url, const QVariantMap& settings) const;
 };
 
 class AprImportWidgetFactory : public ImportWidgetFactory {
 public:
-    virtual ImportWidget *getWidget(const GUrl &url, const QVariantMap &settings) const;
+    virtual ImportWidget* getWidget(const GUrl& url, const QVariantMap& settings) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_WIDGETS_H_
