@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,19 +29,19 @@
 
 namespace U2 {
 
-LabelClickTransmitter::LabelClickTransmitter(QLabel *label, QAbstractButton *button)
+LabelClickTransmitter::LabelClickTransmitter(QLabel* label, QAbstractButton* button)
     : QObject(label), label(label), button(button) {
     label->installEventFilter(this);
 }
 
-bool LabelClickTransmitter::eventFilter(QObject *object, QEvent *event) {
-    CHECK(nullptr != label, false);
-    CHECK(nullptr != button, false);
+bool LabelClickTransmitter::eventFilter(QObject* object, QEvent* event) {
+    CHECK(label != nullptr, false);
+    CHECK(button != nullptr, false);
     CHECK(label == object, false);
 
     CHECK(QEvent::MouseButtonRelease == event->type(), false);
-    QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent *>(event);
-    CHECK(nullptr != event, false);
+    auto mouseEvent = dynamic_cast<QMouseEvent*>(event);
+    CHECK(event != nullptr, false);
     CHECK(Qt::LeftButton == mouseEvent->button(), false);
 
     button->toggle();
