@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LABEL_CLICK_TRANSMITTER_H_
-#define _U2_LABEL_CLICK_TRANSMITTER_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -31,15 +30,13 @@ namespace U2 {
 
 class U2GUI_EXPORT LabelClickTransmitter : public QObject {
 public:
-    LabelClickTransmitter(QLabel *label, QAbstractButton *button);
+    LabelClickTransmitter(QLabel* label, QAbstractButton* button);
 
 private:
-    bool eventFilter(QObject *object, QEvent *event);
+    bool eventFilter(QObject* object, QEvent* event);
 
-    QLabel *label;
-    QAbstractButton *button;
+    QLabel* label;
+    QAbstractButton* button;
 };
 
 }  // namespace U2
-
-#endif  // _U2_LABEL_CLICK_TRANSMITTER_H_
