@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LAST_USED_DIR_HELPER_H_
-#define _U2_LAST_USED_DIR_HELPER_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -28,15 +27,15 @@ namespace U2 {
 
 class U2GUI_EXPORT LastUsedDirHelper {
 public:
-    LastUsedDirHelper(const QString &domain = QString(), const QString &defaultVal = QString());  // reads dir
+    LastUsedDirHelper(const QString& domain = QString(), const QString& defaultVal = QString());  // reads dir
 
     virtual ~LastUsedDirHelper();  // if url is not empty -> derives dir from url and stores it
 
-    static QString getLastUsedDir(const QString &toolType = QString(), const QString &defaultVal = QString());
+    static QString getLastUsedDir(const QString& toolType = QString(), const QString& defaultVal = QString());
 
-    static void setLastUsedDir(const QString &ld, const QString &toolType = QString());
+    static void setLastUsedDir(const QString& ld, const QString& toolType = QString());
 
-    operator const QString &() const {
+    operator const QString&() const {
         return dir;
     }
 
@@ -52,5 +51,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
