@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,7 +28,7 @@
 
 namespace U2 {
 
-LocalToolbar::LocalToolbar(QWidget *p)
+LocalToolbar::LocalToolbar(QWidget* p)
     : OrderedToolbar(p, Qt::Vertical) {
     setBackgroundRole(QPalette::Window);
     setAutoFillBackground(true);
@@ -40,10 +40,10 @@ LocalToolbar::LocalToolbar(QWidget *p)
     setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
 }
 
-void LocalToolbar::addAction(QAction *a) {
+void LocalToolbar::addAction(QAction* a) {
     QToolBar::addAction(a);
 
-    QToolButton *button = qobject_cast<QToolButton *>(widgetForAction(a));
+    auto button = qobject_cast<QToolButton*>(widgetForAction(a));
     button->setFixedSize(TOOLBAR_BUTTON_SIZE, TOOLBAR_BUTTON_SIZE);
 }
 
