@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LOCAL_TOOLBAR_H_
-#define _U2_LOCAL_TOOLBAR_H_
+#pragma once
 
 #include <QToolBar>
 
@@ -32,11 +31,9 @@ namespace U2 {
 
 class U2GUI_EXPORT LocalToolbar : public OrderedToolbar {
 public:
-    LocalToolbar(QWidget *p);
+    LocalToolbar(QWidget* p);
 
-    virtual void addAction(QAction *a);
+    virtual void addAction(QAction* a);
 };
 
 }  // namespace U2
-
-#endif  // _U2_LOCAL_TOOLBAR_H_
