@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MULTI_CLICK_MENU_H_
-#define _U2_MULTI_CLICK_MENU_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -34,15 +33,13 @@ namespace U2 {
  */
 class U2GUI_EXPORT MultiClickMenu : public QObject {
 public:
-    MultiClickMenu(QMenu *menu);
+    MultiClickMenu(QMenu* menu);
 
 private:
-    bool eventFilter(QObject *watched, QEvent *event);
-    bool isSelectEvent(QEvent *event);
+    bool eventFilter(QObject* watched, QEvent* event);
+    bool isSelectEvent(QEvent* event);
 
-    QMenu *menu;
+    QMenu* menu;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MULTI_CLICK_MENU_H_
