@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@
 
 namespace U2 {
 
-ObjectViewTreeController::ObjectViewTreeController(QTreeWidget *w)
+ObjectViewTreeController::ObjectViewTreeController(QTreeWidget* w)
     : QObject(w), tree(w) {
     bookmarkStateIcon = QIcon(":core/images/bookmark_item.png");
     bookmarkActiveIcon = QIcon(":core/images/bookmark.png");
@@ -47,37 +47,42 @@ ObjectViewTreeController::ObjectViewTreeController(QTreeWidget *w)
     tree->setContextMenuPolicy(Qt::CustomContextMenu);
     tree->setObjectName(ACTION_BOOKMARK_TREE_VIEW);
 
-    connect(tree, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)), SLOT(sl_onTreeCurrentChanged(QTreeWidgetItem *, QTreeWidgetItem *)));
-    connect(tree, SIGNAL(customContextMenuRequested(const QPoint &)), SLOT(sl_onContextMenuRequested(const QPoint &)));
-    connect(tree, SIGNAL(itemActivated(QTreeWidgetItem *, int)), SLOT(sl_onItemActivated(QTreeWidgetItem *, int)));
-    connect(tree, SIGNAL(itemChanged(QTreeWidgetItem *, int)), SLOT(sl_onItemChanged(QTreeWidgetItem *, int)));
+    connect(tree, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), SLOT(sl_onTreeCurrentChanged(QTreeWidgetItem*, QTreeWidgetItem*)));
+    connect(tree, SIGNAL(customContextMenuRequested(const QPoint&)), SLOT(sl_onContextMenuRequested(const QPoint&)));
+    connect(tree, SIGNAL(itemActivated(QTreeWidgetItem*, int)), SLOT(sl_onItemActivated(QTreeWidgetItem*, int)));
+    connect(tree, SIGNAL(itemChanged(QTreeWidgetItem*, int)), SLOT(sl_onItemChanged(QTreeWidgetItem*, int)));
 
     activateViewAction = new QAction(tr("Activate view"), this);
     activateViewAction->setObjectName(ACTION_ACTIVATE_VIEW);
     activateViewAction->setShortcut(QKeySequence(Qt::Key_Space));
     activateViewAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(activateViewAction, SIGNAL(triggered()), SLOT(sl_activateView()));
+    connect(activateViewAction, &QAction::triggered, this, &ObjectViewTreeController::sl_activateView);
 
     addStateAction = new QAction(tr("Add bookmark"), this);
     addStateAction->setObjectName(ACTION_ADD_BOOKMARK);
     addStateAction->setIcon(QIcon(":core/images/bookmark_add.png"));
-    connect(addStateAction, SIGNAL(triggered()), SLOT(sl_addState()));
+    connect(addStateAction, &QAction::triggered, this, &ObjectViewTreeController::sl_addState);
+
+    updateStateAction = new QAction(tr("Update bookmark"), this);
+    updateStateAction->setObjectName(ACTION_UPDATE_BOOKMARK);
+    connect(updateStateAction, &QAction::triggered, this, &ObjectViewTreeController::sl_updateState);
 
     removeStateAction = new QAction(tr("Remove bookmark"), this);
     removeStateAction->setObjectName(ACTION_REMOVE_BOOKMARK);
     removeStateAction->setIcon(QIcon(":core/images/bookmark_remove.png"));
     removeStateAction->setShortcut(QKeySequence(Qt::Key_Delete));
     removeStateAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(removeStateAction, SIGNAL(triggered()), SLOT(sl_removeState()));
+    connect(removeStateAction, &QAction::triggered, this, &ObjectViewTreeController::sl_removeState);
 
     renameStateAction = new QAction(tr("Rename bookmark"), this);
     renameStateAction->setObjectName(ACTION_RENAME_BOOKMARK);
     renameStateAction->setIcon(QIcon(":core/images/bookmark_edit.png"));
     renameStateAction->setShortcut(QKeySequence(Qt::Key_F2));
     renameStateAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(renameStateAction, SIGNAL(triggered()), SLOT(sl_renameState()));
+    connect(renameStateAction, &QAction::triggered, this, &ObjectViewTreeController::sl_renameState);
 
     tree->addAction(activateViewAction);
+    tree->addAction(updateStateAction);
     tree->addAction(removeStateAction);
     tree->addAction(renameStateAction);
 
@@ -88,36 +93,36 @@ ObjectViewTreeController::ObjectViewTreeController(QTreeWidget *w)
 }
 
 void ObjectViewTreeController::connectModel() {
-    Project *p = AppContext::getProject();
-    connect(p, SIGNAL(si_objectViewStateAdded(GObjectViewState *)), SLOT(sl_onViewStateAdded(GObjectViewState *)));
-    connect(p, SIGNAL(si_objectViewStateRemoved(GObjectViewState *)), SLOT(sl_onViewStateRemoved(GObjectViewState *)));
+    Project* p = AppContext::getProject();
+    connect(p, SIGNAL(si_objectViewStateAdded(GObjectViewState*)), SLOT(sl_onViewStateAdded(GObjectViewState*)));
+    connect(p, SIGNAL(si_objectViewStateRemoved(GObjectViewState*)), SLOT(sl_onViewStateRemoved(GObjectViewState*)));
 
-    MWMDIManager *mdi = AppContext::getMainWindow()->getMDIManager();
-    connect(mdi, SIGNAL(si_windowAdded(MWMDIWindow *)), SLOT(sl_onMdiWindowAdded(MWMDIWindow *)));
-    connect(mdi, SIGNAL(si_windowClosing(MWMDIWindow *)), SLOT(sl_onMdiWindowClosing(MWMDIWindow *)));
+    MWMDIManager* mdi = AppContext::getMainWindow()->getMDIManager();
+    connect(mdi, SIGNAL(si_windowAdded(MWMDIWindow*)), SLOT(sl_onMdiWindowAdded(MWMDIWindow*)));
+    connect(mdi, SIGNAL(si_windowClosing(MWMDIWindow*)), SLOT(sl_onMdiWindowClosing(MWMDIWindow*)));
 
-    connect(mdi, SIGNAL(si_windowActivated(MWMDIWindow *)), SLOT(sl_onMdiWindowActivated(MWMDIWindow *)));
+    connect(mdi, SIGNAL(si_windowActivated(MWMDIWindow*)), SLOT(sl_onMdiWindowActivated(MWMDIWindow*)));
 }
 
 void ObjectViewTreeController::buildTree() {
     tree->clear();
 
-    const QList<GObjectViewState *> &states = AppContext::getProject()->getGObjectViewStates();
-    foreach (GObjectViewState *s, states) {
+    const QList<GObjectViewState*>& states = AppContext::getProject()->getGObjectViewStates();
+    foreach (GObjectViewState* s, states) {
         addState(s);
     }
 
-    QList<GObjectViewWindow *> views = GObjectViewUtils::getAllActiveViews();
-    foreach (GObjectViewWindow *v, views) {
+    QList<GObjectViewWindow*> views = GObjectViewUtils::getAllActiveViews();
+    foreach (GObjectViewWindow* v, views) {
         addViewWindow(v);
     }
 }
 
-void ObjectViewTreeController::addViewWindow(GObjectViewWindow *viewWindow) {
+void ObjectViewTreeController::addViewWindow(GObjectViewWindow* viewWindow) {
     viewWindow->installEventFilter(this);
-    connect(viewWindow, SIGNAL(si_persistentStateChanged(GObjectViewWindow *)), SLOT(sl_onViewPersistentStateChanged(GObjectViewWindow *)));
-    connect(viewWindow->getObjectView(), SIGNAL(si_nameChanged(const QString &)), SLOT(sl_onViewNameChanged(const QString &)));
-    OVTViewItem *vi = findViewItem(viewWindow->getViewName());
+    connect(viewWindow, SIGNAL(si_persistentStateChanged(GObjectViewWindow*)), SLOT(sl_onViewPersistentStateChanged(GObjectViewWindow*)));
+    connect(viewWindow->getObjectView(), SIGNAL(si_nameChanged(const QString&)), SLOT(sl_onViewNameChanged(const QString&)));
+    OVTViewItem* vi = findViewItem(viewWindow->getViewName());
     if (vi == nullptr) {
         vi = new OVTViewItem(viewWindow, this);
         tree->addTopLevelItem(vi);
@@ -132,13 +137,13 @@ void ObjectViewTreeController::addViewWindow(GObjectViewWindow *viewWindow) {
     }
 }
 
-OVTStateItem *ObjectViewTreeController::addState(GObjectViewState *s) {
-    OVTViewItem *vi = findViewItem(s->getViewName());
+OVTStateItem* ObjectViewTreeController::addState(GObjectViewState* s) {
+    OVTViewItem* vi = findViewItem(s->getViewName());
     if (vi == nullptr) {
         vi = new OVTViewItem(s->getViewName(), this);
         tree->addTopLevelItem(vi);
     }
-    OVTStateItem *si = findStateItem(s);
+    OVTStateItem* si = findStateItem(s);
     SAFE_POINT(si == nullptr, QString("State item is already exists: %1 -> %2").arg(s->getViewName()).arg(s->getStateName()), si);
     si = new OVTStateItem(s, vi, this);
     si->setIcon(0, bookmarkStateIcon);
@@ -146,10 +151,10 @@ OVTStateItem *ObjectViewTreeController::addState(GObjectViewState *s) {
     return si;
 }
 
-void ObjectViewTreeController::removeState(GObjectViewState *s) {
-    OVTStateItem *si = findStateItem(s);
+void ObjectViewTreeController::removeState(GObjectViewState* s) {
+    OVTStateItem* si = findStateItem(s);
     SAFE_POINT(si != nullptr, QString("Failed to find state item to remove: %1 -> %2").arg(s->getViewName()).arg(s->getStateName()), );
-    OVTViewItem *vi = static_cast<OVTViewItem *>(si->parent());
+    auto vi = static_cast<OVTViewItem*>(si->parent());
     delete si;
     if (vi->childCount() == 0) {
         if (vi->viewWindow == nullptr) {
@@ -160,34 +165,34 @@ void ObjectViewTreeController::removeState(GObjectViewState *s) {
     }
 }
 
-OVTItem *ObjectViewTreeController::currentItem() const {
-    QTreeWidgetItem *i = tree->currentItem();
-    return static_cast<OVTItem *>(i);
+OVTItem* ObjectViewTreeController::currentItem() const {
+    QTreeWidgetItem* i = tree->currentItem();
+    return static_cast<OVTItem*>(i);
 }
 
-OVTViewItem *ObjectViewTreeController::currentViewItem(bool deriveFromState) const {
-    OVTItem *i = currentItem();
-    OVTViewItem *vi = (i != nullptr && i->isViewItem()) ? static_cast<OVTViewItem *>(i) : nullptr;
+OVTViewItem* ObjectViewTreeController::currentViewItem(bool deriveFromState) const {
+    OVTItem* i = currentItem();
+    auto vi = (i != nullptr && i->isViewItem()) ? static_cast<OVTViewItem*>(i) : nullptr;
     if (vi == nullptr && deriveFromState) {
-        OVTStateItem *si = currentStateItem();
+        OVTStateItem* si = currentStateItem();
         if (si != nullptr) {
-            vi = static_cast<OVTViewItem *>(si->parent());
+            vi = static_cast<OVTViewItem*>(si->parent());
         }
     }
     return vi;
 }
 
-OVTStateItem *ObjectViewTreeController::currentStateItem() const {
-    OVTItem *i = currentItem();
-    return (i != nullptr && i->isStateItem()) ? static_cast<OVTStateItem *>(i) : nullptr;
+OVTStateItem* ObjectViewTreeController::currentStateItem() const {
+    OVTItem* i = currentItem();
+    return (i != nullptr && i->isStateItem()) ? static_cast<OVTStateItem*>(i) : nullptr;
 }
-OVTViewItem *ObjectViewTreeController::activeViewItem() const {
-    const GObjectViewWindow *w = GObjectViewUtils::getActiveObjectViewWindow();
+OVTViewItem* ObjectViewTreeController::activeViewItem() const {
+    const GObjectViewWindow* w = GObjectViewUtils::getActiveObjectViewWindow();
     if (w == nullptr) {
         return nullptr;
     }
     for (int i = 0; i < tree->topLevelItemCount(); i++) {
-        OVTViewItem *vi = static_cast<OVTViewItem *>(tree->topLevelItem(i));
+        auto vi = static_cast<OVTViewItem*>(tree->topLevelItem(i));
         if (vi->viewWindow == w) {
             return vi;
         }
@@ -195,15 +200,15 @@ OVTViewItem *ObjectViewTreeController::activeViewItem() const {
     return nullptr;
 }
 
-GObjectViewState *ObjectViewTreeController::findStateToOpen() const {
-    OVTStateItem *si = currentStateItem();
-    GObjectViewState *state = nullptr;
+GObjectViewState* ObjectViewTreeController::findStateToOpen() const {
+    OVTStateItem* si = currentStateItem();
+    GObjectViewState* state = nullptr;
     if (si != nullptr) {
         state = si->state;
     } else {
-        OVTViewItem *vi = currentViewItem();
+        OVTViewItem* vi = currentViewItem();
         if (vi != nullptr && vi->viewWindow == nullptr) {
-            const QList<GObjectViewState *> &allStates = AppContext::getProject()->getGObjectViewStates();
+            const QList<GObjectViewState*>& allStates = AppContext::getProject()->getGObjectViewStates();
             state = GObjectViewUtils::findStateInList(vi->viewName, GObjectViewState::APP_CLOSING_STATE_NAME, allStates);
         }
     }
@@ -211,23 +216,24 @@ GObjectViewState *ObjectViewTreeController::findStateToOpen() const {
 }
 
 void ObjectViewTreeController::updateActions() {
-    OVTStateItem *si = currentStateItem();
-    OVTViewItem *vi = currentViewItem(true);
+    OVTStateItem* si = currentStateItem();
+    OVTViewItem* vi = currentViewItem(true);
 
     bool hasActiveView = vi != nullptr && vi->viewWindow != nullptr;
 
-    GObjectViewState *stateToOpen = findStateToOpen();
+    GObjectViewState* stateToOpen = findStateToOpen();
 
     bool canAddStates = hasActiveView && vi->viewWindow->getViewFactory()->supportsSavedStates() && vi->isActiveItem();
 
     activateViewAction->setEnabled(hasActiveView || stateToOpen != nullptr);
     addStateAction->setEnabled(canAddStates);
+    updateStateAction->setEnabled(canAddStates && si != nullptr);
     removeStateAction->setEnabled(si != nullptr || (vi != nullptr && vi->childCount() > 0));
     renameStateAction->setEnabled(si != nullptr);
 }
 
-void ObjectViewTreeController::sl_onMdiWindowAdded(MWMDIWindow *w) {
-    GObjectViewWindow *vw = qobject_cast<GObjectViewWindow *>(w);
+void ObjectViewTreeController::sl_onMdiWindowAdded(MWMDIWindow* w) {
+    auto vw = qobject_cast<GObjectViewWindow*>(w);
     if (vw == nullptr) {
         return;
     }
@@ -235,12 +241,12 @@ void ObjectViewTreeController::sl_onMdiWindowAdded(MWMDIWindow *w) {
     updateActions();
 }
 
-void ObjectViewTreeController::sl_onMdiWindowClosing(MWMDIWindow *w) {
-    GObjectViewWindow *wv = qobject_cast<GObjectViewWindow *>(w);
+void ObjectViewTreeController::sl_onMdiWindowClosing(MWMDIWindow* w) {
+    auto wv = qobject_cast<GObjectViewWindow*>(w);
     if (wv == nullptr) {
         return;
     }
-    OVTViewItem *vi = findViewItem(wv->getViewName());
+    OVTViewItem* vi = findViewItem(wv->getViewName());
     SAFE_POINT(vi != nullptr, QString("Can't find view item on window closing! View name: %1").arg(wv->getViewName()), );
     if (wv->isPersistent()) {
         vi->viewWindow = nullptr;
@@ -252,21 +258,21 @@ void ObjectViewTreeController::sl_onMdiWindowClosing(MWMDIWindow *w) {
     updateActions();
 }
 
-void ObjectViewTreeController::sl_onMdiWindowActivated(MWMDIWindow *w) {
-    GObjectViewWindow *wv = qobject_cast<GObjectViewWindow *>(w);
+void ObjectViewTreeController::sl_onMdiWindowActivated(MWMDIWindow* w) {
+    auto wv = qobject_cast<GObjectViewWindow*>(w);
 
     for (int i = 0; i < tree->topLevelItemCount(); i++) {
-        OVTViewItem *vi = static_cast<OVTViewItem *>(tree->topLevelItem(i));
+        auto vi = static_cast<OVTViewItem*>(tree->topLevelItem(i));
         bool isActiveItem = (vi->viewWindow == wv && wv != nullptr);
         vi->markAsActive(isActiveItem);
     }
     updateActions();
 }
 
-void ObjectViewTreeController::sl_onViewStateAdded(GObjectViewState *s) {
-    OVTStateItem *si = addState(s);
+void ObjectViewTreeController::sl_onViewStateAdded(GObjectViewState* s) {
+    OVTStateItem* si = addState(s);
     updateActions();
-    connect(s, SIGNAL(si_stateModified(GObjectViewState *)), SLOT(sl_onStateModified(GObjectViewState *)));
+    connect(s, SIGNAL(si_stateModified(GObjectViewState*)), SLOT(sl_onStateModified(GObjectViewState*)));
 
     if (s->getStateName() != GObjectViewState::APP_CLOSING_STATE_NAME) {
         // Start renaming to allow user to enter the name for bookmark
@@ -275,21 +281,21 @@ void ObjectViewTreeController::sl_onViewStateAdded(GObjectViewState *s) {
     }
 }
 
-void ObjectViewTreeController::sl_onViewStateRemoved(GObjectViewState *s) {
+void ObjectViewTreeController::sl_onViewStateRemoved(GObjectViewState* s) {
     removeState(s);
     updateActions();
     s->disconnect(this);
 }
 
-void ObjectViewTreeController::sl_onViewPersistentStateChanged(GObjectViewWindow *v) {
-    OVTViewItem *vi = findViewItem(v->getViewName());
+void ObjectViewTreeController::sl_onViewPersistentStateChanged(GObjectViewWindow* v) {
+    OVTViewItem* vi = findViewItem(v->getViewName());
     vi->updateVisual();
     updateActions();
 }
 
-OVTViewItem *ObjectViewTreeController::findViewItem(const QString &name) {
+OVTViewItem* ObjectViewTreeController::findViewItem(const QString& name) {
     for (int i = 0; i < tree->topLevelItemCount(); i++) {
-        OVTViewItem *vi = static_cast<OVTViewItem *>(tree->topLevelItem(i));
+        auto vi = static_cast<OVTViewItem*>(tree->topLevelItem(i));
         if (vi->viewName == name) {
             return vi;
         }
@@ -297,13 +303,13 @@ OVTViewItem *ObjectViewTreeController::findViewItem(const QString &name) {
     return nullptr;
 }
 
-OVTStateItem *ObjectViewTreeController::findStateItem(GObjectViewState *s) {
-    OVTViewItem *vi = findViewItem(s->getViewName());
+OVTStateItem* ObjectViewTreeController::findStateItem(GObjectViewState* s) {
+    OVTViewItem* vi = findViewItem(s->getViewName());
     if (vi == nullptr) {
         return nullptr;
     }
     for (int i = 0; i < vi->childCount(); i++) {
-        OVTStateItem *si = static_cast<OVTStateItem *>(vi->child(i));
+        auto si = static_cast<OVTStateItem*>(vi->child(i));
         if (si->state == s) {
             return si;
         }
@@ -311,7 +317,7 @@ OVTStateItem *ObjectViewTreeController::findStateItem(GObjectViewState *s) {
     return nullptr;
 }
 
-void ObjectViewTreeController::sl_onContextMenuRequested(const QPoint &pos) {
+void ObjectViewTreeController::sl_onContextMenuRequested(const QPoint& pos) {
     Q_UNUSED(pos);
     QMenu popup;
     bool hasItemSelected = tree->currentItem() != nullptr;
@@ -321,6 +327,7 @@ void ObjectViewTreeController::sl_onContextMenuRequested(const QPoint &pos) {
     }
 
     popup.addAction(addStateAction);
+    popup.addAction(updateStateAction);
     popup.addAction(renameStateAction);
     popup.addAction(removeStateAction);
 
@@ -330,7 +337,7 @@ void ObjectViewTreeController::sl_onContextMenuRequested(const QPoint &pos) {
     }
 }
 
-void ObjectViewTreeController::sl_onTreeCurrentChanged(QTreeWidgetItem *current, QTreeWidgetItem *previous) {
+void ObjectViewTreeController::sl_onTreeCurrentChanged(QTreeWidgetItem* current, QTreeWidgetItem* previous) {
     Q_UNUSED(current);
     Q_UNUSED(previous);
     updateActions();
@@ -338,17 +345,17 @@ void ObjectViewTreeController::sl_onTreeCurrentChanged(QTreeWidgetItem *current,
 
 void ObjectViewTreeController::sl_activateView() {
     GCOUNTER(cvar, "Bookmarks::Bookmark Activated");
-    OVTViewItem *vi = currentViewItem();
+    OVTViewItem* vi = currentViewItem();
     if (vi != nullptr && vi->viewWindow != nullptr) {  // raise existing view, no state change
         AppContext::getMainWindow()->getMDIManager()->activateWindow(vi->viewWindow);
         return;
     }
     // open closed view by state or update state of the active view
-    GObjectViewState *state = findStateToOpen();
+    GObjectViewState* state = findStateToOpen();
     if (state == nullptr) {
         return;
     }
-    GObjectViewWindow *view = GObjectViewUtils::findViewByName(state->getViewName());
+    GObjectViewWindow* view = GObjectViewUtils::findViewByName(state->getViewName());
     if (view != nullptr) {
         assert(view->isPersistent());
         AppContext::getMainWindow()->getMDIManager()->activateWindow(view);
@@ -356,18 +363,18 @@ void ObjectViewTreeController::sl_activateView() {
             AppContext::getTaskScheduler()->registerTopLevelTask(view->getObjectView()->updateViewTask(state->getStateName(), state->getStateData()));
         }
     } else {
-        GObjectViewFactory *f = AppContext::getObjectViewFactoryRegistry()->getFactoryById(state->getViewFactoryId());
+        GObjectViewFactory* f = AppContext::getObjectViewFactoryRegistry()->getFactoryById(state->getViewFactoryId());
         AppContext::getTaskScheduler()->registerTopLevelTask(f->createViewTask(state->getViewName(), state->getStateData()));
     }
 }
 
-void ObjectViewTreeController::sl_onItemActivated(QTreeWidgetItem *i, int col) {
+void ObjectViewTreeController::sl_onItemActivated(QTreeWidgetItem* i, int col) {
     Q_UNUSED(i);
     Q_UNUSED(col);
     sl_activateView();
 }
 
-void ObjectViewTreeController::makeViewPersistent(GObjectViewWindow *w) {
+void ObjectViewTreeController::makeViewPersistent(GObjectViewWindow* w) {
     assert(!w->isPersistent());
     assert(w->getViewFactory()->supportsSavedStates());
     w->setPersistent(true);
@@ -375,7 +382,7 @@ void ObjectViewTreeController::makeViewPersistent(GObjectViewWindow *w) {
 
 void ObjectViewTreeController::sl_addState() {
     GCOUNTER(cvar, "Bookmarks::Add New Bookmark");
-    OVTViewItem *vi = activeViewItem();
+    OVTViewItem* vi = activeViewItem();
     SAFE_POINT(vi != nullptr, QString("Can't find view item to add state!"), );
     SAFE_POINT(vi->viewWindow != nullptr, QString("View window is NULL: %1").arg(vi->viewName), );
     if (!vi->viewWindow->isPersistent()) {
@@ -385,31 +392,49 @@ void ObjectViewTreeController::sl_addState() {
 
     QString stateName = GObjectViewUtils::genUniqueStateName(tr("New bookmark"));  // todo: avoid localization here?
     QVariantMap state = vi->viewWindow->getObjectView()->saveState();
-    GObjectViewState *s = new GObjectViewState(vi->viewWindow->getViewFactoryId(), vi->viewWindow->getViewName(), stateName, state);
+    GObjectViewState* s = new GObjectViewState(vi->viewWindow->getViewFactoryId(), vi->viewWindow->getViewName(), stateName, state);
     AppContext::getProject()->addGObjectViewState(s);
 
     vi->setExpanded(true);
 }
 
-void ObjectViewTreeController::makeViewTransient(GObjectViewWindow *w) {
+void ObjectViewTreeController::sl_updateState() {
+    GCOUNTER(cvar, "Bookmarks::Update Bookmark");
+
+    OVTViewItem* vi = activeViewItem();
+    SAFE_POINT(vi != nullptr, QString("Can't find view item to add state!"), );
+    SAFE_POINT(vi->viewWindow != nullptr, QString("View window is NULL: %1").arg(vi->viewName), );
+    SAFE_POINT(vi->viewWindow->isPersistent(), "Window is not persistent: " + vi->viewName, );
+
+    OVTStateItem* si = currentStateItem();
+    SAFE_POINT(si != nullptr, QString("Can't find state item to rename!"), );
+    QString stateName = si->text(0);
+
+    QString viewName = vi->viewWindow->getViewName();
+    QVariantMap state = vi->viewWindow->getObjectView()->saveState();
+    GObjectViewState newState(vi->viewWindow->getViewFactoryId(), vi->viewWindow->getViewName(), stateName, state);
+    AppContext::getProject()->updateGObjectViewState(newState);
+}
+
+void ObjectViewTreeController::makeViewTransient(GObjectViewWindow* w) {
     assert(w->isPersistent());
     w->setPersistent(false);
 }
 
 void ObjectViewTreeController::sl_removeState() {
     GCOUNTER(cvar, "Bookmarks::Remove Bookmark");
-    OVTStateItem *si = currentStateItem();
-    Project *p = AppContext::getProject();
+    OVTStateItem* si = currentStateItem();
+    Project* p = AppContext::getProject();
     if (si != nullptr) {
         assert(si->state != nullptr);
         p->removeGObjectViewState(si->state);
     } else {
-        OVTViewItem *vi = currentViewItem();
+        OVTViewItem* vi = currentViewItem();
         SAFE_POINT(vi != nullptr, QString("Can't find view item to remove its state!"), );
         int childs = vi->childCount();
         assert(childs > 0);
         for (int i = 0; i < childs; i++) {
-            OVTStateItem *si2 = static_cast<OVTStateItem *>(vi->child(0));
+            auto si2 = static_cast<OVTStateItem*>(vi->child(0));
             p->removeGObjectViewState(si2->state);
         }
     }
@@ -417,7 +442,7 @@ void ObjectViewTreeController::sl_removeState() {
 
 void ObjectViewTreeController::sl_renameState() {
     GCOUNTER(cvar, "Bookmarks::Rename Bookmark");
-    OVTStateItem *si = currentStateItem();
+    OVTStateItem* si = currentStateItem();
     SAFE_POINT(si != nullptr, QString("Can't find state item to rename!"), );
 
     si->setFlags(si->flags() | Qt::ItemIsEditable);
@@ -426,20 +451,20 @@ void ObjectViewTreeController::sl_renameState() {
     si->setFlags(si->flags() ^ Qt::ItemIsEditable);
 }
 
-void ObjectViewTreeController::sl_onItemChanged(QTreeWidgetItem *i, int c) {
+void ObjectViewTreeController::sl_onItemChanged(QTreeWidgetItem* i, int c) {
     assert(c == 0);
     Q_UNUSED(c);
-    OVTItem *oi = static_cast<OVTItem *>(i);
+    auto oi = static_cast<OVTItem*>(i);
     if (oi->isViewItem()) {
-        OVTViewItem *vi = static_cast<OVTViewItem *>(oi);
+        auto vi = static_cast<OVTViewItem*>(oi);
         assert(vi->text(0).endsWith(vi->viewName));
         Q_UNUSED(vi);
         return;
     }
     assert(oi->isStateItem());
-    OVTStateItem *si = static_cast<OVTStateItem *>(oi);
+    auto si = static_cast<OVTStateItem*>(oi);
     QString newName = si->text(0);
-    GObjectViewState *state = GObjectViewUtils::findStateByName(si->state->getViewName(), newName);
+    GObjectViewState* state = GObjectViewUtils::findStateByName(si->state->getViewName(), newName);
     if (state == si->state) {
         return;
     }
@@ -454,14 +479,14 @@ void ObjectViewTreeController::sl_onItemChanged(QTreeWidgetItem *i, int c) {
     si->state->setStateName(newName);
 }
 
-void ObjectViewTreeController::sl_onStateModified(GObjectViewState *s) {
-    OVTStateItem *si = findStateItem(s);
+void ObjectViewTreeController::sl_onStateModified(GObjectViewState* s) {
+    OVTStateItem* si = findStateItem(s);
     SAFE_POINT(si != nullptr, QString("Can't find state item to update: %1 -> %2").arg(s->getViewName()).arg(s->getStateName()), );
     si->updateVisual();
 }
 
-void ObjectViewTreeController::sl_onViewNameChanged(const QString &oldName) {
-    OVTViewItem *vi = findViewItem(oldName);
+void ObjectViewTreeController::sl_onViewNameChanged(const QString& oldName) {
+    OVTViewItem* vi = findViewItem(oldName);
     SAFE_POINT(vi, QString("Can't find view item to rename: %1").arg(oldName), );
     vi->updateVisual();
 }
@@ -469,12 +494,12 @@ void ObjectViewTreeController::sl_onViewNameChanged(const QString &oldName) {
 //////////////////////////////////////////////////////////////////////////
 /// tree items
 
-OVTViewItem::OVTViewItem(GObjectViewWindow *v, ObjectViewTreeController *c)
+OVTViewItem::OVTViewItem(GObjectViewWindow* v, ObjectViewTreeController* c)
     : OVTItem(c), viewName(v->getViewName()), viewWindow(v), isActive(false) {
     updateVisual();
 }
 
-OVTViewItem::OVTViewItem(const QString &_viewName, ObjectViewTreeController *c)
+OVTViewItem::OVTViewItem(const QString& _viewName, ObjectViewTreeController* c)
     : OVTItem(c), viewName(_viewName), viewWindow(nullptr), isActive(false) {
     updateVisual();
 }
@@ -494,7 +519,7 @@ void OVTViewItem::markAsActive(bool _isActive) {
     setFont(0, curFont);
 }
 
-OVTStateItem::OVTStateItem(GObjectViewState *_state, OVTViewItem *parent, ObjectViewTreeController *c)
+OVTStateItem::OVTStateItem(GObjectViewState* _state, OVTViewItem* parent, ObjectViewTreeController* c)
     : OVTItem(c), state(_state) {
     updateVisual();
     parent->addChild(this);
