@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,22 +28,22 @@
 
 namespace U2 {
 
-OrderedToolbar::OrderedToolbar(QWidget *parent, Qt::Orientation orientation)
+OrderedToolbar::OrderedToolbar(QWidget* parent, Qt::Orientation orientation)
     : QToolBar(parent),
       tabOrdered(false),
       buttonTabOrderList(nullptr) {
     setOrientation(orientation);
 }
 
-void OrderedToolbar::setButtonTabOrderList(QList<QString> *buttonNamesInNeededOrder) {
-    assert(nullptr != buttonNamesInNeededOrder);
+void OrderedToolbar::setButtonTabOrderList(QList<QString>* buttonNamesInNeededOrder) {
+    assert(buttonNamesInNeededOrder != nullptr);
     buttonTabOrderList = buttonNamesInNeededOrder;
 }
 
 void OrderedToolbar::setVisible(bool visible) {
     QWidget::setVisible(visible);
 
-    if (!tabOrdered && nullptr != buttonTabOrderList) {
+    if (!tabOrdered && buttonTabOrderList != nullptr) {
         setButtonsTabOrder();
         tabOrdered = true;
     }
@@ -52,19 +52,19 @@ void OrderedToolbar::setVisible(bool visible) {
 void OrderedToolbar::setButtonsTabOrder() const {
     assert(!buttonTabOrderList->isEmpty());
 
-    QList<QObject *> barElements = children();
-    QWidget *prevButton = nullptr;
-    QWidget *curButton = nullptr;
+    QList<QObject*> barElements = children();
+    QWidget* prevButton = nullptr;
+    QWidget* curButton = nullptr;
 
     for (QList<QString>::const_iterator it = buttonTabOrderList->constBegin(); it != buttonTabOrderList->constEnd(); it++) {
-        foreach (QObject *element, barElements) {
+        foreach (QObject* element, barElements) {
             if (element->objectName().contains(*it)) {
-                if (nullptr != prevButton) {
-                    curButton = qobject_cast<QWidget *>(element);
+                if (prevButton != nullptr) {
+                    curButton = qobject_cast<QWidget*>(element);
                 } else {
-                    prevButton = qobject_cast<QWidget *>(element);
+                    prevButton = qobject_cast<QWidget*>(element);
                 }
-                if (nullptr == curButton || nullptr == prevButton) {
+                if (curButton == nullptr || prevButton == nullptr) {
                     break;
                 }
 
@@ -74,7 +74,7 @@ void OrderedToolbar::setButtonsTabOrder() const {
                 break;
             }
         }
-        assert(nullptr != prevButton);
+        assert(prevButton != nullptr);
     }
 }
 
