@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ORDERED_TOOLBAR_H_
-#define _U2_ORDERED_TOOLBAR_H_
+#pragma once
 
 #include <QAction>
 #include <QToolBar>
@@ -31,14 +30,14 @@ namespace U2 {
 
 class U2GUI_EXPORT OrderedToolbar : public QToolBar {
 public:
-    OrderedToolbar(QWidget *parent, Qt::Orientation orientation = Qt::Horizontal);
+    OrderedToolbar(QWidget* parent, Qt::Orientation orientation = Qt::Horizontal);
 
-    void setButtonTabOrderList(QList<QString> *buttonNamesInNeededOrder);
+    void setButtonTabOrderList(QList<QString>* buttonNamesInNeededOrder);
 
     virtual void setVisible(bool visible);
 
 protected:
-    void paintEvent(QPaintEvent *) {
+    void paintEvent(QPaintEvent*) {
         // do not draw any special toolbar control -> make is merged with parent widget
     }
 
@@ -46,9 +45,7 @@ private:
     void setButtonsTabOrder() const;
 
     bool tabOrdered;
-    QList<QString> *buttonTabOrderList;
+    QList<QString>* buttonTabOrderList;
 };
 
 }  // namespace U2
-
-#endif  // _U2_ORDERED_TOOLBAR_H_
