@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_POSITION_SELECTOR_H_
-#define _U2_POSITION_SELECTOR_H_
+#pragma once
 
 #include <QDialog>
 #include <QLineEdit>
@@ -33,13 +32,13 @@ namespace U2 {
 class U2GUI_EXPORT PositionSelector : public QWidget {
     Q_OBJECT
 public:
-    PositionSelector(QWidget *p, qint64 rangeStart, qint64 rangeEnd, bool fixedSize = true);
-    PositionSelector(QDialog *d, qint64 rangeStart, qint64 rangeEnd, bool autoclose);
+    PositionSelector(QWidget* p, qint64 rangeStart, qint64 rangeEnd, bool fixedSize = true);
+    PositionSelector(QDialog* d, qint64 rangeStart, qint64 rangeEnd, bool autoclose);
 
     ~PositionSelector();
 
     void updateRange(qint64 rangeStart, qint64 rangeEnd);
-    QLineEdit *getPosEdit() const {
+    QLineEdit* getPosEdit() const {
         return posEdit;
     }
 
@@ -56,11 +55,9 @@ private:
 
     qint64 rangeStart;
     qint64 rangeEnd;
-    QLineEdit *posEdit;
+    QLineEdit* posEdit;
     bool autoclose;
-    QDialog *dialog;
+    QDialog* dialog;
 };
 
 }  // namespace U2
-
-#endif
