@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PROJECT_DOCUMENT_COMBOBOX_CONTROLLER
-#define _U2_PROJECT_DOCUMENT_COMBOBOX_CONTROLLER
+#pragma once
 
 #include <QComboBox>
 #include <QObject>
@@ -34,29 +33,27 @@ class Project;
 class U2GUI_EXPORT ProjectDocumentComboBoxController : public QObject {
     Q_OBJECT
 public:
-    ProjectDocumentComboBoxController(Project *p, QComboBox *cb, QObject *parent, const DocumentFilter *f);
+    ProjectDocumentComboBoxController(Project* p, QComboBox* cb, QObject* parent, const DocumentFilter* f);
     ~ProjectDocumentComboBoxController();
 
-    Document *getDocument() const;
+    Document* getDocument() const;
 
-    void selectDocument(Document *d);
+    void selectDocument(Document* d);
 
-    void selectDocument(const QString &url);
+    void selectDocument(const QString& url);
 
 private slots:
-    void sl_onDocumentAdded(Document *d);
-    void sl_onDocumentRemoved(Document *d);
+    void sl_onDocumentAdded(Document* d);
+    void sl_onDocumentRemoved(Document* d);
 
 private:
-    bool checkConstraints(Document *d);
-    void addDocument(Document *d);
-    void removeDocument(Document *d);
+    bool checkConstraints(Document* d);
+    void addDocument(Document* d);
+    void removeDocument(Document* d);
 
-    Project *p;
-    QComboBox *cb;
-    const DocumentFilter *filter;
+    Project* p;
+    QComboBox* cb;
+    const DocumentFilter* filter;
 };
 
 }  // namespace U2
-
-#endif
