@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PROJECT_TREE_ITEM_SELECTOR_DIALOG_H_
-#define _U2_PROJECT_TREE_ITEM_SELECTOR_DIALOG_H_
+#pragma once
 
 #include <U2Core/Folder.h>
 
@@ -35,12 +34,11 @@ class StateLockableTreeItem;
 
 class U2GUI_EXPORT ProjectTreeItemSelectorDialog {
 public:
-    static QList<Document *> selectDocuments(const ProjectTreeControllerModeSettings &s, QWidget *p);
-    static QList<GObject *> selectObjects(const ProjectTreeControllerModeSettings &s, QWidget *p);
-    static void selectObjectsAndDocuments(const ProjectTreeControllerModeSettings &s, QWidget *p, QList<Document *> &docList, QList<GObject *> &objList);
-    static void selectObjectsAndFolders(const ProjectTreeControllerModeSettings &s, QWidget *p, QList<Folder> &folderList, QList<GObject *> &objList);
-    static Folder selectFolder(QWidget *parent);
+    static QList<Document*> selectDocuments(const ProjectTreeControllerModeSettings& s, QWidget* p);
+    static QList<GObject*> selectObjects(const ProjectTreeControllerModeSettings& s, QWidget* p);
+    static void selectObjectsAndDocuments(const ProjectTreeControllerModeSettings& s, QWidget* p, QList<Document*>& docList, QList<GObject*>& objList);
+    static void selectObjectsAndFolders(const ProjectTreeControllerModeSettings& s, QWidget* p, QList<Folder>& folderList, QList<GObject*>& objList);
+    static Folder selectFolder(QWidget* parent);
 };
 
 }  // namespace U2
-#endif
