@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PROJECT_TREE_ITEM_SELECTOR_DIALOG_IMPL_H_
-#define _U2_PROJECT_TREE_ITEM_SELECTOR_DIALOG_IMPL_H_
+#pragma once
 
 #include "ui_ProjectTreeItemSelectorDialogBase.h"
 
@@ -39,14 +38,12 @@ public:
     bool acceptByDoubleClick;
 
 private slots:
-    void sl_objectClicked(GObject *obj);
+    void sl_objectClicked(GObject* obj);
 
 private:
     friend class ProjectTreeItemSelectorDialog;
-    ProjectTreeItemSelectorDialogImpl(QWidget *p, const ProjectTreeControllerModeSettings &s);
-    ProjectTreeController *controller;
+    ProjectTreeItemSelectorDialogImpl(QWidget* p, const ProjectTreeControllerModeSettings& s);
+    ProjectTreeController* controller;
 };
 
 }  // namespace U2
-
-#endif
