@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,13 +31,9 @@
 
 namespace U2 {
 
-const QString RegionSelectorSettings::WHOLE_SEQUENCE = QApplication::translate("RegionSelectorController", "Whole sequence");
-const QString RegionSelectorSettings::SELECTED_REGION = QApplication::translate("RegionSelectorController", "Selected region");
-const QString RegionSelectorSettings::CUSTOM_REGION = QApplication::translate("RegionSelectorController", "Custom region");
-
 RegionSelectorSettings::RegionSelectorSettings(qint64 maxLen,
                                                bool isCircularSelectionAvailable,
-                                               DNASequenceSelection *selection,
+                                               DNASequenceSelection* selection,
                                                QList<RegionPreset> _presetRegions,
                                                QString defaultPreset)
     : maxLen(maxLen),
@@ -47,10 +43,10 @@ RegionSelectorSettings::RegionSelectorSettings(qint64 maxLen,
       defaultPreset(defaultPreset) {
     if (selection != nullptr && !selection->isEmpty()) {
         U2Region region = getOneRegionFromSelection();
-        presetRegions.prepend(RegionPreset(SELECTED_REGION, region));
+        presetRegions.prepend(RegionPreset(RegionPreset::SELECTED_REGION(), region));
     }
-    presetRegions.prepend(RegionPreset(WHOLE_SEQUENCE, U2Region(0, maxLen)));
-    presetRegions.prepend(RegionPreset(CUSTOM_REGION, U2Region()));
+    presetRegions.prepend(RegionPreset(RegionPreset::WHOLE_SEQUENCE(), U2Region(0, maxLen)));
+    presetRegions.prepend(RegionPreset(RegionPreset::CUSTOM_REGION(), U2Region()));
 }
 
 U2Region RegionSelectorSettings::getOneRegionFromSelection() const {
@@ -71,7 +67,19 @@ U2Region RegionSelectorSettings::getOneRegionFromSelection() const {
     return region;
 }
 
-RegionSelectorController::RegionSelectorController(RegionSelectorGui gui, RegionSelectorSettings settings, QObject *parent)
+QString RegionPreset::WHOLE_SEQUENCE() {
+    return QApplication::translate("RegionSelectorController", "Whole sequence");
+}
+
+QString RegionPreset::SELECTED_REGION() {
+    return QApplication::translate("RegionSelectorController", "Selected region");
+}
+
+QString RegionPreset::CUSTOM_REGION() {
+    return QApplication::translate("RegionSelectorController", "Custom region");
+}
+
+RegionSelectorController::RegionSelectorController(RegionSelectorGui gui, RegionSelectorSettings settings, QObject* parent)
     : QObject(parent),
       gui(gui),
       settings(settings) {
@@ -80,47 +88,46 @@ RegionSelectorController::RegionSelectorController(RegionSelectorGui gui, Region
     connectSlots();
 }
 
-U2Region RegionSelectorController::getRegion(bool *_ok) const {
+U2Region RegionSelectorController::getRegion(bool* _ok) const {
     SAFE_POINT_EXT(gui.startLineEdit != nullptr && gui.endLineEdit != nullptr, *_ok = false, U2Region());
 
     bool ok = false;
-    qint64 v1 = gui.startLineEdit->text().toLongLong(&ok) - 1;
+    qint64 startPosInclusive = gui.startLineEdit->text().toLongLong(&ok) - 1;
 
-    if (!ok || v1 < 0 || v1 > settings.maxLen) {
+    if (!ok || startPosInclusive < 0 || startPosInclusive > settings.maxLen) {
         if (_ok != nullptr) {
             *_ok = false;
         }
-        return U2Region();
+        return {};
     }
 
-    int v2 = gui.endLineEdit->text().toLongLong(&ok);
+    qint64 endPosExlusive = gui.endLineEdit->text().toLongLong(&ok);
 
-    if (!ok || v2 <= 0 || v2 > settings.maxLen) {
+    if (!ok || endPosExlusive <= 0 || endPosExlusive > settings.maxLen) {
         if (_ok != nullptr) {
             *_ok = false;
         }
-        return U2Region();
+        return {};
     }
 
-    if (v1 > v2 && !settings.circular) {  // start > end
+    if (startPosInclusive >= endPosExlusive && !settings.circular) {  // start > end
         if (_ok != nullptr) {
             *_ok = false;
         }
-        return U2Region();
+        return {};
     }
 
     if (_ok != nullptr) {
         *_ok = true;
     }
 
-    if (v1 < v2) {
-        return U2Region(v1, v2 - v1);
-    } else {
-        return U2Region(v1, v2 + settings.maxLen - v1);
+    if (startPosInclusive < endPosExlusive) {
+        return {startPosInclusive, endPosExlusive - startPosInclusive};
     }
+    return {startPosInclusive, endPosExlusive + settings.maxLen - startPosInclusive};
 }
 
-void RegionSelectorController::setRegion(const U2Region &region) {
+void RegionSelectorController::setRegion(const U2Region& region) {
     CHECK(region != getRegion(), );
     SAFE_POINT(region.startPos >= 0 && region.startPos < settings.maxLen && region.length <= settings.maxLen, tr("Region is not in sequence range"), );
 
@@ -144,15 +151,15 @@ QString RegionSelectorController::getPresetName() const {
     return gui.presetsComboBox->currentText();
 }
 
-void RegionSelectorController::setPreset(const QString &preset) {
+void RegionSelectorController::setPreset(const QString& preset) {
     SAFE_POINT(gui.presetsComboBox != nullptr, tr("Cannot set preset, ComboBox is NULL"), );
     gui.presetsComboBox->setCurrentText(preset);
 }
 
-void RegionSelectorController::removePreset(const QString &preset) {
+void RegionSelectorController::removePreset(const QString& preset) {
     gui.presetsComboBox->removeItem(gui.presetsComboBox->findText(preset));
     RegionPreset settingsPreset;
-    foreach (const RegionPreset &r, settings.presetRegions) {
+    foreach (const RegionPreset& r, settings.presetRegions) {
         if (r.text == preset) {
             settingsPreset = r;
             break;
@@ -178,33 +185,30 @@ const QString REGION_IS_INVALID = QApplication::translate("RegionSelectorControl
 
 QString RegionSelectorController::getErrorMessage() const {
     bool ok = false;
-    qint64 v1 = gui.startLineEdit->text().toLongLong(&ok) - 1;
-    if (!ok || v1 < 0 || v1 > settings.maxLen) {
+    qint64 startInclusive = gui.startLineEdit->text().toLongLong(&ok) - 1;
+    if (!ok || startInclusive < 0 || startInclusive > settings.maxLen) {
         return START_IS_INVALID;
     }
-
-    int v2 = gui.endLineEdit->text().toLongLong(&ok);
-    if (!ok || v2 <= 0 || v2 > settings.maxLen) {
+    qint64 endExclusive = gui.endLineEdit->text().toLongLong(&ok);
+    if (!ok || endExclusive <= 0 || endExclusive > settings.maxLen) {
         return END_IS_INVALID;
     }
-
-    if (v1 > v2 && !settings.circular) {  // start > end
+    if (startInclusive >= endExclusive && !settings.circular) {  // start >= end
         return REGION_IS_INVALID;
     }
-
-    return QString();
+    return {};
 }
 
 void RegionSelectorController::sl_onPresetChanged(int index) {
     blockSignals(true);
 
     // set the region
-    if (index == gui.presetsComboBox->findText(RegionSelectorSettings::CUSTOM_REGION)) {
+    if (index == gui.presetsComboBox->findText(RegionPreset::CUSTOM_REGION())) {
         connect(this, SIGNAL(si_regionChanged(U2Region)), this, SLOT(sl_regionChanged()));
         return;
     }
 
-    if (index == gui.presetsComboBox->findText(RegionSelectorSettings::SELECTED_REGION)) {
+    if (index == gui.presetsComboBox->findText(RegionPreset::SELECTED_REGION())) {
         setRegion(settings.getOneRegionFromSelection());
     } else {
         const U2Region region = gui.presetsComboBox->itemData(index).value<U2Region>();
@@ -215,7 +219,7 @@ void RegionSelectorController::sl_onPresetChanged(int index) {
 
 void RegionSelectorController::sl_regionChanged() {
     gui.presetsComboBox->blockSignals(true);
-    gui.presetsComboBox->setCurrentIndex(gui.presetsComboBox->findText(RegionSelectorSettings::CUSTOM_REGION));
+    gui.presetsComboBox->setCurrentIndex(gui.presetsComboBox->findText(RegionPreset::CUSTOM_REGION()));
     gui.presetsComboBox->blockSignals(false);
 }
 
@@ -247,14 +251,14 @@ void RegionSelectorController::sl_onRegionChanged() {
     emit si_regionChanged(r);
 }
 
-void RegionSelectorController::sl_onSelectionChanged(GSelection *selection) {
+void RegionSelectorController::sl_onSelectionChanged(GSelection* selection) {
     CHECK(gui.presetsComboBox != nullptr, );  // no combobox - no selection dependency
 
     SAFE_POINT(settings.selection == selection, "Invalid sequence selection", );
-    int selectedRegionIndex = gui.presetsComboBox->findText(RegionSelectorSettings::SELECTED_REGION);
+    int selectedRegionIndex = gui.presetsComboBox->findText(RegionPreset::SELECTED_REGION());
     if (-1 == selectedRegionIndex) {
-        selectedRegionIndex = gui.presetsComboBox->findText(RegionSelectorSettings::WHOLE_SEQUENCE) + 1;
-        gui.presetsComboBox->insertItem(selectedRegionIndex, RegionSelectorSettings::SELECTED_REGION);
+        selectedRegionIndex = gui.presetsComboBox->findText(RegionPreset::WHOLE_SEQUENCE()) + 1;
+        gui.presetsComboBox->insertItem(selectedRegionIndex, RegionPreset::SELECTED_REGION());
     }
 
     U2Region region = settings.getOneRegionFromSelection();
@@ -270,14 +274,14 @@ void RegionSelectorController::sl_onValueEdited() {
     SAFE_POINT(gui.startLineEdit != nullptr && gui.endLineEdit != nullptr, tr("Region lineEdit is NULL"), );
 
     if (gui.startLineEdit->text().isEmpty() || gui.endLineEdit->text().isEmpty()) {
-        GUIUtils::setWidgetWarning(gui.startLineEdit, gui.startLineEdit->text().isEmpty());
-        GUIUtils::setWidgetWarning(gui.endLineEdit, gui.endLineEdit->text().isEmpty());
+        GUIUtils::setWidgetWarningStyle(gui.startLineEdit, gui.startLineEdit->text().isEmpty());
+        GUIUtils::setWidgetWarningStyle(gui.endLineEdit, gui.endLineEdit->text().isEmpty());
         return;
     }
 
     const U2Region region = getRegion();
-    GUIUtils::setWidgetWarning(gui.startLineEdit, region.isEmpty());
-    GUIUtils::setWidgetWarning(gui.endLineEdit, region.isEmpty());
+    GUIUtils::setWidgetWarningStyle(gui.startLineEdit, region.isEmpty());
+    GUIUtils::setWidgetWarningStyle(gui.endLineEdit, region.isEmpty());
 }
 
 void RegionSelectorController::init() {
@@ -300,14 +304,14 @@ void RegionSelectorController::setupPresets() {
     CHECK(gui.presetsComboBox != nullptr, );
 
     bool foundDefaultPreset = false;
-    foreach (const RegionPreset &presetRegion, settings.presetRegions) {
+    foreach (const RegionPreset& presetRegion, settings.presetRegions) {
         gui.presetsComboBox->addItem(presetRegion.text, QVariant::fromValue(presetRegion.region));
         if (presetRegion.text == settings.defaultPreset) {
             foundDefaultPreset = true;
         }
     }
     if (!foundDefaultPreset) {
-        settings.defaultPreset = RegionSelectorSettings::WHOLE_SEQUENCE;
+        settings.defaultPreset = RegionPreset::WHOLE_SEQUENCE();
     }
 
     gui.presetsComboBox->setCurrentText(settings.defaultPreset);
@@ -319,11 +323,11 @@ void RegionSelectorController::connectSlots() {
     SAFE_POINT(gui.startLineEdit != nullptr && gui.endLineEdit != nullptr, tr("Region lineEdit is NULL"), );
 
     connect(gui.startLineEdit, SIGNAL(editingFinished()), SLOT(sl_onRegionChanged()));
-    connect(gui.startLineEdit, SIGNAL(textEdited(const QString &)), SLOT(sl_onValueEdited()));
+    connect(gui.startLineEdit, SIGNAL(textEdited(const QString&)), SLOT(sl_onValueEdited()));
     connect(gui.startLineEdit, SIGNAL(textChanged(QString)), SLOT(sl_onRegionChanged()));
 
     connect(gui.endLineEdit, SIGNAL(editingFinished()), SLOT(sl_onRegionChanged()));
-    connect(gui.endLineEdit, SIGNAL(textEdited(const QString &)), SLOT(sl_onValueEdited()));
+    connect(gui.endLineEdit, SIGNAL(textEdited(const QString&)), SLOT(sl_onValueEdited()));
     connect(gui.endLineEdit, SIGNAL(textChanged(QString)), SLOT(sl_onRegionChanged()));
 
     if (gui.presetsComboBox != nullptr) {
@@ -332,7 +336,7 @@ void RegionSelectorController::connectSlots() {
     }
 
     if (settings.selection != nullptr) {
-        connect(settings.selection, SIGNAL(si_onSelectionChanged(GSelection *)), SLOT(sl_onSelectionChanged(GSelection *)));
+        connect(settings.selection, SIGNAL(si_onSelectionChanged(GSelection*)), SLOT(sl_onSelectionChanged(GSelection*)));
     }
 }
 
