@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,21 +23,17 @@
 
 #include <QDir>
 #include <QMessageBox>
-#include <QPushButton>
 
 #include <U2Core/AnnotationData.h>
 #include <U2Core/AppContext.h>
 #include <U2Core/BaseDocumentFormats.h>
-#include <U2Core/DocumentModel.h>
 #include <U2Core/ModifySequenceObjectTask.h>
 #include <U2Core/U2SafePoints.h>
 
 #include <U2Formats/DocumentFormatUtils.h>
 #include <U2Formats/GenbankLocationParser.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/HelpButton.h>
-#include <U2Gui/LastUsedDirHelper.h>
 #include <U2Gui/SaveDocumentController.h>
 #include <U2Gui/U2FileDialog.h>
 
@@ -47,8 +43,8 @@ namespace U2 {
 
 RemovePartFromSequenceDialogController::RemovePartFromSequenceDialogController(U2Region _toDelete,
                                                                                U2Region _source,
-                                                                               const QString &docUrl,
-                                                                               QWidget *p)
+                                                                               const QString& docUrl,
+                                                                               QWidget* p)
     : QDialog(p),
       toDelete(_toDelete),
       source(_source),
@@ -125,7 +121,7 @@ void RemovePartFromSequenceDialogController::sl_mergeAnnotationsToggled(bool) {
     ui->formatBox->model()->sort(0);
 }
 
-void RemovePartFromSequenceDialogController::initSaveController(const QString &docUrl) {
+void RemovePartFromSequenceDialogController::initSaveController(const QString& docUrl) {
     const QFileInfo fi(docUrl);
 
     SaveDocumentControllerConfig config;
