@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SCALE_BAR_H_
-#define _U2_SCALE_BAR_H_
+#pragma once
 
 #include <QWidget>
 
@@ -36,7 +35,7 @@ namespace U2 {
 class U2GUI_EXPORT ScaleBar : public QWidget {
     Q_OBJECT
 public:
-    ScaleBar(Qt::Orientation ori = Qt::Vertical, QWidget *parent = 0);
+    ScaleBar(Qt::Orientation ori = Qt::Vertical, QWidget* parent = 0);
 
     int value() const;
     void setValue(int value);
@@ -44,11 +43,11 @@ public:
     void setRange(int minumum, int maximum);
     void setTickInterval(int interval);
 
-    QAction *getPlusAction() const;
-    QAction *getMinusAction() const;
+    QAction* getPlusAction() const;
+    QAction* getMinusAction() const;
 
-    QAbstractButton *getPlusButton() const;
-    QAbstractButton *getMinusButton() const;
+    QAbstractButton* getPlusButton() const;
+    QAbstractButton* getMinusButton() const;
 
 signals:
     void valueChanged(int value);
@@ -59,13 +58,11 @@ private slots:
     void sl_updateState();
 
 protected:
-    QSlider *scaleBar;
-    QAction *minusAction;
-    QAction *plusAction;
-    QToolButton *plusButton;
-    QToolButton *minusButton;
+    QSlider* scaleBar;
+    QAction* minusAction;
+    QAction* plusAction;
+    QToolButton* plusButton;
+    QToolButton* minusButton;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SCALE_BAR_H_
