@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SCRIPT_EDITOR_DELEGATE_H_
-#define _U2_SCRIPT_EDITOR_DELEGATE_H_
+#pragma once
 
 #include <QWidget>
 
@@ -38,22 +37,22 @@ enum ScriptEditorType {
 class AbstractScriptEditorDelegate : public QWidget {
     Q_OBJECT
 public:
-    AbstractScriptEditorDelegate(QWidget *parent);
+    AbstractScriptEditorDelegate(QWidget* parent);
     virtual ~AbstractScriptEditorDelegate();
 
-    virtual void setText(const QString &text) = 0;
+    virtual void setText(const QString& text) = 0;
     virtual QString text() const = 0;
     virtual int cursorLineNumber() const = 0;
     virtual void installScriptHighlighter() const;
 
-    static AbstractScriptEditorDelegate *createInstance(QWidget *parent, ScriptEditorType type);
+    static AbstractScriptEditorDelegate* createInstance(QWidget* parent, ScriptEditorType type);
 
 signals:
     void si_textChanged();
     void si_cursorPositionChanged();
 
 protected:
-    QBoxLayout *layout;
+    QBoxLayout* layout;
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -61,30 +60,28 @@ protected:
 
 class LineEditDelegate : public AbstractScriptEditorDelegate {
 public:
-    LineEditDelegate(QWidget *parent);
+    LineEditDelegate(QWidget* parent);
 
-    void setText(const QString &text);
+    void setText(const QString& text);
     QString text() const;
     int cursorLineNumber() const;
 
 private:
-    QLineEdit *edit;
+    QLineEdit* edit;
 };
 
 class TextEditDelegate : public AbstractScriptEditorDelegate {
     Q_OBJECT
 public:
-    TextEditDelegate(QWidget *parent);
+    TextEditDelegate(QWidget* parent);
 
-    void setText(const QString &text);
+    void setText(const QString& text);
     QString text() const;
     int cursorLineNumber() const;
     void installScriptHighlighter() const;
 
 private:
-    QTextEdit *edit;
+    QTextEdit* edit;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SCRIPT_EDITOR_DELEGATE_H_
