@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SCRIPT_EDITOR_DIALOG_H_
-#define _U2_SCRIPT_EDITOR_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -35,12 +34,12 @@ class ScriptEditorWidget;
 class U2GUI_EXPORT ScriptEditorDialog : public QDialog {
     Q_OBJECT
 public:
-    ScriptEditorDialog(QWidget *p, const QString &roHeaderText, const QString &text = QString());
+    ScriptEditorDialog(QWidget* p, const QString& roHeaderText, const QString& text = QString());
     ~ScriptEditorDialog();
 
-    void setScriptText(const QString &text);
+    void setScriptText(const QString& text);
 
-    void setScriptPath(const QString &path);
+    void setScriptPath(const QString& path);
 
     QString getScriptText() const;
 
@@ -51,18 +50,16 @@ private slots:
     void sl_openScript();
     void sl_saveScript();
     void sl_saveAsScript();
-    void sl_nameChanged(const QString &);
+    void sl_nameChanged(const QString&);
     void sl_scriptChanged();
     void sl_cursorPositionChanged();
 
 private:
     void updateState();
-    void save(const QString &url);
+    void save(const QString& url);
 
-    ScriptEditorWidget *scriptEdit;
-    Ui_ScriptEditorDialog *ui;
+    ScriptEditorWidget* scriptEdit;
+    Ui_ScriptEditorDialog* ui;
 };
 
 }  // namespace U2
-
-#endif
