@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +24,6 @@
 #include <QComboBox>
 #include <QLineEdit>
 #include <QMessageBox>
-#include <QPushButton>
 #include <QToolButton>
 
 #include <U2Core/AppContext.h>
@@ -40,8 +39,8 @@
 
 namespace U2 {
 
-SearchGenbankSequenceDialogController::SearchGenbankSequenceDialogController(QWidget *p)
-    : QDialog(p), searchTask(nullptr), summaryTask(nullptr) {
+SearchGenbankSequenceDialogController::SearchGenbankSequenceDialogController(QWidget* p)
+    : QDialog(p) {
     ui = new Ui_SearchGenbankSequenceDialog();
     ui->setupUi(this);
     new HelpButton(this, ui->buttonBox, "65929336");
@@ -57,11 +56,11 @@ SearchGenbankSequenceDialogController::SearchGenbankSequenceDialogController(QWi
     downloadButton = ui->buttonBox->button(QDialogButtonBox::Ok);
     downloadButton->setEnabled(false);
 
-    connect(ui->searchButton, SIGNAL(clicked()), SLOT(sl_searchButtonClicked()));
-    connect(downloadButton, SIGNAL(clicked()), SLOT(sl_downloadButtonClicked()));
-    connect(ui->treeWidget, SIGNAL(itemSelectionChanged()), SLOT(sl_itemSelectionChanged()));
-    connect(ui->treeWidget, SIGNAL(itemActivated(QTreeWidgetItem *, int)), SLOT(sl_downloadButtonClicked()));
-    connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task *)), SLOT(sl_taskStateChanged(Task *)));
+    connect(ui->searchButton, &QPushButton::clicked, this, &SearchGenbankSequenceDialogController::sl_searchButtonClicked);
+    connect(downloadButton, &QPushButton::clicked, this, &SearchGenbankSequenceDialogController::sl_downloadButtonClicked);
+    connect(ui->treeWidget, &QTreeWidget::itemSelectionChanged, this, &SearchGenbankSequenceDialogController::sl_itemSelectionChanged);
+    connect(ui->treeWidget, &QTreeWidget::itemActivated, this, &SearchGenbankSequenceDialogController::sl_downloadButtonClicked);
+    connect(AppContext::getTaskScheduler(), &TaskScheduler::si_stateChanged, this, &SearchGenbankSequenceDialogController::sl_taskStateChanged);
 
     ui->treeWidget->header()->setStretchLastSection(false);
     ui->treeWidget->header()->setSectionResizeMode(1, QHeaderView::Stretch);
@@ -69,28 +68,28 @@ SearchGenbankSequenceDialogController::SearchGenbankSequenceDialogController(QWi
 
 SearchGenbankSequenceDialogController::~SearchGenbankSequenceDialogController() {
     // if dialog was closed during query execution
-    if (nullptr != summaryTask && !summaryTask->isFinished()) {
+    if (summaryTask != nullptr && !summaryTask->isFinished()) {
         summaryTask->cancel();
     }
-    if (nullptr != searchTask && !searchTask->isFinished()) {
+    if (searchTask != nullptr && !searchTask->isFinished()) {
         searchTask->cancel();
     }
 }
 
-void SearchGenbankSequenceDialogController::addQueryBlockWidget(QWidget *w) {
+void SearchGenbankSequenceDialogController::addQueryBlockWidget(QWidget* w) {
     ui->queryBuilderBox->layout()->addWidget(w);
-    w->setObjectName("query_block_widget_" + QString::number(ui->queryBuilderBox->findChildren<QWidget *>(QRegExp("query_block_widget_\\d+")).size()));
+    w->setObjectName("query_block_widget_" + QString::number(ui->queryBuilderBox->findChildren<QWidget*>(QRegExp("query_block_widget_\\d+")).size()));
 }
 
-void SearchGenbankSequenceDialogController::removeQueryBlockWidget(QWidget *w) {
+void SearchGenbankSequenceDialogController::removeQueryBlockWidget(QWidget* w) {
     ui->queryBuilderBox->layout()->removeWidget(w);
 }
 
-void SearchGenbankSequenceDialogController::setQueryText(const QString &queryText) {
+void SearchGenbankSequenceDialogController::setQueryText(const QString& queryText) {
     ui->queryEdit->setText(queryText);
 }
 
-void SearchGenbankSequenceDialogController::prepareSummaryRequestTask(const QStringList &results) {
+void SearchGenbankSequenceDialogController::prepareSummaryRequestTask(const QStringList& results) {
     summaryTask = nullptr;
     SAFE_POINT(!results.isEmpty(), "There are no search results to process", );
     if (results.size() <= MAX_IDS_PER_QUERY) {
@@ -100,50 +99,47 @@ void SearchGenbankSequenceDialogController::prepareSummaryRequestTask(const QStr
         summaryTask = new EntrezQueryTask(summaryResultHandler.data(), query);
     } else {
         QStringList queries = splitIds(results);
-        QList<Task *> tasks;
-        foreach (const QString &query, queries) {
+        QList<Task*> tasks;
+        for (const QString& query : qAsConst(queries)) {
             tasks << new EntrezQueryTask(new ESummaryResultHandler, query);
         }
         summaryTask = new MultiTask("EntrezQueryTask", tasks, false);
     }
 }
 
-QStringList SearchGenbankSequenceDialogController::splitIds(const QStringList &idsList) {
-    const int fullQueryCount = idsList.size() / MAX_IDS_PER_QUERY;
-    const int tailIdsCount = idsList.size() % MAX_IDS_PER_QUERY;
+QStringList SearchGenbankSequenceDialogController::splitIds(const QStringList& idsList) {
+    int fullQueryCount = idsList.size() / MAX_IDS_PER_QUERY;
+    int tailIdsCount = idsList.size() % MAX_IDS_PER_QUERY;
     QStringList queries;
-
     for (int i = 0; i < fullQueryCount; i++) {
-        const QString ids = getIdsString(idsList, i * MAX_IDS_PER_QUERY, MAX_IDS_PER_QUERY);
+        QString ids = getIdsString(idsList, i * MAX_IDS_PER_QUERY, MAX_IDS_PER_QUERY);
         queries << EntrezUtils::NCBI_ESUMMARY_URL.arg(ui->databaseBox->currentText()).arg(ids);
     }
-
     if (tailIdsCount > 0) {
-        const QString tailIds = getIdsString(idsList, fullQueryCount * MAX_IDS_PER_QUERY, tailIdsCount);
+        QString tailIds = getIdsString(idsList, fullQueryCount * MAX_IDS_PER_QUERY, tailIdsCount);
         queries << EntrezUtils::NCBI_ESUMMARY_URL.arg(ui->databaseBox->currentText()).arg(tailIds);
     }
-
     return queries;
 }
 
-QString SearchGenbankSequenceDialogController::getIdsString(const QStringList &idsList, int startIndex, int count) {
-    const QStringList midList = idsList.mid(startIndex, count);
-    return midList.join(",");
+QString SearchGenbankSequenceDialogController::getIdsString(const QStringList& idsList, int startIndex, int count) {
+    return idsList.mid(startIndex, count).join(",");
 }
 
 QList<EntrezSummary> SearchGenbankSequenceDialogController::getSummaryResults() const {
     QList<EntrezSummary> results;
-    EntrezQueryTask *singleTask = qobject_cast<EntrezQueryTask *>(summaryTask);
-    MultiTask *multiTask = qobject_cast<MultiTask *>(summaryTask);
-    if (nullptr != singleTask) {
-        SAFE_POINT(nullptr != summaryResultHandler, L10N::nullPointerError("summary results handler"), results);
+    auto singleTask = qobject_cast<EntrezQueryTask*>(summaryTask);
+    auto multiTask = qobject_cast<MultiTask*>(summaryTask);
+    if (singleTask != nullptr) {
+        SAFE_POINT_NN(summaryResultHandler, results);
         results << summaryResultHandler->getResults();
-    } else if (nullptr != multiTask) {
-        foreach (const QPointer<Task> &subtask, multiTask->getSubtasks()) {
-            EntrezQueryTask *summarySubtask = qobject_cast<EntrezQueryTask *>(subtask.data());
-            SAFE_POINT(nullptr != summarySubtask, L10N::internalError(tr("an unexpected subtask")), results);
-            const ESummaryResultHandler *resultHandler = dynamic_cast<const ESummaryResultHandler *>(summarySubtask->getResultHandler());
-            SAFE_POINT(nullptr != resultHandler, L10N::nullPointerError("ESummaryResultHandler"), results);
+    } else if (multiTask != nullptr) {
+        QList<QPointer<Task>> multiTaskSubtasks = multiTask->getSubtasks();
+        for (const QPointer<Task>& subtask : qAsConst(multiTaskSubtasks)) {
+            auto summarySubtask = qobject_cast<EntrezQueryTask*>(subtask.data());
+            SAFE_POINT(summarySubtask != nullptr, L10N::internalError(tr("an unexpected subtask")), results);
+            auto resultHandler = dynamic_cast<const ESummaryResultHandler*>(summarySubtask->getResultHandler());
+            SAFE_POINT_NN(resultHandler, results);
             results << resultHandler->getResults();
             delete resultHandler;
         }
@@ -152,13 +148,9 @@ QList<EntrezSummary> SearchGenbankSequenceDialogController::getSummaryResults()
 }
 
 void SearchGenbankSequenceDialogController::sl_searchButtonClicked() {
-    if (!ui->searchButton->isEnabled()) {
-        return;
-    }
+    CHECK(ui->searchButton->isEnabled(), );
     QString query = ui->queryEdit->toPlainText();
-    if (query.isEmpty()) {
-        return;
-    }
+    CHECK(!query.isEmpty(), );
 
     int maxRet = ui->resultLimitBox->value();
     QString qUrl(EntrezUtils::NCBI_ESEARCH_URL.arg(ui->databaseBox->currentText()).arg(query).arg(maxRet));
@@ -169,42 +161,36 @@ void SearchGenbankSequenceDialogController::sl_searchButtonClicked() {
     ui->searchButton->setDisabled(true);
 }
 
-void SearchGenbankSequenceDialogController::sl_taskStateChanged(Task *task) {
-    if (task->getState() == Task::State_Finished) {
-        if (task == searchTask) {
-            ui->treeWidget->clear();
-            const QStringList &results = searchResultHandler->getIdList();
-            if (results.size() == 0) {
-                QMessageBox::information(this, windowTitle(), tr("No results found corresponding to the query"));
-                ui->searchButton->setEnabled(true);
-            } else {
-                prepareSummaryRequestTask(results);
-                if (nullptr != summaryTask) {
-                    AppContext::getTaskScheduler()->registerTopLevelTask(summaryTask);
-                }
-            }
-            searchTask = nullptr;
-        } else if (task == summaryTask) {
-            QList<EntrezSummary> results = getSummaryResults();
-
-            foreach (const EntrezSummary &desc, results) {
-                QTreeWidgetItem *item = new QTreeWidgetItem(ui->treeWidget);
-                item->setText(0, desc.name);
-                item->setText(1, desc.title);
-                item->setText(2, QString("%1").arg(desc.size));
-                ui->treeWidget->addTopLevelItem(item);
-            }
-            summaryTask = nullptr;
+void SearchGenbankSequenceDialogController::sl_taskStateChanged(Task* task) {
+    CHECK(task->getState() == Task::State_Finished, );
+    if (task == searchTask) {
+        ui->treeWidget->clear();
+        const QStringList& results = searchResultHandler->getIdList();
+        if (results.size() == 0) {
+            QMessageBox::information(this, windowTitle(), tr("No results found corresponding to the query"));
             ui->searchButton->setEnabled(true);
+        } else {
+            prepareSummaryRequestTask(results);
+            if (summaryTask != nullptr) {
+                AppContext::getTaskScheduler()->registerTopLevelTask(summaryTask);
+            }
         }
+        searchTask = nullptr;
+    } else if (task == summaryTask) {
+        QList<EntrezSummary> results = getSummaryResults();
+
+        for (const EntrezSummary& desc : qAsConst(results)) {
+            ui->treeWidget->addTopLevelItem(new SearchResultRowItem(ui->treeWidget, desc));
+        }
+        summaryTask = nullptr;
+        ui->searchButton->setEnabled(true);
     }
 }
 
 void SearchGenbankSequenceDialogController::sl_downloadButtonClicked() {
-    QList<QTreeWidgetItem *> selectedItems = ui->treeWidget->selectedItems();
-
+    QList<QTreeWidgetItem*> selectedItems = ui->treeWidget->selectedItems();
     QStringList ids;
-    foreach (QTreeWidgetItem *item, selectedItems) {
+    for (QTreeWidgetItem* item : qAsConst(selectedItems)) {
         ids.append(item->text(0));
     }
 
@@ -218,13 +204,13 @@ void SearchGenbankSequenceDialogController::sl_itemSelectionChanged() {
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 
-QueryBlockWidget::QueryBlockWidget(QueryBuilderController *controller, bool first)
+QueryBlockWidget::QueryBlockWidget(QueryBuilderController* controller, bool first)
     : conditionBox(nullptr), termBox(nullptr), queryEdit(nullptr) {
-    QBoxLayout *layout = new QBoxLayout(QBoxLayout::LeftToRight, this);
+    auto layout = new QBoxLayout(QBoxLayout::LeftToRight, this);
     layout->setMargin(0);
 
     if (first) {
-        QLabel *label = new QLabel(tr("Term:"));
+        auto label = new QLabel(tr("Term:"));
         layout->addWidget(label);
     } else {
         conditionBox = new QComboBox(this);
@@ -242,20 +228,20 @@ QueryBlockWidget::QueryBlockWidget(QueryBuilderController *controller, bool firs
 
     queryEdit = new QLineEdit(this);
     queryEdit->setObjectName("queryEditLineEdit");
-    connect(queryEdit, SIGNAL(textEdited(const QString &)), controller, SLOT(sl_updateQuery()));
+    connect(queryEdit, SIGNAL(textEdited(const QString&)), controller, SLOT(sl_updateQuery()));
     connect(queryEdit, SIGNAL(returnPressed()), controller, SLOT(sl_queryReturnPressed()));
 
     layout->addWidget(termBox);
     layout->addWidget(queryEdit);
 
     if (first) {
-        QToolButton *addBlockButton = new QToolButton();
+        auto addBlockButton = new QToolButton();
         addBlockButton->setText("+");
         layout->addWidget(addBlockButton);
         connect(addBlockButton, SIGNAL(clicked()), controller, SLOT(sl_addQueryBlockWidget()));
         addBlockButton->setObjectName("add_block_button");
     } else {
-        QToolButton *removeBlockButton = new QToolButton();
+        auto removeBlockButton = new QToolButton();
         removeBlockButton->setText("-");
         layout->addWidget(removeBlockButton);
         connect(removeBlockButton, SIGNAL(clicked()), controller, SLOT(sl_removeQueryBlockWidget()));
@@ -265,54 +251,45 @@ QueryBlockWidget::QueryBlockWidget(QueryBuilderController *controller, bool firs
     setLayout(layout);
 }
 
-QueryBlockWidget::~QueryBlockWidget() {
+void QueryBlockWidget::setInputFocus() {
+    queryEdit->setFocus();
 }
 
-QString QueryBlockWidget::getQuery() {
-    QString query;
-
-    query = queryEdit->text();
-
-    if (query.isEmpty()) {
-        return query;
-    }
+QString QueryBlockWidget::getQuery() const {
+    QString query = queryEdit->text();
+    CHECK(!query.isEmpty(), "");
 
     if (termBox->currentIndex() != 0) {
         query += "[" + termBox->currentText() + "]";
     }
-
     if (conditionBox) {
         query.prepend(" " + conditionBox->currentText() + " ");
     }
-
     return query;
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 
-QueryBuilderController::QueryBuilderController(SearchGenbankSequenceDialogController *p)
+QueryBuilderController::QueryBuilderController(SearchGenbankSequenceDialogController* p)
     : QObject(p), parentController(p) {
-    QueryBlockWidget *widget = new QueryBlockWidget(this, true);
+    auto widget = new QueryBlockWidget(this, true);
     parentController->addQueryBlockWidget(widget);
     queryBlockWidgets.append(widget);
     widget->setInputFocus();
 }
 
-QueryBuilderController::~QueryBuilderController() {
-}
-
 void QueryBuilderController::sl_addQueryBlockWidget() {
-    QueryBlockWidget *widget = new QueryBlockWidget(this, false);
+    auto widget = new QueryBlockWidget(this, false);
     parentController->addQueryBlockWidget(widget);
     queryBlockWidgets.append(widget);
 }
 
 void QueryBuilderController::sl_removeQueryBlockWidget() {
-    QToolButton *callbackButton = qobject_cast<QToolButton *>(sender());
-    assert(callbackButton);
+    auto callbackButton = qobject_cast<QToolButton*>(sender());
+    SAFE_POINT(callbackButton, "Not a callbackButton", );
 
-    QueryBlockWidget *queryBlockWidget = qobject_cast<QueryBlockWidget *>(callbackButton->parentWidget());
-    assert(queryBlockWidget);
+    auto queryBlockWidget = qobject_cast<QueryBlockWidget*>(callbackButton->parentWidget());
+    SAFE_POINT(callbackButton, "Not a queryBlockWidget", );
 
     parentController->removeQueryBlockWidget(queryBlockWidget);
     queryBlockWidgets.removeAll(queryBlockWidget);
@@ -324,7 +301,7 @@ void QueryBuilderController::sl_removeQueryBlockWidget() {
 
 void QueryBuilderController::sl_updateQuery() {
     QString query;
-    foreach (QueryBlockWidget *w, queryBlockWidgets) {
+    for (QueryBlockWidget* w : qAsConst(queryBlockWidgets)) {
         query += w->getQuery();
     }
 
@@ -335,4 +312,23 @@ void QueryBuilderController::sl_queryReturnPressed() {
     parentController->sl_searchButtonClicked();
 }
 
+SearchResultRowItem::SearchResultRowItem(QTreeWidget* treeWidget, const EntrezSummary& desc)
+    : QTreeWidgetItem(treeWidget) {
+    setText(0, desc.name);
+    setText(1, desc.title);
+    setText(2, QString("%1").arg(desc.size));
+    setData(2, Qt::UserRole, desc.size);
+    setTextAlignment(2, Qt::AlignRight);
+}
+
+bool SearchResultRowItem::operator<(const QTreeWidgetItem& other) const {
+    int column = treeWidget()->sortColumn();
+    if (column == 2) {
+        int myValue = data(2, Qt::UserRole).toInt();
+        int otherValue = other.data(2, Qt::UserRole).toInt();
+        return myValue < otherValue;
+    }
+    return QTreeWidgetItem::operator<(other);
+}
+
 }  // namespace U2
