@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQ_PASTER_WIDGET_CONTROLLER_H_
-#define _U2_SEQ_PASTER_WIDGET_CONTROLLER_H_
+#pragma once
 
 #include <QWidget>
 
@@ -33,33 +32,31 @@ namespace U2 {
 class U2GUI_EXPORT SeqPasterWidgetController : public QWidget {
     Q_OBJECT
 public:
-    SeqPasterWidgetController(QWidget *p = nullptr, const QByteArray &initText = QByteArray(), bool needWarning = false);
+    SeqPasterWidgetController(QWidget* p = nullptr, const QByteArray& initText = QByteArray(), bool needWarning = false);
     ~SeqPasterWidgetController();
 
     QString validate();
     QList<DNASequence> getSequences() const;
     void disableCustomSettings();
-    void setPreferredAlphabet(const DNAAlphabet *alp);
+    void setPreferredAlphabet(const DNAAlphabet* alp);
     void selectText();
-    void setEventFilter(QObject *evFilter);
+    void setEventFilter(QObject* evFilter);
     void allowFastaFormat(bool allow);
 
-    static QByteArray getNormSequence(const DNAAlphabet *alph, const QByteArray &seq, bool replace, QChar replaceChar);
+    static QByteArray getNormSequence(const DNAAlphabet* alph, const QByteArray& seq, bool replace, QChar replaceChar);
 
 private slots:
-    void sl_currentIndexChanged(const QString &newText);
+    void sl_currentIndexChanged(const QString& newText);
 
 private:
-    QString addSequence(const QString &name, QString data);
-    static bool isFastaFormat(const QString &data);
+    QString addSequence(const QString& name, QString data);
+    static bool isFastaFormat(const QString& data);
 
-    const DNAAlphabet *preferred;
+    const DNAAlphabet* preferred;
     QList<DNASequence> resultSequences;
-    Ui_SeqPasterWidget *ui;
+    Ui_SeqPasterWidget* ui;
     bool additionalWarning;
     bool allowFastaFormatMode;
 };
 
 }  // namespace U2
-
-#endif
