@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_TEXT_EDIT_H_
-#define _U2_SEQUENCE_TEXT_EDIT_H_
+#pragma once
 
 #include <QPlainTextEdit>
 
@@ -37,15 +36,13 @@ public:
      * So, inserting a big sequence as one huge paragraph will cause perfomance problems.
      * TextEdit splits inserted data to paragraphs with the size PARAGRAPH_SIZE.
      */
-    SequenceTextEdit(QWidget *p = nullptr);
+    SequenceTextEdit(QWidget* p = nullptr);
 
 protected:
-    virtual void insertFromMimeData(const QMimeData *source);
+    virtual void insertFromMimeData(const QMimeData* source);
 
     static const int PARAGRAPH_SIZE = 5120;
     static const int NO_QUESTION_LIMIT = 5000000;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SEQUENCE_TEXT_EDIT_H_
