@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TREE_WIDGET_UTILS_H_
-#define _U2_TREE_WIDGET_UTILS_H_
+#pragma once
 
 #include <QTreeWidget>
 
@@ -32,10 +31,10 @@ class TreeWidgetVisitor {
 public:
     virtual ~TreeWidgetVisitor() {
     }
-    virtual bool isChildVisitRequired(QTreeWidgetItem *) {
+    virtual bool isChildVisitRequired(QTreeWidgetItem*) {
         return true;
     }
-    virtual void visit(QTreeWidgetItem *item) = 0;
+    virtual void visit(QTreeWidgetItem* item) = 0;
 };
 
 class U2GUI_EXPORT TreeWidgetUtils {
@@ -44,9 +43,7 @@ private:
     }
 
 public:
-    static void visitDFS(QTreeWidget *tree, TreeWidgetVisitor *visitor);
+    static void visitDFS(QTreeWidget* tree, TreeWidgetVisitor* visitor);
 };
 
 }  // namespace U2
-
-#endif
