@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LONG_LONG_VALIDATOR_H_
-#define _U2_LONG_LONG_VALIDATOR_H_
+#pragma once
 
 #include <QValidator>
 
@@ -31,9 +30,9 @@ namespace U2 {
 class U2GUI_EXPORT U2LongLongValidator : public QValidator {
     Q_OBJECT
 public:
-    U2LongLongValidator(qint64 minimum, qint64 maximum, QObject *parent = 0);
+    U2LongLongValidator(qint64 minimum, qint64 maximum, QObject* parent = 0);
 
-    State validate(QString &input, int &pos) const;
+    State validate(QString& input, int& pos) const;
 
 private:
     qint64 minimum;
@@ -41,5 +40,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_LONG_LONG_VALIDATOR_H_
