@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WIDGET_WITH_LOCAL_TOOLBAR_H_
-#define _U2_WIDGET_WITH_LOCAL_TOOLBAR_H_
+#pragma once
 
 #include <QToolButton>
 #include <QWidget>
@@ -34,22 +33,21 @@ class LocalToolbar;
 class U2GUI_EXPORT WidgetWithLocalToolbar : public QWidget {
     Q_OBJECT
 public:
-    WidgetWithLocalToolbar(QWidget *p = 0);
+    WidgetWithLocalToolbar(QWidget* p = 0);
 
-    void setContentLayout(QLayout *l);
+    void setContentLayout(QLayout* l);
 
-    QToolButton *addActionToLocalToolbar(QAction *action);
+    QToolButton* addActionToLocalToolbar(QAction* action);
 
-    void setLocalToolBarObjectName(const QString &name);
+    void setLocalToolBarObjectName(const QString& name);
 
 protected:
     void setLocalToolbarVisible(bool visible);
-    QWidget *contentWidget;
+
+    QWidget* contentWidget = nullptr;
 
 private:
-    LocalToolbar *toolBar;
+    LocalToolbar* toolBar = nullptr;
 };
 
 }  // namespace U2
-
-#endif  // _U2_WIDGET_WITH_LOCAL_TOOLBAR_H_
