@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMAGE_EXPORT_TASK_H
-#define _U2_IMAGE_EXPORT_TASK_H
+#pragma once
 
 #include <QSize>
 
@@ -33,9 +32,9 @@ namespace U2 {
 
 class U2GUI_EXPORT ImageExportTaskSettings {
 public:
-    ImageExportTaskSettings(const QString &fileName = QString(),
-                            const QString &format = QString(),
-                            const QSize &size = QSize(),
+    ImageExportTaskSettings(const QString& fileName = QString(),
+                            const QString& format = QString(),
+                            const QSize& size = QSize(),
                             const int quality = -1,
                             const int dpi = 96);
 
@@ -57,7 +56,7 @@ public:
 class U2GUI_EXPORT ImageExportTask : public Task {
     Q_OBJECT
 public:
-    ImageExportTask(const ImageExportTaskSettings &settings);
+    ImageExportTask(const ImageExportTaskSettings& settings);
     virtual void run() = 0;
     ReportResult report();
 
@@ -80,14 +79,14 @@ typedef QFlags<ExportImageFormatFlag> ExportImageFormatPolicy;
 class U2GUI_EXPORT ImageExportController : public QObject {
     Q_OBJECT
 public:
-    ImageExportController(const ExportImageFormatPolicy &fPolicy = ExportImageFormatPolicy(EnableRasterFormats));
+    ImageExportController(const ExportImageFormatPolicy& fPolicy = ExportImageFormatPolicy(EnableRasterFormats));
 
-    Task *getTaskInstance(const ImageExportTaskSettings &settings) const;
+    Task* getTaskInstance(const ImageExportTaskSettings& settings) const;
 
-    const QString &getExportDescription() const {
+    const QString& getExportDescription() const {
         return shortDescription;
     }
-    QWidget *getSettingsWidget();
+    QWidget* getSettingsWidget();
 
     virtual int getImageWidth() const {
         return 0;
@@ -114,32 +113,30 @@ public:
     }
 
 public slots:
-    virtual void sl_onFormatChanged(const QString &) {
+    virtual void sl_onFormatChanged(const QString&) {
     }
 
 signals:
     void si_disableExport(bool);
-    void si_showMessage(const QString &);
+    void si_showMessage(const QString&);
 
 protected:
     virtual void initSettingsWidget() = 0;
 
-    virtual Task *getExportToSvgTask(const ImageExportTaskSettings &) const {
+    virtual Task* getExportToSvgTask(const ImageExportTaskSettings&) const {
         return nullptr;
     }
-    virtual Task *getExportToPdfTask(const ImageExportTaskSettings &) const {
+    virtual Task* getExportToPdfTask(const ImageExportTaskSettings&) const {
         return nullptr;
     }
-    virtual Task *getExportToBitmapTask(const ImageExportTaskSettings &) const {
+    virtual Task* getExportToBitmapTask(const ImageExportTaskSettings&) const {
         return nullptr;
     }
 
-    QWidget *settingsWidget;
+    QWidget* settingsWidget;
     QString shortDescription;
     QString disableMessage;
     ExportImageFormatPolicy formatPolicy;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMAGE_EXPORT_TASK_H
