@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WIDGET_SCREENSHOT_EXPORT_TASK_H_
-#define _U2_WIDGET_SCREENSHOT_EXPORT_TASK_H_
+#pragma once
 
 #include "ImageExportTask.h"
 
@@ -31,20 +30,20 @@ namespace U2 {
 class WidgetScreenshotExportTask : public ImageExportTask {
     Q_OBJECT
 public:
-    WidgetScreenshotExportTask(QWidget *widget, const ImageExportTaskSettings &settings)
+    WidgetScreenshotExportTask(QWidget* widget, const ImageExportTaskSettings& settings)
         : ImageExportTask(settings),
           widget(widget) {
     }
     virtual void run() = 0;
 
 protected:
-    QWidget *widget;
+    QWidget* widget;
 };
 
 class WidgetScreenshotExportToSvgTask : public WidgetScreenshotExportTask {
     Q_OBJECT
 public:
-    WidgetScreenshotExportToSvgTask(QWidget *widget, const ImageExportTaskSettings &settings)
+    WidgetScreenshotExportToSvgTask(QWidget* widget, const ImageExportTaskSettings& settings)
         : WidgetScreenshotExportTask(widget, settings) {
     }
     void run();
@@ -52,7 +51,7 @@ public:
 
 class WidgetScreenshotExportToPdfTask : public WidgetScreenshotExportTask {
 public:
-    WidgetScreenshotExportToPdfTask(QWidget *widget, const ImageExportTaskSettings &settings)
+    WidgetScreenshotExportToPdfTask(QWidget* widget, const ImageExportTaskSettings& settings)
         : WidgetScreenshotExportTask(widget, settings) {
     }
     void run();
@@ -60,7 +59,7 @@ public:
 
 class WidgetScreenshotExportToBitmapTask : public WidgetScreenshotExportTask {
 public:
-    WidgetScreenshotExportToBitmapTask(QWidget *widget, const ImageExportTaskSettings &settings)
+    WidgetScreenshotExportToBitmapTask(QWidget* widget, const ImageExportTaskSettings& settings)
         : WidgetScreenshotExportTask(widget, settings) {
     }
     void run();
@@ -69,7 +68,7 @@ public:
 class WidgetScreenshotImageExportController : public ImageExportController {
     Q_OBJECT
 public:
-    WidgetScreenshotImageExportController(QWidget *widget);
+    WidgetScreenshotImageExportController(QWidget* widget);
 
     int getImageWidth() const;
     int getImageHeight() const;
@@ -78,14 +77,12 @@ protected:
     void initSettingsWidget() {
     }
 
-    Task *getExportToSvgTask(const ImageExportTaskSettings &settings) const;
-    Task *getExportToPdfTask(const ImageExportTaskSettings &settings) const;
-    Task *getExportToBitmapTask(const ImageExportTaskSettings &settings) const;
+    Task* getExportToSvgTask(const ImageExportTaskSettings& settings) const;
+    Task* getExportToPdfTask(const ImageExportTaskSettings& settings) const;
+    Task* getExportToBitmapTask(const ImageExportTaskSettings& settings) const;
 
 private:
-    QWidget *widget;
+    QWidget* widget;
 };
 
 }  // namespace U2
-
-#endif  // _U2_WIDGET_SCREENSHOT_EXPORT_TASK_H_
