@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CONNECTIONHELPER_H_
-#define _U2_CONNECTIONHELPER_H_
+#pragma once
 
 #include <U2Core/U2DbiUtils.h>
 #include <U2Core/U2ObjectDbi.h>
@@ -30,14 +29,12 @@ namespace U2 {
 class ConnectionHelper {
     Q_DISABLE_COPY(ConnectionHelper)
 public:
-    ConnectionHelper(const U2DbiRef &dbiRef, U2OpStatus &os);
+    ConnectionHelper(const U2DbiRef& dbiRef, U2OpStatus& os);
     ~ConnectionHelper();
 
-    DbiConnection *con;
-    U2Dbi *dbi;
-    U2ObjectDbi *oDbi;
+    DbiConnection* con;
+    U2Dbi* dbi;
+    U2ObjectDbi* oDbi;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CONNECTIONHELPER_H_
