@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EDITABLE_TREE_VIEW_H_
-#define _U2_EDITABLE_TREE_VIEW_H_
+#pragma once
 
 #include <QTreeView>
 
@@ -30,11 +29,9 @@ namespace U2 {
 
 class U2GUI_EXPORT EditableTreeView : public QTreeView {
 public:
-    EditableTreeView(QWidget *p);
+    EditableTreeView(QWidget* p);
 
     bool isEditingActive();
 };
 
 }  // namespace U2
-
-#endif  // _U2_EDITABLE_TREE_VIEW_H_
