@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FILTERED_PROJECT_ITEM_DELEGATE_H_
-#define _U2_FILTERED_PROJECT_ITEM_DELEGATE_H_
+#pragma once
 
 #include <QStyledItemDelegate>
 
@@ -28,13 +27,11 @@ namespace U2 {
 
 class FilteredProjectItemDelegate : public QStyledItemDelegate {
 public:
-    explicit FilteredProjectItemDelegate(QObject *parent);
+    explicit FilteredProjectItemDelegate(QObject* parent);
 
 protected:
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
+    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_FILTERED_PROJECT_ITEM_DELEGATE_H_
\ No newline at end of file
