@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LOADDOCUMENTTASKPROVIDER_H_
-#define _U2_LOADDOCUMENTTASKPROVIDER_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -32,9 +31,7 @@ class Task;
 class U2GUI_EXPORT LoadDocumentTaskProvider {
 public:
     virtual ~LoadDocumentTaskProvider() {};
-    virtual QList<Task *> createLoadDocumentTasks(const QList<Document *> &docs) const = 0;
+    virtual QList<Task*> createLoadDocumentTasks(const QList<Document*>& docs) const = 0;
 };
 
 }  // namespace U2
-
-#endif  // _U2_LOADDOCUMENTTASKPROVIDER_H_
