@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PROJECT_UTILS_H_
-#define _U2_PROJECT_UTILS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -32,26 +31,14 @@ class LoadUnloadedDocumentTask;
 
 class U2GUI_EXPORT ProjectUtils {
 public:
-    /** Returns true if the document is a shared database */
-    static QList<Document *> getConnectedSharedDatabases();
-    static bool areSharedDatabasesAvailable();
-    static bool isConnectedDatabaseDoc(const Document *doc);
-    static bool isDatabaseDoc(const Document *doc);
+    static bool isSystemFolder(const QString& folderPath);
 
-    static bool isFolderInRecycleBin(const QString &folderPath);
-    static bool isFolderInRecycleBinSubtree(const QString &folderPath);
-
-    static bool isSystemFolder(const QString &folderPath);
-
-    static Document *findDocument(const QString &url);
-    static bool hasLoadedDocument(const QString &url);
-    static bool hasUnloadedDocument(const QString &url);
-    static LoadUnloadedDocumentTask *findLoadTask(const QString &url);
+    static Document* findDocument(const QString& url);
+    static bool hasLoadedDocument(const QString& url);
+    static bool hasUnloadedDocument(const QString& url);
+    static LoadUnloadedDocumentTask* findLoadTask(const QString& url);
 
     static const int MAX_OBJS_TO_SHOW_LOAD_PROGRESS;
-    static const QString RECYCLE_BIN_FOLDER_PATH;
 };
 
 }  // namespace U2
-
-#endif  // _U2_PROJECTUTILS_H_
