@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -37,15 +37,15 @@
 
 namespace U2 {
 
-ProjectViewFilterModel::ProjectViewFilterModel(ProjectViewModel *srcModel, const ProjectTreeControllerModeSettings &settings, QObject *p)
+ProjectViewFilterModel::ProjectViewFilterModel(ProjectViewModel* srcModel, const ProjectTreeControllerModeSettings& settings, QObject* p)
     : QAbstractItemModel(p), settings(settings), srcModel(srcModel) {
-    SAFE_POINT(nullptr != srcModel, L10N::nullPointerError("Project view model"), );
-    connect(&filterController, SIGNAL(si_objectsFiltered(const QString &, const QList<QPointer<GObject>> &)), SLOT(sl_objectsFiltered(const QString &, const QList<QPointer<GObject>> &)));
+    SAFE_POINT_NN(srcModel, );
+    connect(&filterController, SIGNAL(si_objectsFiltered(const QString&, const QList<QPointer<GObject>>&)), SLOT(sl_objectsFiltered(const QString&, const QList<QPointer<GObject>>&)));
     connect(&filterController, SIGNAL(si_filteringStarted()), SIGNAL(si_filteringStarted()));
     connect(&filterController, SIGNAL(si_filteringFinished()), SIGNAL(si_filteringFinished()));
 
-    connect(srcModel, SIGNAL(rowsAboutToBeRemoved(const QModelIndex &, int, int)), SLOT(sl_rowsAboutToBeRemoved(const QModelIndex &, int, int)));
-    connect(srcModel, SIGNAL(dataChanged(const QModelIndex &, const QModelIndex &)), SLOT(sl_dataChanged(const QModelIndex &, const QModelIndex &)));
+    connect(srcModel, SIGNAL(rowsAboutToBeRemoved(const QModelIndex&, int, int)), SLOT(sl_rowsAboutToBeRemoved(const QModelIndex&, int, int)));
+    connect(srcModel, SIGNAL(dataChanged(const QModelIndex&, const QModelIndex&)), SLOT(sl_dataChanged(const QModelIndex&, const QModelIndex&)));
 }
 
 ProjectViewFilterModel::~ProjectViewFilterModel() {
@@ -57,9 +57,9 @@ namespace {
 QList<QPointer<Document>> getAllDocumentsSafely() {
     QList<QPointer<Document>> result;
 
-    Project *proj = AppContext::getProject();
-    SAFE_POINT(nullptr != proj, L10N::nullPointerError("project"), result);
-    foreach (Document *doc, proj->getDocuments()) {
+    Project* proj = AppContext::getProject();
+    SAFE_POINT_NN(proj, result);
+    foreach (Document* doc, proj->getDocuments()) {
         result.append(doc);
     }
     return result;
@@ -67,7 +67,7 @@ QList<QPointer<Document>> getAllDocumentsSafely() {
 
 }  // namespace
 
-void ProjectViewFilterModel::updateSettings(const ProjectTreeControllerModeSettings &newSettings) {
+void ProjectViewFilterModel::updateSettings(const ProjectTreeControllerModeSettings& newSettings) {
     settings = newSettings;
     clearFilterGroups();
 
@@ -78,16 +78,16 @@ void ProjectViewFilterModel::updateSettings(const ProjectTreeControllerModeSetti
     }
 }
 
-void ProjectViewFilterModel::addFilteredObject(const QString &filterGroupName, GObject *obj) {
+void ProjectViewFilterModel::addFilteredObject(const QString& filterGroupName, GObject* obj) {
     SAFE_POINT(!filterGroupName.isEmpty(), "Empty project filter group name", );
-    SAFE_POINT(nullptr != obj, L10N::nullPointerError("object"), );
+    SAFE_POINT_NN(obj, );
 
     if (!hasFilterGroup(filterGroupName)) {
         addFilterGroup(filterGroupName);
     }
 
-    FilteredProjectGroup *group = findFilterGroup(filterGroupName);
-    SAFE_POINT(nullptr != group, L10N::nullPointerError("project filter group"), );
+    FilteredProjectGroup* group = findFilterGroup(filterGroupName);
+    SAFE_POINT_NN(group, );
 
 #ifdef _DEBUG
     SAFE_POINT(!group->contains(obj), "Attempting to add duplicate to a filter group", );
@@ -99,55 +99,57 @@ void ProjectViewFilterModel::addFilteredObject(const QString &filterGroupName, G
     endInsertRows();
 }
 
-FilteredProjectGroup *ProjectViewFilterModel::findFilterGroup(const QString &name) const {
+FilteredProjectGroup* ProjectViewFilterModel::findFilterGroup(const QString& name) const {
     SAFE_POINT(!name.isEmpty(), "Empty project filter group name", nullptr);
 
     if (ProjectFilterNames::OBJ_NAME_FILTER_NAME == name) {
         return filterGroups.isEmpty() ? nullptr : *(filterGroups.constBegin());
     } else {
         FilteredProjectGroup testGroup(name);
-        const QList<FilteredProjectGroup *>::const_iterator begin = filterGroups.constBegin();
-        const QList<FilteredProjectGroup *>::const_iterator end = filterGroups.constEnd();
+        const QList<FilteredProjectGroup*>::const_iterator begin = filterGroups.constBegin();
+        const QList<FilteredProjectGroup*>::const_iterator end = filterGroups.constEnd();
 
-        QList<FilteredProjectGroup *>::const_iterator posNextToResult = std::upper_bound(begin, end, &testGroup, FilteredProjectGroup::groupLessThan);
+        QList<FilteredProjectGroup*>::const_iterator posNextToResult = std::upper_bound(begin, end, &testGroup, FilteredProjectGroup::groupLessThan);
         return (posNextToResult != begin && (*(--posNextToResult))->getGroupName() == name) ? *posNextToResult : nullptr;
     }
 }
 
-QModelIndex ProjectViewFilterModel::getIndexForGroup(FilteredProjectGroup *group) const {
-    const int groupRow = filterGroups.indexOf(group);
-    SAFE_POINT(-1 != groupRow, "Unexpected filter project group detected", QModelIndex());
+QModelIndex ProjectViewFilterModel::getIndexForGroup(FilteredProjectGroup* group) const {
+    SAFE_POINT(group != nullptr, "group is nullptr!", {});
+    int groupRow = filterGroups.indexOf(group);
+    SAFE_POINT(groupRow != -1, "Unexpected filter project group detected", QModelIndex());
     return createIndex(groupRow, 0, group);
 }
 
-QModelIndex ProjectViewFilterModel::getIndexForObject(const QString &groupName, GObject *obj) const {
-    FilteredProjectGroup *group = findFilterGroup(groupName);
-    SAFE_POINT(nullptr != group, L10N::nullPointerError("project filter group"), QModelIndex());
+QModelIndex ProjectViewFilterModel::getIndexForObject(const QString& groupName, GObject* obj) const {
+    FilteredProjectGroup* group = findFilterGroup(groupName);
+    SAFE_POINT_NN(group, {});
 
-    WrappedObject *wrappedObj = group->getWrappedObject(obj);
-    SAFE_POINT(nullptr != wrappedObj, L10N::nullPointerError("filtered object"), QModelIndex());
+    WrappedObject* wrappedObj = group->getWrappedObject(obj);
+    SAFE_POINT_NN(wrappedObj, {});
     return createIndex(group->getWrappedObjectNumber(wrappedObj), 0, wrappedObj);
 }
 
-void ProjectViewFilterModel::addFilterGroup(const QString &name) {
+void ProjectViewFilterModel::addFilterGroup(const QString& name) {
     SAFE_POINT(!name.isEmpty(), "Empty project filter group name", );
 #ifdef _DEBUG
     SAFE_POINT(!hasFilterGroup(name), "Attempting to add a duplicate filter group", );
 #endif
 
-    FilteredProjectGroup *newGroup = new FilteredProjectGroup(name);
-    QList<FilteredProjectGroup *>::iterator insertionPlace = std::upper_bound(filterGroups.begin(), filterGroups.end(), newGroup, FilteredProjectGroup::groupLessThan);
+    auto newGroup = new FilteredProjectGroup(name);
+    QList<FilteredProjectGroup*>::iterator insertionPlace = std::upper_bound(filterGroups.begin(), filterGroups.end(), newGroup, FilteredProjectGroup::groupLessThan);
 
-    const int groupNumber = insertionPlace - filterGroups.begin();
+    int groupNumber = insertionPlace - filterGroups.begin();
     beginInsertRows(QModelIndex(), groupNumber, groupNumber);
     filterGroups.insert(insertionPlace, newGroup);
     endInsertRows();
 
-    emit si_filterGroupAdded(createIndex(groupNumber, 0, newGroup));
+    QModelIndex groupIndex = createIndex(groupNumber, 0, newGroup);
+    emit si_filterGroupAdded(groupIndex);
 }
 
-bool ProjectViewFilterModel::hasFilterGroup(const QString &name) const {
-    return nullptr != findFilterGroup(name);
+bool ProjectViewFilterModel::hasFilterGroup(const QString& name) const {
+    return findFilterGroup(name) != nullptr;
 }
 
 void ProjectViewFilterModel::clearFilterGroups() {
@@ -159,12 +161,12 @@ void ProjectViewFilterModel::clearFilterGroups() {
     endResetModel();
 }
 
-QModelIndex ProjectViewFilterModel::mapToSource(const QModelIndex &proxyIndex) const {
+QModelIndex ProjectViewFilterModel::mapToSource(const QModelIndex& proxyIndex) const {
     switch (getType(proxyIndex)) {
         case GROUP:
             return QModelIndex();
         case OBJECT: {
-            WrappedObject *obj = toObject(proxyIndex);
+            WrappedObject* obj = toObject(proxyIndex);
             return srcModel->getIndexForObject(obj->getObject());
         }
         default:
@@ -172,12 +174,12 @@ QModelIndex ProjectViewFilterModel::mapToSource(const QModelIndex &proxyIndex) c
     }
 }
 
-int ProjectViewFilterModel::rowCount(const QModelIndex &parent) const {
+int ProjectViewFilterModel::rowCount(const QModelIndex& parent) const {
     CHECK(parent.isValid(), filterGroups.size());
 
     switch (getType(parent)) {
         case GROUP: {
-            FilteredProjectGroup *parentFilterGroup = toGroup(parent);
+            FilteredProjectGroup* parentFilterGroup = toGroup(parent);
             return parentFilterGroup->getObjectsCount();
         }
         case OBJECT:
@@ -187,34 +189,37 @@ int ProjectViewFilterModel::rowCount(const QModelIndex &parent) const {
     }
 }
 
-int ProjectViewFilterModel::columnCount(const QModelIndex & /*parent*/) const {
+int ProjectViewFilterModel::columnCount(const QModelIndex& /*parent*/) const {
     return 1;
 }
 
-void ProjectViewFilterModel::sl_objectsFiltered(const QString &groupName, const QList<QPointer<GObject>> &objs) {
-    foreach (const QPointer<GObject> &obj, objs) {
-        const QString objPath = srcModel->getObjectFolder(obj->getDocument(), obj.data());
-        if (!obj.isNull() && !ProjectUtils::isFolderInRecycleBinSubtree(objPath)) {
-            addFilteredObject(groupName, obj.data());
-        }
+void ProjectViewFilterModel::sl_objectsFiltered(const QString& groupName, const QList<QPointer<GObject>>& objs) {
+    for (const QPointer<GObject>& obj : qAsConst(objs)) {
+        CHECK_CONTINUE(!obj.isNull());
+        QString objPath = srcModel->getObjectFolder(obj->getDocument(), obj);
+        addFilteredObject(groupName, obj);
     }
 }
 
-QModelIndex ProjectViewFilterModel::index(int row, int column, const QModelIndex &parent) const {
+QModelIndex ProjectViewFilterModel::index(int row, int column, const QModelIndex& parent) const {
     if (!parent.isValid()) {
-        CHECK(row < filterGroups.size(), QModelIndex());
+        CHECK(row < filterGroups.size(), {});
         return createIndex(row, column, filterGroups[row]);
     }
 
-    switch (getType(parent)) {
-        case GROUP:
-            return createIndex(row, column, toGroup(parent)->getWrappedObject(row));
+    ItemType parentType = getType(parent);
+    switch (parentType) {
+        case GROUP: {
+            FilteredProjectGroup* group = toGroup(parent);
+            SAFE_POINT(group != nullptr, "toGroup(parent) returned nullptr!", {});
+            return createIndex(row, column, group->getWrappedObject(row));
+        }
         default:
-            FAIL("Unexpected parent item type", QModelIndex());
+            FAIL("Unexpected parent item type", {});
     }
 }
 
-QModelIndex ProjectViewFilterModel::parent(const QModelIndex &index) const {
+QModelIndex ProjectViewFilterModel::parent(const QModelIndex& index) const {
     CHECK(index.isValid(), QModelIndex());
 
     switch (getType(index)) {
@@ -227,7 +232,7 @@ QModelIndex ProjectViewFilterModel::parent(const QModelIndex &index) const {
     }
 }
 
-Qt::ItemFlags ProjectViewFilterModel::flags(const QModelIndex &index) const {
+Qt::ItemFlags ProjectViewFilterModel::flags(const QModelIndex& index) const {
     CHECK(index.isValid(), QAbstractItemModel::flags(index));
 
     switch (getType(index)) {
@@ -242,7 +247,7 @@ Qt::ItemFlags ProjectViewFilterModel::flags(const QModelIndex &index) const {
     }
 }
 
-QVariant ProjectViewFilterModel::getGroupData(const QModelIndex &index, int role) const {
+QVariant ProjectViewFilterModel::getGroupData(const QModelIndex& index, int role) const {
     SAFE_POINT(0 <= index.row() && index.row() < filterGroups.size(), "Project group number out of range", QVariant());
 
     switch (role) {
@@ -253,7 +258,7 @@ QVariant ProjectViewFilterModel::getGroupData(const QModelIndex &index, int role
     }
 }
 
-QVariant ProjectViewFilterModel::data(const QModelIndex &index, int role) const {
+QVariant ProjectViewFilterModel::data(const QModelIndex& index, int role) const {
     const ItemType itemType = getType(index);
     switch (itemType) {
         case GROUP:
@@ -265,12 +270,12 @@ QVariant ProjectViewFilterModel::data(const QModelIndex &index, int role) const
     }
 }
 
-void ProjectViewFilterModel::sl_dataChanged(const QModelIndex &before, const QModelIndex &after) {
+void ProjectViewFilterModel::sl_dataChanged(const QModelIndex& before, const QModelIndex& after) {
     SAFE_POINT(before == after, "Unexpected project item index change", );
 
     if (ProjectViewModel::itemType(before) == ProjectViewModel::OBJECT) {
-        GObject *object = ProjectViewModel::toObject(before);
-        foreach (FilteredProjectGroup *group, filterGroups) {
+        GObject* object = ProjectViewModel::toObject(before);
+        foreach (FilteredProjectGroup* group, filterGroups) {
             if (group->contains(object)) {
                 const QModelIndex proxyObjIndex = getIndexForObject(group->getGroupName(), object);
                 emit dataChanged(proxyObjIndex, proxyObjIndex);
@@ -279,17 +284,17 @@ void ProjectViewFilterModel::sl_dataChanged(const QModelIndex &before, const QMo
     }
 }
 
-void ProjectViewFilterModel::sl_rowsAboutToBeRemoved(const QModelIndex &parent, int first, int last) {
+void ProjectViewFilterModel::sl_rowsAboutToBeRemoved(const QModelIndex& parent, int first, int last) {
     SAFE_POINT(first == last, "Unexpected row range", );
 
     const QModelIndex removedIndex = srcModel->index(first, 0, parent);
-    QList<GObject *> objectsBeingRemoved;
+    QList<GObject*> objectsBeingRemoved;
     switch (ProjectViewModel::itemType(removedIndex)) {
         case ProjectViewModel::OBJECT:
             objectsBeingRemoved.append(ProjectViewModel::toObject(removedIndex));
             break;
         case ProjectViewModel::FOLDER: {
-            Folder *folder = ProjectViewModel::toFolder(removedIndex);
+            Folder* folder = ProjectViewModel::toFolder(removedIndex);
             objectsBeingRemoved.append(srcModel->getFolderObjects(folder->getDocument(), folder->getFolderPath()));
         } break;
         case ProjectViewModel::DOCUMENT:
@@ -299,13 +304,13 @@ void ProjectViewFilterModel::sl_rowsAboutToBeRemoved(const QModelIndex &parent,
             FAIL("Unexpected project item type", );
     }
 
-    foreach (GObject *obj, objectsBeingRemoved) {
-        foreach (FilteredProjectGroup *group, filterGroups) {
-            WrappedObject *wrappedObj = group->getWrappedObject(obj);
-            if (nullptr != wrappedObj) {
-                const QModelIndex parentIndex = getIndexForGroup(group);
-                const int objNumber = group->getWrappedObjectNumber(wrappedObj);
-                SAFE_POINT(-1 != objNumber, "Unexpected object number", );
+    for (GObject* obj : qAsConst(objectsBeingRemoved)) {
+        foreach (FilteredProjectGroup* group, filterGroups) {
+            WrappedObject* wrappedObj = group->getWrappedObject(obj);
+            if (wrappedObj != nullptr) {
+                QModelIndex parentIndex = getIndexForGroup(group);
+                int objNumber = group->getWrappedObjectNumber(wrappedObj);
+                SAFE_POINT(objNumber != -1, "Unexpected object number", );
                 beginRemoveRows(parentIndex, objNumber, objNumber);
                 group->removeAt(objNumber);
                 endRemoveRows();
@@ -314,13 +319,13 @@ void ProjectViewFilterModel::sl_rowsAboutToBeRemoved(const QModelIndex &parent,
     }
 }
 
-QString ProjectViewFilterModel::getStyledObjectName(GObject *obj, FilteredProjectGroup *group) const {
-    SAFE_POINT(nullptr != obj && nullptr != group, "Invalid arguments supplied", QString());
+QString ProjectViewFilterModel::getStyledObjectName(GObject* obj, FilteredProjectGroup* group) const {
+    SAFE_POINT(obj != nullptr && group != nullptr, "Invalid arguments supplied", QString());
 
     QString result = obj->getGObjectName();
     if (group->getGroupName() == ProjectFilterNames::OBJ_NAME_FILTER_NAME) {
         const QString stylePattern = "<span style=\"background-color:yellow;color:black\">%1</span>";
-        foreach (const QString &token, settings.tokensToShow) {
+        foreach (const QString& token, settings.tokensToShow) {
             int nextTokenPos = -1;
             const int tokenSize = token.length();
             while (-1 != (nextTokenPos = result.indexOf(token, nextTokenPos + 1, Qt::CaseInsensitive))) {
@@ -339,33 +344,32 @@ QString ProjectViewFilterModel::getStyledObjectName(GObject *obj, FilteredProjec
     return result;
 }
 
-QVariant ProjectViewFilterModel::getObjectData(const QModelIndex &index, int role) const {
+QVariant ProjectViewFilterModel::getObjectData(const QModelIndex& index, int role) const {
     QVariant result = srcModel->data(mapToSource(index), role);
 
-    if (Qt::DisplayRole == role) {
-        GObject *object = toObject(index)->getObject();
-        Document *parentDoc = object->getDocument();
-        if (nullptr != parentDoc) {
-            const QString objectPath = srcModel->getObjectFolder(parentDoc, object);
-            const bool isDatabase = parentDoc->isDatabaseConnection();
-            const QString itemDocInfo = parentDoc->getName() + (isDatabase ? ": " + objectPath : QString());
-            const QString objectName = getStyledObjectName(object, toGroup(index.parent()));
+    if (role == Qt::DisplayRole) {
+        GObject* object = toObject(index)->getObject();
+        Document* parentDoc = object->getDocument();
+        if (parentDoc != nullptr) {
+            QString objectPath = srcModel->getObjectFolder(parentDoc, object);
+            QString itemDocInfo = parentDoc->getName();
+            QString objectName = getStyledObjectName(object, toGroup(index.parent()));
             result = QString("%1<p style=\"margin-top:0px;font-size:small;\">%2</p>").arg(objectName).arg(itemDocInfo);
         }
     }
     return result;
 }
 
-QMimeData *ProjectViewFilterModel::mimeData(const QModelIndexList &indexes) const {
-    QSet<GObject *> uniqueObjs;
-    foreach (const QModelIndex &index, indexes) {
+QMimeData* ProjectViewFilterModel::mimeData(const QModelIndexList& indexes) const {
+    QSet<GObject*> uniqueObjs;
+    foreach (const QModelIndex& index, indexes) {
         if (isObject(index)) {
             uniqueObjs.insert(toObject(index)->getObject());
         }
     }
 
     QModelIndexList reducedIndexes;
-    foreach (GObject *obj, uniqueObjs) {
+    foreach (GObject* obj, uniqueObjs) {
         reducedIndexes.append(srcModel->getIndexForObject(obj));
     }
 
@@ -379,35 +383,35 @@ QStringList ProjectViewFilterModel::mimeTypes() const {
     return result;
 }
 
-ProjectViewFilterModel::ItemType ProjectViewFilterModel::getType(const QModelIndex &index) {
-    QObject *data = toQObject(index);
-    CHECK(nullptr != data, GROUP);
+ProjectViewFilterModel::ItemType ProjectViewFilterModel::getType(const QModelIndex& index) {
+    QObject* data = toQObject(index);
+    CHECK(data != nullptr, GROUP);
 
-    if (nullptr != qobject_cast<WrappedObject *>(data)) {
+    if (qobject_cast<WrappedObject*>(data) != nullptr) {
         return OBJECT;
-    } else if (nullptr != qobject_cast<FilteredProjectGroup *>(data)) {
+    } else if (qobject_cast<FilteredProjectGroup*>(data) != nullptr) {
         return GROUP;
     } else {
         FAIL("Unexpected data type", GROUP);
     }
 }
 
-bool ProjectViewFilterModel::isObject(const QModelIndex &index) {
-    return OBJECT == getType(index);
+bool ProjectViewFilterModel::isObject(const QModelIndex& index) {
+    return getType(index) == OBJECT;
 }
 
-QObject *ProjectViewFilterModel::toQObject(const QModelIndex &index) {
-    QObject *internalObj = static_cast<QObject *>(index.internalPointer());
-    SAFE_POINT(nullptr != internalObj, "Invalid index data", nullptr);
+QObject* ProjectViewFilterModel::toQObject(const QModelIndex& index) {
+    auto internalObj = static_cast<QObject*>(index.internalPointer());
+    SAFE_POINT(internalObj != nullptr, "Invalid index data", nullptr);
     return internalObj;
 }
 
-FilteredProjectGroup *ProjectViewFilterModel::toGroup(const QModelIndex &index) {
-    return qobject_cast<FilteredProjectGroup *>(toQObject(index));
+FilteredProjectGroup* ProjectViewFilterModel::toGroup(const QModelIndex& index) {
+    return qobject_cast<FilteredProjectGroup*>(toQObject(index));
 }
 
-WrappedObject *ProjectViewFilterModel::toObject(const QModelIndex &index) {
-    return qobject_cast<WrappedObject *>(toQObject(index));
+WrappedObject* ProjectViewFilterModel::toObject(const QModelIndex& index) {
+    return qobject_cast<WrappedObject*>(toQObject(index));
 }
 
 }  // namespace U2
