@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,6 +21,7 @@
 
 #include "FeatureKeyFilterTask.h"
 
+#include <U2Core/AnnotationTableObject.h>
 #include <U2Core/L10n.h>
 #include <U2Core/U2DbiUtils.h>
 #include <U2Core/U2FeatureDbi.h>
@@ -34,12 +35,12 @@ namespace U2 {
 /// FeatureKeyFilterTask
 //////////////////////////////////////////////////////////////////////////
 
-FeatureKeyFilterTask::FeatureKeyFilterTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document>> &docs)
+FeatureKeyFilterTask::FeatureKeyFilterTask(const ProjectTreeControllerModeSettings& settings, const QList<QPointer<Document>>& docs)
     : AbstractProjectFilterTask(settings, ProjectFilterNames::FEATURE_KEY_FILTER_NAME, docs) {
 }
 
 void FeatureKeyFilterTask::run() {
-    foreach (const QPointer<Document> &doc, docs) {
+    foreach (const QPointer<Document>& doc, docs) {
         if (!doc.isNull()) {
             filterDocument(doc.data());
         }
@@ -49,35 +50,31 @@ void FeatureKeyFilterTask::run() {
     }
 }
 
-void FeatureKeyFilterTask::filterDocument(Document *doc) {
-    SAFE_POINT_EXT(nullptr != doc, stateInfo.setError(L10N::nullPointerError("document")), );
+void FeatureKeyFilterTask::filterDocument(Document* doc) {
+    SAFE_POINT_EXT(doc != nullptr, stateInfo.setError(L10N::nullPointerError("document")), );
     CHECK(doc->isLoaded(), );
-
     const U2DbiRef dbiRef = doc->getDbiRef();
-    SAFE_POINT_EXT(dbiRef.isValid(), setError(tr("DbiRef is invalid")), );
-    if (!dbiRef2AnnotationTables.contains(dbiRef)) {
-        DbiConnection connection(dbiRef, stateInfo);
-        CHECK_OP(stateInfo, );
-        SAFE_POINT_EXT(nullptr != connection.dbi, stateInfo.setError(L10N::nullPointerError("Database connection")), );
-        U2FeatureDbi *featureDbi = connection.dbi->getFeatureDbi();
-        SAFE_POINT_EXT(nullptr != featureDbi, stateInfo.setError(L10N::nullPointerError("Feature DBI")), );
-
-        dbiRef2AnnotationTables[dbiRef] = featureDbi->getAnnotationTablesByFeatureKey(settings.tokensToShow, stateInfo);
-        SAFE_POINT_OP(stateInfo, );
-    }
-
-    const QMap<U2DataId, QStringList> &annNames = dbiRef2AnnotationTables[dbiRef];
-    const int foundObjectsNumber = annNames.size();
+    SAFE_POINT_EXT(dbiRef.isValid(), setError(tr("DbiRef is invalid")), );    
+    DbiConnection connection(dbiRef, stateInfo);
+    CHECK_OP(stateInfo, );
+    SAFE_POINT_EXT(connection.dbi != nullptr, stateInfo.setError(L10N::nullPointerError("Database connection")), );
+    U2FeatureDbi* featureDbi = connection.dbi->getFeatureDbi();
+    SAFE_POINT_EXT(featureDbi != nullptr, stateInfo.setError(L10N::nullPointerError("Feature DBI")), );    
+    QMap<U2DataId, QStringList> annotationTablesByFk = featureDbi->getAnnotationTablesByFeatureKey(settings.tokensToShow, stateInfo, doc->findGObjectIdsByType(GObjectTypes::ANNOTATION_TABLE));
+    SAFE_POINT_OP(stateInfo, );
+    CHECK(!annotationTablesByFk.isEmpty(), );
+    const int foundObjectsNumber = annotationTablesByFk.size();
     const int totalDocObjectsNumber = doc->getObjects().size();
-    foreach (const U2DataId &annTableId, annNames.keys()) {
-        GObject *annTable = doc->getObjectById(annTableId);
-        if (nullptr == annTable) {
+    foreach (const U2DataId& annTableId, annotationTablesByFk.keys()) {
+        GObject* annTable = doc->getObjectById(annTableId);
+        if (annTable == nullptr) {
             coreLog.error("Annotation table object not found in the document");
             continue;
         }
         SafeObjList filteredResult;
         filteredResult.append(annTable);
-        foreach (const QString &filterName, annNames[annTableId]) {
+        QStringList filterNames = annotationTablesByFk[annTableId];
+        for (const QString& filterName : qAsConst(filterNames)) {
             emit si_objectsFiltered(filterName, filteredResult);
         }
         stateInfo.setProgress(stateInfo.getProgress() + (totalDocObjectsNumber / foundObjectsNumber / totalObjectCount) * 100);
@@ -91,9 +88,10 @@ void FeatureKeyFilterTask::filterDocument(Document *doc) {
 /// FeatureKeyFilterTaskFactory
 //////////////////////////////////////////////////////////////////////////
 
-AbstractProjectFilterTask *FeatureKeyFilterTaskFactory::createNewTask(const ProjectTreeControllerModeSettings &settings,
-                                                                      const QList<QPointer<Document>> &docs) const {
-    return new FeatureKeyFilterTask(settings, docs);
+AbstractProjectFilterTask* FeatureKeyFilterTaskFactory::createNewTask(const ProjectTreeControllerModeSettings& settings,
+                                                                      const QList<QPointer<Document>>& docs) const {
+    QList<QPointer<Document>> acceptedDocs = getAcceptedDocs(docs, {GObjectTypes::ANNOTATION_TABLE});
+    return acceptedDocs.isEmpty() ? nullptr : new FeatureKeyFilterTask(settings, acceptedDocs);
 }
 
 }  // namespace U2
