@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,13 +32,13 @@ namespace U2 {
 /// SequenceAccFilterTask
 //////////////////////////////////////////////////////////////////////////
 
-SequenceAccFilterTask::SequenceAccFilterTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document>> &docs)
+SequenceAccFilterTask::SequenceAccFilterTask(const ProjectTreeControllerModeSettings& settings, const QList<QPointer<Document>>& docs)
     : AbstractProjectFilterTask(settings, ProjectFilterNames::SEQUENCE_ACC_FILTER_NAME, docs) {
 }
 
-bool SequenceAccFilterTask::filterAcceptsObject(GObject *obj) {
-    U2SequenceObject *seqObject = qobject_cast<U2SequenceObject *>(obj);
-    CHECK(nullptr != seqObject, false);
+bool SequenceAccFilterTask::filterAcceptsObject(GObject* obj) {
+    auto seqObject = qobject_cast<U2SequenceObject*>(obj);
+    CHECK(seqObject != nullptr, false);
     return settings.nameFilterAcceptsString(seqObject->getSequenceInfo()[DNAInfo::ACCESSION].toString());
 }
 
@@ -46,9 +46,10 @@ bool SequenceAccFilterTask::filterAcceptsObject(GObject *obj) {
 /// SequenceAccFilterTaskFactory
 //////////////////////////////////////////////////////////////////////////
 
-AbstractProjectFilterTask *SequenceAccFilterTaskFactory::createNewTask(const ProjectTreeControllerModeSettings &settings,
-                                                                       const QList<QPointer<Document>> &docs) const {
-    return new SequenceAccFilterTask(settings, docs);
+AbstractProjectFilterTask* SequenceAccFilterTaskFactory::createNewTask(const ProjectTreeControllerModeSettings& settings,
+                                                                       const QList<QPointer<Document>>& docs) const {
+    QList<QPointer<Document>> acceptedDocs = getAcceptedDocs(docs, {GObjectTypes::SEQUENCE});
+    return acceptedDocs.isEmpty() ? nullptr : new SequenceAccFilterTask(settings, acceptedDocs);
 }
 
 }  // namespace U2
