@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_ACC_FILTER_TASK_H_
-#define _U2_SEQUENCE_ACC_FILTER_TASK_H_
+#pragma once
 
 #include <U2Core/AbstractProjectFilterTask.h>
 
@@ -32,10 +31,10 @@ namespace U2 {
 
 class SequenceAccFilterTask : public AbstractProjectFilterTask {
 public:
-    SequenceAccFilterTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document>> &docs);
+    SequenceAccFilterTask(const ProjectTreeControllerModeSettings& settings, const QList<QPointer<Document>>& docs);
 
 protected:
-    bool filterAcceptsObject(GObject *obj);
+    bool filterAcceptsObject(GObject* obj);
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -44,9 +43,7 @@ protected:
 
 class U2GUI_EXPORT SequenceAccFilterTaskFactory : public ProjectFilterTaskFactory {
 protected:
-    AbstractProjectFilterTask *createNewTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document>> &docs) const;
+    AbstractProjectFilterTask* createNewTask(const ProjectTreeControllerModeSettings& settings, const QList<QPointer<Document>>& docs) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SEQUENCE_ACC_FILTER_TASK_H_
