@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,13 +32,13 @@ namespace U2 {
 /// TextContentFilterTask
 //////////////////////////////////////////////////////////////////////////
 
-TextContentFilterTask::TextContentFilterTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document>> &docs)
+TextContentFilterTask::TextContentFilterTask(const ProjectTreeControllerModeSettings& settings, const QList<QPointer<Document>>& docs)
     : AbstractProjectFilterTask(settings, ProjectFilterNames::TEXT_CONTENT_FILTER_NAME, docs) {
 }
 
-bool TextContentFilterTask::filterAcceptsObject(GObject *obj) {
-    TextObject *textObject = qobject_cast<TextObject *>(obj);
-    CHECK(nullptr != textObject, false);
+bool TextContentFilterTask::filterAcceptsObject(GObject* obj) {
+    auto textObject = qobject_cast<TextObject*>(obj);
+    CHECK(textObject != nullptr, false);
     return settings.nameFilterAcceptsString(textObject->getText());
 }
 
@@ -46,9 +46,10 @@ bool TextContentFilterTask::filterAcceptsObject(GObject *obj) {
 /// TextContentFilterTaskFactory
 //////////////////////////////////////////////////////////////////////////
 
-AbstractProjectFilterTask *TextContentFilterTaskFactory::createNewTask(const ProjectTreeControllerModeSettings &settings,
-                                                                       const QList<QPointer<Document>> &docs) const {
-    return new TextContentFilterTask(settings, docs);
+AbstractProjectFilterTask* TextContentFilterTaskFactory::createNewTask(const ProjectTreeControllerModeSettings& settings,
+                                                                       const QList<QPointer<Document>>& docs) const {
+    QList<QPointer<Document>> acceptedDocs = getAcceptedDocs(docs, {GObjectTypes::TEXT});
+    return acceptedDocs.isEmpty() ? nullptr : new TextContentFilterTask(settings, acceptedDocs);
 }
 
 }  // namespace U2
