@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_OPTIONS_WIDGET_H_
-#define _U2_IMPORT_OPTIONS_WIDGET_H_
+#pragma once
 
 #include <QWidget>
 
@@ -34,18 +33,16 @@ class U2GUI_EXPORT ImportOptionsWidget : public QWidget {
     Q_OBJECT
 
 public:
-    ImportOptionsWidget(QWidget *parent = 0);
+    ImportOptionsWidget(QWidget* parent = 0);
     ~ImportOptionsWidget();
 
-    void init(const QString &baseFolder, const ImportToDatabaseOptions &options);
+    void init(const QString& baseFolder, const ImportToDatabaseOptions& options);
 
     QString getFolder() const;
     ImportToDatabaseOptions getOptions() const;
 
 private:
-    Ui_ImportOptionsWidget *ui;
+    Ui_ImportOptionsWidget* ui;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_OPTIONS_WIDGET_H_
