@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -51,7 +51,7 @@
 
 namespace U2 {
 
-ImportToDatabaseDialog::ImportToDatabaseDialog(Document *dbConnection, const QString &defaultFolder, QWidget *parent)
+ImportToDatabaseDialog::ImportToDatabaseDialog(Document* dbConnection, const QString& defaultFolder, QWidget* parent)
     : QDialog(parent),
       ui(new Ui_ImportToDatabaseDialog),
       dbConnection(dbConnection),
@@ -75,20 +75,20 @@ void ImportToDatabaseDialog::sl_selectionChanged() {
     updateState();
 }
 
-void ImportToDatabaseDialog::sl_itemDoubleClicked(QTreeWidgetItem *item, int column) {
+void ImportToDatabaseDialog::sl_itemDoubleClicked(QTreeWidgetItem* item, int column) {
     CHECK(COLUMN_FOLDER == column, );
     ui->twOrders->editItem(item, column);
 }
 
-void ImportToDatabaseDialog::sl_itemChanged(QTreeWidgetItem *item, int column) {
+void ImportToDatabaseDialog::sl_itemChanged(QTreeWidgetItem* item, int column) {
     CHECK(COLUMN_FOLDER == column, );
     const QString dstFolder = item->text(column);
     item->setText(column, U2DbiUtils::makeFolderCanonical(dstFolder));
 }
 
-void ImportToDatabaseDialog::sl_customContextMenuRequested(const QPoint &position) {
-    QTreeWidgetItem *item = ui->twOrders->currentItem();
-    CHECK(nullptr != item, );
+void ImportToDatabaseDialog::sl_customContextMenuRequested(const QPoint& position) {
+    QTreeWidgetItem* item = ui->twOrders->currentItem();
+    CHECK(item != nullptr, );
     CHECK(isEssential(item), );
 
     ui->twOrders->setCurrentItem(item);
@@ -106,8 +106,8 @@ void ImportToDatabaseDialog::sl_customContextMenuRequested(const QPoint &positio
 }
 
 void ImportToDatabaseDialog::sl_resetOptions() {
-    QTreeWidgetItem *item = ui->twOrders->currentItem();
-    CHECK(nullptr != item, );
+    QTreeWidgetItem* item = ui->twOrders->currentItem();
+    CHECK(item != nullptr, );
 
     const ImportToDatabaseOptions oldOptions = privateOptions.take(item);
     updateItemsState(oldOptions, commonOptions);
@@ -116,7 +116,7 @@ void ImportToDatabaseDialog::sl_resetOptions() {
 
 void ImportToDatabaseDialog::sl_addFileClicked() {
     const QStringList fileList = getFilesToImport();
-    foreach (const QString &url, fileList) {
+    foreach (const QString& url, fileList) {
         addFile(url);
     }
 
@@ -131,8 +131,8 @@ void ImportToDatabaseDialog::sl_addFolderClicked() {
 }
 
 void ImportToDatabaseDialog::sl_addObjectClicked() {
-    QList<Document *> docsToImport;
-    QList<GObject *> objsToImport;
+    QList<Document*> docsToImport;
+    QList<GObject*> objsToImport;
     getProjectItemsToImport(docsToImport, objsToImport);
 
     addObjectsAndDocuments(docsToImport, objsToImport);
@@ -154,8 +154,8 @@ void ImportToDatabaseDialog::sl_optionsClicked() {
 }
 
 void ImportToDatabaseDialog::sl_editOptions() {
-    QTreeWidgetItem *item = ui->twOrders->currentItem();
-    CHECK(nullptr != item, );
+    QTreeWidgetItem* item = ui->twOrders->currentItem();
+    CHECK(item != nullptr, );
 
     ImportToDatabaseOptions currentOptions = privateOptions.value(item, commonOptions);
     QObjectScopedPointer<ItemToImportEditDialog> editDialog = new ItemToImportEditDialog(item->text(COLUMN_ITEM_TEXT), item->text(COLUMN_FOLDER), currentOptions, this);
@@ -173,27 +173,27 @@ void ImportToDatabaseDialog::sl_editOptions() {
 }
 
 void ImportToDatabaseDialog::sl_removeClicked() {
-    QList<QTreeWidgetItem *> selectedItems = ui->twOrders->selectedItems();
+    QList<QTreeWidgetItem*> selectedItems = ui->twOrders->selectedItems();
     removeItems(selectedItems);
 
     updateState();
 }
 
 void ImportToDatabaseDialog::sl_taskFinished() {
-    Task *task = qobject_cast<Task *>(sender());
-    CHECK(nullptr != task, );
+    auto task = qobject_cast<Task*>(sender());
+    CHECK(task != nullptr, );
     CHECK(task->isFinished(), );
 }
 
 void ImportToDatabaseDialog::accept() {
-    QList<Task *> importTasks;
+    QList<Task*> importTasks;
     importTasks << createImportFilesTasks();
     importTasks << createImportFoldersTasks();
     importTasks << createimportObjectsTasks();
     importTasks << createImportDocumentsTasks();
 
     if (!importTasks.isEmpty()) {
-        ImportToDatabaseTask *importTask = new ImportToDatabaseTask(importTasks, 1);
+        ImportToDatabaseTask* importTask = new ImportToDatabaseTask(importTasks, 1);
         AppContext::getTaskScheduler()->registerTopLevelTask(importTask);
     }
 
@@ -210,8 +210,8 @@ void ImportToDatabaseDialog::init() {
 
 void ImportToDatabaseDialog::connectSignals() {
     connect(ui->twOrders, SIGNAL(itemSelectionChanged()), SLOT(sl_selectionChanged()));
-    connect(ui->twOrders, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), SLOT(sl_itemDoubleClicked(QTreeWidgetItem *, int)));
-    connect(ui->twOrders, SIGNAL(itemChanged(QTreeWidgetItem *, int)), SLOT(sl_itemChanged(QTreeWidgetItem *, int)));
+    connect(ui->twOrders, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)), SLOT(sl_itemDoubleClicked(QTreeWidgetItem*, int)));
+    connect(ui->twOrders, SIGNAL(itemChanged(QTreeWidgetItem*, int)), SLOT(sl_itemChanged(QTreeWidgetItem*, int)));
     connect(ui->twOrders, SIGNAL(customContextMenuRequested(QPoint)), SLOT(sl_customContextMenuRequested(QPoint)));
 
     connect(ui->pbAddFiles, SIGNAL(clicked()), SLOT(sl_addFileClicked()));
@@ -231,8 +231,8 @@ void ImportToDatabaseDialog::updateState() {
     ui->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(isOrdersFilled);
 }
 
-void ImportToDatabaseDialog::updateItemsState(const ImportToDatabaseOptions &oldOptions, const ImportToDatabaseOptions &newOptions) {
-    foreach (QTreeWidgetItem *item, folders) {
+void ImportToDatabaseDialog::updateItemsState(const ImportToDatabaseOptions& oldOptions, const ImportToDatabaseOptions& newOptions) {
+    foreach (QTreeWidgetItem* item, folders) {
         if (privateOptions.contains(item)) {
             continue;
         }
@@ -240,7 +240,7 @@ void ImportToDatabaseDialog::updateItemsState(const ImportToDatabaseOptions &old
     }
 }
 
-void ImportToDatabaseDialog::updateItemState(QTreeWidgetItem *item, const ImportToDatabaseOptions &oldOptions, const ImportToDatabaseOptions &newOptions) {
+void ImportToDatabaseDialog::updateItemState(QTreeWidgetItem* item, const ImportToDatabaseOptions& oldOptions, const ImportToDatabaseOptions& newOptions) {
     if (folders.contains(item)) {
         if (oldOptions.createSubfolderForTopLevelFolder && !newOptions.createSubfolderForTopLevelFolder) {
             QString dstFolder = item->text(COLUMN_FOLDER);
@@ -257,8 +257,8 @@ void ImportToDatabaseDialog::updateItemState(QTreeWidgetItem *item, const Import
     }
 }
 
-void ImportToDatabaseDialog::markItem(QTreeWidgetItem *item, bool mark) {
-    CHECK(nullptr != item, );
+void ImportToDatabaseDialog::markItem(QTreeWidgetItem* item, bool mark) {
+    CHECK(item != nullptr, );
 
     QFont fontItemText = item->font(COLUMN_ITEM_TEXT);
     fontItemText.setBold(mark);
@@ -271,7 +271,7 @@ void ImportToDatabaseDialog::markItem(QTreeWidgetItem *item, bool mark) {
     setTooltip(item);
 }
 
-bool ImportToDatabaseDialog::isEssential(QTreeWidgetItem *item) const {
+bool ImportToDatabaseDialog::isEssential(QTreeWidgetItem* item) const {
     return files.contains(item) ||
            folders.contains(item) ||
            treeItem2Document.contains(item) ||
@@ -320,12 +320,12 @@ QString ImportToDatabaseDialog::getFolderToImport() {
     return dir;
 }
 
-void ImportToDatabaseDialog::getProjectItemsToImport(QList<Document *> &docList, QList<GObject *> &objList) {
+void ImportToDatabaseDialog::getProjectItemsToImport(QList<Document*>& docList, QList<GObject*>& objList) {
     ProjectTreeControllerModeSettings settings;
 
     // do not show objects from the current database
-    QList<GObject *> docObjects = dbConnection->getObjects();
-    foreach (GObject *obj, docObjects) {
+    QList<GObject*> docObjects = dbConnection->getObjects();
+    foreach (GObject* obj, docObjects) {
         settings.excludeObjectList.append(obj);
     }
 
@@ -334,79 +334,79 @@ void ImportToDatabaseDialog::getProjectItemsToImport(QList<Document *> &docList,
     ProjectTreeItemSelectorDialog::selectObjectsAndDocuments(settings, this, docList, objList);
 }
 
-void ImportToDatabaseDialog::addFolder(const QString &url) {
+void ImportToDatabaseDialog::addFolder(const QString& url) {
     CHECK(!url.isEmpty(), );
 
     const QString dstFolder = commonOptions.createSubfolderForTopLevelFolder ? U2DbiUtils::makeFolderCanonical(baseFolder + U2ObjectDbi::PATH_SEP + QFileInfo(url).fileName()) : baseFolder;
 
-    QTreeWidgetItem *newItem = new QTreeWidgetItem(QStringList() << url << dstFolder);
+    QTreeWidgetItem* newItem = new QTreeWidgetItem(QStringList() << url << dstFolder);
     newItem->setIcon(COLUMN_ITEM_TEXT, QIcon(":U2Designer/images/directory.png"));
     newItem->setFlags(Qt::ItemIsEditable | newItem->flags());
     setFolderTooltip(newItem);
     folders << newItem;
 
-    QTreeWidgetItem *headerItem = getHeaderItem(FILE_AND_FOLDER);
+    QTreeWidgetItem* headerItem = getHeaderItem(FILE_AND_FOLDER);
     headerItem->addChild(newItem);
     headerItem->setExpanded(true);
 }
 
-void ImportToDatabaseDialog::addFile(const QString &url) {
+void ImportToDatabaseDialog::addFile(const QString& url) {
     CHECK(!url.isEmpty(), );
 
-    QTreeWidgetItem *newItem = new QTreeWidgetItem(QStringList() << url << baseFolder);
+    QTreeWidgetItem* newItem = new QTreeWidgetItem(QStringList() << url << baseFolder);
     newItem->setIcon(COLUMN_ITEM_TEXT, QIcon(":/core/images/document.png"));
     newItem->setFlags(Qt::ItemIsEditable | newItem->flags());
     setFileTooltip(newItem);
     files << newItem;
 
-    QTreeWidgetItem *headerItem = getHeaderItem(FILE_AND_FOLDER);
+    QTreeWidgetItem* headerItem = getHeaderItem(FILE_AND_FOLDER);
     headerItem->addChild(newItem);
     headerItem->setExpanded(true);
 }
 
-void ImportToDatabaseDialog::addObjectsAndDocuments(const QList<Document *> &docsToImport, const QList<GObject *> &objsToImport) {
-    foreach (Document *doc, docsToImport) {
+void ImportToDatabaseDialog::addObjectsAndDocuments(const QList<Document*>& docsToImport, const QList<GObject*>& objsToImport) {
+    foreach (Document* doc, docsToImport) {
         addDocument(doc);
     }
 
-    foreach (GObject *object, objsToImport) {
+    foreach (GObject* object, objsToImport) {
         addObject(object, nullptr);
     }
 }
 
-void ImportToDatabaseDialog::addDocument(Document *document) {
-    CHECK(nullptr != document, );
+void ImportToDatabaseDialog::addDocument(Document* document) {
+    CHECK(document != nullptr, );
 
-    QTreeWidgetItem *newItem = new QTreeWidgetItem(QStringList() << document->getName() << baseFolder);
+    QTreeWidgetItem* newItem = new QTreeWidgetItem(QStringList() << document->getName() << baseFolder);
     newItem->setIcon(COLUMN_ITEM_TEXT, QIcon(":/core/images/document.png"));
     newItem->setFlags(Qt::ItemIsEditable | newItem->flags());
     setDocumentTooltip(newItem);
     treeItem2Document.insert(newItem, document);
 
-    QTreeWidgetItem *headerItem = getHeaderItem(OBJECT_AND_DOCUMENT);
+    QTreeWidgetItem* headerItem = getHeaderItem(OBJECT_AND_DOCUMENT);
     headerItem->addChild(newItem);
     headerItem->setExpanded(true);
 
     addSubObjects(document, newItem);
 }
 
-void ImportToDatabaseDialog::addObject(GObject *object, QTreeWidgetItem *parent) {
-    CHECK(nullptr != object, );
-    CHECK(nullptr != object->getDocument(), );
+void ImportToDatabaseDialog::addObject(GObject* object, QTreeWidgetItem* parent) {
+    CHECK(object != nullptr, );
+    CHECK(object->getDocument() != nullptr, );
 
     const QString objectText = "[" + GObjectTypes::getTypeInfo(object->getGObjectType()).treeSign + "] " + object->getGObjectName();
 
     QString dstFolder = baseFolder;
-    if (nullptr != parent &&
-        nullptr != treeItem2Document.value(parent, nullptr) &&
+    if (parent != nullptr &&
+        treeItem2Document.value(parent, nullptr) != nullptr &&
         commonOptions.createSubfolderForEachDocument) {
         dstFolder = baseFolder + U2ObjectDbi::PATH_SEP + treeItem2Document[parent]->getName();
         dstFolder = U2DbiUtils::makeFolderCanonical(dstFolder);
     }
 
-    QTreeWidgetItem *newItem = new QTreeWidgetItem(QStringList() << objectText << dstFolder);
+    QTreeWidgetItem* newItem = new QTreeWidgetItem(QStringList() << objectText << dstFolder);
 
-    if (nullptr == parent) {
+    if (parent == nullptr) {
         treeItem2Object[newItem] = object;
         setObjectTooltip(newItem);
         parent = getHeaderItem(OBJECT_AND_DOCUMENT);
@@ -420,19 +420,19 @@ void ImportToDatabaseDialog::addObject(GObject *object, QTreeWidgetItem *parent)
     parent->setExpanded(true);
 }
 
-void ImportToDatabaseDialog::addSubObjects(Document *document, QTreeWidgetItem *docItem) {
-    foreach (GObject *object, document->getObjects()) {
+void ImportToDatabaseDialog::addSubObjects(Document* document, QTreeWidgetItem* docItem) {
+    foreach (GObject* object, document->getObjects()) {
         addObject(object, docItem);
     }
 }
 
-void ImportToDatabaseDialog::removeItems(QList<QTreeWidgetItem *> itemList) {
+void ImportToDatabaseDialog::removeItems(QList<QTreeWidgetItem*> itemList) {
     CHECK(!itemList.isEmpty(), );
 
-    QSet<QTreeWidgetItem *> parents;
-    QSet<QTreeWidgetItem *> removedItems;
-    foreach (QTreeWidgetItem *item, itemList) {
-        if (nullptr != item->parent()) {
+    QSet<QTreeWidgetItem*> parents;
+    QSet<QTreeWidgetItem*> removedItems;
+    foreach (QTreeWidgetItem* item, itemList) {
+        if (item->parent() != nullptr) {
             parents << item->parent();
         }
 
@@ -441,8 +441,8 @@ void ImportToDatabaseDialog::removeItems(QList<QTreeWidgetItem *> itemList) {
         }
     }
 
-    QList<QTreeWidgetItem *> emptyParents;
-    foreach (QTreeWidgetItem *parent, parents) {
+    QList<QTreeWidgetItem*> emptyParents;
+    foreach (QTreeWidgetItem* parent, parents) {
         if (!removedItems.contains(parent) && 0 == parent->childCount()) {
             emptyParents << parent;
         }
@@ -451,9 +451,9 @@ void ImportToDatabaseDialog::removeItems(QList<QTreeWidgetItem *> itemList) {
     removeItems(emptyParents);
 }
 
-QList<QTreeWidgetItem *> ImportToDatabaseDialog::removeRecursively(QTreeWidgetItem *item) {
-    QList<QTreeWidgetItem *> removedItems;
-    CHECK(nullptr != item, removedItems);
+QList<QTreeWidgetItem*> ImportToDatabaseDialog::removeRecursively(QTreeWidgetItem* item) {
+    QList<QTreeWidgetItem*> removedItems;
+    CHECK(item != nullptr, removedItems);
 
     for (int i = 0; i < item->childCount(); i++) {
         removedItems << removeRecursively(item->child(i));
@@ -471,9 +471,9 @@ QList<QTreeWidgetItem *> ImportToDatabaseDialog::removeRecursively(QTreeWidgetIt
     return removedItems;
 }
 
-QList<Task *> ImportToDatabaseDialog::createImportFilesTasks() const {
-    QList<Task *> tasks;
-    foreach (QTreeWidgetItem *fileTreeItem, files) {
+QList<Task*> ImportToDatabaseDialog::createImportFilesTasks() const {
+    QList<Task*> tasks;
+    foreach (QTreeWidgetItem* fileTreeItem, files) {
         tasks << new ImportFileToDatabaseTask(fileTreeItem->text(COLUMN_ITEM_TEXT),
                                               dbConnection->getDbiRef(),
                                               fileTreeItem->text(COLUMN_FOLDER),
@@ -482,9 +482,9 @@ QList<Task *> ImportToDatabaseDialog::createImportFilesTasks() const {
     return tasks;
 }
 
-QList<Task *> ImportToDatabaseDialog::createImportFoldersTasks() const {
-    QList<Task *> tasks;
-    foreach (QTreeWidgetItem *folderTreeItem, folders) {
+QList<Task*> ImportToDatabaseDialog::createImportFoldersTasks() const {
+    QList<Task*> tasks;
+    foreach (QTreeWidgetItem* folderTreeItem, folders) {
         tasks << new ImportDirToDatabaseTask(folderTreeItem->text(COLUMN_ITEM_TEXT),
                                              dbConnection->getDbiRef(),
                                              folderTreeItem->text(COLUMN_FOLDER),
@@ -493,9 +493,9 @@ QList<Task *> ImportToDatabaseDialog::createImportFoldersTasks() const {
     return tasks;
 }
 
-QList<Task *> ImportToDatabaseDialog::createimportObjectsTasks() const {
-    QList<Task *> tasks;
-    foreach (QTreeWidgetItem *objectTreeItem, treeItem2Object.keys()) {
+QList<Task*> ImportToDatabaseDialog::createimportObjectsTasks() const {
+    QList<Task*> tasks;
+    foreach (QTreeWidgetItem* objectTreeItem, treeItem2Object.keys()) {
         tasks << new ImportObjectToDatabaseTask(treeItem2Object[objectTreeItem],
                                                 dbConnection->getDbiRef(),
                                                 objectTreeItem->text(COLUMN_FOLDER));
@@ -503,9 +503,9 @@ QList<Task *> ImportToDatabaseDialog::createimportObjectsTasks() const {
     return tasks;
 }
 
-QList<Task *> ImportToDatabaseDialog::createImportDocumentsTasks() const {
-    QList<Task *> tasks;
-    foreach (QTreeWidgetItem *documentTreeItem, treeItem2Document.keys()) {
+QList<Task*> ImportToDatabaseDialog::createImportDocumentsTasks() const {
+    QList<Task*> tasks;
+    foreach (QTreeWidgetItem* documentTreeItem, treeItem2Document.keys()) {
         tasks << new ImportDocumentToDatabaseTask(treeItem2Document[documentTreeItem],
                                                   dbConnection->getDbiRef(),
                                                   documentTreeItem->text(COLUMN_FOLDER),
@@ -514,12 +514,12 @@ QList<Task *> ImportToDatabaseDialog::createImportDocumentsTasks() const {
     return tasks;
 }
 
-QTreeWidgetItem *ImportToDatabaseDialog::getHeaderItem(HeaderType headerType) const {
+QTreeWidgetItem* ImportToDatabaseDialog::getHeaderItem(HeaderType headerType) const {
     const QString itemText = (FILE_AND_FOLDER == headerType ? FILES_AND_FOLDERS : OBJECTS_AND_DOCUMENTS);
-    const QList<QTreeWidgetItem *> itemsList = ui->twOrders->findItems(itemText, Qt::MatchExactly);
+    const QList<QTreeWidgetItem*> itemsList = ui->twOrders->findItems(itemText, Qt::MatchExactly);
 
     if (itemsList.isEmpty()) {
-        QTreeWidgetItem *headerItem = new QTreeWidgetItem(QStringList() << itemText);
+        QTreeWidgetItem* headerItem = new QTreeWidgetItem(QStringList() << itemText);
         ui->twOrders->addTopLevelItem(headerItem);
         return headerItem;
     }
@@ -527,7 +527,7 @@ QTreeWidgetItem *ImportToDatabaseDialog::getHeaderItem(HeaderType headerType) co
     return itemsList.first();
 }
 
-void ImportToDatabaseDialog::setTooltip(QTreeWidgetItem *item) {
+void ImportToDatabaseDialog::setTooltip(QTreeWidgetItem* item) {
     if (files.contains(item)) {
         setFileTooltip(item);
     } else if (folders.contains(item)) {
@@ -541,7 +541,7 @@ void ImportToDatabaseDialog::setTooltip(QTreeWidgetItem *item) {
     }
 }
 
-void ImportToDatabaseDialog::setFileTooltip(QTreeWidgetItem *item) {
+void ImportToDatabaseDialog::setFileTooltip(QTreeWidgetItem* item) {
     ImportToDatabaseOptions currentOptions = privateOptions.value(item, commonOptions);
     QString tooltip;
 
@@ -580,7 +580,7 @@ void ImportToDatabaseDialog::setFileTooltip(QTreeWidgetItem *item) {
     item->setToolTip(COLUMN_FOLDER, tooltip);
 }
 
-void ImportToDatabaseDialog::setFolderTooltip(QTreeWidgetItem *item) {
+void ImportToDatabaseDialog::setFolderTooltip(QTreeWidgetItem* item) {
     ImportToDatabaseOptions currentOptions = privateOptions.value(item, commonOptions);
     QString tooltip;
 
@@ -624,7 +624,7 @@ void ImportToDatabaseDialog::setFolderTooltip(QTreeWidgetItem *item) {
     item->setToolTip(COLUMN_FOLDER, tooltip);
 }
 
-void ImportToDatabaseDialog::setObjectTooltip(QTreeWidgetItem *item) {
+void ImportToDatabaseDialog::setObjectTooltip(QTreeWidgetItem* item) {
     const QString typeName = GObjectTypes::getTypeInfo(treeItem2Object[item]->getGObjectType()).name;
     QString tooltip;
 
@@ -644,7 +644,7 @@ void ImportToDatabaseDialog::setObjectTooltip(QTreeWidgetItem *item) {
     item->setToolTip(COLUMN_FOLDER, tooltip);
 }
 
-void ImportToDatabaseDialog::setDocumentTooltip(QTreeWidgetItem *item) {
+void ImportToDatabaseDialog::setDocumentTooltip(QTreeWidgetItem* item) {
     QString tooltip;
 
     if (privateOptions.contains(item)) {
