@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ITEM_TO_IMPORT_EDIT_DIALOG_H_
-#define _U2_ITEM_TO_IMPORT_EDIT_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -33,17 +32,15 @@ namespace U2 {
 class ItemToImportEditDialog : public QDialog {
     Q_OBJECT
 public:
-    explicit ItemToImportEditDialog(const QString &item, const QString &folder, const ImportToDatabaseOptions &options, QWidget *parent = 0);
+    explicit ItemToImportEditDialog(const QString& item, const QString& folder, const ImportToDatabaseOptions& options, QWidget* parent = 0);
     ~ItemToImportEditDialog();
 
     QString getFolder() const;
     ImportToDatabaseOptions getOptions() const;
 
 private:
-    void init(const QString &item, const QString &folder, const ImportToDatabaseOptions &options);
-    Ui_ItemToImportEditDialog *ui;
+    void init(const QString& item, const QString& folder, const ImportToDatabaseOptions& options);
+    Ui_ItemToImportEditDialog* ui;
 };
 
 }  // namespace U2
-
-#endif  // _U2_ITEM_TO_IMPORT_EDIT_DIALOG_H_
