@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __U2_WORKFLOW_BASE_ATTRIBUTES_H_
-#define __U2_WORKFLOW_BASE_ATTRIBUTES_H_
+#pragma once
 
 #include <U2Lang/Descriptor.h>
 
@@ -57,5 +56,3 @@ public:
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // __U2_WORKFLOW_BASE_ATTRIBUTES_H_
