@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,35 +27,35 @@
 namespace U2 {
 namespace LocalWorkflow {
 
-BaseOneOneWorker::BaseOneOneWorker(Actor *a, bool autoTransitBus, const QString &inPortId, const QString &outPortId)
+BaseOneOneWorker::BaseOneOneWorker(Actor* a, bool autoTransitBus, const QString& inPortId, const QString& outPortId)
     : BaseWorker(a, autoTransitBus), inPortId(inPortId), outPortId(outPortId), input(nullptr), output(nullptr), prepared(false) {
 }
 
 void BaseOneOneWorker::init() {
     input = ports.value(inPortId);
     output = ports.value(outPortId);
-    SAFE_POINT(nullptr != input, QString("Input port '%1' is NULL").arg(inPortId), );
-    SAFE_POINT(nullptr != output, QString("Output port '%1' is NULL").arg(outPortId), );
+    SAFE_POINT(input != nullptr, QString("Input port '%1' is NULL").arg(inPortId), );
+    SAFE_POINT(output != nullptr, QString("Output port '%1' is NULL").arg(outPortId), );
 }
 
-Task *BaseOneOneWorker::tick() {
+Task* BaseOneOneWorker::tick() {
     if (!prepared) {
         U2OpStatusImpl os;
-        Task *prepareTask = prepare(os);
+        Task* prepareTask = prepare(os);
         CHECK_OP(os, nullptr);
-        if (nullptr != prepareTask) {
+        if (prepareTask != nullptr) {
             return prepareTask;
         }
     }
 
     if (input->hasMessage()) {
-        Task *tickTask = processNextInputMessage();
-        CHECK(nullptr != tickTask, nullptr);
+        Task* tickTask = processNextInputMessage();
+        CHECK(tickTask != nullptr, nullptr);
         connect(tickTask, SIGNAL(si_stateChanged()), SLOT(sl_taskFinished()));
         return tickTask;
     } else if (input->isEnded()) {
-        Task *lastTickTask = onInputEnded();
-        if (nullptr == lastTickTask) {
+        Task* lastTickTask = onInputEnded();
+        if (lastTickTask == nullptr) {
             output->setEnded();
             setDone();
         } else {
@@ -66,22 +66,22 @@ Task *BaseOneOneWorker::tick() {
     return nullptr;
 }
 
-Task *BaseOneOneWorker::createPrepareTask(U2OpStatus & /*os*/) const {
+Task* BaseOneOneWorker::createPrepareTask(U2OpStatus& /*os*/) const {
     return nullptr;
 }
 
-void BaseOneOneWorker::onPrepared(Task * /*task*/, U2OpStatus & /*os*/) {
+void BaseOneOneWorker::onPrepared(Task* /*task*/, U2OpStatus& /*os*/) {
 }
 
 void BaseOneOneWorker::sl_taskFinished() {
-    Task *task = dynamic_cast<Task *>(sender());
-    CHECK(nullptr != task, );
+    auto task = dynamic_cast<Task*>(sender());
+    CHECK(task != nullptr, );
     CHECK(task->isFinished() && !task->isCanceled() && !task->hasError(), );
     U2OpStatusImpl os;
     QList<Message> result = fetchResult(task, os);
     CHECK_OP_EXT(os, reportError(os.getError()), );
 
-    foreach (const Message &message, result) {
+    foreach (const Message& message, result) {
         if (-1 != message.getMetadataId()) {
             output->setContext(output->getContext(), -1);
         }
@@ -90,8 +90,8 @@ void BaseOneOneWorker::sl_taskFinished() {
 }
 
 void BaseOneOneWorker::sl_prepared() {
-    Task *task = dynamic_cast<Task *>(sender());
-    CHECK(nullptr != task, );
+    auto task = dynamic_cast<Task*>(sender());
+    CHECK(task != nullptr, );
     CHECK(task->isFinished(), );
     if (task->isCanceled() || task->hasError()) {
         output->setEnded();
@@ -108,15 +108,15 @@ void BaseOneOneWorker::sl_prepared() {
     }
 }
 
-Task *BaseOneOneWorker::prepare(U2OpStatus &os) {
+Task* BaseOneOneWorker::prepare(U2OpStatus& os) {
     CHECK(!prepared, nullptr);
-    Task *task = createPrepareTask(os);
+    Task* task = createPrepareTask(os);
     if (os.hasError()) {
         reportError(os.getError());
         output->setEnded();
         setDone();
     }
-    if (nullptr != task) {
+    if (task != nullptr) {
         connect(task, SIGNAL(si_stateChanged()), SLOT(sl_prepared()));
     }
     prepared = true;
