@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BASE_ONE_ONE_WORKER_H_
-#define _U2_BASE_ONE_ONE_WORKER_H_
+#pragma once
 
 #include <U2Lang/LocalDomain.h>
 
@@ -33,35 +32,33 @@ namespace LocalWorkflow {
 class U2LANG_EXPORT BaseOneOneWorker : public BaseWorker {
     Q_OBJECT
 public:
-    BaseOneOneWorker(Actor *a, bool autoTransitBus, const QString &inPortId, const QString &outPortId);
+    BaseOneOneWorker(Actor* a, bool autoTransitBus, const QString& inPortId, const QString& outPortId);
 
     void init();
-    Task *tick();
+    Task* tick();
 
 protected:
-    virtual Task *createPrepareTask(U2OpStatus &os) const;
-    virtual void onPrepared(Task *task, U2OpStatus &os);
-    virtual Task *processNextInputMessage() = 0;
-    virtual Task *onInputEnded() = 0;
-    virtual QList<Message> fetchResult(Task *task, U2OpStatus &os) = 0;
+    virtual Task* createPrepareTask(U2OpStatus& os) const;
+    virtual void onPrepared(Task* task, U2OpStatus& os);
+    virtual Task* processNextInputMessage() = 0;
+    virtual Task* onInputEnded() = 0;
+    virtual QList<Message> fetchResult(Task* task, U2OpStatus& os) = 0;
 
 private slots:
     void sl_taskFinished();
     void sl_prepared();
 
 private:
-    Task *prepare(U2OpStatus &os);
+    Task* prepare(U2OpStatus& os);
 
 protected:
     const QString inPortId;
     const QString outPortId;
-    IntegralBus *input;
-    IntegralBus *output;
+    IntegralBus* input;
+    IntegralBus* output;
 
     bool prepared;
 };
 
 }  // namespace LocalWorkflow
 }  // namespace U2
-
-#endif  // _U2_BASE_ONE_ONE_WORKER_H_
