@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __U2_WORKFLOW_BASE_SLOTS_H_
-#define __U2_WORKFLOW_BASE_SLOTS_H_
+#pragma once
 
 #include <U2Core/U2Type.h>
 
@@ -32,18 +31,16 @@ namespace Workflow {
 class U2LANG_EXPORT BaseSlots : public QObject {
     Q_OBJECT
 public:
-    static const Descriptor DNA_SEQUENCE_SLOT();
-    static const Descriptor MULTIPLE_ALIGNMENT_SLOT();
-    static const Descriptor ANNOTATION_TABLE_SLOT();
-    static const Descriptor TEXT_SLOT();
-    static const Descriptor URL_SLOT();
-    static const Descriptor FASTA_HEADER_SLOT();
-    static const Descriptor VARIATION_TRACK_SLOT();
-    static const Descriptor ASSEMBLY_SLOT();
-    static const Descriptor DATASET_SLOT();
+    static Descriptor DNA_SEQUENCE_SLOT();
+    static Descriptor MULTIPLE_ALIGNMENT_SLOT();
+    static Descriptor ANNOTATION_TABLE_SLOT();
+    static Descriptor TEXT_SLOT();
+    static Descriptor URL_SLOT();
+    static Descriptor FASTA_HEADER_SLOT();
+    static Descriptor VARIATION_TRACK_SLOT();
+    static Descriptor ASSEMBLY_SLOT();
+    static Descriptor DATASET_SLOT();
 };  // BaseSlots
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // __U2_WORKFLOW_BASE_SLOTS_H_
