@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _WORKFLOW_LAST_READY_SCHEDULER_H_
-#define _WORKFLOW_LAST_READY_SCHEDULER_H_
+#pragma once
 
 #include <U2Lang/LocalDomain.h>
 
@@ -36,37 +35,35 @@ namespace LocalWorkflow {
 class ElapsedTimeUpdater;
 class LastReadyScheduler : public Scheduler {
 public:
-    LastReadyScheduler(Schema *sh);
+    LastReadyScheduler(Schema* sh);
     virtual ~LastReadyScheduler();
 
     // reimplemented from Worker
     virtual void init();
     virtual bool isReady() const;
-    virtual Task *tick();
+    virtual Task* tick();
     virtual bool isDone() const;
     virtual void cleanup();
 
-    virtual WorkerState getWorkerState(const ActorId &actor);
-    virtual Task *replayLastWorkerTick();
+    virtual WorkerState getWorkerState(const ActorId& actor);
+    virtual Task* replayLastWorkerTick();
     virtual bool cancelCurrentTaskIfAllowed();
-    virtual void makeOneTick(const ActorId &actor);
+    virtual void makeOneTick(const ActorId& actor);
 
 protected:
-    virtual WorkerState getWorkerState(const Actor *a);
+    virtual WorkerState getWorkerState(const Actor* a);
     ActorId actorId() const;
     bool hasValidFinishedTask() const;
     qint64 lastTaskTimeSec() const;
     void measuredTick();
 
-    QMap<int, QList<Actor *>> topologicSortedGraph;
-    BaseWorker *lastWorker;
+    QMap<int, QList<Actor*>> topologicSortedGraph;
+    BaseWorker* lastWorker;
     bool canLastTaskBeCanceled;
     ActorId requestedActorForNextTick;
-    ElapsedTimeUpdater *timeUpdater;
+    ElapsedTimeUpdater* timeUpdater;
 };
 
 }  // namespace LocalWorkflow
 
 }  // namespace U2
-
-#endif  // _WORKFLOW_LAST_READY_SCHEDULER_H_
