@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_LOCAL_DOMAIN_H_
-#define _U2_WORKFLOW_LOCAL_DOMAIN_H_
+#pragma once
 
 #include <limits.h>
 
@@ -49,32 +48,32 @@ class U2LANG_EXPORT BaseWorker : public QObject, public Worker, public Communica
 public:
     using Workflow::Worker::tick;
 
-    BaseWorker(Actor *a, bool autoTransitBus = true);
-    virtual ~BaseWorker();
+    BaseWorker(Actor* a, bool autoTransitBus = true);
+    ~BaseWorker() override;
 
     virtual ActorId getActorId() const;
 
     virtual void setDone();
 
     // reimplemented from Worker
-    virtual bool isDone() const;
-    virtual bool isReady() const;
+    bool isDone() const override;
+    bool isReady() const override;
 
     // reimplemented from CommunicationSubject
-    virtual bool addCommunication(const QString &name, CommunicationChannel *_ch);
-    virtual CommunicationChannel *getCommunication(const QString &name);
+    bool addCommunication(const QString& name, CommunicationChannel* _ch) override;
+    CommunicationChannel* getCommunication(const QString& name) override;
     virtual QStringList getOutputFiles();
 
     // if you want your worker support scripts -> you should call this function to get Messages from channels
     // call this when channel has message
     // after calling: set all needed values for running your worker
     // called from 'tick' and then setup worker params
-    virtual Message getMessageAndSetupScriptValues(CommunicationChannel *channel);
+    virtual Message getMessageAndSetupScriptValues(CommunicationChannel* channel);
 
-    QMap<QString, IntegralBus *> &getPorts() {
+    QMap<QString, IntegralBus*>& getPorts() {
         return ports;
     }
-    Actor *getActor() const {
+    Actor* getActor() const {
         return actor;
     }
 
@@ -88,43 +87,43 @@ public:
     // method should be invoked by scheduler instead of tick().
     // parameter canBeCanceled indicates if the returning task can be canceled
     // in case of the schema's pause
-    Task *tick(bool &canResultBeCanceled);
+    Task* tick(bool& canResultBeCanceled);
 
-    QList<ExternalToolListener *> createLogListeners(int listenersNumber = 1) const;
+    QList<ExternalToolListener*> createLogListeners(int listenersNumber = 1) const;
 
 private:
     // bind values from input ports to script vars.
     // This function is called before 'get' data from channel -> to set up parameters for scripting
     void bindScriptValues();
-    void setScriptVariableFromBus(AttributeScript *script, IntegralBus *bus);
+    void setScriptVariableFromBus(AttributeScript* script, IntegralBus* bus);
     bool processDone;
 
     // this field contains all messages that Worker processes during one tick.
     // New messages are added here in getMessageAndSetupScriptValues(CommunicationChannel *) method.
     // Also during the pause state it contains backup messages
     // (which were existed at the moment before the pause) from the same ports
-    QMap<CommunicationChannel *, QQueue<Message>> messagesProcessedOnLastTick;
+    QMap<CommunicationChannel*, QQueue<Message>> messagesProcessedOnLastTick;
 
     // puts all messages from messagesProcessedOnLastTick to appropriate channel
     // which is actually key for the queue of messages
-    void addMessagesFromBackupToAppropriratePort(CommunicationChannel *channel);
+    void addMessagesFromBackupToAppropriratePort(CommunicationChannel* channel);
 
 protected:
-    Actor *actor;
+    Actor* actor;
     // integral buses of actor's ports
-    QMap<QString, IntegralBus *> ports;
+    QMap<QString, IntegralBus*> ports;
 
     // default implementation always return false
     // TODO: check all workers' task and override this method
     // in order to cancel tasks on debug events (e.g. pause, breakpoint, etc)
-    virtual bool canTaskBeCanceled(Task *workerTask) const;
+    virtual bool canTaskBeCanceled(Task* workerTask) const;
 
     /** Returns the value of a parameter with paramId */
     template<class T>
-    T getValue(const QString &paramId) const;
+    T getValue(const QString& paramId) const;
 
-    WorkflowMonitor *monitor() const;
-    void reportError(const QString &message);
+    WorkflowMonitor* monitor() const;
+    void reportError(const QString& message);
 };  // BaseWorker
 
 /**
@@ -133,23 +132,21 @@ protected:
 class U2LANG_EXPORT SimpleQueue : public CommunicationChannel {
 public:
     SimpleQueue();
-    virtual ~SimpleQueue() {
-    }
 
     // reimplemented from CommunicationChannel
-    virtual Message get();
-    virtual Message look() const;
-    virtual void put(const Message &m, bool isMessageRestored = false);
-    virtual int hasMessage() const;
-    virtual int takenMessages() const;
-    virtual int hasRoom(const DataType *) const;
-    virtual bool isEnded() const;
-    virtual void setEnded();
+    Message get() override;
+    Message look() const override;
+    void put(const Message& m, bool isMessageRestored = false) override;
+    int hasMessage() const override;
+    int takenMessages() const override;
+    int hasRoom(const DataType*) const override;
+    bool isEnded() const override;
+    void setEnded() override;
     // capacity is INT_MAX
-    virtual int capacity() const;
+    int capacity() const override;
     // does nothing
-    virtual void setCapacity(int);
-    virtual QQueue<Message> getMessages(int startIndex = 0, int endIndex = -1) const;
+    void setCapacity(int) override;
+    QQueue<Message> getMessages(int startIndex = 0, int endIndex = -1) const override;
 
 protected:
     // first in, first out
@@ -172,13 +169,11 @@ public:
 
 public:
     LocalDomainFactory();
-    virtual ~LocalDomainFactory() {
-    }
 
-    virtual Worker *createWorker(Actor *);
-    virtual CommunicationChannel *createConnection(Link *);
-    virtual Scheduler *createScheduler(Schema *);
-    virtual void destroy(Scheduler *, Schema *);
+    Worker* createWorker(Actor*) override;
+    CommunicationChannel* createConnection(Link*) override;
+    Scheduler* createScheduler(Schema*) override;
+    void destroy(Scheduler*, Schema*) override;
 
 };  // LocalDomainFactory
 
@@ -186,18 +181,18 @@ public:
 /* Template definitions */
 /************************************************************************/
 template<class T>
-T BaseWorker::getValue(const QString &paramId) const {
-    Attribute *attr = actor->getParameter(paramId);
-    if (nullptr == attr) {
+T BaseWorker::getValue(const QString& paramId) const {
+    Attribute* attr = actor->getParameter(paramId);
+    if (attr == nullptr) {
         return T();
     }
     return attr->getAttributeValue<T>(context);
 }
 
 template<>
-inline QString BaseWorker::getValue(const QString &paramId) const {
-    Attribute *attr = actor->getParameter(paramId);
-    if (nullptr == attr) {
+inline QString BaseWorker::getValue(const QString& paramId) const {
+    Attribute* attr = actor->getParameter(paramId);
+    if (attr == nullptr) {
         return "";
     }
     QString value = attr->getAttributeValue<QString>(context);
@@ -211,5 +206,3 @@ inline QString BaseWorker::getValue(const QString &paramId) const {
 }  // namespace LocalWorkflow
 
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_LOCAL_DOMAIN_H_
