@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ACTORCONTEXT_H_
-#define _U2_ACTORCONTEXT_H_
+#pragma once
 
 #include <U2Lang/LocalDomain.h>
 
@@ -30,18 +29,16 @@ namespace LocalWorkflow {
 
 class U2LANG_EXPORT ActorContext {
 public:
-    static QScriptValue createContext(BaseWorker *worker, QScriptEngine *engine);
+    static QScriptValue createContext(BaseWorker* worker, QScriptEngine* engine);
 
     static const QString OUTPUT;
     static const QString INPUT;
     static const QString PARAMETERS;
 
 private:
-    static QScriptValue createInBus(IntegralBus *bus, QScriptEngine *engine);
-    static QScriptValue createOutBus(Port *port, QScriptEngine *engine);
+    static QScriptValue createInBus(IntegralBus* bus, QScriptEngine* engine);
+    static QScriptValue createOutBus(Port* port, QScriptEngine* engine);
 };
 
 }  // namespace LocalWorkflow
 }  // namespace U2
-
-#endif  // _U2_ACTORCONTEXT_H_
