@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -38,11 +38,11 @@ ScriptDbiData::ScriptDbiData() {
 ScriptDbiData::~ScriptDbiData() {
 }
 
-ScriptDbiData::ScriptDbiData(const Workflow::SharedDbiDataHandler &_seqId)
+ScriptDbiData::ScriptDbiData(const Workflow::SharedDbiDataHandler& _seqId)
     : id(_seqId) {
 }
 
-const Workflow::SharedDbiDataHandler &ScriptDbiData::getId() const {
+const Workflow::SharedDbiDataHandler& ScriptDbiData::getId() const {
     return id;
 }
 
@@ -53,7 +53,7 @@ void ScriptDbiData::release() {
 /************************************************************************/
 /* DbiClassPrototype */
 /************************************************************************/
-DbiClassPrototype::DbiClassPrototype(QObject *parent)
+DbiClassPrototype::DbiClassPrototype(QObject* parent)
     : QObject(parent) {
 }
 
@@ -61,40 +61,40 @@ DbiClassPrototype::~DbiClassPrototype() {
 }
 
 QScriptValue DbiClassPrototype::getId() {
-    CHECK(nullptr != thisData(), QScriptValue::NullValue);
+    CHECK(thisData() != nullptr, QScriptValue::NullValue);
     Workflow::SharedDbiDataHandler id = thisData()->getId();
-    SCRIPT_CHECK(nullptr != id.constData(), context(), "Invalid data id. Was it released?", QScriptValue::NullValue);
+    SCRIPT_CHECK(id.constData() != nullptr, context(), "Invalid data id. Was it released?", QScriptValue::NullValue);
 
     return engine()->newVariant(qVariantFromValue(id));
 }
 
 void DbiClassPrototype::release() {
-    CHECK(nullptr != thisData(), );
+    CHECK(thisData() != nullptr, );
     thisData()->release();
 }
 
-ScriptDbiData *DbiClassPrototype::thisData() const {
-    ScriptDbiData *result = qscriptvalue_cast<ScriptDbiData *>(thisObject().data());
-    SCRIPT_CHECK(nullptr != result, context(), "No this object", nullptr);
+ScriptDbiData* DbiClassPrototype::thisData() const {
+    auto result = qscriptvalue_cast<ScriptDbiData*>(thisObject().data());
+    SCRIPT_CHECK(result != nullptr, context(), "No this object", nullptr);
     return result;
 }
 
-WorkflowScriptEngine *DbiClassPrototype::workflowEngine() const {
+WorkflowScriptEngine* DbiClassPrototype::workflowEngine() const {
     return ScriptEngineUtils::workflowEngine(engine());
 }
 
-Workflow::DbiDataStorage *DbiClassPrototype::dataStorage() const {
-    WorkflowScriptEngine *we = workflowEngine();
-    CHECK(nullptr != we, nullptr);
-    Workflow::WorkflowContext *wc = we->getWorkflowContext();
-    CHECK(nullptr != wc, nullptr);
+Workflow::DbiDataStorage* DbiClassPrototype::dataStorage() const {
+    WorkflowScriptEngine* we = workflowEngine();
+    CHECK(we != nullptr, nullptr);
+    Workflow::WorkflowContext* wc = we->getWorkflowContext();
+    CHECK(wc != nullptr, nullptr);
     return wc->getDataStorage();
 }
 
 /************************************************************************/
 /* DbiScriptClass */
 /************************************************************************/
-DbiScriptClass::DbiScriptClass(QScriptEngine *engine)
+DbiScriptClass::DbiScriptClass(QScriptEngine* engine)
     : QObject(engine), QScriptClass(engine) {
 }
 
@@ -102,13 +102,13 @@ QScriptValue DbiScriptClass::prototype() const {
     return proto;
 }
 
-QScriptValue DbiScriptClass::newInstance(const Workflow::SharedDbiDataHandler &id) {
+QScriptValue DbiScriptClass::newInstance(const Workflow::SharedDbiDataHandler& id) {
     ScriptDbiData dbiData(id);
     QScriptValue data = engine()->newVariant(qVariantFromValue(dbiData));
     return engine()->newObject(this, data);
 }
 
-void DbiScriptClass::fromScriptValue(const QScriptValue &obj, ScriptDbiData &id) {
+void DbiScriptClass::fromScriptValue(const QScriptValue& obj, ScriptDbiData& id) {
     id = qvariant_cast<ScriptDbiData>(obj.data().toVariant());
 }
 
