@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SCRIPTENGINEUTILS_H_
-#define _U2_SCRIPTENGINEUTILS_H_
+#pragma once
 
 #include <U2Lang/WorkflowScriptEngine.h>
 
@@ -37,15 +36,13 @@ using namespace Workflow;
 
 class U2LANG_EXPORT ScriptEngineUtils {
 public:
-    static WorkflowScriptEngine *workflowEngine(QScriptEngine *engine);
-    static DbiDataStorage *dataStorage(QScriptEngine *engine);
-    static SequenceScriptClass *getSequenceClass(QScriptEngine *engine);
-    static SharedDbiDataHandler getDbiId(QScriptEngine *engine, const QScriptValue &value, const QString &className);
-    static SharedDbiDataHandler getDbiId(QScriptEngine *engine, const QScriptValue &value);
-    static QScriptValue toScriptValue(QScriptEngine *engine, const QVariant &value, DataTypePtr type);
-    static QVariant fromScriptValue(QScriptEngine *engine, const QScriptValue &value, DataTypePtr type);
+    static WorkflowScriptEngine* workflowEngine(QScriptEngine* engine);
+    static DbiDataStorage* dataStorage(QScriptEngine* engine);
+    static SequenceScriptClass* getSequenceClass(QScriptEngine* engine);
+    static SharedDbiDataHandler getDbiId(QScriptEngine* engine, const QScriptValue& value, const QString& className);
+    static SharedDbiDataHandler getDbiId(QScriptEngine* engine, const QScriptValue& value);
+    static QScriptValue toScriptValue(QScriptEngine* engine, const QVariant& value, DataTypePtr type);
+    static QVariant fromScriptValue(QScriptEngine* engine, const QScriptValue& value, DataTypePtr type);
 };
 
 }  // namespace U2
-
-#endif  // _U2_SCRIPTENGINEUTILS_H_
