@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_REG_H_
-#define _U2_WORKFLOW_REG_H_
+#pragma once
 
 #include <U2Lang/ActorModel.h>
 
@@ -39,23 +38,21 @@ public:
     virtual ~ActorPrototypeRegistry();
 
     // standard registry
-    bool registerProto(const Descriptor &group, ActorPrototype *proto);
-    ActorPrototype *unregisterProto(const QString &id);
-    const QMap<Descriptor, QList<ActorPrototype *>> &getProtos() const {
+    bool registerProto(const Descriptor& group, ActorPrototype* proto);
+    ActorPrototype* unregisterProto(const QString& id);
+    const QMap<Descriptor, QList<ActorPrototype*>>& getProtos() const {
         return groups;
     }
-    ActorPrototype *getProto(const QString &id) const;
+    ActorPrototype* getProto(const QString& id) const;
 
 signals:
     void si_registryModified();
 
 private:
-    QMap<Descriptor, QList<ActorPrototype *>> groups;
+    QMap<Descriptor, QList<ActorPrototype*>> groups;
 
 };  // ActorPrototypeRegistry
 
 }  // namespace Workflow
 
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_REG_H_
