@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_CONFIGURATION_H_
-#define _U2_WORKFLOW_CONFIGURATION_H_
+#pragma once
 
 #include "Attribute.h"
 #include "ConfigurationValidator.h"
@@ -38,54 +37,52 @@ public:
     Configuration();
     virtual ~Configuration();
 
-    virtual QMap<QString, Attribute *> getParameters() const;
+    virtual QMap<QString, Attribute*> getParameters() const;
     // returns NULL if no parameter identified with 'name'
-    virtual Attribute *getParameter(const QString &name) const;
+    virtual Attribute* getParameter(const QString& name) const;
 
     // returns removed parameter
     // caller takes ownership of the attribute
-    virtual Attribute *removeParameter(const QString &name);
-    virtual void addParameter(const QString &name, Attribute *attr);
+    virtual Attribute* removeParameter(const QString& name);
+    virtual void addParameter(const QString& name, Attribute* attr);
 
     // sets if only parameter with 'name' exists
-    virtual void setParameter(const QString &name, const QVariant &val);
-    void setParameters(const QVariantMap &);
+    virtual void setParameter(const QString& name, const QVariant& val);
+    void setParameters(const QVariantMap&);
     QVariantMap getValues() const;
-    virtual bool hasParameter(const QString &name) const;
+    virtual bool hasParameter(const QString& name) const;
 
     // getters/setters
-    virtual ConfigurationEditor *getEditor() const;
-    void setEditor(ConfigurationEditor *ed);
-    virtual ConfigurationValidator *getValidator();
-    void setValidator(ConfigurationValidator *v);
+    virtual ConfigurationEditor* getEditor() const;
+    void setEditor(ConfigurationEditor* ed);
+    virtual ConfigurationValidator* getValidator();
+    void setValidator(ConfigurationValidator* v);
 
     // returns 'false' if validations fails, otherwise 'true'
     // if validation fails, new errors appended to errorList
-    virtual bool validate(NotificationsList &notificationList) const;
+    virtual bool validate(NotificationsList& notificationList) const;
 
     // when schema copied, actors in new schema get new id's
     // in this case, we need to remap all links between actors
     // see Port realizations
-    virtual void remap(const QMap<ActorId, ActorId> &) = 0;
+    virtual void remap(const QMap<ActorId, ActorId>&) = 0;
 
-    virtual QList<Attribute *> getAttributes() const;
+    virtual QList<Attribute*> getAttributes() const;
 
-    bool isAttributeVisible(Attribute *attribute) const;
+    bool isAttributeVisible(Attribute* attribute) const;
 
 protected:
     // controller for ui editor of this configuration
-    ConfigurationEditor *editor;
+    ConfigurationEditor* editor;
     // standard validations if required attribute is empty are done in validate() function
     // this validator can make any non-trivial validations
-    ConfigurationValidator *validator;
+    ConfigurationValidator* validator;
 
 private:
     // named attributes
-    QMap<QString, Attribute *> params;
-    QList<Attribute *> attrs;  // For sorting attributes by order of creation
+    QMap<QString, Attribute*> params;
+    QList<Attribute*> attrs;  // For sorting attributes by order of creation
 
 };  // Configuration
 
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_CONFIGURATION_H_
