@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _WORKFLOW_DBI_DATA_HANDLER_H_
-#define _WORKFLOW_DBI_DATA_HANDLER_H_
+#pragma once
 
 #include <U2Core/U2ObjectDbi.h>
 #include <U2Core/U2Type.h>
@@ -37,23 +36,26 @@ class U2LANG_EXPORT DbiDataHandler : public QSharedData {
     friend class DbiDataStorage;
 
 public:
-    DbiDataHandler(const U2EntityRef &entRef, U2ObjectDbi *dbi, bool useGC);
+    DbiDataHandler(const U2EntityRef& entityRef, U2ObjectDbi* dbi, bool useGC);
     virtual ~DbiDataHandler();
 
     int getReferenceCount() const;
     U2DbiRef getDbiRef() const;
 
-    bool equals(const DbiDataHandler *other) const;
+    /** Returns entity-ref this data handler holds. */
+    const U2EntityRef& getEntityRef() const;
+
+    bool equals(const DbiDataHandler* other) const;
 
     bool isValid() const;
 
 private:
-    const U2EntityRef entRef;
-    U2ObjectDbi *dbi;
+    const U2EntityRef entityRef;
+    U2ObjectDbi* dbi;
     bool useGC;
 
-    DbiDataHandler(const DbiDataHandler &);
-    DbiDataHandler &operator=(const DbiDataHandler &);
+    DbiDataHandler(const DbiDataHandler&);
+    DbiDataHandler& operator=(const DbiDataHandler&);
 };
 
 }  // namespace Workflow
@@ -61,5 +63,3 @@ private:
 
 Q_DECLARE_METATYPE(U2::Workflow::SharedDbiDataHandler);
 Q_DECLARE_METATYPE(QList<U2::Workflow::SharedDbiDataHandler>);
-
-#endif
