@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXTERNAL_TOOL_CONFIG_H_
-#define _U2_EXTERNAL_TOOL_CONFIG_H_
+#pragma once
 
 #include <QMap>
 #include <QObject>
@@ -48,7 +47,7 @@ public:
     bool isAlignment() const;
     bool isText() const;
 
-    bool operator==(const DataConfig &other) const;
+    bool operator==(const DataConfig& other) const;
 
     static const DocumentFormatId STRING_VALUE;
     static const DocumentFormatId OUTPUT_FILE_URL;
@@ -88,7 +87,7 @@ public:
     bool isOutputUrl() const;
     bool isFile() const;
     bool isFolder() const;
-    bool operator==(const AttributeConfig &other) const;
+    bool operator==(const AttributeConfig& other) const;
 };
 
 class U2LANG_EXPORT ExternalProcessConfig {
@@ -108,23 +107,23 @@ public:
     QString customToolPath;
     QString integratedToolId;
 
-    bool operator==(const ExternalProcessConfig &other) const;
-    bool operator!=(const ExternalProcessConfig &other) const;
+    bool operator==(const ExternalProcessConfig& other) const;
+    bool operator!=(const ExternalProcessConfig& other) const;
 };
 
 class U2LANG_EXPORT ExternalToolCfgRegistry : public QObject {
     Q_OBJECT
 public:
-    ExternalToolCfgRegistry(QObject *parent = nullptr);
+    ExternalToolCfgRegistry(QObject* parent = nullptr);
 
-    bool registerExternalTool(ExternalProcessConfig *cfg);
-    void unregisterConfig(const QString &id);
+    bool registerExternalTool(ExternalProcessConfig* cfg);
+    void unregisterConfig(const QString& id);
 
-    ExternalProcessConfig *getConfigById(const QString &id) const;
-    QList<ExternalProcessConfig *> getConfigs() const;
+    ExternalProcessConfig* getConfigById(const QString& id) const;
+    QList<ExternalProcessConfig*> getConfigs() const;
 
 private:
-    QMap<QString, ExternalProcessConfig *> configs;
+    QMap<QString, ExternalProcessConfig*> configs;
 };
 
 }  // namespace U2
@@ -132,5 +131,3 @@ private:
 Q_DECLARE_METATYPE(U2::AttributeConfig)
 Q_DECLARE_METATYPE(U2::DataConfig)
 Q_DECLARE_OPERATORS_FOR_FLAGS(U2::AttributeConfig::Flags)
-
-#endif  // _U2_EXTERNAL_TOOL_CONFIG_H_
