@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,14 +25,14 @@
 
 namespace U2 {
 
-GrouperOutSlotAttribute::GrouperOutSlotAttribute(const Descriptor &d, const DataTypePtr type, bool required, const QVariant &defaultValue)
+GrouperOutSlotAttribute::GrouperOutSlotAttribute(const Descriptor& d, const DataTypePtr type, bool required, const QVariant& defaultValue)
     : Attribute(d, type, required, defaultValue) {
 }
 
 GrouperOutSlotAttribute::~GrouperOutSlotAttribute() {
 }
 
-Attribute *GrouperOutSlotAttribute::clone() {
+Attribute* GrouperOutSlotAttribute::clone() {
     return new GrouperOutSlotAttribute(*this);
 }
 
@@ -40,21 +40,21 @@ AttributeGroup GrouperOutSlotAttribute::getGroup() {
     return GROUPER_SLOT_GROUP;
 }
 
-QList<GrouperOutSlot> &GrouperOutSlotAttribute::getOutSlots() {
+QList<GrouperOutSlot>& GrouperOutSlotAttribute::getOutSlots() {
     return outSlots;
 }
 
-const QList<GrouperOutSlot> &GrouperOutSlotAttribute::getOutSlots() const {
+const QList<GrouperOutSlot>& GrouperOutSlotAttribute::getOutSlots() const {
     return outSlots;
 }
 
-void GrouperOutSlotAttribute::addOutSlot(const GrouperOutSlot &outSlot) {
+void GrouperOutSlotAttribute::addOutSlot(const GrouperOutSlot& outSlot) {
     outSlots.append(outSlot);
 }
 
-void GrouperOutSlotAttribute::updateActorIds(const QMap<ActorId, ActorId> &actorIdsMap) {
+void GrouperOutSlotAttribute::updateActorIds(const QMap<ActorId, ActorId>& actorIdsMap) {
     QList<GrouperOutSlot> newOutSlots;
-    foreach (const GrouperOutSlot &gSlot, outSlots) {
+    for (const GrouperOutSlot& gSlot : qAsConst(outSlots)) {
         QString slotStr = gSlot.getInSlotStr();
         slotStr = GrouperOutSlot::readable2busMap(slotStr);
         Workflow::IntegralBusType::remapSlotString(slotStr, actorIdsMap);
@@ -68,15 +68,15 @@ void GrouperOutSlotAttribute::updateActorIds(const QMap<ActorId, ActorId> &actor
     outSlots = newOutSlots;
 }
 
-GroupSlotAttribute::GroupSlotAttribute(const Descriptor &d, const DataTypePtr type, bool required, const QVariant &defaultValue)
+GroupSlotAttribute::GroupSlotAttribute(const Descriptor& d, const DataTypePtr type, bool required, const QVariant& defaultValue)
     : Attribute(d, type, required, defaultValue) {
 }
 
-Attribute *GroupSlotAttribute::clone() {
+Attribute* GroupSlotAttribute::clone() {
     return new GroupSlotAttribute(*this);
 }
 
-void GroupSlotAttribute::updateActorIds(const QMap<ActorId, ActorId> &actorIdsMap) {
+void GroupSlotAttribute::updateActorIds(const QMap<ActorId, ActorId>& actorIdsMap) {
     QString slotStr = this->getAttributeValueWithoutScript<QString>();
     slotStr = GrouperOutSlot::readable2busMap(slotStr);
     Workflow::IntegralBusType::remapSlotString(slotStr, actorIdsMap);
@@ -85,7 +85,7 @@ void GroupSlotAttribute::updateActorIds(const QMap<ActorId, ActorId> &actorIdsMa
     this->setAttributeValue(slotStr);
 }
 
-void GroupSlotAttribute::setAttributeValue(const QVariant &newVal) {
+void GroupSlotAttribute::setAttributeValue(const QVariant& newVal) {
     QString slotStr = newVal.toString();
     Attribute::setAttributeValue(GrouperOutSlot::busMap2readable(slotStr));
 }
