@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _GROUPER_SLOT_ATTRIBUTE_
-#define _GROUPER_SLOT_ATTRIBUTE_
+#pragma once
 
 #include <U2Lang/Attribute.h>
 #include <U2Lang/GrouperOutSlot.h>
@@ -29,16 +28,16 @@ namespace U2 {
 
 class U2LANG_EXPORT GrouperOutSlotAttribute : public Attribute {
 public:
-    GrouperOutSlotAttribute(const Descriptor &d, const DataTypePtr type, bool required = false, const QVariant &defaultValue = QVariant());
+    GrouperOutSlotAttribute(const Descriptor& d, const DataTypePtr type, bool required = false, const QVariant& defaultValue = QVariant());
     ~GrouperOutSlotAttribute();
 
-    virtual Attribute *clone();
+    virtual Attribute* clone();
     virtual AttributeGroup getGroup();
-    virtual void updateActorIds(const QMap<ActorId, ActorId> &actorIdsMap);
+    virtual void updateActorIds(const QMap<ActorId, ActorId>& actorIdsMap);
 
-    QList<GrouperOutSlot> &getOutSlots();
-    const QList<GrouperOutSlot> &getOutSlots() const;
-    void addOutSlot(const GrouperOutSlot &outSlot);
+    QList<GrouperOutSlot>& getOutSlots();
+    const QList<GrouperOutSlot>& getOutSlots() const;
+    void addOutSlot(const GrouperOutSlot& outSlot);
 
 private:
     QList<GrouperOutSlot> outSlots;
@@ -46,13 +45,11 @@ private:
 
 class U2LANG_EXPORT GroupSlotAttribute : public Attribute {
 public:
-    GroupSlotAttribute(const Descriptor &d, const DataTypePtr type, bool required = false, const QVariant &defaultValue = QVariant());
+    GroupSlotAttribute(const Descriptor& d, const DataTypePtr type, bool required = false, const QVariant& defaultValue = QVariant());
 
-    virtual Attribute *clone();
-    virtual void updateActorIds(const QMap<ActorId, ActorId> &actorIdsMap);
-    virtual void setAttributeValue(const QVariant &newVal);
+    virtual Attribute* clone();
+    virtual void updateActorIds(const QMap<ActorId, ActorId>& actorIdsMap);
+    virtual void setAttributeValue(const QVariant& newVal);
 };
 
 }  // namespace U2
-
-#endif  // _GROUPER_SLOT_ATTRIBUTE_
