@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,81 +27,81 @@
 namespace U2 {
 namespace Workflow {
 
-IncludedProtoFactory *IncludedProtoFactory::instance = nullptr;
+IncludedProtoFactory* IncludedProtoFactory::instance = nullptr;
 
-void IncludedProtoFactory::init(IncludedProtoFactory *protoMaker) {
+void IncludedProtoFactory::init(IncludedProtoFactory* protoMaker) {
     instance = protoMaker;
 }
 
-ActorPrototype *IncludedProtoFactory::getScriptProto(QList<DataTypePtr> input, QList<DataTypePtr> output, QList<Attribute *> attrs, const QString &name, const QString &description, const QString &actorFilePath, bool isAliasName) {
-    if (nullptr != instance) {
+ActorPrototype* IncludedProtoFactory::getScriptProto(QList<DataTypePtr> input, QList<DataTypePtr> output, QList<Attribute*> attrs, const QString& name, const QString& description, const QString& actorFilePath, bool isAliasName) {
+    if (instance != nullptr) {
         return instance->_getScriptProto(input, output, attrs, name, description, actorFilePath, isAliasName);
     } else {
         return nullptr;
     }
 }
 
-ActorPrototype *IncludedProtoFactory::getExternalToolProto(ExternalProcessConfig *cfg) {
-    if (nullptr != instance) {
+ActorPrototype* IncludedProtoFactory::getExternalToolProto(ExternalProcessConfig* cfg) {
+    if (instance != nullptr) {
         return instance->_getExternalToolProto(cfg);
     } else {
         return nullptr;
     }
 }
 
-ActorPrototype *IncludedProtoFactory::getSchemaActorProto(Schema *schema, const QString &name, const QString &actorFilePath) {
-    if (nullptr != instance) {
+ActorPrototype* IncludedProtoFactory::getSchemaActorProto(Schema* schema, const QString& name, const QString& actorFilePath) {
+    if (instance != nullptr) {
         return instance->_getSchemaActorProto(schema, name, actorFilePath);
     } else {
         return nullptr;
     }
 }
 
-bool IncludedProtoFactory::registerExternalToolWorker(ExternalProcessConfig *cfg) {
-    if (nullptr != instance) {
+bool IncludedProtoFactory::registerExternalToolWorker(ExternalProcessConfig* cfg) {
+    if (instance != nullptr) {
         return instance->_registerExternalToolWorker(cfg);
     } else {
         return false;
     }
 }
 
-void IncludedProtoFactory::registerScriptWorker(const QString &actorName) {
-    if (nullptr != instance) {
+void IncludedProtoFactory::registerScriptWorker(const QString& actorName) {
+    if (instance != nullptr) {
         return instance->_registerScriptWorker(actorName);
     } else {
         return;
     }
 }
 
-ExternalProcessConfig *IncludedProtoFactory::getExternalToolWorker(const QString &id) {
-    if (nullptr != instance) {
+ExternalProcessConfig* IncludedProtoFactory::getExternalToolWorker(const QString& id) {
+    if (instance != nullptr) {
         return instance->_getExternalToolWorker(id);
     } else {
         return nullptr;
     }
 }
 
-ExternalProcessConfig *IncludedProtoFactory::unregisterExternalToolWorker(const QString &id) {
-    if (nullptr != instance) {
+ExternalProcessConfig* IncludedProtoFactory::unregisterExternalToolWorker(const QString& id) {
+    if (instance != nullptr) {
         return instance->_unregisterExternalToolWorker(id);
     } else {
         return nullptr;
     }
 }
 
-bool IncludedProtoFactory::isRegistered(const QString &actorName) {
-    ActorPrototype *proto = WorkflowEnv::getProtoRegistry()->getProto(actorName);
+bool IncludedProtoFactory::isRegistered(const QString& actorName) {
+    ActorPrototype* proto = WorkflowEnv::getProtoRegistry()->getProto(actorName);
 
-    if (nullptr == proto) {
+    if (proto == nullptr) {
         return false;
     } else {
         return true;
     }
 }
 
-bool IncludedProtoFactory::isRegisteredTheSameProto(const QString &actorId, ActorPrototype *proto) {
-    ActorPrototype *regProto = WorkflowEnv::getProtoRegistry()->getProto(actorId);
-    assert(nullptr != proto);
+bool IncludedProtoFactory::isRegisteredTheSameProto(const QString& actorId, ActorPrototype* proto) {
+    ActorPrototype* regProto = WorkflowEnv::getProtoRegistry()->getProto(actorId);
+    assert(proto != nullptr);
 
     // compare simple proto parameters
     if (regProto->isScriptFlagSet() != proto->isScriptFlagSet()) {
@@ -110,14 +110,14 @@ bool IncludedProtoFactory::isRegisteredTheSameProto(const QString &actorId, Acto
 
     // compare attributes
     {
-        QList<Attribute *> attrList = proto->getAttributes();
-        QList<Attribute *> regAttrList = regProto->getAttributes();
+        QList<Attribute*> attrList = proto->getAttributes();
+        QList<Attribute*> regAttrList = regProto->getAttributes();
         if (attrList.size() != regAttrList.size()) {
             return false;
         }
-        for (Attribute *attr : qAsConst(attrList)) {
+        for (Attribute* attr : qAsConst(attrList)) {
             bool found = false;
-            for (Attribute *regAttr : qAsConst(regAttrList)) {
+            for (Attribute* regAttr : qAsConst(regAttrList)) {
                 if (*attr == *regAttr) {
                     found = true;
                     break;
@@ -131,14 +131,14 @@ bool IncludedProtoFactory::isRegisteredTheSameProto(const QString &actorId, Acto
 
     // compare ports
     {
-        QList<PortDescriptor *> portList = proto->getPortDesciptors();
-        QList<PortDescriptor *> regPortList = regProto->getPortDesciptors();
+        QList<PortDescriptor*> portList = proto->getPortDesciptors();
+        QList<PortDescriptor*> regPortList = regProto->getPortDesciptors();
         if (portList.size() != regPortList.size()) {
             return false;
         }
-        for (PortDescriptor *port : qAsConst(portList)) {
+        for (PortDescriptor* port : qAsConst(portList)) {
             bool found = false;
-            for (PortDescriptor *regPort : qAsConst(regPortList)) {
+            for (PortDescriptor* regPort : qAsConst(regPortList)) {
                 if (*port == *regPort) {
                     found = true;
                     break;
