@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_INTEGRAL_BUS_H_
-#define _U2_WORKFLOW_INTEGRAL_BUS_H_
+#pragma once
 
 #include <QMutex>
 
@@ -38,15 +37,15 @@ namespace Workflow {
  */
 class U2LANG_EXPORT BusMap {
 public:
-    BusMap(const StrStrMap &busMap, const QMap<QString, QStringList> &listMap, const SlotPathMap &paths);
-    BusMap(const StrStrMap &busMap, bool breaksDataflow, const QString &actorId);
+    BusMap(const StrStrMap& busMap, const QMap<QString, QStringList>& listMap, const SlotPathMap& paths);
+    BusMap(const StrStrMap& busMap, bool breaksDataflow, const QString& actorId);
 
-    Message takeMessageMap(CommunicationChannel *ch, QVariantMap &context);
-    Message lookMessageMap(CommunicationChannel *ch);
-    QVariantMap composeMessageMap(const Message &m, const QVariantMap &context);
+    Message takeMessageMap(CommunicationChannel* ch, QVariantMap& context);
+    Message lookMessageMap(CommunicationChannel* ch);
+    QVariantMap composeMessageMap(const Message& m, const QVariantMap& context);
 
-    static void parseSource(const QString &src, QString &srcId, QStringList &path);
-    static QString getNewSourceId(const QString &srcId, const QString &actorId);
+    static void parseSource(const QString& src, QString& srcId, QStringList& path);
+    static QString getNewSourceId(const QString& srcId, const QString& actorId);
 
 private:
     bool input;
@@ -59,7 +58,7 @@ private:
     QString actorId;
 
 private:
-    QVariantMap getMessageData(const Message &m) const;
+    QVariantMap getMessageData(const Message& m) const;
 };
 
 /**
@@ -71,24 +70,24 @@ private:
 class U2LANG_EXPORT IntegralBus : public QObject, public CommunicationSubject, public CommunicationChannel {
     Q_OBJECT
 public:
-    IntegralBus(Port *peer);
+    IntegralBus(Port* peer);
     ~IntegralBus();
 
     // reimplemented from CommunicationSubject
-    virtual bool addCommunication(const QString &id, CommunicationChannel *ch);
-    virtual CommunicationChannel *getCommunication(const QString &id);
+    virtual bool addCommunication(const QString& id, CommunicationChannel* ch);
+    virtual CommunicationChannel* getCommunication(const QString& id);
 
-    void putWithoutContext(const Message &m);
+    void putWithoutContext(const Message& m);
 
     // reimplemented from CommunicationChannel
     virtual Message get();
     virtual Message look() const;
-    virtual void put(const Message &m, bool isMessageRestored = false);
+    virtual void put(const Message& m, bool isMessageRestored = false);
     // put incoming context to the output channels
     virtual void transit();
     virtual int hasMessage() const;
     virtual int takenMessages() const;
-    virtual int hasRoom(const DataType *t = nullptr) const;
+    virtual int hasRoom(const DataType* t = nullptr) const;
     virtual bool isEnded() const;
     virtual void setEnded();
     virtual int capacity() const {
@@ -105,10 +104,10 @@ public:
     QVariantMap getLastMessageContext() const {
         return lastMessageContext;
     }
-    void setContext(const QVariantMap &m, int metadataId);
+    void setContext(const QVariantMap& m, int metadataId);
     int getContextMetadataId() const;
 
-    virtual void addComplement(IntegralBus *b) {
+    virtual void addComplement(IntegralBus* b) {
         assert(!complement);
         complement = b;
     }
@@ -120,26 +119,26 @@ public:
         return busType;
     }
 
-    void setPrintSlots(bool in, const QList<QString> &printSlots);
+    void setPrintSlots(bool in, const QList<QString>& printSlots);
 
-    void setWorkflowContext(WorkflowContext *context);
+    void setWorkflowContext(WorkflowContext* context);
 
 protected:
-    virtual Message composeMessage(const Message &);
+    virtual Message composeMessage(const Message&);
 
 protected:
     // type of port integral bus is binded to
     DataTypePtr busType;
     // communications with other ports
-    QMap<QString, CommunicationChannel *> outerChannels;
+    QMap<QString, CommunicationChannel*> outerChannels;
     // busmap of port integral bus is binded to
-    BusMap *busMap;
+    BusMap* busMap;
     // context of an output message. See put() for details
     QVariantMap context;
     QVariantMap lastMessageContext;
     int contextMetadataId;
     //
-    IntegralBus *complement;
+    IntegralBus* complement;
     // integral bus is binded to port with this id
     QString portId;
     //
@@ -148,14 +147,12 @@ protected:
     // a content of these slots is printed to the standart output
     QList<QString> printSlots;
     ActorId actorId;
-    WorkflowContext *workflowContext;
+    WorkflowContext* workflowContext;
 
-    QMutex *contextMutex;
+    QMutex* contextMutex;
 
 };  // IntegralBus
 
 }  // namespace Workflow
 
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_INTEGRAL_BUS_H_
