@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,20 +25,20 @@
 
 namespace U2 {
 
-MarkerAttribute::MarkerAttribute(const Descriptor &d, const DataTypePtr type, bool required, const QVariant &defaultValue)
+MarkerAttribute::MarkerAttribute(const Descriptor& d, const DataTypePtr type, bool required, const QVariant& defaultValue)
     : Attribute(d, type, required, defaultValue) {
 }
 
-void MarkerAttribute::setAttributeValue(const QVariant & /*newVal*/) {
+void MarkerAttribute::setAttributeValue(const QVariant& /*newVal*/) {
     FAIL("marker set value", );
 }
 
-const QVariant &MarkerAttribute::getAttributePureValue() const {
+const QVariant& MarkerAttribute::getAttributePureValue() const {
     QStringList names;
-    foreach (Marker *marker, markers) {
+    foreach (Marker* marker, markers) {
         names << marker->getName();
     }
-    const_cast<QVariant &>(value) = names.join(",");
+    const_cast<QVariant&>(value) = names.join(",");
     return value;
 }
 
@@ -46,7 +46,7 @@ bool MarkerAttribute::isDefaultValue() const {
     return (defaultValue == getAttributePureValue());
 }
 
-Attribute *MarkerAttribute::clone() {
+Attribute* MarkerAttribute::clone() {
     return new MarkerAttribute(*this);
 }
 
@@ -54,13 +54,13 @@ AttributeGroup MarkerAttribute::getGroup() {
     return MARKER_GROUP;
 }
 
-QList<Marker *> &MarkerAttribute::getMarkers() {
+QList<Marker*>& MarkerAttribute::getMarkers() {
     return markers;
 }
 
-bool MarkerAttribute::contains(const QString &markerId) const {
-    foreach (Marker *marker, markers) {
-        if (nullptr == marker) {
+bool MarkerAttribute::contains(const QString& markerId) const {
+    foreach (Marker* marker, markers) {
+        if (marker == nullptr) {
             continue;
         }
         if (marker->getName() == markerId) {
