@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_INPUT_DATA_PORT_VALIDATOR_H_
-#define _U2_INPUT_DATA_PORT_VALIDATOR_H_
+#pragma once
 
 #include <QCoreApplication>
 
@@ -32,8 +31,8 @@ namespace Workflow {
 class U2LANG_EXPORT PairedReadsPortValidator : public PortValidator {
     Q_DECLARE_TR_FUNCTIONS(PairedReadsPortValidator)
 public:
-    PairedReadsPortValidator(const QString &inputId, const QString &inputPairedId);
-    bool validate(const IntegralBusPort *port, NotificationsList &notificationList) const;
+    PairedReadsPortValidator(const QString& inputId, const QString& inputPairedId);
+    bool validate(const IntegralBusPort* port, NotificationsList& notificationList) const;
 
 private:
     QString inputSlotId;
@@ -42,5 +41,3 @@ private:
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // _U2_INPUT_DATA_PORT_VALIDATOR_H_
