@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@
 
 namespace U2 {
 
-void QDParameters::setParameter(const QString &name, const QVariant &val) {
+void QDParameters::setParameter(const QString& name, const QVariant& val) {
     Configuration::setParameter(name, val);
     emit si_modified();
 }
@@ -40,20 +40,20 @@ void QDParameters::setParameter(const QString &name, const QVariant &val) {
 //////////////////////////////////////////////////////////////////////////
 const int QDActor::DEFAULT_MAX_RESULT_LENGTH(10000);
 
-QDActor::QDActor(QDActorPrototype const *_proto)
+QDActor::QDActor(QDActorPrototype const* _proto)
     : scheme(nullptr), proto(_proto), strand(QDStrand_Both), simmetric(false) {
     cfg = new QDActorParameters;
-    foreach (Attribute *a, proto->getParameters()) {
+    foreach (Attribute* a, proto->getParameters()) {
         cfg->addParameter(a->getId(), a->clone());
     }
-    ConfigurationEditor *ed = proto->getEditor();
+    ConfigurationEditor* ed = proto->getEditor();
 
     if (ed) {
         cfg->setEditor(ed);
     }
 
-    const QMap<QString, Attribute *> &attrs = cfg->getParameters();
-    QMapIterator<QString, Attribute *> it(attrs);
+    const QMap<QString, Attribute*>& attrs = cfg->getParameters();
+    QMapIterator<QString, Attribute*> it(attrs);
     while (it.hasNext()) {
         it.next();
         defaultCfg[it.key()] = it.value()->getAttributePureValue();
@@ -66,15 +66,15 @@ QDActor::~QDActor() {
 }
 
 void QDActor::reset() {
-    const QMap<QString, Attribute *> &attrs = cfg->getParameters();
-    foreach (const QString &key, attrs.keys()) {
-        Attribute *a = attrs[key];
+    const QMap<QString, Attribute*>& attrs = cfg->getParameters();
+    foreach (const QString& key, attrs.keys()) {
+        Attribute* a = attrs[key];
         a->setAttributeValue(defaultCfg.value(key));
     }
 }
 
-bool contains(const QDResultUnit &res, const QVector<U2Region> &location) {
-    foreach (const U2Region &r, location) {
+bool contains(const QDResultUnit& res, const QVector<U2Region>& location) {
+    foreach (const U2Region& r, location) {
         if (r.contains(res->region)) {
             return true;
         }
@@ -82,7 +82,7 @@ bool contains(const QDResultUnit &res, const QVector<U2Region> &location) {
     return false;
 }
 
-void QDActor::filterResults(const QVector<U2Region> &) {
+void QDActor::filterResults(const QVector<U2Region>&) {
     /*QList<QDResultGroup*> res = results;
     foreach(QDResultGroup* grp, res) {
         foreach(const QDResultUnit& ru, grp->getResultsList()) {
@@ -94,8 +94,8 @@ void QDActor::filterResults(const QVector<U2Region> &) {
     }*/
 }
 
-QList<QDResultGroup *> QDActor::popResults() {
-    QList<QDResultGroup *> res = results;
+QList<QDResultGroup*> QDActor::popResults() {
+    QList<QDResultGroup*> res = results;
     results.clear();
     return res;
 }
@@ -104,7 +104,7 @@ static const QString KEY_ATTR = "key";
 
 QList<QPair<QString, QString>> QDActor::saveConfiguration() const {
     QList<QPair<QString, QString>> res;
-    QMapIterator<QString, Attribute *> it(cfg->getParameters());
+    QMapIterator<QString, Attribute*> it(cfg->getParameters());
     QString annKey = cfg->getAnnotationKey();
     if (annKey.contains(' ')) {
         annKey = "\"" + annKey + "\"";
@@ -112,7 +112,7 @@ QList<QPair<QString, QString>> QDActor::saveConfiguration() const {
     res.append(qMakePair(KEY_ATTR, annKey));
     while (it.hasNext()) {
         it.next();
-        Attribute *a = it.value();
+        Attribute* a = it.value();
         if (a->getAttributePureValue() == defaultCfg.value(it.key())) {
             continue;
         }
@@ -124,15 +124,15 @@ QList<QPair<QString, QString>> QDActor::saveConfiguration() const {
     return res;
 }
 
-void QDActor::loadConfiguration(const QList<QPair<QString, QString>> &strMap) {
-    foreach (const StringAttribute &attr, strMap) {
+void QDActor::loadConfiguration(const QList<QPair<QString, QString>>& strMap) {
+    foreach (const StringAttribute& attr, strMap) {
         if (attr.first == KEY_ATTR) {
             cfg->setAnnotationKey(attr.second);
         }
-        QMapIterator<QString, Attribute *> paramsIterator(cfg->getParameters());
+        QMapIterator<QString, Attribute*> paramsIterator(cfg->getParameters());
         while (paramsIterator.hasNext()) {
             paramsIterator.next();
-            Attribute *a = paramsIterator.value();
+            Attribute* a = paramsIterator.value();
             if (QDAttributeNameConverter::convertAttrName(a->getId()) == attr.first) {
                 QVariant val = QDAttributeValueMapper::stringToAttributeValue(attr.second);
                 cfg->setParameter(a->getId(), val);
@@ -174,18 +174,18 @@ void QDActor::setStrand(QDStrandOption stOp) {
     emit si_strandChanged(strand);
 }
 
-QList<QDConstraint *> QDActor::getConstraints() const {
-    QList<QDConstraint *> res;
-    foreach (QDSchemeUnit *su, units) {
+QList<QDConstraint*> QDActor::getConstraints() const {
+    QList<QDConstraint*> res;
+    foreach (QDSchemeUnit* su, units) {
         res << su->getConstraints();
     }
     return res;
 }
 
-QList<QDDistanceConstraint *> QDSchemeUnit::getDistanceConstraints() const {
-    QList<QDDistanceConstraint *> res;
-    foreach (QDConstraint *c, schemeConstraints) {
-        QDDistanceConstraint *dc = static_cast<QDDistanceConstraint *>(c);
+QList<QDDistanceConstraint*> QDSchemeUnit::getDistanceConstraints() const {
+    QList<QDDistanceConstraint*> res;
+    foreach (QDConstraint* c, schemeConstraints) {
+        auto dc = static_cast<QDDistanceConstraint*>(c);
         if (dc) {
             res.append(dc);
         }
@@ -196,15 +196,15 @@ QList<QDDistanceConstraint *> QDSchemeUnit::getDistanceConstraints() const {
 // QDScheme
 //////////////////////////////////////////////////////////////////////////
 QDScheme::~QDScheme() {
-    foreach (QDActor *a, actors) {
+    foreach (QDActor* a, actors) {
         removeActor(a);
     }
 }
 
-void QDScheme::addActor(QDActor *a) {
+void QDScheme::addActor(QDActor* a) {
     assert(!actors.contains(a));
     assert(a->scheme == nullptr);
-    foreach (QDSchemeUnit *su, a->getSchemeUnits()) {
+    foreach (QDSchemeUnit* su, a->getSchemeUnits()) {
         assert(su->getConstraints().isEmpty());
         Q_UNUSED(su);
     }
@@ -213,17 +213,17 @@ void QDScheme::addActor(QDActor *a) {
     emit si_schemeChanged();
 }
 
-bool QDScheme::removeActor(QDActor *a) {
+bool QDScheme::removeActor(QDActor* a) {
     if (actors.contains(a)) {
-        QList<QDSchemeUnit *> schemaUnits = a->getSchemeUnits();
-        for (QDSchemeUnit *schemaUnit : qAsConst(schemaUnits)) {
-            QList<QDConstraint *> constraints = schemaUnit->getConstraints();
-            for (QDConstraint *c : qAsConst(constraints)) {
+        QList<QDSchemeUnit*> schemaUnits = a->getSchemeUnits();
+        for (QDSchemeUnit* schemaUnit : qAsConst(schemaUnits)) {
+            QList<QDConstraint*> constraints = schemaUnit->getConstraints();
+            for (QDConstraint* c : qAsConst(constraints)) {
                 removeConstraint(c);
             }
         }
         actors.removeOne(a);
-        const QString &ag = getActorGroup(a);
+        const QString& ag = getActorGroup(a);
         if (!ag.isEmpty()) {
             actorGroups[ag].removeOne(a);
         }
@@ -234,18 +234,18 @@ bool QDScheme::removeActor(QDActor *a) {
     return false;
 }
 
-void QDScheme::addConstraint(QDConstraint *constraint) {
-    foreach (QDSchemeUnit *su, constraint->getSchemeUnits()) {
+void QDScheme::addConstraint(QDConstraint* constraint) {
+    foreach (QDSchemeUnit* su, constraint->getSchemeUnits()) {
         assert(actors.contains(su->getActor()));
         su->schemeConstraints.append(constraint);
     }
     emit si_schemeChanged();
 }
 
-void QDScheme::removeConstraint(QDConstraint *constraint) {
-    const QList<QDSchemeUnit *> &constraintUnits = constraint->getSchemeUnits();
-    foreach (QDSchemeUnit *su, constraintUnits) {
-        QDActor *actor = su->getActor();
+void QDScheme::removeConstraint(QDConstraint* constraint) {
+    const QList<QDSchemeUnit*>& constraintUnits = constraint->getSchemeUnits();
+    foreach (QDSchemeUnit* su, constraintUnits) {
+        QDActor* actor = su->getActor();
         Q_UNUSED(actor);
         assert(actors.contains(actor));
         assert(su->getConstraints().contains(constraint));
@@ -255,13 +255,13 @@ void QDScheme::removeConstraint(QDConstraint *constraint) {
     emit si_schemeChanged();
 }
 
-QList<QDConstraint *> QDScheme::getConstraints() const {
-    QList<QDConstraint *> res;
-    for (QDActor *actor : qAsConst(actors)) {
-        QList<QDSchemeUnit *> schemeUnits = actor->getSchemeUnits();
-        for (QDSchemeUnit *su : qAsConst(schemeUnits)) {
-            const QList<QDConstraint *> &constraints = su->getConstraints();
-            for (QDConstraint *c : qAsConst(constraints)) {
+QList<QDConstraint*> QDScheme::getConstraints() const {
+    QList<QDConstraint*> res;
+    for (QDActor* actor : qAsConst(actors)) {
+        QList<QDSchemeUnit*> schemeUnits = actor->getSchemeUnits();
+        for (QDSchemeUnit* su : qAsConst(schemeUnits)) {
+            const QList<QDConstraint*>& constraints = su->getConstraints();
+            for (QDConstraint* c : qAsConst(constraints)) {
                 if (!res.contains(c)) {
                     res.append(c);
                 }
@@ -271,12 +271,12 @@ QList<QDConstraint *> QDScheme::getConstraints() const {
     return res;
 }
 
-QList<QDConstraint *>
-    QDScheme::getConstraints(QDSchemeUnit const *su1, QDSchemeUnit const *su2) const {
-    QList<QDConstraint *> sharedConstraints;
-    const QList<QDConstraint *> &su1Cons = su1->getConstraints();
-    const QList<QDConstraint *> &su2Cons = su2->getConstraints();
-    for (QDConstraint *con : qAsConst(su1Cons)) {
+QList<QDConstraint*>
+    QDScheme::getConstraints(QDSchemeUnit const* su1, QDSchemeUnit const* su2) const {
+    QList<QDConstraint*> sharedConstraints;
+    const QList<QDConstraint*>& su1Cons = su1->getConstraints();
+    const QList<QDConstraint*>& su2Cons = su2->getConstraints();
+    for (QDConstraint* con : qAsConst(su1Cons)) {
         if (su2Cons.contains(con)) {
             sharedConstraints.append(con);
         }
@@ -287,60 +287,60 @@ QList<QDConstraint *>
 void QDScheme::clear() {
     // delete dna;
     dna = DNASequence();
-    QList<QDActor *> actorsCopy = actors;
-    for (QDActor *a : qAsConst(actorsCopy)) {
+    QList<QDActor*> actorsCopy = actors;
+    for (QDActor* a : qAsConst(actorsCopy)) {
         removeActor(a);
     }
     actorGroups.clear();
     emit si_schemeChanged();
 }
 
-QList<QDPath *> QDScheme::findPaths(QDSchemeUnit *src, QDSchemeUnit *dst) {
-    QList<QDSchemeUnit *> currentRoute = {src};
-    QList<QList<QDSchemeUnit *>> routes;
+QList<QDPath*> QDScheme::findPaths(QDSchemeUnit* src, QDSchemeUnit* dst) {
+    QList<QDSchemeUnit*> currentRoute = {src};
+    QList<QList<QDSchemeUnit*>> routes;
     findRoute(src, dst, currentRoute, routes);
-    QList<QDPath *> res;
-    for (const QList<QDSchemeUnit *> &route : qAsConst(routes)) {
-        QList<QDPath *> paths;
+    QList<QDPath*> res;
+    for (const QList<QDSchemeUnit*>& route : qAsConst(routes)) {
+        QList<QDPath*> paths;
         for (int routeIndex = 0, m = route.size() - 1; routeIndex < m; routeIndex++) {
-            QDSchemeUnit *routeSrc = route.at(routeIndex);
-            QDSchemeUnit *routeDst = route.at(routeIndex + 1);
-            QList<QDConstraint *> joint = getConstraints(routeSrc, routeDst);
+            QDSchemeUnit* routeSrc = route.at(routeIndex);
+            QDSchemeUnit* routeDst = route.at(routeIndex + 1);
+            QList<QDConstraint*> joint = getConstraints(routeSrc, routeDst);
 
             // include "parameter" constraints
-            foreach (QDConstraint *con, routeSrc->getActor()->getParamConstraints()) {
+            foreach (QDConstraint* con, routeSrc->getActor()->getParamConstraints()) {
                 if (con->getSchemeUnits().contains(routeSrc) && con->getSchemeUnits().contains(routeDst)) {
                     joint.append(con);
                 }
             }
-            QList<QDDistanceConstraint *> jointCons;
-            for (QDConstraint *con : qAsConst(joint)) {
-                if (auto dc = static_cast<QDDistanceConstraint *>(con)) {
+            QList<QDDistanceConstraint*> jointCons;
+            for (QDConstraint* con : qAsConst(joint)) {
+                if (auto dc = static_cast<QDDistanceConstraint*>(con)) {
                     jointCons.append(dc);
                 }
             }
             assert(!jointCons.isEmpty());
 
             if (paths.isEmpty()) {
-                for (QDDistanceConstraint *dc : qAsConst(jointCons)) {
-                    QDPath *newPath = new QDPath;
+                for (QDDistanceConstraint* dc : qAsConst(jointCons)) {
+                    QDPath* newPath = new QDPath;
                     bool ok = newPath->addConstraint(dc);
                     assert(ok);
                     Q_UNUSED(ok);
                     paths << newPath;
                 }
             } else {
-                QList<QDPath *> newPaths;
+                QList<QDPath*> newPaths;
                 for (int jointConstraintIndex = 1, n = jointCons.size(); jointConstraintIndex < n; jointConstraintIndex++) {
-                    for (QDPath *path : qAsConst(paths)) {
-                        QDPath *newPath = path->clone();
+                    for (QDPath* path : qAsConst(paths)) {
+                        QDPath* newPath = path->clone();
                         bool ok = newPath->addConstraint(jointCons.at(jointConstraintIndex));
                         assert(ok);
                         Q_UNUSED(ok);
                         newPaths.append(newPath);
                     }
                 }
-                for (QDPath *path : qAsConst(paths)) {
+                for (QDPath* path : qAsConst(paths)) {
                     bool ok = path->addConstraint(jointCons.at(0));
                     assert(ok);
                     Q_UNUSED(ok);
@@ -355,27 +355,27 @@ QList<QDPath *> QDScheme::findPaths(QDSchemeUnit *src, QDSchemeUnit *dst) {
     return res;
 }
 
-void QDScheme::findRoute(QDSchemeUnit *curSu, QDSchemeUnit *routeDst, QList<QDSchemeUnit *> &currentRoute, QList<QList<QDSchemeUnit *>> routes) {
+void QDScheme::findRoute(QDSchemeUnit* curSu, QDSchemeUnit* routeDst, QList<QDSchemeUnit*>& currentRoute, QList<QList<QDSchemeUnit*>> routes) {
     if (curSu == routeDst) {
         routes.append(currentRoute);
     } else {
         // build list of adjacent vertexes
-        QList<QDSchemeUnit *> adjacentList;
-        QList<QDDistanceConstraint *> dcList = curSu->getDistanceConstraints();
+        QList<QDSchemeUnit*> adjacentList;
+        QList<QDDistanceConstraint*> dcList = curSu->getDistanceConstraints();
         // include "parameter" constraints
-        foreach (QDConstraint *con, curSu->getActor()->getParamConstraints()) {
+        foreach (QDConstraint* con, curSu->getActor()->getParamConstraints()) {
             if (con->constraintType() == QDConstraintTypes::DISTANCE) {
-                QDDistanceConstraint *dc = static_cast<QDDistanceConstraint *>(con);
+                auto dc = static_cast<QDDistanceConstraint*>(con);
                 if (dc->getSchemeUnits().contains(curSu)) {
                     dcList.append(dc);
                 }
             }
         }
 
-        for (QDDistanceConstraint *dc : qAsConst(dcList)) {
-            QDSchemeUnit *dcSrc = dc->getSource();
-            QDSchemeUnit *dcDst = dc->getDestination();
-            QDSchemeUnit *adj;
+        for (QDDistanceConstraint* dc : qAsConst(dcList)) {
+            QDSchemeUnit* dcSrc = dc->getSource();
+            QDSchemeUnit* dcDst = dc->getDestination();
+            QDSchemeUnit* adj;
             if (curSu == dcSrc) {
                 adj = dcDst;
             } else {
@@ -386,7 +386,7 @@ void QDScheme::findRoute(QDSchemeUnit *curSu, QDSchemeUnit *routeDst, QList<QDSc
                 adjacentList.append(adj);
             }
         }
-        for (QDSchemeUnit *adj : qAsConst(adjacentList)) {
+        for (QDSchemeUnit* adj : qAsConst(adjacentList)) {
             if (!currentRoute.contains(adj)) {
                 currentRoute.append(adj);
                 findRoute(adj, routeDst, currentRoute, routes);
@@ -402,18 +402,18 @@ QDPath::~QDPath() {
     delete overallConstraint;
 }
 
-QDPath *QDPath::clone() const {
-    QDPath *cln = new QDPath;
+QDPath* QDPath::clone() const {
+    QDPath* cln = new QDPath;
     cln->constraints = constraints;
     cln->pathSrc = pathSrc;
     cln->pathDst = pathDst;
     return cln;
 }
 
-bool QDPath::addConstraint(QDDistanceConstraint *dc) {
+bool QDPath::addConstraint(QDDistanceConstraint* dc) {
     assert(!constraints.contains(dc));
-    QDSchemeUnit *dcSrc = dc->getSource();
-    QDSchemeUnit *dcDst = dc->getDestination();
+    QDSchemeUnit* dcSrc = dc->getSource();
+    QDSchemeUnit* dcDst = dc->getDestination();
     if (!pathSrc) {
         assert(!pathDst);
         pathSrc = dcSrc;
@@ -442,21 +442,21 @@ bool QDPath::addConstraint(QDDistanceConstraint *dc) {
     return true;
 }
 
-QDDistanceConstraint *QDPath::toConstraint() {
+QDDistanceConstraint* QDPath::toConstraint() {
     if (constraints.isEmpty()) {
         return nullptr;
     }
     delete overallConstraint;
     int minDist = 0, maxDist = 0;
-    QDSchemeUnit *curSu = pathSrc;
+    QDSchemeUnit* curSu = pathSrc;
     for (int i = 0, n = constraints.size(); i < n; i++) {
-        QDDistanceConstraint *curDc = constraints.at(i);
-        QDDistanceConstraint *nextDc = nullptr;
+        QDDistanceConstraint* curDc = constraints.at(i);
+        QDDistanceConstraint* nextDc = nullptr;
         if (i + 1 < n) {
             nextDc = constraints.at(i + 1);
         }
-        QDSchemeUnit *curDcSrc = curDc->getSource();
-        QDSchemeUnit *curDcDst = curDc->getDestination();
+        QDSchemeUnit* curDcSrc = curDc->getSource();
+        QDSchemeUnit* curDcDst = curDc->getDestination();
 
         if (curSu == curDcSrc) {
             curSu = curDcDst;
@@ -465,8 +465,8 @@ QDDistanceConstraint *QDPath::toConstraint() {
             if (!nextDc) {
                 continue;
             }
-            QDSchemeUnit *nextDcSrc = nextDc->getSource();
-            QDSchemeUnit *nextDcDst = nextDc->getDestination();
+            QDSchemeUnit* nextDcSrc = nextDc->getSource();
+            QDSchemeUnit* nextDcDst = nextDc->getDestination();
 
             if (nextDcSrc == curSu) {
                 if (curDc->distanceType() == S2S || curDc->distanceType() == E2S) {
@@ -503,8 +503,8 @@ QDDistanceConstraint *QDPath::toConstraint() {
             if (!nextDc) {
                 continue;
             }
-            QDSchemeUnit *nextDcSrc = nextDc->getSource();
-            QDSchemeUnit *nextDcDst = nextDc->getDestination();
+            QDSchemeUnit* nextDcSrc = nextDc->getSource();
+            QDSchemeUnit* nextDcDst = nextDc->getDestination();
 
             if (nextDcSrc == curSu) {
                 if (curDc->distanceType() == S2S || curDc->distanceType() == S2E) {
@@ -540,9 +540,9 @@ QDDistanceConstraint *QDPath::toConstraint() {
         return nullptr;
     }
 
-    QDDistanceConstraint *firstDc = constraints.first();
-    QDDistanceConstraint *lastDc = constraints.last();
-    QList<QDSchemeUnit *> units;
+    QDDistanceConstraint* firstDc = constraints.first();
+    QDDistanceConstraint* lastDc = constraints.last();
+    QList<QDSchemeUnit*> units;
     units << pathSrc << pathDst;
 
     QDDistanceType distType;
@@ -614,7 +614,7 @@ QDDistanceConstraint *QDPath::toConstraint() {
     return overallConstraint;
 }
 
-void QDScheme::setOrder(QDActor *a, int serialNum) {
+void QDScheme::setOrder(QDActor* a, int serialNum) {
     assert(actors.contains(a));
     int aIdx = actors.indexOf(a);
     if (serialNum < 0) {
@@ -630,25 +630,25 @@ void QDScheme::setOrder(QDActor *a, int serialNum) {
 
 bool QDScheme::isValid() const {
     bool res = true;
-    foreach (QDActor *actor, getActors()) {
-        QDActorParameters *cfg = actor->getParameters();
+    foreach (QDActor* actor, getActors()) {
+        QDActorParameters* cfg = actor->getParameters();
         NotificationsList notificationList;
         if (!cfg->validate(notificationList)) {
             res = false;
-            for (const WorkflowNotification &notification : qAsConst(notificationList)) {
+            for (const WorkflowNotification& notification : qAsConst(notificationList)) {
                 coreLog.error(QObject::tr("%1. %2").arg(cfg->getLabel()).arg(notification.message));
             }
         }
     }
-    foreach (QDConstraint *con, getConstraints()) {
+    foreach (QDConstraint* con, getConstraints()) {
         if (con->constraintType() == QDConstraintTypes::DISTANCE) {
-            QDDistanceConstraint *dc = static_cast<QDDistanceConstraint *>(con);
+            auto dc = static_cast<QDDistanceConstraint*>(con);
             if (dc->getMin() > dc->getMax()) {
                 coreLog.error(QObject::tr("Invalid distance values"));
                 res = false;
             }
-            QDActor *src = dc->getSource()->getActor();
-            QDActor *dst = dc->getDestination()->getActor();
+            QDActor* src = dc->getSource()->getActor();
+            QDActor* dst = dc->getDestination()->getActor();
             QString group = getActorGroup(src);
             if (!group.isEmpty() && getActors(group).contains(dst)) {
                 coreLog.error(QObject::tr("Constraints can not be placed between elements of the same group"));
@@ -659,8 +659,8 @@ bool QDScheme::isValid() const {
     return res;
 }
 
-QDActor *QDScheme::getActorByLabel(const QString &label) const {
-    foreach (QDActor *a, actors) {
+QDActor* QDScheme::getActorByLabel(const QString& label) const {
+    foreach (QDActor* a, actors) {
         if (a->getParameters()->getLabel() == label) {
             return a;
         }
@@ -668,7 +668,7 @@ QDActor *QDScheme::getActorByLabel(const QString &label) const {
     return nullptr;
 }
 
-void QDScheme::addActorToGroup(QDActor *a, const QString &group) {
+void QDScheme::addActorToGroup(QDActor* a, const QString& group) {
     assert(actors.contains(a));
     assert(getActorGroup(a).isEmpty());
     assert(actorGroups.keys().contains(group));
@@ -676,8 +676,8 @@ void QDScheme::addActorToGroup(QDActor *a, const QString &group) {
     emit si_schemeChanged();
 }
 
-bool QDScheme::removeActorFromGroup(QDActor *a) {
-    const QString &group = getActorGroup(a);
+bool QDScheme::removeActorFromGroup(QDActor* a) {
+    const QString& group = getActorGroup(a);
     if (!group.isEmpty()) {
         bool res = actorGroups[group].removeOne(a);
         if (res) {
@@ -687,22 +687,22 @@ bool QDScheme::removeActorFromGroup(QDActor *a) {
     return false;
 }
 
-void QDScheme::createActorGroup(const QString &name) {
+void QDScheme::createActorGroup(const QString& name) {
     assert(validateGroupName(name));
     assert(!actorGroups.keys().contains(name));
-    actorGroups.insert(name, QList<QDActor *>());
+    actorGroups.insert(name, QList<QDActor*>());
     actorGroupReqNum[name] = 1;
     emit si_schemeChanged();
 }
 
-bool QDScheme::removeActorGroup(const QString &name) {
+bool QDScheme::removeActorGroup(const QString& name) {
     bool res = actorGroups.remove(name);
     emit si_schemeChanged();
     return res;
 }
 
-QString QDScheme::getActorGroup(QDActor *a) const {
-    QMapIterator<QString, QList<QDActor *>> i(actorGroups);
+QString QDScheme::getActorGroup(QDActor* a) const {
+    QMapIterator<QString, QList<QDActor*>> i(actorGroups);
     while (i.hasNext()) {
         i.next();
         if (i.value().contains(a)) {
@@ -712,16 +712,16 @@ QString QDScheme::getActorGroup(QDActor *a) const {
     return QString();
 }
 
-bool QDScheme::validateGroupName(const QString &name) const {
+bool QDScheme::validateGroupName(const QString& name) const {
     if (name.isEmpty()) {
         return false;
     }
     return true;
 }
 
-void QDScheme::setRequiredNum(const QString &group, int num) {
+void QDScheme::setRequiredNum(const QString& group, int num) {
     assert(actorGroups.keys().contains(group));
-    const QList<QDActor *> &grpMembrs = actorGroups.value(group);
+    const QList<QDActor*>& grpMembrs = actorGroups.value(group);
     Q_UNUSED(grpMembrs);
     assert(num <= grpMembrs.size());
     actorGroupReqNum[group] = num;
@@ -729,14 +729,14 @@ void QDScheme::setRequiredNum(const QString &group, int num) {
 }
 
 void QDScheme::adaptActorsOrder() {
-    QList<QDActor *> actorsQueue;
-    foreach (QDActor *a, actors) {
+    QList<QDActor*> actorsQueue;
+    foreach (QDActor* a, actors) {
         QString group = getActorGroup(a);
         if (group.isEmpty()) {
             assert(!actorsQueue.contains(a));
             actorsQueue.append(a);
         } else if (!actorsQueue.contains(a)) {
-            const QList<QDActor *> &groupActors = getActors(group);
+            const QList<QDActor*>& groupActors = getActors(group);
             actorsQueue.append(groupActors);
         }
     }
@@ -745,7 +745,7 @@ void QDScheme::adaptActorsOrder() {
 
 // QDResultGroup
 //////////////////////////////////////////////////////////////////////////
-void QDResultGroup::add(const QDResultUnit &res) {
+void QDResultGroup::add(const QDResultUnit& res) {
     if (results.isEmpty()) {
         startPos = res->region.startPos;
         endPos = res->region.endPos();
@@ -760,15 +760,15 @@ void QDResultGroup::add(const QDResultUnit &res) {
     results.append(res);
 }
 
-void QDResultGroup::add(const QList<QDResultUnit> &res) {
-    foreach (const QDResultUnit &r, res) {
+void QDResultGroup::add(const QList<QDResultUnit>& res) {
+    foreach (const QDResultUnit& r, res) {
         add(r);
     }
 }
 
-void QDResultGroup::buildGroupFromSingleResult(const QDResultUnit &ru, QList<QDResultGroup *> &results) {
+void QDResultGroup::buildGroupFromSingleResult(const QDResultUnit& ru, QList<QDResultGroup*>& results) {
     QDStrandOption groupStrand = ru->strand == U2Strand::Direct ? QDStrand_DirectOnly : QDStrand_ComplementOnly;
-    QDResultGroup *g = new QDResultGroup(groupStrand);
+    QDResultGroup* g = new QDResultGroup(groupStrand);
     g->add(ru);
     results.append(g);
 }
@@ -789,14 +789,14 @@ QMap<QString, bool> QDAttributeValueMapper::initBooleanMap() {
     return map;
 }
 
-QVariant QDAttributeValueMapper::stringToAttributeValue(const QString &str) {
+QVariant QDAttributeValueMapper::stringToAttributeValue(const QString& str) {
     if (getType(str) == BOOLEAN_TYPE) {
         return qVariantFromValue(BOOLEAN_MAP.value(str));
     }
     return qVariantFromValue(str);
 }
 
-QDAttributeValueMapper::ValueType QDAttributeValueMapper::getType(const QString &val) {
+QDAttributeValueMapper::ValueType QDAttributeValueMapper::getType(const QString& val) {
     if (BOOLEAN_MAP.keys().contains(val)) {
         return BOOLEAN_TYPE;
     } else {
