@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_QD_SCHEME_H_
-#define _U2_QD_SCHEME_H_
+#pragma once
 
 #include <QPair>
 #include <QSharedData>
@@ -39,8 +38,8 @@ enum QDStrandOption { QDStrand_DirectOnly,
 class U2LANG_EXPORT QDParameters : public QObject, public Configuration {
     Q_OBJECT
 public:
-    virtual void setParameter(const QString &name, const QVariant &val);
-    virtual void remap(const QMap<ActorId, ActorId> &) {
+    virtual void setParameter(const QString& name, const QVariant& val);
+    virtual void remap(const QMap<ActorId, ActorId>&) {
     }
 signals:
     void si_modified();
@@ -52,18 +51,18 @@ public:
     QDActorParameters()
         : annKey("misc_feature") {
     }
-    void setLabel(const QString &l) {
+    void setLabel(const QString& l) {
         label = l;
         emit si_modified();
     }
-    const QString &getLabel() const {
+    const QString& getLabel() const {
         return label;
     }
-    void setAnnotationKey(const QString &key) {
+    void setAnnotationKey(const QString& key) {
         annKey = key;
         emit si_modified();
     }
-    const QString &getAnnotationKey() const {
+    const QString& getAnnotationKey() const {
         return annKey;
     }
 
@@ -79,7 +78,7 @@ public:
         : owner(nullptr) {
     }
 
-    QDSchemeUnit *owner;
+    QDSchemeUnit* owner;
     U2Strand strand;
     U2Region region;
     QVector<U2Qualifier> quals;
@@ -93,12 +92,12 @@ public:
         : strand(_strand), startPos(0), endPos(0) {
     }
     U2Region location() const;
-    void add(const QDResultUnit &res);
-    void add(const QList<QDResultUnit> &res);
-    const QList<QDResultUnit> &getResultsList() const;
+    void add(const QDResultUnit& res);
+    void add(const QList<QDResultUnit>& res);
+    const QList<QDResultUnit>& getResultsList() const;
 
 public:
-    static void buildGroupFromSingleResult(const QDResultUnit &ru, QList<QDResultGroup *> &results);
+    static void buildGroupFromSingleResult(const QDResultUnit& ru, QList<QDResultGroup*>& results);
 
 public:
     QDStrandOption strand;
@@ -112,7 +111,7 @@ private:
 inline U2Region QDResultGroup::location() const {
     return U2Region(startPos, endPos - startPos);
 }
-inline const QList<QDResultUnit> &QDResultGroup::getResultsList() const {
+inline const QList<QDResultUnit>& QDResultGroup::getResultsList() const {
     return results;
 }
 
@@ -128,14 +127,14 @@ public:
         : editor(nullptr) {
     }
     virtual ~QDActorPrototype();
-    const QList<Attribute *> &getParameters() const {
+    const QList<Attribute*>& getParameters() const {
         return attributes;
     }
-    ConfigurationEditor *getEditor() const {
+    ConfigurationEditor* getEditor() const {
         return editor;
     }
 
-    const Descriptor &getDescriptor() const {
+    const Descriptor& getDescriptor() const {
         return descriptor;
     }
     QString getId() const {
@@ -148,11 +147,11 @@ public:
         return QIcon();
     }
 
-    virtual QDActor *createInstance() const = 0;
+    virtual QDActor* createInstance() const = 0;
 
 protected:
-    QList<Attribute *> attributes;
-    ConfigurationEditor *editor;
+    QList<Attribute*> attributes;
+    ConfigurationEditor* editor;
     Descriptor descriptor;
 };
 
@@ -160,28 +159,28 @@ class U2LANG_EXPORT QDActor : public QObject {
     friend class QDScheme;
     Q_OBJECT
 public:
-    QDActor(QDActorPrototype const *proto);
+    QDActor(QDActorPrototype const* proto);
     virtual ~QDActor();
 
-    QDScheme *getScheme() const {
+    QDScheme* getScheme() const {
         return scheme;
     }
-    QDActorPrototype const *getProto() const {
+    QDActorPrototype const* getProto() const {
         return proto;
     }
-    QDActorParameters *getParameters() const {
+    QDActorParameters* getParameters() const {
         return cfg;
     }
-    QString getUnitId(QDSchemeUnit *su) const {
+    QString getUnitId(QDSchemeUnit* su) const {
         return units.key(su);
     }
-    QDSchemeUnit *getSchemeUnit(const QString &id) const {
+    QDSchemeUnit* getSchemeUnit(const QString& id) const {
         return units.value(id);
     }
-    QList<QDSchemeUnit *> getSchemeUnits() const {
+    QList<QDSchemeUnit*> getSchemeUnits() const {
         return units.values();
     }
-    const QList<QDConstraint *> &getParamConstraints() const {
+    const QList<QDConstraint*>& getParamConstraints() const {
         return paramConstraints;
     }
 
@@ -205,30 +204,30 @@ public:
         return simmetric;
     }
 
-    QList<QDConstraint *> getConstraints() const;
+    QList<QDConstraint*> getConstraints() const;
 
     QString getActorType() const {
         return proto->getId();
     }
-    const QString &annotateAs() const {
+    const QString& annotateAs() const {
         return cfg->getAnnotationKey();
     }
 
-    void filterResults(const QVector<U2Region> &location);
+    void filterResults(const QVector<U2Region>& location);
 
-    QList<QDResultGroup *> popResults();
+    QList<QDResultGroup*> popResults();
     void reset();
 
     virtual int getMinResultLen() const = 0;
     virtual int getMaxResultLen() const = 0;
     virtual QString getText() const = 0;
-    virtual Task *getAlgorithmTask(const QVector<U2Region> &location) = 0;
+    virtual Task* getAlgorithmTask(const QVector<U2Region>& location) = 0;
     virtual bool hasStrand() const {
         return true;
     }
     // implement in subclass to provide configuration representation in serialized scheme
     virtual QList<QPair<QString, QString>> saveConfiguration() const;
-    virtual void loadConfiguration(const QList<QPair<QString, QString>> &strMap);
+    virtual void loadConfiguration(const QList<QPair<QString, QString>>& strMap);
     // implement in subclass to customize the color of the visual actor representation
     virtual QColor defaultColor() const {
         return QColor(0x98, 0xff, 0xc5);
@@ -243,12 +242,12 @@ protected:
     QDStrandOption getStrandToRun() const;
 
 protected:
-    QDScheme *scheme;
-    QDActorPrototype const *proto;
-    QDActorParameters *cfg;
-    QMap<QString, QDSchemeUnit *> units;
-    QList<QDConstraint *> paramConstraints;
-    QList<QDResultGroup *> results;
+    QDScheme* scheme;
+    QDActorPrototype const* proto;
+    QDActorParameters* cfg;
+    QMap<QString, QDSchemeUnit*> units;
+    QList<QDConstraint*> paramConstraints;
+    QList<QDResultGroup*> results;
     QMap<QString, QVariant> defaultCfg;
     QDStrandOption strand;
     bool simmetric;
@@ -259,24 +258,24 @@ class U2LANG_EXPORT QDSchemeUnit {
     friend class QDScheme;
 
 public:
-    QDSchemeUnit(QDActor *parent)
+    QDSchemeUnit(QDActor* parent)
         : actor(parent) {
     }
-    const QList<QDConstraint *> &getConstraints() const {
+    const QList<QDConstraint*>& getConstraints() const {
         return schemeConstraints;
     }
-    QList<QDDistanceConstraint *> getDistanceConstraints() const;
-    QDActor *getActor() const {
+    QList<QDDistanceConstraint*> getDistanceConstraints() const;
+    QDActor* getActor() const {
         return actor;
     }
     QString getId() const {
-        QDSchemeUnit *thisPtr = const_cast<QDSchemeUnit *>(this);
+        auto thisPtr = const_cast<QDSchemeUnit*>(this);
         return actor->getUnitId(thisPtr);
     }
 
 private:
-    QDActor *actor;
-    QList<QDConstraint *> schemeConstraints;
+    QDActor* actor;
+    QList<QDConstraint*> schemeConstraints;
 };
 
 class U2LANG_EXPORT QDPath {
@@ -285,29 +284,29 @@ public:
         : pathSrc(nullptr), pathDst(nullptr), overallConstraint(nullptr) {
     }
     ~QDPath();
-    QDPath *clone() const;
-    bool addConstraint(QDDistanceConstraint *dc);
-    QDSchemeUnit const *getSrc() const {
+    QDPath* clone() const;
+    bool addConstraint(QDDistanceConstraint* dc);
+    QDSchemeUnit const* getSrc() const {
         return pathSrc;
     }
-    QDSchemeUnit const *getDst() const {
+    QDSchemeUnit const* getDst() const {
         return pathDst;
     }
-    const QList<QDDistanceConstraint *> &getConstraints() const {
+    const QList<QDDistanceConstraint*>& getConstraints() const {
         return constraints;
     }
     // returns unsorted list of involved scheme units
-    const QList<QDSchemeUnit *> &getSchemeUnits() const {
+    const QList<QDSchemeUnit*>& getSchemeUnits() const {
         return schemeUnits;
     }
-    QDDistanceConstraint *toConstraint();
+    QDDistanceConstraint* toConstraint();
 
 private:
-    QDSchemeUnit *pathSrc;
-    QDSchemeUnit *pathDst;
-    QDDistanceConstraint *overallConstraint;
-    QList<QDDistanceConstraint *> constraints;
-    QList<QDSchemeUnit *> schemeUnits;
+    QDSchemeUnit* pathSrc;
+    QDSchemeUnit* pathDst;
+    QDDistanceConstraint* overallConstraint;
+    QList<QDDistanceConstraint*> constraints;
+    QList<QDSchemeUnit*> schemeUnits;
 };
 
 class U2SequenceObject;
@@ -319,34 +318,34 @@ public:
     }
     ~QDScheme();
     void clear();
-    void addActor(QDActor *a);
-    void addConstraint(QDConstraint *constraint);
-    bool removeActor(QDActor *a);
-    void removeConstraint(QDConstraint *constraint);
-    const DNASequence &getSequence() const {
+    void addActor(QDActor* a);
+    void addConstraint(QDConstraint* constraint);
+    bool removeActor(QDActor* a);
+    void removeConstraint(QDConstraint* constraint);
+    const DNASequence& getSequence() const {
         return dna;
     }
     U2EntityRef getEntityRef() const {
         return entityRef;
     }
-    void setSequence(const DNASequence &sequence) {
+    void setSequence(const DNASequence& sequence) {
         dna = sequence;
     }
-    void setEntityRef(const U2EntityRef &_entityRef) {
+    void setEntityRef(const U2EntityRef& _entityRef) {
         entityRef = _entityRef;
     }
-    const QList<QDActor *> &getActors() const {
+    const QList<QDActor*>& getActors() const {
         return actors;
     }
-    QList<QDConstraint *> getConstraints() const;
-    QList<QDConstraint *> getConstraints(QDSchemeUnit const *su1, QDSchemeUnit const *su2) const;
-    QList<QDPath *> findPaths(QDSchemeUnit *src, QDSchemeUnit *dst);
-    void setOrder(QDActor *a, int serialNum);
+    QList<QDConstraint*> getConstraints() const;
+    QList<QDConstraint*> getConstraints(QDSchemeUnit const* su1, QDSchemeUnit const* su2) const;
+    QList<QDPath*> findPaths(QDSchemeUnit* src, QDSchemeUnit* dst);
+    void setOrder(QDActor* a, int serialNum);
     bool isEmpty() const {
         return actors.isEmpty();
     }
     bool isValid() const;
-    QDActor *getActorByLabel(const QString &label) const;
+    QDActor* getActorByLabel(const QString& label) const;
 
     QDStrandOption getStrand() const {
         return strand;
@@ -357,31 +356,31 @@ public:
 
     // actor group methods
     void adaptActorsOrder();
-    QString getActorGroup(QDActor *a) const;
+    QString getActorGroup(QDActor* a) const;
     QList<QString> getActorGroups() const {
         return actorGroups.keys();
     }
-    QList<QDActor *> getActors(const QString &group) const {
+    QList<QDActor*> getActors(const QString& group) const {
         return actorGroups.value(group);
     }
-    void addActorToGroup(QDActor *a, const QString &group);
-    bool removeActorFromGroup(QDActor *a);
-    void createActorGroup(const QString &name);
-    bool removeActorGroup(const QString &name);
-    bool validateGroupName(const QString &name) const;
-    int getRequiredNumber(const QString &group) const {
+    void addActorToGroup(QDActor* a, const QString& group);
+    bool removeActorFromGroup(QDActor* a);
+    void createActorGroup(const QString& name);
+    bool removeActorGroup(const QString& name);
+    bool validateGroupName(const QString& name) const;
+    int getRequiredNumber(const QString& group) const {
         return actorGroupReqNum.value(group);
     }
-    void setRequiredNum(const QString &group, int num);
+    void setRequiredNum(const QString& group, int num);
 signals:
     void si_schemeChanged();
 
 private:
-    void findRoute(QDSchemeUnit *curSu, QDSchemeUnit *routeDst, QList<QDSchemeUnit *>& currentRoute, QList<QList<QDSchemeUnit *>> routes);
+    void findRoute(QDSchemeUnit* curSu, QDSchemeUnit* routeDst, QList<QDSchemeUnit*>& currentRoute, QList<QList<QDSchemeUnit*>> routes);
 
 private:
-    QList<QDActor *> actors;
-    QMap<QString, QList<QDActor *>> actorGroups;
+    QList<QDActor*> actors;
+    QMap<QString, QList<QDActor*>> actorGroups;
     QMap<QString, int> actorGroupReqNum;
     U2EntityRef entityRef;
     DNASequence dna;
@@ -390,7 +389,7 @@ private:
 
 class U2LANG_EXPORT QDAttributeNameConverter {
 public:
-    static QString convertAttrName(const QString &str) {
+    static QString convertAttrName(const QString& str) {
         return str.toLower().replace(' ', '_');
     }
 };
@@ -400,8 +399,8 @@ public:
     enum ValueType { BOOLEAN_TYPE,
                      UNKNOWN_TYPE };
 
-    static QVariant stringToAttributeValue(const QString &str);
-    static ValueType getType(const QString &val);
+    static QVariant stringToAttributeValue(const QString& str);
+    static ValueType getType(const QString& val);
 
 public:
     static const QMap<QString, bool> BOOLEAN_MAP;
@@ -412,6 +411,4 @@ private:
 
 }  // namespace U2
 
-Q_DECLARE_METATYPE(U2::QDActorPrototype *)
-
-#endif
+Q_DECLARE_METATYPE(U2::QDActorPrototype*)
