@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_QUERY_DESIGNER_REGISTRY_H_
-#define _U2_QUERY_DESIGNER_REGISTRY_H_
+#pragma once
 
 #include <U2Core/IdRegistry.h>
 
@@ -31,12 +30,12 @@ namespace U2 {
 class U2LANG_EXPORT QDActorPrototypeRegistry : public QObject, public IdRegistry<QDActorPrototype> {
     Q_OBJECT
 public:
-    void registerProto(QDActorPrototype *_factory);
-    QDActorPrototype *unregisterProto(const QString &id);
-    QList<QDActorPrototype *> getProtos() {
+    void registerProto(QDActorPrototype* _factory);
+    QDActorPrototype* unregisterProto(const QString& id);
+    QList<QDActorPrototype*> getProtos() {
         return IdRegistry<QDActorPrototype>::getAllEntries();
     }
-    QDActorPrototype *getProto(const QString &id) {
+    QDActorPrototype* getProto(const QString& id) {
         return IdRegistry<QDActorPrototype>::getById(id);
     }
 signals:
@@ -44,5 +43,3 @@ signals:
 };
 
 }  // namespace U2
-
-#endif
