@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_READ_DB_OBJ_ACTOR_PROTOTYPE_H_
-#define _U2_READ_DB_OBJ_ACTOR_PROTOTYPE_H_
+#pragma once
 
 #include <U2Lang/IntegralBusModel.h>
 
@@ -30,14 +29,12 @@ namespace Workflow {
 
 class U2LANG_EXPORT ReadDbObjActorPrototype : public IntegralBusActorPrototype {
 public:
-    ReadDbObjActorPrototype(const Descriptor &desc, const QList<PortDescriptor *> &ports = QList<PortDescriptor *>(), const QList<Attribute *> &attrs = QList<Attribute *>());
+    ReadDbObjActorPrototype(const Descriptor& desc, const QList<PortDescriptor*>& ports = QList<PortDescriptor*>(), const QList<Attribute*>& attrs = QList<Attribute*>());
 
     // set @types as a compatible types for a URL attribute
-    virtual void setCompatibleDbObjectTypes(const QSet<GObjectType> &types);
+    virtual void setCompatibleDbObjectTypes(const QSet<GObjectType>& types);
 };
 
 }  // namespace Workflow
 
 }  // namespace U2
-
-#endif  // _U2_READ_DB_OBJ_ACTOR_PROTOTYPE_H_
