@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@
 namespace U2 {
 namespace Workflow {
 
-bool SchemaActorsRegistry::registerSchema(const QString &protoId, Schema *schema) {
+bool SchemaActorsRegistry::registerSchema(const QString& protoId, Schema* schema) {
     QMutexLocker lock(&mutex);
     if (schemas.keys().contains(protoId)) {
         return false;
@@ -41,20 +41,20 @@ bool SchemaActorsRegistry::registerSchema(const QString &protoId, Schema *schema
     return true;
 }
 
-Schema *SchemaActorsRegistry::unregisterSchema(const QString &protoId) {
+Schema* SchemaActorsRegistry::unregisterSchema(const QString& protoId) {
     QMutexLocker lock(&mutex);
-    Schema *res = schemas.value(protoId, nullptr);
+    Schema* res = schemas.value(protoId, nullptr);
     schemas.remove(protoId);
     return res;
 }
 
-Schema *SchemaActorsRegistry::getSchema(const QString &protoId) {
+Schema* SchemaActorsRegistry::getSchema(const QString& protoId) {
     QMutexLocker lock(&mutex);
-    Schema *schema = schemas.value(protoId, nullptr);
-    if (nullptr == schema) {
+    Schema* schema = schemas.value(protoId, nullptr);
+    if (schema == nullptr) {
         return nullptr;
     }
-    Schema *copy = new Schema();
+    Schema* copy = new Schema();
     U2OpStatusImpl os;
     HRSchemaSerializer::deepCopy(*schema, copy, os);
     SAFE_POINT_EXT(!os.isCoR(), copy->reset(), nullptr);
