@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _SCHEMA_ACTORS_REGISTRY_H_
-#define _SCHEMA_ACTORS_REGISTRY_H_
+#pragma once
 
 #include <QMutex>
 
@@ -31,16 +30,14 @@ namespace Workflow {
 
 class U2LANG_EXPORT SchemaActorsRegistry {
 public:
-    bool registerSchema(const QString &protoId, Schema *schema);
-    Schema *unregisterSchema(const QString &protoId);
-    Schema *getSchema(const QString &protoId);
+    bool registerSchema(const QString& protoId, Schema* schema);
+    Schema* unregisterSchema(const QString& protoId);
+    Schema* getSchema(const QString& protoId);
 
 private:
-    QMap<QString, Schema *> schemas;
+    QMap<QString, Schema*> schemas;
     QMutex mutex;
 };
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // _SCHEMA_ACTORS_REGISTRY_H_
