@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SCHEMACONFIG_H_
-#define _U2_SCHEMACONFIG_H_
+#pragma once
 
 #include <U2Lang/AttributeInfo.h>
 #include <U2Lang/RunFileSystem.h>
@@ -34,11 +33,9 @@ public:
     virtual ~SchemaConfig() {
     }
 
-    virtual RunFileSystem *getRFS() = 0;
-    virtual QVariant getAttributeValue(const AttributeInfo &info) const = 0;
-    virtual void setAttributeValue(const AttributeInfo &info, const QVariant &value) = 0;
+    virtual RunFileSystem* getRFS() = 0;
+    virtual QVariant getAttributeValue(const AttributeInfo& info) const = 0;
+    virtual void setAttributeValue(const AttributeInfo& info, const QVariant& value) = 0;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SCHEMACONFIG_H_
