@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SLOT_RELATION_H_
-#define _U2_SLOT_RELATION_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -28,17 +27,17 @@ namespace U2 {
 
 class U2LANG_EXPORT SlotRelationDescriptor {
 public:
-    SlotRelationDescriptor(const QString &portId, const QString &slotId, const QVariantList &valuesWithEnabledSlot)
+    SlotRelationDescriptor(const QString& portId, const QString& slotId, const QVariantList& valuesWithEnabledSlot)
         : portId(portId), slotId(slotId), valuesWithEnabledSlot(valuesWithEnabledSlot) {
     }
     virtual ~SlotRelationDescriptor() {
     }
 
-    virtual SlotRelationDescriptor *clone() const {
+    virtual SlotRelationDescriptor* clone() const {
         return new SlotRelationDescriptor(*this);
     }
 
-    virtual bool isSlotEnabled(const QVariant &attrValue) const {
+    virtual bool isSlotEnabled(const QVariant& attrValue) const {
         return valuesWithEnabledSlot.contains(attrValue);
     }
 
@@ -48,5 +47,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // _U2_SLOT_RELATION_H_
