@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_CONTEXT_H_
-#define _U2_WORKFLOW_CONTEXT_H_
+#pragma once
 
 #include <QMutex>
 
@@ -43,38 +42,38 @@ class WorkflowMonitor;
 class U2LANG_EXPORT WorkflowContext {
     Q_DISABLE_COPY(WorkflowContext)
 public:
-    WorkflowContext(const QList<Actor *> &procs, WorkflowMonitor *monitor);
+    WorkflowContext(const QList<Actor*>& procs, WorkflowMonitor* monitor);
     virtual ~WorkflowContext();
 
     bool init();
-    DbiDataStorage *getDataStorage();
-    WorkflowMonitor *getMonitor();
+    DbiDataStorage* getDataStorage();
+    WorkflowMonitor* getMonitor();
 
     /**
      * @slotStr = "actor.slot>actor_path1,actor_path1,..."
      * or just "actor.slot"
      */
-    DataTypePtr getOutSlotType(const QString &slotStr);
+    DataTypePtr getOutSlotType(const QString& slotStr);
     /**
      * Files created by external tools workers could be used by some other scheme elements.
      * In that case, it is needed to add these files to the context and remove them after
      * the whole scheme performing is finished.
      */
-    void addExternalProcessFile(const QString &url);
+    void addExternalProcessFile(const QString& url);
 
-    const WorkflowProcess &getWorkflowProcess() const;
-    WorkflowProcess &getWorkflowProcess();
+    const WorkflowProcess& getWorkflowProcess() const;
+    WorkflowProcess& getWorkflowProcess();
 
     QString workingDir() const;
-    QString absolutePath(const QString &relative) const;
+    QString absolutePath(const QString& relative) const;
 
-    MessageMetadataStorage &getMetadataStorage();
+    MessageMetadataStorage& getMetadataStorage();
 
 private:
-    WorkflowMonitor *monitor;
-    DbiDataStorage *storage;
+    WorkflowMonitor* monitor;
+    DbiDataStorage* storage;
     MessageMetadataStorage metadataStorage;
-    QMap<QString, Actor *> procMap;
+    QMap<QString, Actor*> procMap;
 
     QMutex addFileMutex;
     QStringList externalProcessFiles;
@@ -89,16 +88,14 @@ private:
 
 class WorkflowContextCMDLine {
 public:
-    static QString getOutputDirectory(U2OpStatus &os);
-    static QString createSubDirectoryForRun(const QString &root, U2OpStatus &os);
+    static QString getOutputDirectory(U2OpStatus& os);
+    static QString createSubDirectoryForRun(const QString& root, U2OpStatus& os);
     static bool useOutputDir();
     static bool useSubDirs();
-    static void saveRunInfo(const QString &dir);
+    static void saveRunInfo(const QString& dir);
 
     static const QString WORKING_DIR;
 };
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_CONTEXT_H_
