@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,9 +26,9 @@
 namespace U2 {
 namespace Workflow {
 
-WorkflowEnv *WorkflowEnv::instance = nullptr;
+WorkflowEnv* WorkflowEnv::instance = nullptr;
 
-bool WorkflowEnv::init(WorkflowEnv *env) {
+bool WorkflowEnv::init(WorkflowEnv* env) {
     if (instance) {
         assert(0);  // Duplicate initialization;
         return false;
@@ -46,8 +46,8 @@ bool WorkflowEnv::init(WorkflowEnv *env) {
     return true;
 }
 
-WorkflowEnv *WorkflowEnv::getInstance() {
-    SAFE_POINT(nullptr != instance, "WorkflowEnv instance is NULL", nullptr);
+WorkflowEnv* WorkflowEnv::getInstance() {
+    SAFE_POINT(instance != nullptr, "WorkflowEnv instance is NULL", nullptr);
     return instance;
 }
 
