@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_MNGR_H_
-#define _U2_WORKFLOW_MNGR_H_
+#pragma once
 
 #include <assert.h>
 
@@ -51,11 +50,7 @@ namespace Workflow {
  */
 class U2LANG_EXPORT Worker {
 public:
-    Worker()
-        : context(nullptr) {
-    }
-    virtual ~Worker() {
-    }
+    virtual ~Worker() = default;
 
     // initialize input and output ports
     virtual void init() = 0;
@@ -64,18 +59,18 @@ public:
     // get data from actor and return task
     // if you want your worker support scripting:
     // use BaseWorker::getMessageAndSetupScriptValues to take data from port
-    virtual Task *tick() = 0;
+    virtual Task* tick() = 0;
     // nothing to do
     virtual bool isDone() const = 0;
     // opened files, etc...
     virtual void cleanup() = 0;
 
-    void setContext(WorkflowContext *newContext) {
+    void setContext(WorkflowContext* newContext) {
         context = newContext;
     }
 
 protected:
-    WorkflowContext *context;
+    WorkflowContext* context = nullptr;
 
 };  // Worker
 
@@ -96,25 +91,25 @@ enum WorkerState {
  */
 class U2LANG_EXPORT Scheduler : public Worker {
 public:
-    Scheduler(Schema *sch)
+    Scheduler(Schema* sch)
         : schema(sch), lastTask(nullptr) {
     }
-    virtual WorkerState getWorkerState(const ActorId &) = 0;
-    virtual Task *replayLastWorkerTick() = 0;
+    virtual WorkerState getWorkerState(const ActorId&) = 0;
+    virtual Task* replayLastWorkerTick() = 0;
     // returning value indicates if current task was canceled
     virtual bool cancelCurrentTaskIfAllowed() = 0;
-    virtual void makeOneTick(const ActorId &) = 0;
-    virtual void setDebugInfo(WorkflowDebugStatus *newDebugInfo) {
-        Q_ASSERT(nullptr != newDebugInfo);
+    virtual void makeOneTick(const ActorId&) = 0;
+    virtual void setDebugInfo(WorkflowDebugStatus* newDebugInfo) {
+        Q_ASSERT(newDebugInfo != nullptr);
         debugInfo = newDebugInfo;
     }
 
 protected:
-    Schema *schema;
-    Task *lastTask;
-    WorkflowDebugStatus *debugInfo;
+    Schema* schema;
+    Task* lastTask;
+    WorkflowDebugStatus* debugInfo;
 
-    virtual WorkerState getWorkerState(const Actor *) = 0;
+    virtual WorkerState getWorkerState(const Actor*) = 0;
 };  // Scheduler
 
 /**
@@ -127,30 +122,30 @@ protected:
  */
 class U2LANG_EXPORT DomainFactory : public IdRegistry<DomainFactory>, public Descriptor {
 public:
-    DomainFactory(const Descriptor &d)
+    DomainFactory(const Descriptor& d)
         : Descriptor(d) {
     }
-    DomainFactory(const QString &id)
+    DomainFactory(const QString& id)
         : Descriptor(id) {
     }
     virtual ~DomainFactory() {
     }
 
     // computational tasks domain
-    virtual Worker *createWorker(Actor *) = 0;
+    virtual Worker* createWorker(Actor*) = 0;
 
     // execution domain
-    virtual CommunicationChannel *createConnection(Link *) {
+    virtual CommunicationChannel* createConnection(Link*) {
         return nullptr;
     }
-    virtual Scheduler *createScheduler(Schema *) {
+    virtual Scheduler* createScheduler(Schema*) {
         return nullptr;
     }
-    virtual void destroy(Scheduler *, Schema *) {
+    virtual void destroy(Scheduler*, Schema*) {
     }
-    static void addParametersSetToMap(QVariantMap &map, const QString &attrValue, const QStringList &parametersList) {
+    static void addParametersSetToMap(QVariantMap& map, const QString& attrValue, const QStringList& parametersList) {
         QVariantMap parametersMap;
-        foreach (const QString &curStr, parametersList) {
+        foreach (const QString& curStr, parametersList) {
             parametersMap[curStr] = curStr;
         }
         map.insert(attrValue, parametersMap);
@@ -168,5 +163,3 @@ class U2LANG_EXPORT DomainFactoryRegistry : public IdRegistry<DomainFactory> {
 }  // namespace Workflow
 
 }  // namespace U2
-
-#endif
