@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_SCRIPT_ENGINE_H_
-#define _U2_WORKFLOW_SCRIPT_ENGINE_H_
+#pragma once
 
 #include <U2Core/ScriptEngine.h>
 
@@ -30,13 +29,11 @@ namespace U2 {
 
 class U2LANG_EXPORT WorkflowScriptEngine : public QScriptEngine {
 public:
-    WorkflowScriptEngine(Workflow::WorkflowContext *context);
-    Workflow::WorkflowContext *getWorkflowContext();
+    WorkflowScriptEngine(Workflow::WorkflowContext* context);
+    Workflow::WorkflowContext* getWorkflowContext();
 
 private:
-    Workflow::WorkflowContext *context;
+    Workflow::WorkflowContext* context;
 };
 
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_SCRIPT_ENGINE_H_
