@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ACTORCONFIGURATIONEDITOR_H_
-#define _U2_ACTORCONFIGURATIONEDITOR_H_
+#pragma once
 
 #include <U2Lang/ConfigurationEditor.h>
 
@@ -36,16 +35,14 @@ class U2LANG_EXPORT ActorConfigurationEditor : public ConfigurationEditor {
     Q_OBJECT
 public:
     ActorConfigurationEditor();
-    ActorConfigurationEditor(const ActorConfigurationEditor &other);
+    ActorConfigurationEditor(const ActorConfigurationEditor& other);
 
-    virtual void setConfiguration(Actor *actor);
-    virtual ConfigurationEditor *clone();
+    virtual void setConfiguration(Actor* actor);
+    virtual ConfigurationEditor* clone();
 
 protected:
-    Actor *cfg;
+    Actor* cfg;
 };  // ActorConfigurationEditor
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // _U2_ACTORCONFIGURATIONEDITOR_H_
