@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,71 +29,71 @@
 namespace U2 {
 namespace Workflow {
 
-QList<PortDescriptor *> ActorPrototype::getPortDesciptors() const {
+QList<PortDescriptor*> ActorPrototype::getPortDesciptors() const {
     return ports;
 }
 
-QList<Attribute *> ActorPrototype::getAttributes() const {
+QList<Attribute*> ActorPrototype::getAttributes() const {
     return attrs;
 }
 
-void ActorPrototype::addAttribute(Attribute *a) {
+void ActorPrototype::addAttribute(Attribute* a) {
     assert(a != nullptr);
     attrs << a;
 }
 
-int ActorPrototype::removeAttribute(Attribute *attr) {
+int ActorPrototype::removeAttribute(Attribute* attr) {
     assert(attr != nullptr);
     return attrs.removeAll(attr);
 }
 
-void ActorPrototype::setEditor(ConfigurationEditor *e) {
+void ActorPrototype::setEditor(ConfigurationEditor* e) {
     assert(e != nullptr);
     ed = e;
 }
 
-ConfigurationEditor *ActorPrototype::getEditor() const {
+ConfigurationEditor* ActorPrototype::getEditor() const {
     return ed;
 }
 
-void ActorPrototype::setValidator(ConfigurationValidator *v) {
+void ActorPrototype::setValidator(ConfigurationValidator* v) {
     assert(v != nullptr);
     val = v;
 }
 
-void ActorPrototype::setPrompter(Prompter *p) {
+void ActorPrototype::setPrompter(Prompter* p) {
     assert(p != nullptr);
     prompter = p;
 }
 
-void ActorPrototype::setPortValidator(const QString &id, ConfigurationValidator *v) {
+void ActorPrototype::setPortValidator(const QString& id, ConfigurationValidator* v) {
     assert(v != nullptr);
     portValidators[id] = v;
 }
 
-bool ActorPrototype::isAcceptableDrop(const QMimeData *, QVariantMap *) const {
+bool ActorPrototype::isAcceptableDrop(const QMimeData*, QVariantMap*) const {
     return false;
 }
 
-Port *ActorPrototype::createPort(const PortDescriptor &d, Actor *p) {
+Port* ActorPrototype::createPort(const PortDescriptor& d, Actor* p) {
     return new Port(d, p);
 }
 
-Actor *ActorPrototype::createInstance(const ActorId &actorId, AttributeScript *script, const QVariantMap &params) {
-    Actor *proc = new Actor(actorId, this, script);
+Actor* ActorPrototype::createInstance(const ActorId& actorId, AttributeScript* script, const QVariantMap& params) {
+    Actor* proc = new Actor(actorId, this, script);
     if (ed) {
         ed->updateDelegates();
     }
 
-    foreach (PortDescriptor *pd, getPortDesciptors()) {
-        Port *p = createPort(*pd, proc);
+    foreach (PortDescriptor* pd, getPortDesciptors()) {
+        Port* p = createPort(*pd, proc);
         QString pid = pd->getId();
         if (portValidators.contains(pid)) {
             p->setValidator(portValidators.value(pid));
         }
         proc->ports[pid] = p;
     }
-    foreach (Attribute *a, getAttributes()) {
+    foreach (Attribute* a, getAttributes()) {
         proc->addParameter(a->getId(), a->clone());
     }
     if (val) {
@@ -109,9 +109,9 @@ Actor *ActorPrototype::createInstance(const ActorId &actorId, AttributeScript *s
         proc->setParameter(i.key(), i.value());
     }
     if (ed) {
-        ActorConfigurationEditor *actorEd = dynamic_cast<ActorConfigurationEditor *>(ed);
-        if (nullptr != actorEd) {
-            ActorConfigurationEditor *editor = dynamic_cast<ActorConfigurationEditor *>(ed->clone());
+        auto actorEd = dynamic_cast<ActorConfigurationEditor*>(ed);
+        if (actorEd != nullptr) {
+            auto editor = dynamic_cast<ActorConfigurationEditor*>(ed->clone());
             editor->setConfiguration(proc);
             proc->setEditor(editor);
         } else {
@@ -126,19 +126,19 @@ Actor *ActorPrototype::createInstance(const ActorId &actorId, AttributeScript *s
     return proc;
 }
 
-void ActorPrototype::setDisplayName(const QString &n) {
+void ActorPrototype::setDisplayName(const QString& n) {
     VisualDescriptor::setDisplayName(n);
     emit si_nameChanged();
 }
 
-void ActorPrototype::setDocumentation(const QString &d) {
+void ActorPrototype::setDocumentation(const QString& d) {
     VisualDescriptor::setDocumentation(d);
     emit si_descriptionChanged();
 }
 
-Attribute *ActorPrototype::getAttribute(const QString &id) const {
-    Attribute *res = nullptr;
-    foreach (Attribute *a, attrs) {
+Attribute* ActorPrototype::getAttribute(const QString& id) const {
+    Attribute* res = nullptr;
+    foreach (Attribute* a, attrs) {
         if (a->getId() == id) {
             res = a;
             break;
@@ -151,22 +151,22 @@ void ActorPrototype::setScriptFlag(bool flag) {
     isScript = flag;
 }
 
-void ActorPrototype::setNonStandard(const QString &path) {
+void ActorPrototype::setNonStandard(const QString& path) {
     isStandard = false;
     actorFilePath = path;
 }
 
-void ActorPrototype::setSchema(const QString &path) {
+void ActorPrototype::setSchema(const QString& path) {
     isStandard = false;
     isSchema = true;
     actorFilePath = path;
 }
 
-void ActorPrototype::addExternalTool(const QString &toolId, const QString &paramId) {
+void ActorPrototype::addExternalTool(const QString& toolId, const QString& paramId) {
     externalTools[toolId] = paramId;
 }
 
-const StrStrMap &ActorPrototype::getExternalTools() const {
+const StrStrMap& ActorPrototype::getExternalTools() const {
     return externalTools;
 }
 
@@ -174,9 +174,9 @@ void ActorPrototype::clearExternalTools() {
     externalTools.clear();
 }
 
-ActorPrototype::ActorPrototype(const Descriptor &d,
-                               const QList<PortDescriptor *> &ports,
-                               const QList<Attribute *> &attrs)
+ActorPrototype::ActorPrototype(const Descriptor& d,
+                               const QList<PortDescriptor*>& ports,
+                               const QList<Attribute*>& attrs)
     : QObject(nullptr), VisualDescriptor(d), attrs(attrs), ports(ports), ed(nullptr), val(nullptr), prompter(nullptr),
       isScript(false), isStandard(true), isSchema(false), allowsEmptyPorts(false), influenceOnPathFlag(false), usageCounter(0) {
 }
