@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ACTORVALIDATOR_H_
-#define _U2_ACTORVALIDATOR_H_
+#pragma once
 
 #include <QMutex>
 
@@ -35,30 +34,30 @@ public:
     virtual ~ActorValidator() {
     }
 
-    virtual bool validate(const Configuration *cfg, NotificationsList &notificationList) const;
-    virtual bool validate(const Actor *actor, NotificationsList &notificationList, const QMap<QString, QString> &options) const = 0;
+    virtual bool validate(const Configuration* cfg, NotificationsList& notificationList) const;
+    virtual bool validate(const Actor* actor, NotificationsList& notificationList, const QMap<QString, QString>& options) const = 0;
 
 protected:
     template<class T>
-    T getValue(const Actor *actor, const QString &attrId) const;
+    T getValue(const Actor* actor, const QString& attrId) const;
 };
 
 class U2LANG_EXPORT ActorValidatorRegistry {
 public:
     ActorValidatorRegistry();
     ~ActorValidatorRegistry();
-    bool addValidator(const QString &id, ActorValidator *validator);
-    ActorValidator *findValidator(const QString &id);
+    bool addValidator(const QString& id, ActorValidator* validator);
+    ActorValidator* findValidator(const QString& id);
 
 private:
     QMutex mutex;
-    QMap<QString, ActorValidator *> validators;
+    QMap<QString, ActorValidator*> validators;
 };
 
 template<class T>
-T ActorValidator::getValue(const Actor *actor, const QString &attrId) const {
-    Attribute *attr = actor->getParameter(attrId);
-    if (nullptr == attr) {
+T ActorValidator::getValue(const Actor* actor, const QString& attrId) const {
+    Attribute* attr = actor->getParameter(attrId);
+    if (attr == nullptr) {
         return T();
     }
     return attr->getAttributePureValue().value<T>();
@@ -66,5 +65,3 @@ T ActorValidator::getValue(const Actor *actor, const QString &attrId) const {
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // _U2_ACTORVALIDATOR_H_
