@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DB_FOLDER_SCANNER_
-#define _U2_DB_FOLDER_SCANNER_
+#pragma once
 
 #include <U2Core/FilesIterator.h>
 #include <U2Core/U2DbiUtils.h>
@@ -29,16 +28,16 @@ namespace U2 {
 
 class U2LANG_EXPORT DbFolderScanner : public FilesIterator {
 public:
-    DbFolderScanner(const QString &url, const QString &accFilter, const QString &objNameFilter, bool recursive);
+    DbFolderScanner(const QString& url, const QString& accFilter, const QString& objNameFilter, bool recursive);
 
     virtual QString getNextFile();
     virtual bool hasNext();
 
 private:
-    void initTargetObjectList(const QSet<QString> &paths, const QString &objNameFilter, U2OpStatus &os);
-    void getSubfolders(const QString &folderPath, QSet<QString> &subfolders, U2OpStatus &os);
-    bool passFilter(const QString &objUrl);
-    bool hasAccession(const QString &objUrl);
+    void initTargetObjectList(const QSet<QString>& paths, const QString& objNameFilter, U2OpStatus& os);
+    void getSubfolders(const QString& folderPath, QSet<QString>& subfolders, U2OpStatus& os);
+    bool passFilter(const QString& objUrl);
+    bool hasAccession(const QString& objUrl);
 
     DbiConnection dbConnection;
     QStringList unusedObjects;
@@ -47,5 +46,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_DB_FOLDER_SCANNER_
