@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,24 +29,24 @@
 
 namespace U2 {
 
-static QString toUniversal(const QString &url) {
+static QString toUniversal(const QString& url) {
     return QFileInfo(url).absoluteFilePath();
 }
 
-URLContainer::URLContainer(const QString &_url, bool convertUrlToAbsolute)
+URLContainer::URLContainer(const QString& _url, bool convertUrlToAbsolute)
     : url(convertUrlToAbsolute ? toUniversal(_url) : _url) {
 }
 
 URLContainer::~URLContainer() {
 }
 
-const QString &URLContainer::getUrl() const {
+const QString& URLContainer::getUrl() const {
     return url;
 }
 
 //////////////////////////////////////////////////////////////////////////
 
-URLContainer *URLContainerFactory::createUrlContainer(const QString &url) {
+URLContainer* URLContainerFactory::createUrlContainer(const QString& url) {
     if (SharedDbUrlUtils::isDbObjectUrl(url)) {
         return new DbObjUrlContainer(url);
     } else if (SharedDbUrlUtils::isDbFolderUrl(url)) {
@@ -67,82 +67,82 @@ URLContainer *URLContainerFactory::createUrlContainer(const QString &url) {
 
 //////////////////////////////////////////////////////////////////////////
 
-FileUrlContainer::FileUrlContainer(const QString &url)
+FileUrlContainer::FileUrlContainer(const QString& url)
     : URLContainer(url) {
 }
 
-FilesIterator *FileUrlContainer::getFileUrls() {
+FilesIterator* FileUrlContainer::getFileUrls() {
     return FilesIteratorFactory::createFileList(QStringList() << url);
 }
 
-URLContainer *FileUrlContainer::clone() {
+URLContainer* FileUrlContainer::clone() {
     return new FileUrlContainer(url);
 }
 
-void FileUrlContainer::accept(URLContainerVisitor *visitor) {
+void FileUrlContainer::accept(URLContainerVisitor* visitor) {
     visitor->visit(this);
 }
 
-bool FileUrlContainer::validateUrl(NotificationsList &notificationList) {
+bool FileUrlContainer::validateUrl(NotificationsList& notificationList) {
     return WorkflowUtils::validateInputFiles(url, notificationList);
 }
 
 //////////////////////////////////////////////////////////////////////////
 
-DbObjUrlContainer::DbObjUrlContainer(const QString &url)
+DbObjUrlContainer::DbObjUrlContainer(const QString& url)
     : URLContainer(url, false) {
 }
 
-FilesIterator *DbObjUrlContainer::getFileUrls() {
+FilesIterator* DbObjUrlContainer::getFileUrls() {
     return FilesIteratorFactory::createFileList(QStringList() << url);
 }
 
-URLContainer *DbObjUrlContainer::clone() {
+URLContainer* DbObjUrlContainer::clone() {
     return new DbObjUrlContainer(url);
 }
 
-void DbObjUrlContainer::accept(URLContainerVisitor *visitor) {
+void DbObjUrlContainer::accept(URLContainerVisitor* visitor) {
     visitor->visit(this);
 }
 
-bool DbObjUrlContainer::validateUrl(NotificationsList &notificationList) {
+bool DbObjUrlContainer::validateUrl(NotificationsList& notificationList) {
     return WorkflowUtils::validateInputDbObject(url, notificationList);
 }
 
 //////////////////////////////////////////////////////////////////////////
 
-DirUrlContainer::DirUrlContainer(const QString &url)
+DirUrlContainer::DirUrlContainer(const QString& url)
     : URLContainer(url), recursive(false) {
 }
 
-DirUrlContainer::DirUrlContainer(const QString &url, const QString &_incFilter, const QString &_excFilter, bool _recursive)
+DirUrlContainer::DirUrlContainer(const QString& url, const QString& _incFilter, const QString& _excFilter, bool _recursive)
     : URLContainer(url), incFilter(_incFilter), excFilter(_excFilter), recursive(_recursive) {
 }
 
-FilesIterator *DirUrlContainer::getFileUrls() {
+FilesIterator* DirUrlContainer::getFileUrls() {
     return FilesIteratorFactory::createDirectoryScanner(QStringList() << url, incFilter, excFilter, recursive);
 }
 
-URLContainer *DirUrlContainer::clone() {
-    DirUrlContainer *cloned = new DirUrlContainer(url);
+URLContainer* DirUrlContainer::clone() {
+    DirUrlContainer* cloned = new DirUrlContainer(url);
     cloned->incFilter = incFilter;
     cloned->excFilter = excFilter;
     cloned->recursive = recursive;
     return cloned;
 }
 
-void DirUrlContainer::accept(URLContainerVisitor *visitor) {
+void DirUrlContainer::accept(URLContainerVisitor* visitor) {
     visitor->visit(this);
 }
 
-bool DirUrlContainer::validateUrl(NotificationsList &notificationList) {
+bool DirUrlContainer::validateUrl(NotificationsList& notificationList) {
     bool res = WorkflowUtils::validateInputDirs(url, notificationList);
     if (!res) {
         return false;
     }
 
-    FilesIterator *it = getFileUrls();
-    SAFE_POINT(nullptr != it, "NULL fileIterator!", false);
+    FilesIterator* it = getFileUrls();
+    SAFE_POINT(it != nullptr, "NULL fileIterator!", false);
     while (it->hasNext()) {
         QString fileUrl = it->getNextFile();
         bool urlIsValid = WorkflowUtils::validateInputFiles(fileUrl, notificationList);
@@ -151,11 +151,11 @@ bool DirUrlContainer::validateUrl(NotificationsList &notificationList) {
     return res;
 }
 
-const QString &DirUrlContainer::getIncludeFilter() const {
+const QString& DirUrlContainer::getIncludeFilter() const {
     return incFilter;
 }
 
-const QString &DirUrlContainer::getExcludeFilter() const {
+const QString& DirUrlContainer::getExcludeFilter() const {
     return excFilter;
 }
 
@@ -163,11 +163,11 @@ bool DirUrlContainer::isRecursive() const {
     return recursive;
 }
 
-void DirUrlContainer::setIncludeFilter(const QString &value) {
+void DirUrlContainer::setIncludeFilter(const QString& value) {
     incFilter = value;
 }
 
-void DirUrlContainer::setExcludeFilter(const QString &value) {
+void DirUrlContainer::setExcludeFilter(const QString& value) {
     excFilter = value;
 }
 
@@ -177,34 +177,34 @@ void DirUrlContainer::setRecursive(bool value) {
 
 //////////////////////////////////////////////////////////////////////////
 
-DbFolderUrlContainer::DbFolderUrlContainer(const QString &url)
+DbFolderUrlContainer::DbFolderUrlContainer(const QString& url)
     : URLContainer(url, false), recursive(false) {
 }
 
-DbFolderUrlContainer::DbFolderUrlContainer(const QString &url, const QString &accFilter, const QString &objNameFilter, bool recursive)
+DbFolderUrlContainer::DbFolderUrlContainer(const QString& url, const QString& accFilter, const QString& objNameFilter, bool recursive)
     : URLContainer(url, false), accFilter(accFilter), objNameFilter(objNameFilter), recursive(recursive) {
 }
 
-FilesIterator *DbFolderUrlContainer::getFileUrls() {
+FilesIterator* DbFolderUrlContainer::getFileUrls() {
     return new DbFolderScanner(url, accFilter, objNameFilter, recursive);
 }
 
-URLContainer *DbFolderUrlContainer::clone() {
+URLContainer* DbFolderUrlContainer::clone() {
     return new DbFolderUrlContainer(url, accFilter, objNameFilter, recursive);
 }
 
-void DbFolderUrlContainer::accept(URLContainerVisitor *visitor) {
+void DbFolderUrlContainer::accept(URLContainerVisitor* visitor) {
     visitor->visit(this);
 }
 
-bool DbFolderUrlContainer::validateUrl(NotificationsList &notificationList) {
+bool DbFolderUrlContainer::validateUrl(NotificationsList& notificationList) {
     bool res = WorkflowUtils::validateInputDbFolders(url, notificationList);
     if (!res) {
         return false;
     }
 
-    FilesIterator *it = getFileUrls();
-    SAFE_POINT(nullptr != it, "Invalid DB object iterator", false);
+    FilesIterator* it = getFileUrls();
+    SAFE_POINT(it != nullptr, "Invalid DB object iterator", false);
     while (it->hasNext()) {
         QString fileUrl = it->getNextFile();
         bool urlIsValid = WorkflowUtils::validateInputDbObject(fileUrl, notificationList);
@@ -213,19 +213,19 @@ bool DbFolderUrlContainer::validateUrl(NotificationsList &notificationList) {
     return res;
 }
 
-const QString &DbFolderUrlContainer::getSequenceAccFilter() const {
+const QString& DbFolderUrlContainer::getSequenceAccFilter() const {
     return accFilter;
 }
 
-const QString &DbFolderUrlContainer::getObjNameFilter() const {
+const QString& DbFolderUrlContainer::getObjNameFilter() const {
     return objNameFilter;
 }
 
-void DbFolderUrlContainer::setSequenceAccFilter(const QString &acc) {
+void DbFolderUrlContainer::setSequenceAccFilter(const QString& acc) {
     accFilter = acc;
 }
 
-void DbFolderUrlContainer::setObjNameFilter(const QString &name) {
+void DbFolderUrlContainer::setObjNameFilter(const QString& name) {
     objNameFilter = name;
 }
 
