@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ELEMENTSELECTORWIDGET_H_
-#define _U2_ELEMENTSELECTORWIDGET_H_
+#pragma once
 
 #include <U2Lang/Schema.h>
 #include <U2Lang/WizardWidget.h>
@@ -33,16 +32,16 @@ class U2LANG_EXPORT ElementSelectorWidget : public WizardWidget {
 public:
     ElementSelectorWidget();
 
-    virtual void accept(WizardWidgetVisitor *visitor);
-    virtual void validate(const QList<Actor *> &actors, U2OpStatus &os) const;
+    virtual void accept(WizardWidgetVisitor* visitor);
+    virtual void validate(const QList<Actor*>& actors, U2OpStatus& os) const;
 
-    void setActorId(const QString &value);
-    void addValue(const SelectorValue &value);
-    void setLabel(const QString &value);
+    void setActorId(const QString& value);
+    void addValue(const SelectorValue& value);
+    void setLabel(const QString& value);
 
-    const QString &getActorId() const;
-    const QList<SelectorValue> &getValues() const;
-    const QString &getLabel() const;
+    const QString& getActorId() const;
+    const QList<SelectorValue>& getValues() const;
+    const QString& getLabel() const;
 
     static const QString ID;
 
@@ -52,12 +51,10 @@ private:
     QList<SelectorValue> values;
 
     /** Returns found actor or NULL */
-    Workflow::Actor *validateActorId(QList<Workflow::Actor *> actors, U2OpStatus &os) const;
-    void validateDuplicates(const SelectorValue &value,
-                            const QSet<QString> &valueSet,
-                            U2OpStatus &os) const;
+    Workflow::Actor* validateActorId(QList<Workflow::Actor*> actors, U2OpStatus& os) const;
+    void validateDuplicates(const SelectorValue& value,
+                            const QSet<QString>& valueSet,
+                            U2OpStatus& os) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_ELEMENTSELECTORWIDGET_H_
