@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IDMAPPING_H_
-#define _U2_IDMAPPING_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -28,7 +27,7 @@ namespace U2 {
 
 class U2LANG_EXPORT IdMapping {
 public:
-    IdMapping(const QString &srcId, const QString &dstId);
+    IdMapping(const QString& srcId, const QString& dstId);
     virtual ~IdMapping();
 
     QString getSrcId() const;
@@ -42,5 +41,3 @@ protected:
 };
 
 }  // namespace U2
-
-#endif  // _U2_IDMAPPING_H_
