@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SLOTMAPPING_H_
-#define _U2_SLOTMAPPING_H_
+#pragma once
 
 #include <U2Core/U2OpStatus.h>
 
@@ -32,11 +31,9 @@ namespace U2 {
 
 class SlotMapping : public IdMapping {
 public:
-    SlotMapping(const QString &srcSlotId, const QString &dstSlotId);
+    SlotMapping(const QString& srcSlotId, const QString& dstSlotId);
 
-    void validate(DataTypePtr srcSlotType, DataTypePtr dstSlotType, U2OpStatus &os) const;
+    void validate(DataTypePtr srcSlotType, DataTypePtr dstSlotType, U2OpStatus& os) const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SLOTMAPPING_H_
