@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_VARIABLE_H_
-#define _U2_VARIABLE_H_
+#pragma once
 
 #include <QMap>
 
@@ -31,14 +30,14 @@ namespace U2 {
 class U2LANG_EXPORT Variable {
 public:
     Variable();
-    Variable(const QString &name);
+    Variable(const QString& name);
     virtual ~Variable();
 
-    const QString &getName() const;
-    const QString &getValue() const;
-    void setValue(const QString &value);
+    const QString& getName() const;
+    const QString& getValue() const;
+    void setValue(const QString& value);
     bool isAssigned() const;
-    bool operator==(const Variable &other) const;
+    bool operator==(const Variable& other) const;
 
 private:
     QString name;
@@ -49,19 +48,17 @@ private:
 class U2LANG_EXPORT Predicate {
 public:
     Predicate();
-    Predicate(const Variable &v, const QString &value);
+    Predicate(const Variable& v, const QString& value);
 
     Variable variable() const;
-    bool isTrue(const QMap<QString, Variable> &vars) const;
-    bool operator<(const Predicate &other) const;
+    bool isTrue(const QMap<QString, Variable>& vars) const;
+    bool operator<(const Predicate& other) const;
     QString toString() const;
 
-    static Predicate fromString(const QString &string, U2OpStatus &os);
+    static Predicate fromString(const QString& string, U2OpStatus& os);
 
 private:
     Variable var;
 };
 
 }  // namespace U2
-
-#endif  // _U2_VARIABLE_H_
