@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WIZARD_H_
-#define _U2_WIZARD_H_
+#pragma once
 
 #include <U2Core/U2OpStatus.h>
 #include <U2Core/global.h>
@@ -32,24 +31,24 @@ namespace U2 {
 
 class WizardPage;
 
-class U2LANG_EXPORT Wizard {
+class U2LANG_EXPORT Wizard : public QObject {
 public:
-    Wizard(const QString &name, const QList<WizardPage *> &pages, const QString &helpPageId);
+    Wizard(const QString& name, const QList<WizardPage*>& pages, const QString& helpPageId);
     virtual ~Wizard();
 
-    void validate(const Workflow::Schema *schema, U2OpStatus &os) const;
-    void addVariable(const Variable &v);
+    void validate(const Workflow::Schema* schema, U2OpStatus& os) const;
+    void addVariable(const Variable& v);
     QMap<QString, Variable> getVariables() const;
-    QString getResult(const QMap<QString, Variable> &vars) const;
+    QString getResult(const QMap<QString, Variable>& vars) const;
 
-    const QString &getName() const;
-    const QList<WizardPage *> &getPages() const;
+    const QString& getName() const;
+    const QList<WizardPage*>& getPages() const;
 
-    void addResult(const QList<Predicate> &preds, const QString &result);
+    void addResult(const QList<Predicate>& preds, const QString& result);
     QMap<QString, QList<Predicate>> getResults() const;
 
     QString getFinishLabel() const;
-    void setFinishLabel(const QString &value);
+    void setFinishLabel(const QString& value);
 
     bool isAutoRun() const;
     void setAutoRun(bool value);
@@ -66,7 +65,7 @@ public:
 
 private:
     QString name;
-    QList<WizardPage *> pages;
+    QList<WizardPage*> pages;
     QMap<QString, Variable> vars;
     bool autoRun;
     bool withRunButton;
@@ -77,5 +76,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_WIZARD_H_
