@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -38,7 +38,7 @@ WizardWidget::WizardWidget() {
 WizardWidget::~WizardWidget() {
 }
 
-void WizardWidget::validate(const QList<Actor *> & /*actors*/, U2OpStatus & /*os*/) const {
+void WizardWidget::validate(const QList<Actor*>& /*actors*/, U2OpStatus& /*os*/) const {
 }
 
 /**********************************
@@ -46,22 +46,22 @@ void WizardWidget::validate(const QList<Actor *> & /*actors*/, U2OpStatus & /*os
  *********************************/
 const QString LogoWidget::ID("logo");
 
-LogoWidget::LogoWidget(const QString &_logoPath)
+LogoWidget::LogoWidget(const QString& _logoPath)
     : WizardWidget(), logoPath(_logoPath) {
 }
 
 LogoWidget::~LogoWidget() {
 }
 
-void LogoWidget::accept(WizardWidgetVisitor *visitor) {
+void LogoWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-void LogoWidget::setLogoPath(const QString &value) {
+void LogoWidget::setLogoPath(const QString& value) {
     logoPath = value;
 }
 
-const QString &LogoWidget::getLogoPath() const {
+const QString& LogoWidget::getLogoPath() const {
     return logoPath;
 }
 
@@ -72,12 +72,12 @@ bool LogoWidget::isDefault() const {
 /**********************************
  * WidgetsArea
  *********************************/
-WidgetsArea::WidgetsArea(const QString &_name, const QString &_title)
+WidgetsArea::WidgetsArea(const QString& _name, const QString& _title)
     : WizardWidget(), titleable(true), name(_name), title(_title) {
     labelSize = -1;
 }
 
-WidgetsArea::WidgetsArea(const QString &_name)
+WidgetsArea::WidgetsArea(const QString& _name)
     : WizardWidget(), titleable(false), name(_name) {
     labelSize = -1;
 }
@@ -85,34 +85,34 @@ WidgetsArea::WidgetsArea(const QString &_name)
 WidgetsArea::~WidgetsArea() {
 }
 
-void WidgetsArea::accept(WizardWidgetVisitor *visitor) {
+void WidgetsArea::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-void WidgetsArea::validate(const QList<Actor *> &actors, U2OpStatus &os) const {
-    foreach (WizardWidget *w, widgets) {
+void WidgetsArea::validate(const QList<Actor*>& actors, U2OpStatus& os) const {
+    foreach (WizardWidget* w, widgets) {
         w->validate(actors, os);
         CHECK_OP(os, );
     }
 }
 
-void WidgetsArea::addWidget(WizardWidget *widget) {
+void WidgetsArea::addWidget(WizardWidget* widget) {
     widgets << widget;
 }
 
-const QList<WizardWidget *> &WidgetsArea::getWidgets() const {
+const QList<WizardWidget*>& WidgetsArea::getWidgets() const {
     return widgets;
 }
 
-const QString &WidgetsArea::getName() const {
+const QString& WidgetsArea::getName() const {
     return name;
 }
 
-const QString &WidgetsArea::getTitle() const {
+const QString& WidgetsArea::getTitle() const {
     return title;
 }
 
-void WidgetsArea::setTitle(const QString &value) {
+void WidgetsArea::setTitle(const QString& value) {
     titleable = true;
     title = value;
 }
@@ -138,14 +138,14 @@ GroupWidget::GroupWidget()
     : WidgetsArea(ID), type(DEFAULT) {
 }
 
-GroupWidget::GroupWidget(const QString &title, Type _type)
+GroupWidget::GroupWidget(const QString& title, Type _type)
     : WidgetsArea(ID, title), type(_type) {
 }
 
 GroupWidget::~GroupWidget() {
 }
 
-void GroupWidget::accept(WizardWidgetVisitor *visitor) {
+void GroupWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
@@ -167,11 +167,11 @@ AttributeWidget::AttributeWidget()
 AttributeWidget::~AttributeWidget() {
 }
 
-void AttributeWidget::accept(WizardWidgetVisitor *visitor) {
+void AttributeWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-void AttributeWidget::validate(const QList<Actor *> &actors, U2OpStatus &os) const {
+void AttributeWidget::validate(const QList<Actor*>& actors, U2OpStatus& os) const {
     info.validate(actors, os);
 }
 
@@ -183,15 +183,15 @@ QString AttributeWidget::getAttributeId() const {
     return info.attrId;
 }
 
-void AttributeWidget::setInfo(const AttributeInfo &value) {
+void AttributeWidget::setInfo(const AttributeInfo& value) {
     info = value;
 }
 
-const AttributeInfo &AttributeWidget::getInfo() const {
+const AttributeInfo& AttributeWidget::getInfo() const {
     return info;
 }
 
-const QVariantMap &AttributeWidget::getWigdetHints() const {
+const QVariantMap& AttributeWidget::getWigdetHints() const {
     return info.hints;
 }
 
@@ -202,7 +202,7 @@ QVariantMap AttributeWidget::getProperties() const {
     return extHints;
 }
 
-QString AttributeWidget::getProperty(const QString &id) const {
+QString AttributeWidget::getProperty(const QString& id) const {
     QString value = info.hints.value(id, "").toString();
     if (AttributeInfo::TYPE == id && value.isEmpty()) {
         return AttributeInfo::DEFAULT;
@@ -221,18 +221,18 @@ PairedReadsWidget::PairedReadsWidget()
     : WizardWidget() {
 }
 
-void PairedReadsWidget::accept(WizardWidgetVisitor *visitor) {
+void PairedReadsWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-void PairedReadsWidget::validate(const QList<Actor *> &actors, U2OpStatus &os) const {
-    foreach (const AttributeInfo &info, infos) {
+void PairedReadsWidget::validate(const QList<Actor*>& actors, U2OpStatus& os) const {
+    foreach (const AttributeInfo& info, infos) {
         info.validate(actors, os);
         CHECK_OP(os, );
     }
 }
 
-void PairedReadsWidget::addInfo(const AttributeInfo &value) {
+void PairedReadsWidget::addInfo(const AttributeInfo& value) {
     infos << value;
 }
 
@@ -249,18 +249,18 @@ UrlAndDatasetWidget::UrlAndDatasetWidget()
     : WizardWidget() {
 }
 
-void UrlAndDatasetWidget::accept(WizardWidgetVisitor *visitor) {
+void UrlAndDatasetWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-void UrlAndDatasetWidget::validate(const QList<Actor *> &actors, U2OpStatus &os) const {
-    foreach (const AttributeInfo &info, infos) {
+void UrlAndDatasetWidget::validate(const QList<Actor*>& actors, U2OpStatus& os) const {
+    foreach (const AttributeInfo& info, infos) {
         info.validate(actors, os);
         CHECK_OP(os, );
     }
 }
 
-void UrlAndDatasetWidget::addInfo(const AttributeInfo &value) {
+void UrlAndDatasetWidget::addInfo(const AttributeInfo& value) {
     infos << value;
 }
 
@@ -280,23 +280,23 @@ RadioWidget::RadioWidget()
     : WizardWidget() {
 }
 
-void RadioWidget::accept(WizardWidgetVisitor *visitor) {
+void RadioWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-const QString &RadioWidget::var() const {
+const QString& RadioWidget::var() const {
     return _var;
 }
 
-void RadioWidget::setVar(const QString &value) {
+void RadioWidget::setVar(const QString& value) {
     _var = value;
 }
 
-const QList<RadioWidget::Value> &RadioWidget::values() const {
+const QList<RadioWidget::Value>& RadioWidget::values() const {
     return _values;
 }
 
-void RadioWidget::add(const Value &value) {
+void RadioWidget::add(const Value& value) {
     _values << value;
 }
 
@@ -309,29 +309,29 @@ SettingsWidget::SettingsWidget()
     : WizardWidget() {
 }
 
-void SettingsWidget::accept(WizardWidgetVisitor *visitor) {
+void SettingsWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-const QString &SettingsWidget::var() const {
+const QString& SettingsWidget::var() const {
     return _var;
 }
-void SettingsWidget::setVar(const QString &value) {
+void SettingsWidget::setVar(const QString& value) {
     _var = value;
 }
 
-const QString &SettingsWidget::type() const {
+const QString& SettingsWidget::type() const {
     return _type;
 }
 
-void SettingsWidget::setType(const QString &value) {
+void SettingsWidget::setType(const QString& value) {
     _type = value;
 }
 
-const QString &SettingsWidget::label() const {
+const QString& SettingsWidget::label() const {
     return _label;
 }
-void SettingsWidget::setLabel(const QString &value) {
+void SettingsWidget::setLabel(const QString& value) {
     _label = value;
 }
 
@@ -343,11 +343,11 @@ BowtieWidget::BowtieWidget()
     : WizardWidget(), idxDir("", ""), idxName("", "") {
 }
 
-void BowtieWidget::accept(WizardWidgetVisitor *visitor) {
+void BowtieWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-void BowtieWidget::validate(const QList<Actor *> &actors, U2OpStatus &os) const {
+void BowtieWidget::validate(const QList<Actor*>& actors, U2OpStatus& os) const {
     idxName.validate(actors, os);
     idxDir.validate(actors, os);
 }
@@ -360,19 +360,19 @@ TophatSamplesWidget::TophatSamplesWidget()
     : WizardWidget(), samplesAttr("", "") {
 }
 
-void TophatSamplesWidget::accept(WizardWidgetVisitor *visitor) {
+void TophatSamplesWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
-void TophatSamplesWidget::validate(const QList<Actor *> &actors, U2OpStatus &os) const {
+void TophatSamplesWidget::validate(const QList<Actor*>& actors, U2OpStatus& os) const {
     samplesAttr.validate(actors, os);
     CHECK_OP(os, );
 
-    foreach (const Actor *a, actors) {
+    foreach (const Actor* a, actors) {
         if (a->getId() == datasetsProvider) {
-            Attribute *attr = a->getParameter(BaseAttributes::URL_IN_ATTRIBUTE().getId());
-            URLAttribute *datasetAttr = dynamic_cast<URLAttribute *>(attr);
-            if (nullptr == datasetAttr) {
+            Attribute* attr = a->getParameter(BaseAttributes::URL_IN_ATTRIBUTE().getId());
+            auto datasetAttr = dynamic_cast<URLAttribute*>(attr);
+            if (datasetAttr == nullptr) {
                 os.setError(QObject::tr("The actor has not the dataset attribute"));
             }
             return;
@@ -394,7 +394,7 @@ LabelWidget::LabelWidget()
     backgroundColor = DEFAULT_BG_COLOR;
 }
 
-void LabelWidget::accept(WizardWidgetVisitor *visitor) {
+void LabelWidget::accept(WizardWidgetVisitor* visitor) {
     visitor->visit(this);
 }
 
