@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WIZARDWIDGETVISITOR_H_
-#define _U2_WIZARDWIDGETVISITOR_H_
+#pragma once
 
 #include <U2Lang/ElementSelectorWidget.h>
 #include <U2Lang/WizardWidget.h>
@@ -29,20 +28,18 @@ namespace U2 {
 
 class U2LANG_EXPORT WizardWidgetVisitor {
 public:
-    virtual void visit(AttributeWidget *) = 0;
-    virtual void visit(WidgetsArea *) = 0;
-    virtual void visit(GroupWidget *) = 0;
-    virtual void visit(LogoWidget *) = 0;
-    virtual void visit(ElementSelectorWidget *) = 0;
-    virtual void visit(PairedReadsWidget *) = 0;
-    virtual void visit(UrlAndDatasetWidget *) = 0;
-    virtual void visit(RadioWidget *) = 0;
-    virtual void visit(SettingsWidget *) = 0;
-    virtual void visit(BowtieWidget *) = 0;
-    virtual void visit(TophatSamplesWidget *) = 0;
-    virtual void visit(LabelWidget *) = 0;
+    virtual void visit(AttributeWidget*) = 0;
+    virtual void visit(WidgetsArea*) = 0;
+    virtual void visit(GroupWidget*) = 0;
+    virtual void visit(LogoWidget*) = 0;
+    virtual void visit(ElementSelectorWidget*) = 0;
+    virtual void visit(PairedReadsWidget*) = 0;
+    virtual void visit(UrlAndDatasetWidget*) = 0;
+    virtual void visit(RadioWidget*) = 0;
+    virtual void visit(SettingsWidget*) = 0;
+    virtual void visit(BowtieWidget*) = 0;
+    virtual void visit(TophatSamplesWidget*) = 0;
+    virtual void visit(LabelWidget*) = 0;
 };
 
 }  // namespace U2
-
-#endif  // _U2_WIZARDWIDGETVISITOR_H_
