@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOWMONITOR_H_
-#define _U2_WORKFLOWMONITOR_H_
+#pragma once
 
 #include <QTextStream>
 
@@ -41,14 +40,14 @@ namespace Monitor {
 class U2LANG_EXPORT FileInfo {
 public:
     FileInfo();
-    FileInfo(const QString &url, const QString &producer, bool openBySystem = false);
+    FileInfo(const QString& url, const QString& producer, bool openBySystem = false);
 
     QString url;
     QString actor;
     bool openBySystem;
     bool isDir;
 
-    bool operator==(const FileInfo &other) const;
+    bool operator==(const FileInfo& other) const;
 };
 
 class U2LANG_EXPORT WorkerInfo {
@@ -61,8 +60,8 @@ class U2LANG_EXPORT WorkerParamsInfo {
 public:
     WorkerParamsInfo();
     QString workerName;
-    QList<Attribute *> parameters;
-    Actor *actor;
+    QList<Attribute*> parameters;
+    Actor* actor;
 };
 class U2LANG_EXPORT WorkerLogInfo {
 public:
@@ -70,7 +69,7 @@ public:
         : workerRunNumber(0) {
     }
     int workerRunNumber;
-    QList<ExternalToolListener *> logs;
+    QList<ExternalToolListener*> logs;
 };
 
 class U2LANG_EXPORT LogEntry {
@@ -102,47 +101,47 @@ enum U2LANG_EXPORT TaskState {
 class U2LANG_EXPORT WorkflowMonitor : public QObject {
     Q_OBJECT
 public:
-    WorkflowMonitor(WorkflowAbstractIterationRunner *task, Schema *schema);
+    WorkflowMonitor(WorkflowAbstractIterationRunner* task, Schema* schema);
 
-    const QList<Monitor::FileInfo> &getOutputFiles() const;
-    const NotificationsList &getNotifications() const;
-    const QMap<QString, Monitor::WorkerInfo> &getWorkersInfo() const;
-    const QList<Monitor::WorkerParamsInfo> &getWorkersParameters() const;
-    const QMap<QString, Monitor::WorkerLogInfo> &getWorkersLog() const;
-    const QMap<QString, QMultiMap<QString, QString>> &getWorkersReports() const;
-    QString actorName(const QString &id) const;
-    int getDataProduced(const QString &actor) const;
-    bool containsOutputFile(const QString &url) const;
+    const QList<Monitor::FileInfo>& getOutputFiles() const;
+    const NotificationsList& getNotifications() const;
+    const QMap<QString, Monitor::WorkerInfo>& getWorkersInfo() const;
+    const QList<Monitor::WorkerParamsInfo>& getWorkersParameters() const;
+    const QMap<QString, Monitor::WorkerLogInfo>& getWorkersLog() const;
+    const QMap<QString, QMultiMap<QString, QString>>& getWorkersReports() const;
+    QString actorName(const QString& id) const;
+    int getDataProduced(const QString& actor) const;
+    bool containsOutputFile(const QString& url) const;
 
-    void addOutputFile(const QString &url, const QString &producer, bool openBySystem = false);
-    void addOutputFolder(const QString &url, const QString &producer);
-    void addInfo(const QString &message, const QString &actor, const QString &type = WorkflowNotification::U2_INFO);
-    void addError(const QString &message, const QString &actor, const QString &type = WorkflowNotification::U2_ERROR);
+    void addOutputFile(const QString& url, const QString& producer, bool openBySystem = false);
+    void addOutputFolder(const QString& url, const QString& producer);
+    void addInfo(const QString& message, const QString& actor, const QString& type = WorkflowNotification::U2_INFO);
+    void addError(const QString& message, const QString& actor, const QString& type = WorkflowNotification::U2_ERROR);
     /** Can be called only one time for the task */
-    void addTaskError(Task *task, const QString &message = "");
-    void addTaskWarning(Task *task, const QString &message = "");
-    void addTime(qint64 timeMks, const QString &actor);
-    void addTick(qint64 timeMks, const QString &actor);
+    void addTaskError(Task* task, const QString& message = "");
+    void addTaskWarning(Task* task, const QString& message = "");
+    void addTime(qint64 timeMks, const QString& actor);
+    void addTick(qint64 timeMks, const QString& actor);
 
     void start();
     void pause();
     void resume();
     bool isExternalToolScheme() const;
 
-    void registerTask(Task *task, const QString &actor);
+    void registerTask(Task* task, const QString& actor);
 
-    void setOutputDir(const QString &dir);
+    void setOutputDir(const QString& dir);
     QString outputDir() const;
     QString getLogsDir() const;
-    QString getLogUrl(const QString &actorId, int actorRunNumber, const QString &toolName, int toolRunNumber, int contentType) const;
+    QString getLogUrl(const QString& actorId, int actorRunNumber, const QString& toolName, int toolRunNumber, int contentType) const;
 
-    void setSaveSchema(const Metadata &meta);
+    void setSaveSchema(const Metadata& meta);
 
-    QList<ExternalToolListener *> createWorkflowListeners(const QString &workerId, const QString &workerName, int listenersNumber = 1);
-    WDListener *getListener(const QString &actorId, int actorRunNumber, const QString &toolName, int toolRunNumber) const;
-    int getNewToolRunNumber(const QString &actorId, int actorRunNumber, const QString &toolName);
+    QList<ExternalToolListener*> createWorkflowListeners(const QString& workerId, const QString& workerName, int listenersNumber = 1);
+    WDListener* getListener(const QString& actorId, int actorRunNumber, const QString& toolName, int toolRunNumber) const;
+    int getNewToolRunNumber(const QString& actorId, int actorRunNumber, const QString& toolName);
 
-    void onLogChanged(const WDListener *listener, int messageType, const QString &message);
+    void onLogChanged(const WDListener* listener, int messageType, const QString& message);
 
     Monitor::TaskState getTaskState() const;
 
@@ -151,28 +150,28 @@ public:
 public slots:
     void sl_progressChanged();
     void sl_taskStateChanged();
-    void sl_workerTaskFinished(Task *workerTask);
+    void sl_workerTaskFinished(Task* workerTask);
 
 signals:
     void si_firstNotification();
-    void si_newOutputFile(const Monitor::FileInfo &info);
-    void si_newNotification(const WorkflowNotification &info, int count);
-    void si_workerInfoChanged(const QString &actor, const Monitor::WorkerInfo &info);
+    void si_newOutputFile(const Monitor::FileInfo& info);
+    void si_newNotification(const WorkflowNotification& info, int count);
+    void si_workerInfoChanged(const QString& actor, const Monitor::WorkerInfo& info);
     void si_progressChanged(int progress);
     void si_runStateChanged(bool paused);
     void si_taskStateChanged(Monitor::TaskState state);
     void si_updateProducers();
-    void si_dirSet(const QString &dir);
+    void si_dirSet(const QString& dir);
     void si_logChanged(Monitor::LogEntry entry);
 
 private:
-    Schema *schema;
+    Schema* schema;
     QScopedPointer<Metadata> meta;
     QPointer<WorkflowAbstractIterationRunner> task;
     QMap<QString, QPointer<Actor>> procMap;
     StrStrMap processNames;
-    QMap<Task *, Actor *> taskMap;
-    QList<Task *> errorTasks;
+    QMap<Task*, Actor*> taskMap;
+    QList<Task*> errorTasks;
     QList<Monitor::FileInfo> outputFiles;
     NotificationsList notifications;
     QMap<QString, Monitor::WorkerInfo> workers;
@@ -185,32 +184,32 @@ private:
     bool externalTools;
 
 protected:
-    void setWorkerInfo(const QString &actorId, const Monitor::WorkerInfo &info);
+    void setWorkerInfo(const QString& actorId, const Monitor::WorkerInfo& info);
     void setRunState(bool paused);
-    void addNotification(const WorkflowNotification &notification);
+    void addNotification(const WorkflowNotification& notification);
     bool hasWarnings() const;
     bool hasErrors() const;
 };
 
 class U2LANG_EXPORT MonitorUtils {
 public:
-    static QMap<QString, QList<Monitor::FileInfo>> filesByActor(const WorkflowMonitor *m);
-    static QStringList sortedByAppearanceActorIds(const WorkflowMonitor *m);
-    static QString toSlashedUrl(const QString &url);
+    static QMap<QString, QList<Monitor::FileInfo>> filesByActor(const WorkflowMonitor* m);
+    static QStringList sortedByAppearanceActorIds(const WorkflowMonitor* m);
+    static QString toSlashedUrl(const QString& url);
 };
 
 class U2LANG_EXPORT WDListener : public ExternalToolListener {
 public:
-    WDListener(WorkflowMonitor *monitor, const QString &actorId, const QString &actorName, int actorRunNumber);
+    WDListener(WorkflowMonitor* monitor, const QString& actorId, const QString& actorName, int actorRunNumber);
 
-    void addNewLogMessage(const QString &message, int messageType) override;
+    void addNewLogMessage(const QString& message, int messageType) override;
 
-    void setToolName(const QString &toolName) override;
+    void setToolName(const QString& toolName) override;
 
-    const QString &getActorId() const {
+    const QString& getActorId() const {
         return actorId;
     }
-    const QString &getActorName() const {
+    const QString& getActorName() const {
         return actorName;
     }
 
@@ -225,15 +224,15 @@ public:
     QString getStderrLogFileUrl();
 
 private:
-    static QString getStdoutLogFileUrl(const QString &actorName, int actorRunNumber, const QString &toolName, int toolRunNumber);
-    static QString getStderrLogFileUrl(const QString &actorName, int actorRunNumber, const QString &toolName, int toolRunNumber);
+    static QString getStdoutLogFileUrl(const QString& actorName, int actorRunNumber, const QString& toolName, int toolRunNumber);
+    static QString getStderrLogFileUrl(const QString& actorName, int actorRunNumber, const QString& toolName, int toolRunNumber);
 
     void initLogFile(int contentType);
 
-    void writeToFile(int messageType, const QString &message);
-    static void writeToFile(QTextStream &logStream, const QString &message);
+    void writeToFile(int messageType, const QString& message);
+    static void writeToFile(QTextStream& logStream, const QString& message);
 
-    WorkflowMonitor *monitor;
+    WorkflowMonitor* monitor;
     QString actorId;
     QString actorName;
     int actorRunNumber;
@@ -255,5 +254,3 @@ Q_DECLARE_METATYPE(U2::Workflow::Monitor::FileInfo)
 Q_DECLARE_METATYPE(U2::Workflow::Monitor::WorkerInfo)
 Q_DECLARE_METATYPE(U2::Workflow::Monitor::LogEntry)
 Q_DECLARE_METATYPE(U2::Workflow::Monitor::WorkerParamsInfo)
-
-#endif  // _U2_WORKFLOWMONITOR_H_
