@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BASE_NGS_WORKER_H_
-#define _U2_BASE_NGS_WORKER_H_
+#pragma once
 
 #include <U2Core/GUrl.h>
 
@@ -40,15 +39,15 @@ public:
     QString outName;
     QString inputUrl;
     QVariantMap customParameters;
-    QList<ExternalToolListener *> listeners;
+    QList<ExternalToolListener*> listeners;
 };
 
 class U2LANG_EXPORT BaseNGSWorker : public BaseWorker {
     Q_OBJECT
 public:
-    BaseNGSWorker(Actor *a);
+    BaseNGSWorker(Actor* a);
     void init();
-    Task *tick();
+    Task* tick();
     void cleanup();
 
     static const QString INPUT_PORT;
@@ -63,19 +62,19 @@ protected:
         return QVariantMap();
     }
     virtual QString getDefaultFileName() const = 0;
-    virtual Task *getTask(const BaseNGSSetting &settings) const = 0;
+    virtual Task* getTask(const BaseNGSSetting& settings) const = 0;
 
     QString takeUrl();
-    QString getTargetName(const QString &fileUrl, const QString &outDir);
-    void sendResult(const QString &url);
+    QString getTargetName(const QString& fileUrl, const QString& outDir);
+    void sendResult(const QString& url);
 
 protected:
-    IntegralBus *inputUrlPort;
-    IntegralBus *outputUrlPort;
+    IntegralBus* inputUrlPort;
+    IntegralBus* outputUrlPort;
     QStringList outUrls;
 
 public slots:
-    void sl_taskFinished(Task *task);
+    void sl_taskFinished(Task* task);
 
 };  // BaseNGSWorker
 
@@ -83,8 +82,8 @@ class U2LANG_EXPORT BaseNGSParser : public ExternalToolLogParser {
 public:
     BaseNGSParser();
 
-    void parseOutput(const QString &partOfLog);
-    void parseErrOutput(const QString &partOfLog);
+    void parseOutput(const QString& partOfLog);
+    void parseErrOutput(const QString& partOfLog);
 
 private:
     QString lastErrLine;
@@ -93,7 +92,7 @@ private:
 class U2LANG_EXPORT BaseNGSTask : public Task {
     Q_OBJECT
 public:
-    BaseNGSTask(const BaseNGSSetting &settings);
+    BaseNGSTask(const BaseNGSSetting& settings);
 
     void prepare();
     void run();
@@ -109,8 +108,8 @@ protected:
     /**
      * Don't delete customParser, it will be deleted automatically.
      */
-    virtual ExternalToolRunTask *getExternalToolTask(const QString &toolId, ExternalToolLogParser *customParser = nullptr);
-    virtual QStringList getParameters(U2OpStatus &os) = 0;
+    virtual ExternalToolRunTask* getExternalToolTask(const QString& toolId, ExternalToolLogParser* customParser = nullptr);
+    virtual QStringList getParameters(U2OpStatus& os) = 0;
 
 protected:
     BaseNGSSetting settings;
@@ -119,5 +118,3 @@ protected:
 
 }  // namespace LocalWorkflow
 }  // namespace U2
-
-#endif  //_U2_BASE_NGS_WORKER_H_
