@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_CORE_LIB_CONSTANTS_H_
-#define _U2_WORKFLOW_CORE_LIB_CONSTANTS_H_
+#pragma once
 
 #include <QString>
 
@@ -60,5 +59,3 @@ public:
 }  // namespace Workflow
 
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_CORE_LIB_CONSTANTS_H_
