@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,13 +30,13 @@
 namespace U2 {
 namespace LocalWorkflow {
 
-ElapsedTimeUpdater::ElapsedTimeUpdater(const ActorId &runningActorId, WorkflowMonitor *monitor, Task *executedTask)
+ElapsedTimeUpdater::ElapsedTimeUpdater(const ActorId& runningActorId, WorkflowMonitor* monitor, Task* executedTask)
     : runningActorId(runningActorId), monitor(monitor), executedTask(executedTask), elapsedTime(0) {
     connect(this, SIGNAL(timeout()), SLOT(sl_updateTime()));
-    connect(new TaskSignalMapper(executedTask), SIGNAL(si_taskFinished(Task *)), SLOT(sl_taskFinished(Task *)));
+    connect(new TaskSignalMapper(executedTask), SIGNAL(si_taskFinished(Task*)), SLOT(sl_taskFinished(Task*)));
 }
 
-void ElapsedTimeUpdater::sl_taskFinished(Task *) {
+void ElapsedTimeUpdater::sl_taskFinished(Task*) {
     stop();
     qint64 newElapsedTime = GTimer::currentTimeMicros() - executedTask->getTimeInfo().startTime;
     monitor->addTick(newElapsedTime - elapsedTime, runningActorId);
@@ -44,7 +44,7 @@ void ElapsedTimeUpdater::sl_taskFinished(Task *) {
 }
 
 ElapsedTimeUpdater::~ElapsedTimeUpdater() {
-    CHECK(nullptr != executedTask, );
+    CHECK(executedTask != nullptr, );
     qint64 newElapsedTime = executedTask->getTimeInfo().finishTime - executedTask->getTimeInfo().startTime;
     if (newElapsedTime > elapsedTime) {
         monitor->addTick(newElapsedTime - elapsedTime, runningActorId);
