@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _ELAPSED_TIME_UPDATER_H_
-#define _ELAPSED_TIME_UPDATER_H_
+#pragma once
 
 #include <U2Lang/LocalDomain.h>
 
@@ -31,21 +30,19 @@ namespace LocalWorkflow {
 class ElapsedTimeUpdater : public QTimer {
     Q_OBJECT
 public:
-    ElapsedTimeUpdater(const ActorId &runningActorId, WorkflowMonitor *monitor, Task *executedTask);
+    ElapsedTimeUpdater(const ActorId& runningActorId, WorkflowMonitor* monitor, Task* executedTask);
     ~ElapsedTimeUpdater();
 
 private:
     ActorId runningActorId;
-    WorkflowMonitor *monitor;
-    Task *executedTask;
+    WorkflowMonitor* monitor;
+    Task* executedTask;
     qint64 elapsedTime;
 private slots:
     void sl_updateTime();
-    void sl_taskFinished(Task *);
+    void sl_taskFinished(Task*);
 };
 
 }  // namespace LocalWorkflow
 
 }  // namespace U2
-
-#endif  // _ELAPSED_TIME_UPDATER_H_
