@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_INTEGRAL_BUS_UTILS_H_
-#define _U2_INTEGRAL_BUS_UTILS_H_
+#pragma once
 
 #include <U2Lang/ActorModel.h>
 #include <U2Lang/Datatype.h>
@@ -36,24 +35,24 @@ public:
         QList<Descriptor> otherDescs;
     };
 
-    static SplitResult splitCandidates(const QList<Descriptor> &candidates, const Descriptor &toDesc, DataTypePtr toDatatype);
-    static void remapBus(StrStrMap &busMap, const ActorId &oldId, const ActorId &newId, const PortMapping &mapping);
-    static void remapPathedSlotString(QString &pathedSlotStr, const ActorId &oldId, const ActorId &newId, const PortMapping &mapping);
-    static QList<Descriptor> getSlotsByType(const QMap<Descriptor, DataTypePtr> &busMap, const Descriptor &slot, const DataTypePtr &type);
+    static SplitResult splitCandidates(const QList<Descriptor>& candidates, const Descriptor& toDesc, DataTypePtr toDatatype);
+    static void remapBus(StrStrMap& busMap, const ActorId& oldId, const ActorId& newId, const PortMapping& mapping);
+    static void remapPathedSlotString(QString& pathedSlotStr, const ActorId& oldId, const ActorId& newId, const PortMapping& mapping);
+    static QList<Descriptor> getSlotsByType(const QMap<Descriptor, DataTypePtr>& busMap, const Descriptor& slot, const DataTypePtr& type);
 };
 
 class U2LANG_EXPORT CandidatesSplitter {
 public:
-    CandidatesSplitter(const QString &id);
+    CandidatesSplitter(const QString& id);
     virtual ~CandidatesSplitter();
 
-    virtual bool canSplit(const Descriptor &toDesc, DataTypePtr toDatatype) = 0;
-    virtual IntegralBusUtils::SplitResult splitCandidates(const QList<Descriptor> &candidates);
+    virtual bool canSplit(const Descriptor& toDesc, DataTypePtr toDatatype) = 0;
+    virtual IntegralBusUtils::SplitResult splitCandidates(const QList<Descriptor>& candidates);
 
-    const QString &getId() const;
+    const QString& getId() const;
 
 protected:
-    virtual bool isMain(const QString &candidateSlotId) = 0;
+    virtual bool isMain(const QString& candidateSlotId) = 0;
 
 private:
     const QString id;
@@ -62,17 +61,17 @@ private:
 class U2LANG_EXPORT CandidatesSplitterRegistry {
 public:
     ~CandidatesSplitterRegistry();
-    static CandidatesSplitterRegistry *instance();
+    static CandidatesSplitterRegistry* instance();
 
-    CandidatesSplitter *findSplitter(const Descriptor &toDesc, DataTypePtr toDatatype);
-    CandidatesSplitter *findSplitter(const QString &id);
+    CandidatesSplitter* findSplitter(const Descriptor& toDesc, DataTypePtr toDatatype);
+    CandidatesSplitter* findSplitter(const QString& id);
 
-    void registerSplitter(CandidatesSplitter *splitter);
-    void unregisterSplitter(const QString &id);
+    void registerSplitter(CandidatesSplitter* splitter);
+    void unregisterSplitter(const QString& id);
 
 private:
-    static CandidatesSplitterRegistry *_instance;
-    QList<CandidatesSplitter *> splitters;
+    static CandidatesSplitterRegistry* _instance;
+    QList<CandidatesSplitter*> splitters;
 
 private:
     CandidatesSplitterRegistry();
@@ -80,5 +79,3 @@ private:
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // _U2_INTEGRAL_BUS_UTILS_H_
