@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _MARKER_UTILS_H_
-#define _MARKER_UTILS_H_
+#pragma once
 
 #include <U2Lang/Marker.h>
 
@@ -28,8 +27,8 @@ namespace U2 {
 
 class U2LANG_EXPORT MarkerUtils {
 public:
-    static bool stringToValue(MarkerDataType dataType, const QString &string, QVariantList &value);
-    static void valueToString(MarkerDataType dataType, const QVariantList &value, QString &string);
+    static bool stringToValue(MarkerDataType dataType, const QString& string, QVariantList& value);
+    static void valueToString(MarkerDataType dataType, const QVariantList& value, QString& string);
 
     static const QString INTERVAL_OPERATION;
     static const QString LESS_OPERATION;
@@ -42,15 +41,13 @@ public:
     static const QString REST_OPERATION;
 
 private:
-    static bool stringToIntValue(const QString &string, QVariantList &value);
-    static bool stringToFloatValue(const QString &string, QVariantList &value);
-    static bool stringToTextValue(const QString &string, QVariantList &value);
+    static bool stringToIntValue(const QString& string, QVariantList& value);
+    static bool stringToFloatValue(const QString& string, QVariantList& value);
+    static bool stringToTextValue(const QString& string, QVariantList& value);
 
-    static void integerValueToString(const QVariantList &value, QString &string);
-    static void floatValueToString(const QVariantList &value, QString &string);
-    static void textValueToString(const QVariantList &value, QString &string);
+    static void integerValueToString(const QVariantList& value, QString& string);
+    static void floatValueToString(const QVariantList& value, QString& string);
+    static void textValueToString(const QVariantList& value, QString& string);
 };
 
 }  // namespace U2
-
-#endif  // _MARKER_UTILS_H_
