@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_NOFAILTASKWRAPPER_H_
-#define _U2_NOFAILTASKWRAPPER_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -33,18 +32,16 @@ namespace U2 {
 class U2LANG_EXPORT NoFailTaskWrapper : public Task {
     Q_OBJECT
 public:
-    NoFailTaskWrapper(Task *task);
+    NoFailTaskWrapper(Task* task);
     virtual void prepare();
 
-    Task *originalTask() const;
+    Task* originalTask() const;
 
     virtual bool hasWarning() const;
     virtual QStringList getWarnings() const;
 
 private:
-    Task *subTask;
+    Task* subTask;
 };
 
 }  // namespace U2
-
-#endif  // _U2_NOFAILTASKWRAPPER_H_
