@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _SCRIPT_WORKER_SERIALIZER_H_
-#define _SCRIPT_WORKER_SERIALIZER_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -31,9 +30,7 @@ namespace U2 {
 class U2LANG_EXPORT ScriptWorkerSerializer {
 public:
     // If a error occurs this returns NULL and writes a error message to @error.
-    static Workflow::ActorPrototype *string2actor(const QString data, const QString actorName, QString &error, const QString actorFilePath);
+    static Workflow::ActorPrototype* string2actor(const QString data, const QString actorName, QString& error, const QString actorFilePath);
 };
 
 }  // namespace U2
-
-#endif  // _SCRIPT_WORKER_SERIALIZER_H_
