@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,8 +21,7 @@
 
 /** Set of wrappers for typical workflow tasks */
 
-#ifndef _SIMPLE_WORKFLOW_TASK_H_
-#define _SIMPLE_WORKFLOW_TASK_H_
+#pragma once
 
 #include <QTemporaryFile>
 
@@ -46,7 +45,7 @@ class MultipleSequenceAlignmentObject;
 class U2LANG_EXPORT SimpleInOutWorkflowTaskConfig {
 public:
     SimpleInOutWorkflowTaskConfig();
-    QList<GObject *> objects;
+    QList<GObject*> objects;
     DocumentFormatId inFormat;
     QVariantMap inDocHints;
     DocumentFormatId outFormat;
@@ -64,24 +63,24 @@ public:
 class U2LANG_EXPORT SimpleInOutWorkflowTask : public DocumentProviderTask {
     Q_OBJECT
 public:
-    SimpleInOutWorkflowTask(const SimpleInOutWorkflowTaskConfig &conf);
+    SimpleInOutWorkflowTask(const SimpleInOutWorkflowTaskConfig& conf);
     void prepare();
-    virtual QList<Task *> onSubTaskFinished(Task *subTask);
+    virtual QList<Task*> onSubTaskFinished(Task* subTask);
 
 private:
-    void prepareTmpFile(QTemporaryFile &tmpFile, const QString &tmpl);
+    void prepareTmpFile(QTemporaryFile& tmpFile, const QString& tmpl);
 
     SimpleInOutWorkflowTaskConfig conf;
 
-    Document *inDoc;
+    Document* inDoc;
 
-    SaveDocumentTask *saveInputTask;
+    SaveDocumentTask* saveInputTask;
     QTemporaryFile inputTmpFile;
 
-    CmdlineTaskRunner *runWorkflowTask;
+    CmdlineTaskRunner* runWorkflowTask;
 
     QTemporaryFile resultTmpFile;
-    LoadDocumentTask *loadResultTask;
+    LoadDocumentTask* loadResultTask;
 
     QString schemaPath;
 };
@@ -97,7 +96,7 @@ class U2LANG_EXPORT SimpleMSAWorkflow4GObjectTask : public Task {
     Q_OBJECT
 
 public:
-    SimpleMSAWorkflow4GObjectTask(const QString &taskName, MultipleSequenceAlignmentObject *maObj, const SimpleMSAWorkflowTaskConfig &conf);
+    SimpleMSAWorkflow4GObjectTask(const QString& taskName, MultipleSequenceAlignmentObject* maObj, const SimpleMSAWorkflowTaskConfig& conf);
 
     void prepare();
     ReportResult report();
@@ -107,10 +106,8 @@ private:
     QPointer<MultipleSequenceAlignmentObject> msaObjectPointer;
     QString docName;
     SimpleMSAWorkflowTaskConfig conf;
-    SimpleInOutWorkflowTask *runWorkflowTask;
+    SimpleInOutWorkflowTask* runWorkflowTask;
     QPointer<StateLock> msaObjectLock;
 };
 
 }  // namespace U2
-
-#endif  // #ifndef _RUN_SCHEMA_FOR_TASK_H_
