@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SUPPORT_CLASS_H_
-#define _U2_SUPPORT_CLASS_H_
+#pragma once
 
 #include <QMetaType>
 #include <QString>
@@ -40,13 +39,13 @@ typedef QList<WorkflowNotification> NotificationsList;
 
 class U2LANG_EXPORT WorkflowNotification {
 public:
-    WorkflowNotification(const QString &message = "", const QString &actorId = "", const QString &type = U2_ERROR);
+    WorkflowNotification(const QString& message = "", const QString& actorId = "", const QString& type = U2_ERROR);
     QString message;
     QString actorId;
     QString type;
     QString port;
 
-    bool operator==(const WorkflowNotification &other) const;
+    bool operator==(const WorkflowNotification& other) const;
 
     static const QString U2_ERROR;
     static const QString U2_WARNING;
@@ -56,5 +55,3 @@ public:
 }  // namespace U2
 
 Q_DECLARE_METATYPE(U2::WorkflowNotification)
-
-#endif  // _U2_SUPPORT_CLASS_H_
