@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SUPPORTSTRUCTURES_H_
-#define _U2_SUPPORTSTRUCTURES_H_
+#pragma once
 
 #include <QStringList>
 
@@ -30,12 +29,10 @@ namespace U2 {
 
 class U2LANG_EXPORT TophatSample {
 public:
-    TophatSample(const QString &name, const QStringList &datasets);
+    TophatSample(const QString& name, const QStringList& datasets);
 
     QString name;
     QStringList datasets;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SUPPORTSTRUCTURES_H_
