@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@
 
 namespace U2 {
 
-WorkflowBreakpoint::WorkflowBreakpoint(const ActorId &actor, Workflow::WorkflowContext *context)
+WorkflowBreakpoint::WorkflowBreakpoint(const ActorId& actor, Workflow::WorkflowContext* context)
     : enabled(true),
       actorId(actor),
       hitCounter(BaseBreakpointHitCounter::createInstance()),
@@ -48,7 +48,7 @@ ActorId WorkflowBreakpoint::getActorId() const {
     return actorId;
 }
 
-void WorkflowBreakpoint::setLabels(const QList<BreakpointLabel> &newLabels) {
+void WorkflowBreakpoint::setLabels(const QList<BreakpointLabel>& newLabels) {
     labels = newLabels;
 }
 
@@ -81,7 +81,7 @@ void WorkflowBreakpoint::setConditionParameter(BreakpointConditionParameter newP
     conditionChecker.setConditionParameter(newParameter);
 }
 
-void WorkflowBreakpoint::setConditionText(const QString &text) {
+void WorkflowBreakpoint::setConditionText(const QString& text) {
     conditionChecker.setConditionText(text);
 }
 
@@ -93,17 +93,17 @@ quint32 WorkflowBreakpoint::getHitCount() const {
     return hitCounter->getHitCount();
 }
 
-bool WorkflowBreakpoint::hit(const AttributeScript *conditionContext) {
-    Q_ASSERT(nullptr != hitCounter);
-    return (conditionChecker.evaluateCondition(conditionContext) && hitCounter->hit());
+bool WorkflowBreakpoint::hit(const AttributeScript* conditionContext) {
+    Q_ASSERT(hitCounter != nullptr);
+    return conditionChecker.evaluateCondition(conditionContext) && hitCounter->hit();
 }
 
 void WorkflowBreakpoint::resetHitCounter() {
-    Q_ASSERT(nullptr != hitCounter);
+    Q_ASSERT(hitCounter != nullptr);
     hitCounter->reset();
 }
 
-void WorkflowBreakpoint::setContext(Workflow::WorkflowContext *context) {
+void WorkflowBreakpoint::setContext(Workflow::WorkflowContext* context) {
     conditionChecker.setContext(context);
 }
 
