@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_DEBUG_MESSAGE_PARSER_H_
-#define _U2_WORKFLOW_DEBUG_MESSAGE_PARSER_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -40,21 +39,19 @@ public:
     WorkflowDebugMessageParser();
     virtual ~WorkflowDebugMessageParser();
 
-    void setContext(Workflow::WorkflowContext *context);
-    void setSourceData(const QQueue<Workflow::Message> &sourceData);
+    void setContext(Workflow::WorkflowContext* context);
+    void setSourceData(const QQueue<Workflow::Message>& sourceData);
 
     virtual WorkflowInvestigationData getAllMessageValues() = 0;
-    virtual void convertMessagesToDocuments(const QString &convertedType,
-                                            const QString &schemeName,
+    virtual void convertMessagesToDocuments(const QString& convertedType,
+                                            const QString& schemeName,
                                             quint32 messageNumber) = 0;
 
 protected:
     QQueue<QVariantMap> sourceMessages;
-    Workflow::WorkflowContext *context;
+    Workflow::WorkflowContext* context;
 
     static QStringList possibleMessageTypes;
 };
 
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_DEBUG_MESSAGE_PARSER_H_
