@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_ENVIMPL_H_
-#define _U2_WORKFLOW_ENVIMPL_H_
+#pragma once
 
 #include <U2Lang/WorkflowEnv.h>
 
@@ -35,17 +34,15 @@ class U2LANG_EXPORT WorkflowEnvImpl : public WorkflowEnv {
 protected:
     virtual ~WorkflowEnvImpl();
 
-    virtual DataTypeRegistry *initDataRegistry();
-    virtual ActorPrototypeRegistry *initProtoRegistry();
-    virtual DomainFactoryRegistry *initDomainRegistry();
-    virtual DataTypeValueFactoryRegistry *initDataTypeValueFactoryRegistry();
-    virtual ExternalToolCfgRegistry *initExternalToolCfgRegistry();
-    virtual SchemaActorsRegistry *initSchemaActorsRegistry();
-    virtual WorkflowTasksRegistry *initWorkflowTasksRegistry();
-    virtual ActorValidatorRegistry *initActorValidatorRegistry();
+    virtual DataTypeRegistry* initDataRegistry();
+    virtual ActorPrototypeRegistry* initProtoRegistry();
+    virtual DomainFactoryRegistry* initDomainRegistry();
+    virtual DataTypeValueFactoryRegistry* initDataTypeValueFactoryRegistry();
+    virtual ExternalToolCfgRegistry* initExternalToolCfgRegistry();
+    virtual SchemaActorsRegistry* initSchemaActorsRegistry();
+    virtual WorkflowTasksRegistry* initWorkflowTasksRegistry();
+    virtual ActorValidatorRegistry* initActorValidatorRegistry();
 };  // WorkflowEnvImpl
 
 }  // namespace Workflow
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_ENVIMPL_H_
