@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_IO_TASK_H_
-#define _U2_WORKFLOW_IO_TASK_H_
+#pragma once
 
 #include <QPointer>
 
@@ -37,7 +36,7 @@ using namespace Workflow;
 class U2LANG_EXPORT LoadWorkflowTask : public Task {
     Q_OBJECT
 public:
-    LoadWorkflowTask(const QSharedPointer<Schema> &schema, Metadata *meta, const QString &url);
+    LoadWorkflowTask(const QSharedPointer<Schema>& schema, Metadata* meta, const QString& url);
     virtual void run();
     Task::ReportResult report();
     QSharedPointer<Schema> getSchema() const {
@@ -46,7 +45,7 @@ public:
     QString getURL() const {
         return url;
     }
-    Metadata *getMetadata() {
+    Metadata* getMetadata() {
         return meta;
     }
     QMap<ActorId, ActorId> getRemapping() {
@@ -58,12 +57,12 @@ public:
         XML,
         UNKNOWN
     };
-    static FileFormat detectFormat(const QString &rawData);
+    static FileFormat detectFormat(const QString& rawData);
 
 protected:
     const QString url;
     const QSharedPointer<Schema> schema;
-    Metadata *meta;
+    Metadata* meta;
     QString rawData;
     FileFormat format;
     QMap<ActorId, ActorId> remap;
@@ -73,7 +72,7 @@ protected:
 class U2LANG_EXPORT SaveWorkflowTask : public Task {
     Q_OBJECT
 public:
-    SaveWorkflowTask(Schema *schema, const Metadata &meta, bool copyMode);
+    SaveWorkflowTask(Schema* schema, const Metadata& meta, bool copyMode);
     Task::ReportResult report();
     virtual void run();
 
@@ -84,4 +83,3 @@ private:
 };  // SaveWorkflowTask
 
 }  // namespace U2
-#endif
