@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -37,36 +37,36 @@
 
 namespace U2 {
 
-WorkflowAbstractRunner::WorkflowAbstractRunner(const QString &name, TaskFlags flags)
+WorkflowAbstractRunner::WorkflowAbstractRunner(const QString& name, TaskFlags flags)
     : CmdlineTask(name, flags) {
 }
 
-const QList<WorkflowMonitor *> &WorkflowAbstractRunner::getMonitors() const {
+const QList<WorkflowMonitor*>& WorkflowAbstractRunner::getMonitors() const {
     return monitors;
 }
 
-WorkflowAbstractIterationRunner::WorkflowAbstractIterationRunner(const QString &name, TaskFlags flags)
+WorkflowAbstractIterationRunner::WorkflowAbstractIterationRunner(const QString& name, TaskFlags flags)
     : Task(name, flags) {
 }
 
 /*******************************************
  * WorkflowRunTask
  *******************************************/
-WorkflowRunTask::WorkflowRunTask(const Schema &sh, const QMap<ActorId, ActorId> &remap, WorkflowDebugStatus *debugInfo)
+WorkflowRunTask::WorkflowRunTask(const Schema& sh, const QMap<ActorId, ActorId>& remap, WorkflowDebugStatus* debugInfo)
     : WorkflowAbstractRunner(tr("Execute workflow"),
                              TaskFlags(TaskFlag_NoRun) | TaskFlag_ReportingIsSupported | TaskFlag_OnlyNotificationReport),
       rmap(remap), flows(sh.getFlows()) {
     GCOUNTER(cvar, "WorkflowRunTask");
-    if (nullptr == debugInfo) {
-        debugInfo = new WorkflowDebugStatus;
+    if (debugInfo == nullptr) {
+        debugInfo = new WorkflowDebugStatus();
     }
-    if (nullptr == debugInfo->parent()) {
+    if (debugInfo->parent() == nullptr) {
         debugInfo->setParent(this);
     }
 
-    WorkflowIterationRunTask *t = new WorkflowIterationRunTask(sh, debugInfo);
-    WorkflowMonitor *m = t->getMonitor();
-    if (nullptr != m) {
+    auto t = new WorkflowIterationRunTask(sh, debugInfo);
+    WorkflowMonitor* m = t->getMonitor();
+    if (m != nullptr) {
         monitors << m;
     }
     connect(t, SIGNAL(si_ticked()), SIGNAL(si_ticked()));
@@ -75,7 +75,7 @@ WorkflowRunTask::WorkflowRunTask(const Schema &sh, const QMap<ActorId, ActorId>
     setMaxParallelSubtasks(MAX_PARALLEL_SUBTASKS_AUTO);
 }
 
-inline bool isValidFile(const QString &link, const qint64 &processStartTime) {
+inline bool isValidFile(const QString& link, const qint64& processStartTime) {
     GUrl url(link);
     if (url.isLocalFile()) {
         if (QFile::exists(link)) {
@@ -88,47 +88,50 @@ inline bool isValidFile(const QString &link, const qint64 &processStartTime) {
     return false;
 }
 
-QList<WorkerState> WorkflowRunTask::getState(Actor *actor) {
+QList<WorkerState> WorkflowRunTask::getState(Actor* actor) {
     QList<WorkerState> ret;
-    foreach (const QPointer<Task> &t, getSubtasks()) {
-        WorkflowIterationRunTask *rt = qobject_cast<WorkflowIterationRunTask *>(t.data());
+    foreach (const QPointer<Task>& t, getSubtasks()) {
+        auto rt = qobject_cast<WorkflowIterationRunTask*>(t.data());
         ret << rt->getState(actor->getId());
     }
     return ret;
 }
 
-int WorkflowRunTask::getMsgNum(const Link *l) {
+int WorkflowRunTask::getMsgNum(const Link* l) {
     int ret = 0;
-    foreach (const QPointer<Task> &t, getSubtasks()) {
-        WorkflowIterationRunTask *rt = qobject_cast<WorkflowIterationRunTask *>(t.data());
+    foreach (const QPointer<Task>& t, getSubtasks()) {
+        auto rt = qobject_cast<WorkflowIterationRunTask*>(t.data());
         ret += rt->getMsgNum(l);
     }
     return ret;
 }
 
-int WorkflowRunTask::getMsgPassed(const Link *l) {
+int WorkflowRunTask::getMsgPassed(const Link* l) {
     int ret = 0;
-    foreach (const QPointer<Task> &t, getSubtasks()) {
-        ret += qobject_cast<WorkflowIterationRunTask *>(t.data())->getMsgPassed(l);
+    foreach (const QPointer<Task>& t, getSubtasks()) {
+        ret += qobject_cast<WorkflowIterationRunTask*>(t.data())->getMsgPassed(l);
     }
     return ret;
 }
 
 QString WorkflowRunTask::generateReport() const {
     QString report;
-    foreach (WorkflowMonitor *monitor, getMonitors()) {
+    QList<WorkflowMonitor*> monitors = getMonitors();
+    for (const WorkflowMonitor* monitor : qAsConst(monitors)) {
         const QMap<QString, QMultiMap<QString, QString>> workersReports = monitor->getWorkersReports();
-        foreach (const QString &worker, workersReports.keys()) {
-            const QMultiMap<QString, QString> tasksReports = workersReports[worker];
+        QList<QString> workerReportKeys = workersReports.keys();
+        for (const QString& worker : qAsConst(workerReportKeys)) {
+            QMultiMap<QString, QString> tasksReports = workersReports[worker];
             QString workerReport;
-            foreach (const QString &taskName, tasksReports.uniqueKeys()) {
-                foreach (const QString &taskReport, tasksReports.values(taskName)) {
+            QList<QString> taskNames = tasksReports.uniqueKeys();
+            for (const QString& taskName : qAsConst(taskNames)) {
+                foreach (const QString& taskReport, tasksReports.values(taskName)) {
                     if (!taskReport.isEmpty()) {
-                        workerReport += QString("<div class=\"task\" id=\"%1\">%2</div>").arg(taskName).arg(QString(taskReport.toUtf8().toBase64()));
+                        workerReport += QString(R"(<div class="task" id="%1">%2</div>)").arg(taskName).arg(QString(taskReport.toUtf8().toBase64()));
                     }
                 }
             }
-            report += QString("<div class=\"worker\" id=\"%1\">%2</div>").arg(worker).arg(workerReport);
+            report += QString(R"(<div class="worker" id="%1">%2</div>)").arg(worker).arg(workerReport);
         }
     }
     return report;
@@ -139,8 +142,8 @@ QString WorkflowRunTask::getTaskError() const {
         return getError();
     }
 
-    foreach (WorkflowMonitor *monitor, monitors) {
-        foreach (const WorkflowNotification &notification, monitor->getNotifications()) {
+    for (const WorkflowMonitor* monitor : qAsConst(monitors)) {
+        foreach (const WorkflowNotification& notification, monitor->getNotifications()) {
             if (WorkflowNotification::U2_ERROR == notification.type) {
                 return notification.message;
             }
@@ -156,36 +159,35 @@ namespace {
 const int UPDATE_PROGRESS_INTERVAL = 500;
 }
 
-WorkflowIterationRunTask::WorkflowIterationRunTask(const Schema &sh,
-                                                   WorkflowDebugStatus *initDebugInfo)
+WorkflowIterationRunTask::WorkflowIterationRunTask(const Schema& sh,
+                                                   WorkflowDebugStatus* initDebugInfo)
     : WorkflowAbstractIterationRunner(tr("Workflow run"),
                                       (getAdditionalFlags() | TaskFlag_CancelOnSubtaskCancel | TaskFlag_FailOnSubtaskError)),
-      context(nullptr), schema(new Schema()), scheduler(nullptr), debugInfo(initDebugInfo),
-      nextTickRestoring(false), contextInitialized(false) {
+      schema(new Schema()), debugInfo(initDebugInfo) {
     rmap = HRSchemaSerializer::deepCopy(sh, schema, stateInfo);
     SAFE_POINT_OP(stateInfo, );
 
     if (schema->getDomain().isEmpty()) {
-        QList<DomainFactory *> factories = WorkflowEnv::getDomainRegistry()->getAllEntries();
+        QList<DomainFactory*> factories = WorkflowEnv::getDomainRegistry()->getAllEntries();
         assert(!factories.isEmpty());
         schema->setDomain(factories.isEmpty() ? "" : factories.at(0)->getId());
     }
-    DomainFactory *df = WorkflowEnv::getDomainRegistry()->getById(schema->getDomain());
+    DomainFactory* df = WorkflowEnv::getDomainRegistry()->getById(schema->getDomain());
     if (!df) {
         stateInfo.setError(tr("Unknown domain %1").arg(schema->getDomain()));
         return;
     }
 
     connect(debugInfo, SIGNAL(si_pauseStateChanged(bool)), SLOT(sl_pauseStateChanged(bool)));
-    connect(debugInfo, SIGNAL(si_singleStepIsRequested(const ActorId &)), SLOT(sl_singleStepIsRequested(const ActorId &)));
-    connect(debugInfo, SIGNAL(si_busInvestigationIsRequested(const Workflow::Link *, int)), SLOT(sl_busInvestigationIsRequested(const Workflow::Link *, int)));
-    connect(debugInfo, SIGNAL(si_busCountOfMessagesIsRequested(const Workflow::Link *)), SLOT(sl_busCountOfMessagesRequested(const Workflow::Link *)));
-    connect(debugInfo, SIGNAL(si_convertMessages2Documents(const Workflow::Link *, const QString &, int, const QString &)), SLOT(sl_convertMessages2Documents(const Workflow::Link *, const QString &, int, const QString &)));
+    connect(debugInfo, SIGNAL(si_singleStepIsRequested(const ActorId&)), SLOT(sl_singleStepIsRequested(const ActorId&)));
+    connect(debugInfo, SIGNAL(si_busInvestigationIsRequested(const Workflow::Link*, int)), SLOT(sl_busInvestigationIsRequested(const Workflow::Link*, int)));
+    connect(debugInfo, SIGNAL(si_busCountOfMessagesIsRequested(const Workflow::Link*)), SLOT(sl_busCountOfMessagesRequested(const Workflow::Link*)));
+    connect(debugInfo, SIGNAL(si_convertMessages2Documents(const Workflow::Link*, const QString&, int, const QString&)), SLOT(sl_convertMessages2Documents(const Workflow::Link*, const QString&, int, const QString&)));
 
-    WorkflowMonitor *m = new WorkflowMonitor(this, schema);
+    auto m = new WorkflowMonitor(this, schema);
     context = new WorkflowContext(schema->getProcesses(), m);
 
-    QTimer *timer = new QTimer(this);
+    auto timer = new QTimer(this);
     connect(timer, SIGNAL(timeout()), SIGNAL(si_updateProducers()));
     timer->start(UPDATE_PROGRESS_INTERVAL);
 }
@@ -197,7 +199,7 @@ TaskFlags WorkflowIterationRunTask::getAdditionalFlags() {
 
 WorkflowIterationRunTask::~WorkflowIterationRunTask() {
     lmap.clear();
-    DomainFactory *df = WorkflowEnv::getDomainRegistry()->getById(schema->getDomain());
+    DomainFactory* df = WorkflowEnv::getDomainRegistry()->getById(schema->getDomain());
     if (df) {
         df->destroy(scheduler, schema);
     }
@@ -218,10 +220,10 @@ void WorkflowIterationRunTask::prepare() {
         stateInfo.setError(tr("Failed to preprocess the workflow. Some of included files are broken"));
         return;
     }
-    DomainFactory *df = WorkflowEnv::getDomainRegistry()->getById(schema->getDomain());
+    DomainFactory* df = WorkflowEnv::getDomainRegistry()->getById(schema->getDomain());
     assert(df != nullptr);  // checked in constructor
-    foreach (Actor *a, schema->getProcesses()) {
-        Worker *w = df->createWorker(a);
+    foreach (Actor* a, schema->getProcesses()) {
+        Worker* w = df->createWorker(a);
         if (!w) {
             stateInfo.setError(tr("Failed to create worker %1 %2 in domain %3")
                                    .arg(a->getProto()->getId())
@@ -230,8 +232,8 @@ void WorkflowIterationRunTask::prepare() {
             return;
         }
     }
-    foreach (Link *l, schema->getFlows()) {
-        CommunicationChannel *cc = df->createConnection(l);
+    foreach (Link* l, schema->getFlows()) {
+        CommunicationChannel* cc = df->createConnection(l);
         if (!cc) {
             stateInfo.setError(tr("Failed to create connection %1 %2 in domain %3"));  // fixme
             return;
@@ -261,7 +263,7 @@ void WorkflowIterationRunTask::prepare() {
     scheduler->setDebugInfo(debugInfo);
     context->getMonitor()->start();
     while (scheduler->isReady() && !isCanceled()) {
-        Task *t = scheduler->tick();
+        Task* t = scheduler->tick();
         if (t) {
             addSubTask(t);
             break;
@@ -269,16 +271,16 @@ void WorkflowIterationRunTask::prepare() {
     }
 }
 
-QList<Task *> WorkflowIterationRunTask::onSubTaskFinished(Task *subTask) {
-    QList<Task *> tasks;
+QList<Task*> WorkflowIterationRunTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> tasks;
     // handle the situation when pause signal was not delivered to the current thread
     while (debugInfo->isPaused() && !isCanceled()) {
         QCoreApplication::processEvents();
     }
     if (scheduler->isReady() && nextTickRestoring) {
-        Task *replayingTask = scheduler->replayLastWorkerTick();
+        Task* replayingTask = scheduler->replayLastWorkerTick();
         nextTickRestoring = false;
-        if (nullptr != replayingTask) {
+        if (replayingTask != nullptr) {
             tasks << replayingTask;
             emit si_ticked();
             return tasks;
@@ -292,7 +294,7 @@ QList<Task *> WorkflowIterationRunTask::onSubTaskFinished(Task *subTask) {
         getMonitor()->addTaskWarning(subTask);
     }
     while (scheduler->isReady() && !isCanceled()) {
-        Task *t = scheduler->tick();
+        Task* t = scheduler->tick();
         if (t) {
             tasks << t;
             break;
@@ -313,17 +315,19 @@ Task::ReportResult WorkflowIterationRunTask::report() {
         if (!scheduler->isDone()) {
             if (!hasError() && !isCanceled()) {
                 setError(tr("No workers are ready, while not all workers are done. Workflow is broken?"));
-                algoLog.error(stateInfo.getError());
             }
         }
     }
+    if (hasError()) {
+        algoLog.error(stateInfo.getError());
+    }
 
     // add unregistered output files
     qint64 startTimeSec = getTimeInfo().startTime / 1000000;
-    foreach (Actor *a, schema->getProcesses()) {
-        LocalWorkflow::BaseWorker *bw = a->castPeer<LocalWorkflow::BaseWorker>();
+    foreach (Actor* a, schema->getProcesses()) {
+        auto bw = a->castPeer<LocalWorkflow::BaseWorker>();
         QStringList urls = bw->getOutputFiles();
-        foreach (const QString &url, urls) {
+        for (const QString& url : qAsConst(urls)) {
             QString absUrl = context->absolutePath(url);
             if (isValidFile(absUrl, startTimeSec)) {
                 context->getMonitor()->addOutputFile(absUrl, a->getId());
@@ -335,7 +339,7 @@ Task::ReportResult WorkflowIterationRunTask::report() {
     return ReportResult_Finished;
 }
 
-WorkerState WorkflowIterationRunTask::getState(const ActorId &id) {
+WorkerState WorkflowIterationRunTask::getState(const ActorId& id) {
     if (scheduler) {
         const WorkerState currentState = scheduler->getWorkerState(rmap.value(id));
         return (debugInfo->isPaused() && Workflow::WorkerRunning == currentState) ? Workflow::WorkerPaused : currentState;
@@ -343,7 +347,7 @@ WorkerState WorkflowIterationRunTask::getState(const ActorId &id) {
     return WorkerWaiting;
 }
 
-static QString getKey(const Link *l) {
+static QString getKey(const Link* l) {
     QStringList lst;
     lst << (l->source()->owner()->getId());
     lst << (l->source()->getId());
@@ -352,37 +356,37 @@ static QString getKey(const Link *l) {
     return lst.join("|");
 }
 
-inline static bool isSourceActor(const QString &actor, const QString &key) {
+inline static bool isSourceActor(const QString& actor, const QString& key) {
     QStringList lst = key.split("|");
     CHECK(4 == lst.size(), false);
     return lst.first() == actor;
 }
 
-WorkflowMonitor *WorkflowIterationRunTask::getMonitor() const {
-    CHECK(nullptr != context, nullptr);
+WorkflowMonitor* WorkflowIterationRunTask::getMonitor() const {
+    CHECK(context != nullptr, nullptr);
     return context->getMonitor();
 }
 
-int WorkflowIterationRunTask::getMsgNum(const Link *l) {
-    CommunicationChannel *cc = lmap.value(getKey(l));
+int WorkflowIterationRunTask::getMsgNum(const Link* l) {
+    CommunicationChannel* cc = lmap.value(getKey(l));
     if (cc) {
         return cc->hasMessage();
     }
     return 0;
 }
 
-int WorkflowIterationRunTask::getMsgPassed(const Link *l) {
-    CommunicationChannel *cc = lmap.value(getKey(l));
+int WorkflowIterationRunTask::getMsgPassed(const Link* l) {
+    CommunicationChannel* cc = lmap.value(getKey(l));
     if (cc != nullptr) {
         return cc->takenMessages();
     }
     return 0;
 }
 
-QList<CommunicationChannel *> WorkflowIterationRunTask::getActorLinks(const QString &actor) {
-    QList<CommunicationChannel *> result;
+QList<CommunicationChannel*> WorkflowIterationRunTask::getActorLinks(const QString& actor) {
+    QList<CommunicationChannel*> result;
 
-    QMap<QString, CommunicationChannel *>::ConstIterator i = lmap.constBegin();
+    QMap<QString, CommunicationChannel*>::ConstIterator i = lmap.constBegin();
     for (; i != lmap.constEnd(); i++) {
         if (isSourceActor(actor, i.key())) {
             result << i.value();
@@ -391,9 +395,9 @@ QList<CommunicationChannel *> WorkflowIterationRunTask::getActorLinks(const QStr
     return result;
 }
 
-int WorkflowIterationRunTask::getDataProduced(const ActorId &actor) {
+int WorkflowIterationRunTask::getDataProduced(const ActorId& actor) {
     int result = 0;
-    foreach (CommunicationChannel *cc, getActorLinks(actor)) {
+    foreach (CommunicationChannel* cc, getActorLinks(actor)) {
         result += cc->hasMessage();
         result += cc->takenMessages();
         break;
@@ -414,39 +418,39 @@ void WorkflowIterationRunTask::sl_pauseStateChanged(bool isPaused) {
     }
 }
 
-void WorkflowIterationRunTask::sl_busInvestigationIsRequested(const Workflow::Link *bus,
+void WorkflowIterationRunTask::sl_busInvestigationIsRequested(const Workflow::Link* bus,
                                                               int messageNumber) {
-    CommunicationChannel *channel = lmap.value(getKey(bus));
-    if (nullptr != channel && debugInfo->isPaused()) {
+    CommunicationChannel* channel = lmap.value(getKey(bus));
+    if (channel != nullptr && debugInfo->isPaused()) {
         QQueue<Message> messages = channel->getMessages(messageNumber, messageNumber);
-        WorkflowDebugMessageParser *parser = debugInfo->getMessageParser();
-        SAFE_POINT(nullptr != parser, "Invalid debug message parser!", );
+        WorkflowDebugMessageParser* parser = debugInfo->getMessageParser();
+        SAFE_POINT(parser != nullptr, "Invalid debug message parser!", );
         parser->setSourceData(messages);
         WorkflowInvestigationData data = parser->getAllMessageValues();
         debugInfo->respondToInvestigator(data, bus);
     }
 }
 
-void WorkflowIterationRunTask::sl_busCountOfMessagesRequested(const Workflow::Link *bus) {
+void WorkflowIterationRunTask::sl_busCountOfMessagesRequested(const Workflow::Link* bus) {
     debugInfo->respondMessagesCount(bus, getMsgNum(bus));
 }
 
-void WorkflowIterationRunTask::sl_singleStepIsRequested(const ActorId &actor) {
+void WorkflowIterationRunTask::sl_singleStepIsRequested(const ActorId& actor) {
     if (debugInfo->isPaused()) {
         scheduler->makeOneTick(actor);
     }
 }
 
-void WorkflowIterationRunTask::sl_convertMessages2Documents(const Workflow::Link *bus,
-                                                            const QString &messageType,
+void WorkflowIterationRunTask::sl_convertMessages2Documents(const Workflow::Link* bus,
+                                                            const QString& messageType,
                                                             int messageNumber,
-                                                            const QString &schemeName) {
-    CommunicationChannel *channel = lmap.value(getKey(bus));
-    if (nullptr != channel && debugInfo->isPaused()) {
+                                                            const QString& schemeName) {
+    CommunicationChannel* channel = lmap.value(getKey(bus));
+    if (channel != nullptr && debugInfo->isPaused()) {
         QQueue<Message> messages = channel->getMessages(messageNumber, messageNumber);
         if (!messages.isEmpty()) {
-            WorkflowDebugMessageParser *parser = debugInfo->getMessageParser();
-            SAFE_POINT(nullptr != parser, "Invalid debug message parser!", );
+            WorkflowDebugMessageParser* parser = debugInfo->getMessageParser();
+            SAFE_POINT(parser != nullptr, "Invalid debug message parser!", );
             parser->setSourceData(messages);
             parser->convertMessagesToDocuments(messageType, schemeName, messageNumber);
         }
