@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_SETTINGS_H_
-#define _U2_WORKFLOW_SETTINGS_H_
+#pragma once
 
 #include <QFont>
 #include <QObject>
@@ -28,8 +27,6 @@
 
 #include <U2Core/global.h>
 
-//#define SETTINGS QString("workflowview/")
-
 namespace U2 {
 
 class Watcher : public QObject {
@@ -55,42 +52,31 @@ public:
     static void setDebuggerEnabled(bool v);
 
     static QString defaultStyle();
-    static void setDefaultStyle(const QString &);
+    static void setDefaultStyle(const QString&);
 
     static QFont defaultFont();
-    static void setDefaultFont(const QFont &);
+    static void setDefaultFont(const QFont&);
 
     static const QString getUserDirectory();
-    static void setUserDirectory(const QString &dir);
+    static void setUserDirectory(const QString& dir);
 
     static QColor getBGColor();
-    static void setBGColor(const QColor &color);
-
-    static int getRunMode();
-    static void setRunMode(int md);
+    static void setBGColor(const QColor& color);
 
     static bool getScriptingMode();
     static void setScriptingMode(bool md);
 
-    static QString getCmdlineUgenePath();
-
-    static void setExternalToolDirectory(const QString &newDir);
+    static void setExternalToolDirectory(const QString& newDir);
     static const QString getExternalToolDirectory();
 
-    static void setIncludedElementsDirectory(const QString &newDir);
+    static void setIncludedElementsDirectory(const QString& newDir);
     static const QString getIncludedElementsDirectory();
 
     static bool isOutputDirectorySet();
-    static void setWorkflowOutputDirectory(const QString &newDir);
+    static void setWorkflowOutputDirectory(const QString& newDir);
     static const QString getWorkflowOutputDirectory();
 
-    /** Specifies whether hint for load schema button on the dashboard should be shown or not */
-    static bool isShowLoadButtonHint();
-    static void setShowLoadButtonHint(bool value);
-
-    static Watcher *const watcher;
+    static Watcher* const watcher;
 };
 
 }  // namespace U2
-
-#endif
