@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,30 +23,30 @@
 
 namespace U2 {
 
-ScriptableScheduler::ScriptableScheduler(Workflow::Schema *scheme)
+ScriptableScheduler::ScriptableScheduler(Workflow::Schema* scheme)
     : LastReadyScheduler(scheme) {
 }
 ScriptableScheduler::~ScriptableScheduler() {
 }
 
-void ScriptableScheduler::addActorToNextTick(const ActorId &actor) {
+void ScriptableScheduler::addActorToNextTick(const ActorId& actor) {
     nextTicks << actor;
 }
 
-QMap<int, QList<Workflow::Actor *>> ScriptableScheduler::getTopologicalSortedGraph() const {
+QMap<int, QList<Workflow::Actor*>> ScriptableScheduler::getTopologicalSortedGraph() const {
     return topologicSortedGraph;
 }
 
-void ScriptableScheduler::setScheme(Workflow::Schema *newScheme) {
-    Q_ASSERT(nullptr != newScheme && newScheme != schema);
+void ScriptableScheduler::setScheme(Workflow::Schema* newScheme) {
+    Q_ASSERT(newScheme != nullptr && newScheme != schema);
     schema = newScheme;
 }
 
-Workflow::Actor *ScriptableScheduler::getActorById(const ActorId &id) const {
-    return (nullptr != schema) ? schema->actorById(id) : nullptr;
+Workflow::Actor* ScriptableScheduler::getActorById(const ActorId& id) const {
+    return (schema != nullptr) ? schema->actorById(id) : nullptr;
 }
 
-WorkflowDebugStatus *ScriptableScheduler::getDebugStatus() const {
+WorkflowDebugStatus* ScriptableScheduler::getDebugStatus() const {
     return debugInfo;
 }
 
