@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WORKFLOW_RUN_FROM_SCRIPT_TASK_H_
-#define _U2_WORKFLOW_RUN_FROM_SCRIPT_TASK_H_
+#pragma once
 
 #include <U2Core/Task.h>
 
@@ -37,33 +36,31 @@ class WorkflowRunTask;
 class U2LANG_EXPORT BaseSerializedSchemeRunner : public Task {
     Q_OBJECT
 public:
-    BaseSerializedSchemeRunner(const QString &pathToScheme,
-                               ScriptableScheduler *scheduler,
-                               QStringList &outputFiles);
+    BaseSerializedSchemeRunner(const QString& pathToScheme,
+                               ScriptableScheduler* scheduler,
+                               QStringList& outputFiles);
 
 protected:
-    QStringList &workflowResultFiles;
+    QStringList& workflowResultFiles;
     const QString pathToScheme;
-    ScriptableScheduler *scheduler;
+    ScriptableScheduler* scheduler;
 };
 
 class U2LANG_EXPORT WorkflowRunSerializedSchemeTask : public BaseSerializedSchemeRunner {
     Q_OBJECT
 public:
-    WorkflowRunSerializedSchemeTask(const QString &pathToScheme,
-                                    ScriptableScheduler *scheduler,
-                                    QStringList &outputFiles);
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    WorkflowRunSerializedSchemeTask(const QString& pathToScheme,
+                                    ScriptableScheduler* scheduler,
+                                    QStringList& outputFiles);
+    QList<Task*> onSubTaskFinished(Task* subTask);
     QStringList getWorkflowOutputFiles() const;
 
 private:
-    LoadWorkflowTask *createLoadSchemeTask();
+    LoadWorkflowTask* createLoadSchemeTask();
 
     QSharedPointer<Workflow::Schema> scheme;
-    LoadWorkflowTask *loadTask;
-    WorkflowRunTask *runTask;
+    LoadWorkflowTask* loadTask;
+    WorkflowRunTask* runTask;
 };
 
 }  // namespace U2
-
-#endif  // _U2_WORKFLOW_RUN_FROM_SCRIPT_TASK_H_
