@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_OLDUWL_H_
-#define _U2_OLDUWL_H_
+#pragma once
 
 #include "Tokenizer.h"
 
@@ -32,8 +31,8 @@ namespace WorkflowSerialize {
 
 class OldUWL {
 public:
-    static void parseMarkerDefinition(Tokenizer &tokenizer, QMap<QString, Workflow::Actor *> &actorMap);
-    static void parseOldAttributes(Workflow::Actor *proc, ParsedPairs &pairs);
+    static void parseMarkerDefinition(Tokenizer& tokenizer, QMap<QString, Workflow::Actor*>& actorMap);
+    static void parseOldAttributes(Workflow::Actor* proc, ParsedPairs& pairs);
 };
 
 class OldConstants {
@@ -43,5 +42,3 @@ public:
 
 }  // namespace WorkflowSerialize
 }  // namespace U2
-
-#endif  // _U2_OLDUWL_H_
