@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,15 +30,15 @@ WorkflowTasksRegistry::WorkflowTasksRegistry() {
 }
 
 WorkflowTasksRegistry::~WorkflowTasksRegistry() {
-    foreach (const QString &id, readTasks.keys()) {
-        ReadDocumentTaskFactory *factory = readTasks.value(id);
+    foreach (const QString& id, readTasks.keys()) {
+        ReadDocumentTaskFactory* factory = readTasks.value(id);
         delete factory;
     }
     readTasks.clear();
 }
 
-bool WorkflowTasksRegistry::registerReadDocumentTaskFactory(ReadDocumentTaskFactory *factory) {
-    SAFE_POINT(nullptr != factory, "NULL ReadDocumentTaskFactory", false);
+bool WorkflowTasksRegistry::registerReadDocumentTaskFactory(ReadDocumentTaskFactory* factory) {
+    SAFE_POINT(factory != nullptr, "NULL ReadDocumentTaskFactory", false);
     SAFE_POINT(!readTasks.contains(factory->getId()),
                QString("Double ReadDocumentTaskFactory registering: %1").arg(factory->getId()),
                false);
@@ -47,7 +47,7 @@ bool WorkflowTasksRegistry::registerReadDocumentTaskFactory(ReadDocumentTaskFact
     return true;
 }
 
-ReadDocumentTaskFactory *WorkflowTasksRegistry::getReadDocumentTaskFactory(const QString &id) {
+ReadDocumentTaskFactory* WorkflowTasksRegistry::getReadDocumentTaskFactory(const QString& id) {
     return readTasks.value(id, nullptr);
 }
 
