@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -50,12 +50,12 @@ AppSettingsImpl::~AppSettingsImpl() {
 }
 
 void AppSettingsImpl::addPublicDbCredentials2Settings() {
-    Settings *settings = AppContext::getSettings();
-    SAFE_POINT(nullptr != settings, "Invalid application settings", );
+    Settings* settings = AppContext::getSettings();
+    SAFE_POINT(settings != nullptr, "Invalid application settings", );
     settings->setValue("/shared_database/recent_connections/" + U2DbiUtils::PUBLIC_DATABASE_NAME, U2DbiUtils::PUBLIC_DATABASE_URL);
 
-    PasswordStorage *passStorage = AppContext::getPasswordStorage();
-    SAFE_POINT(nullptr != passStorage, "Invalid shared DB passwords storage", );
+    PasswordStorage* passStorage = AppContext::getPasswordStorage();
+    SAFE_POINT(passStorage != nullptr, "Invalid shared DB passwords storage", );
     passStorage->addEntry(U2DbiUtils::PUBLIC_DATABASE_URL, U2DbiUtils::PUBLIC_DATABASE_PASSWORD, true);
 }
 
