@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CONSOLE_LOG_DRIVER_H_
-#define _U2_CONSOLE_LOG_DRIVER_H_
+#pragma once
 
 #include <U2Core/Log.h>
 
@@ -54,15 +53,15 @@ public:
     ConsoleLogDriver();
     virtual ~ConsoleLogDriver();
 
-    void onMessage(const LogMessage &msg);
+    void onMessage(const LogMessage& msg);
 
 private:
     void setCmdLineSettings();
-    QString getEffectiveCategory(const LogMessage &msg) const;
+    QString getEffectiveCategory(const LogMessage& msg) const;
     QString getLevelName(int i) const;
 
 private slots:
-    QString prepareText(const LogMessage &msg) const;
+    QString prepareText(const LogMessage& msg) const;
 
 private:
     bool printToConsole;
@@ -70,5 +69,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
