@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _DOCUMENT_FORMAT_REGISTRY_IMPL_H_
-#define _DOCUMENT_FORMAT_REGISTRY_IMPL_H_
+#pragma once
 
 #include <U2Core/DocumentImport.h>
 #include <U2Core/DocumentModel.h>
@@ -30,25 +29,25 @@ namespace U2 {
 class U2PRIVATE_EXPORT DocumentFormatRegistryImpl : public DocumentFormatRegistry {
     Q_OBJECT
 public:
-    DocumentFormatRegistryImpl(QObject *p = nullptr)
+    DocumentFormatRegistryImpl(QObject* p = nullptr)
         : DocumentFormatRegistry(p) {
         init();
     }
     ~DocumentFormatRegistryImpl() override;
 
-    virtual bool registerFormat(DocumentFormat *dfs) override;
+    virtual bool registerFormat(DocumentFormat* dfs) override;
 
-    virtual bool unregisterFormat(DocumentFormat *dfs) override;
+    virtual bool unregisterFormat(DocumentFormat* dfs) override;
 
     virtual QList<DocumentFormatId> getRegisteredFormats() const override;
 
-    virtual DocumentFormat *getFormatById(DocumentFormatId id) const override;
+    virtual DocumentFormat* getFormatById(DocumentFormatId id) const override;
 
-    virtual DocumentFormat *selectFormatByFileExtension(const QString &fileExt) const override;
+    virtual DocumentFormat* selectFormatByFileExtension(const QString& fileExt) const override;
 
-    virtual QList<DocumentFormatId> selectFormats(const DocumentFormatConstraints &c) const override;
+    virtual QList<DocumentFormatId> selectFormats(const DocumentFormatConstraints& c) const override;
 
-    virtual DocumentImportersRegistry *getImportSupport() override {
+    virtual DocumentImportersRegistry* getImportSupport() override {
         return &importSupport;
     }
 
@@ -60,4 +59,3 @@ private:
 };
 
 }  // namespace U2
-#endif
