@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +21,6 @@
 
 #include "IOAdapterRegistryImpl.h"
 
-#include <U2Core/DatabaseConnectionAdapter.h>
 #include <U2Core/HttpFileAdapter.h>
 #include <U2Core/LocalFileAdapter.h>
 #include <U2Core/StringAdapter.h>
@@ -29,7 +28,7 @@
 
 namespace U2 {
 
-bool IOAdapterRegistryImpl::registerIOAdapter(IOAdapterFactory *io) {
+bool IOAdapterRegistryImpl::registerIOAdapter(IOAdapterFactory* io) {
     if (getIOAdapterFactoryById(io->getAdapterId()) != nullptr) {
         return false;
     }
@@ -37,13 +36,13 @@ bool IOAdapterRegistryImpl::registerIOAdapter(IOAdapterFactory *io) {
     return true;
 }
 
-bool IOAdapterRegistryImpl::unregisterIOAdapter(IOAdapterFactory *io) {
+bool IOAdapterRegistryImpl::unregisterIOAdapter(IOAdapterFactory* io) {
     int n = adapters.removeAll(io);
     return n > 0;
 }
 
-IOAdapterFactory *IOAdapterRegistryImpl::getIOAdapterFactoryById(IOAdapterId id) const {
-    foreach (IOAdapterFactory *io, adapters) {
+IOAdapterFactory* IOAdapterRegistryImpl::getIOAdapterFactoryById(IOAdapterId id) const {
+    foreach (IOAdapterFactory* io, adapters) {
         if (io->getAdapterId() == id) {
             return io;
         }
@@ -58,7 +57,6 @@ void IOAdapterRegistryImpl::init() {
     registerIOAdapter(new GzippedHttpFileAdapterFactory(this));
     registerIOAdapter(new VFSAdapterFactory(this));
     registerIOAdapter(new StringAdapterFactory(this));
-    registerIOAdapter(new DatabaseConnectionAdapterFactory(this));
 }
 
 }  // namespace U2
