@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _IOADAPTER_REGISTRY_IMPL_H_
-#define _IOADAPTER_REGISTRY_IMPL_H_
+#pragma once
 
 #include <U2Core/IOAdapter.h>
 
@@ -28,26 +27,25 @@ namespace U2 {
 
 class U2PRIVATE_EXPORT IOAdapterRegistryImpl : public IOAdapterRegistry {
 public:
-    IOAdapterRegistryImpl(QObject *p = nullptr)
+    IOAdapterRegistryImpl(QObject* p = nullptr)
         : IOAdapterRegistry(p) {
         init();
     }
 
-    virtual bool registerIOAdapter(IOAdapterFactory *io);
+    virtual bool registerIOAdapter(IOAdapterFactory* io);
 
-    virtual bool unregisterIOAdapter(IOAdapterFactory *io);
+    virtual bool unregisterIOAdapter(IOAdapterFactory* io);
 
-    virtual const QList<IOAdapterFactory *> &getRegisteredIOAdapters() const {
+    virtual const QList<IOAdapterFactory*>& getRegisteredIOAdapters() const {
         return adapters;
     }
 
-    virtual IOAdapterFactory *getIOAdapterFactoryById(IOAdapterId id) const;
+    virtual IOAdapterFactory* getIOAdapterFactoryById(IOAdapterId id) const;
 
 private:
     void init();
 
-    QList<IOAdapterFactory *> adapters;
+    QList<IOAdapterFactory*> adapters;
 };
 
 }  // namespace U2
-#endif
