@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,14 +26,27 @@
 #include <U2Core/AppContext.h>
 #include <U2Core/CMDLineRegistry.h>
 #include <U2Core/Settings.h>
+#include <U2Core/U2SafePoints.h>
 
 #define SETTINGS_ROOT QString("log_settings/")
 
 namespace U2 {
 
-QString LogCategories::localizedLevelNames[LogLevel_NumLevels];
+LoggerSettings::LoggerSettings()
+    : activeLevelFlag(LogLevel_NumLevels, false) {
+}
+
+QVector<QString> LogCategories::localizedLevelNames;
+
+const QString& LogCategories::getLocalizedLevelName(const LogLevel& logLevel) {
+    SAFE_POINT(logLevel >= 0 && logLevel < LogLevel_NumLevels,
+               "Illegal log level: " + QString::number(logLevel),
+               localizedLevelNames[LogLevel_TRACE]);
+    return localizedLevelNames[logLevel];
+}
 
 void LogCategories::init() {
+    localizedLevelNames.resize(LogLevel_NumLevels);
     localizedLevelNames[LogLevel_TRACE] = tr("TRACE");
     localizedLevelNames[LogLevel_DETAILS] = tr("DETAILS");
     localizedLevelNames[LogLevel_INFO] = tr("INFO");
@@ -41,40 +54,27 @@ void LogCategories::init() {
 }
 
 LogSettings::LogSettings()
-    : showDate(false),
-      showLevel(false),
-      showCategory(false),
-      enableColor(false),
-      toFile(false) {
-    // created in not inited state
-    memset(activeLevelGlobalFlag, 0, sizeof(bool) * LogLevel_NumLevels);
+    : levelColors(LogLevel_NumLevels), activeLevelGlobalFlag(LogLevel_NumLevels, false) {
 }
 
-const LoggerSettings &LogSettings::getLoggerSettings(const QString &cName) {
+const LoggerSettings& LogSettings::getLoggerSettings(const QString& cName) {
     QHash<QString, LoggerSettings>::const_iterator it = categories.find(cName);
     if (it == categories.end()) {
         reinitCategories();
         it = categories.find(cName);
         assert(it != categories.end());
     }
-    const LoggerSettings &cs = it.value();
+    const LoggerSettings& cs = it.value();
     return cs;
 }
 
 void LogSettings::reinitAll() {
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
 
-    for (int i = 0; i < LogLevel_NumLevels; i++) {
-        if (i == LogLevel_TRACE) {
-            levelColors[i] = QColor(Qt::darkGray).name();
-        } else if (i == LogLevel_INFO) {
-            levelColors[i] = QColor(Qt::darkBlue).name();
-        } else if (i == LogLevel_ERROR) {
-            levelColors[i] = QColor(Qt::darkRed).name();
-        } else {
-            levelColors[i] = QColor(Qt::black).name();
-        }
-    }
+    levelColors.fill(QColor(Qt::black).name());
+    levelColors[LogLevel_TRACE] = QColor(Qt::darkGray).name();
+    levelColors[LogLevel_INFO] = QColor(Qt::darkBlue).name();
+    levelColors[LogLevel_ERROR] = QColor(Qt::darkRed).name();
 
     showDate = s->getValue(SETTINGS_ROOT + "showDate", true).toBool();
     showLevel = s->getValue(SETTINGS_ROOT + "showLevel", true).toBool();
@@ -89,40 +89,41 @@ void LogSettings::reinitAll() {
 
 void LogSettings::reinitCategories() {
     LogCategories::init();
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
     for (int i = 0; i < LogLevel_NumLevels; i++) {
         activeLevelGlobalFlag[i] = s->getValue(SETTINGS_ROOT + "activeFlagLevel" + QString::number(i), i >= LogLevel_INFO).toBool();
     }
 
-    LogServer *ls = LogServer::getInstance();
-    const QStringList &categoryList = ls->getCategories();
-    foreach (const QString &name, categoryList) {
+    LogServer* ls = LogServer::getInstance();
+    const QStringList& categoryList = ls->getCategories();
+    foreach (const QString& name, categoryList) {
         if (!categories.contains(name)) {
             LoggerSettings cs;
             cs.categoryName = name;
             for (int i = 0; i < LogLevel_NumLevels; i++) {
-                cs.activeLevelFlag[i] = s->getValue(SETTINGS_ROOT + "categories/" + cs.categoryName + "/activeFlagLevel" + QString::number(i), activeLevelGlobalFlag[i]).toBool();
+                QString key = SETTINGS_ROOT + "categories/" + cs.categoryName + "/activeFlagLevel" + QString::number(i);
+                cs.activeLevelFlag[i] = s->getValue(key, activeLevelGlobalFlag[i]).toBool();
             }
             categories[name] = cs;
         }
     }
 }
 
-void LogSettings::removeCategory(const QString &name) {
+void LogSettings::removeCategory(const QString& name) {
     int n = categories.remove(name);
     assert(n == 1);
     Q_UNUSED(n);
 }
 
-void LogSettings::addCategory(const LoggerSettings &newcs) {
+void LogSettings::addCategory(const LoggerSettings& newcs) {
     assert(!categories.contains(newcs.categoryName));
     categories[newcs.categoryName] = newcs;
 }
 
 void LogSettings::save() {
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
 
-    foreach (const LoggerSettings &cs, categories.values()) {
+    foreach (const LoggerSettings& cs, categories.values()) {
         for (int i = 0; i < LogLevel_NumLevels; i++) {
             s->setValue(SETTINGS_ROOT + "categories/" + cs.categoryName + "/activeFlagLevel" + QString::number(i), cs.activeLevelFlag[i]);
         }
@@ -141,13 +142,16 @@ void LogSettings::save() {
     s->setValue(SETTINGS_ROOT + "outFilePath", outputFile);
 }
 
-bool LogSettings::operator==(const LogSettings &other) const {
-    bool res = levelColors == other.levelColors && activeLevelGlobalFlag == other.activeLevelGlobalFlag && showDate == other.showDate && showLevel == other.showLevel && showCategory == other.showCategory && categories == other.categories;
-
-    return res;
+bool LogSettings::operator==(const LogSettings& other) const {
+    return levelColors == other.levelColors &&
+           activeLevelGlobalFlag == other.activeLevelGlobalFlag &&
+           showDate == other.showDate &&
+           showLevel == other.showLevel &&
+           showCategory == other.showCategory &&
+           categories == other.categories;
 }
 
-void LogSettingsHolder::setSettings(const LogSettings &s) {
+void LogSettingsHolder::setSettings(const LogSettings& s) {
     if (settings == s) {
         return;
     }
