@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,10 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LOG_SETTINGS_H_
-#define _U2_LOG_SETTINGS_H_
+#pragma once
 
 #include <QHash>
+#include <QVector>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/Log.h>
@@ -31,60 +31,57 @@
 namespace U2 {
 
 struct U2PRIVATE_EXPORT LoggerSettings {
-    LoggerSettings() {
-        std::fill(activeLevelFlag, activeLevelFlag + LogLevel_NumLevels, 0);
-    }
+    LoggerSettings();
 
-    bool operator==(const LoggerSettings &other) const {
+    bool operator==(const LoggerSettings& other) const {
         return categoryName == other.categoryName && activeLevelFlag == other.activeLevelFlag;
     }
 
     QString categoryName;
-    bool activeLevelFlag[LogLevel_NumLevels];
+    QVector<bool> activeLevelFlag;
 };
 
 class U2PRIVATE_EXPORT LogCategories : QObject {
     Q_OBJECT
 public:
     static void init();
-    static const QString getLocalizedLevelName(LogLevel l) {
-        return localizedLevelNames[l];
-    }
+
+    static const QString& getLocalizedLevelName(const LogLevel& logLevel);
 
 protected:
-    static QString localizedLevelNames[LogLevel_NumLevels];
+    static QVector<QString> localizedLevelNames;
 };
 
 class U2PRIVATE_EXPORT LogSettings {
 public:
     LogSettings();
 
-    void removeCategory(const QString &name);
+    void removeCategory(const QString& name);
 
-    void addCategory(const LoggerSettings &newcs);
+    void addCategory(const LoggerSettings& newcs);
 
-    const LoggerSettings &getLoggerSettings(const QString &cName);
+    const LoggerSettings& getLoggerSettings(const QString& cName);
 
     const QHash<QString, LoggerSettings> getLoggerSettings() const {
         return categories;
     }
 
-    bool operator==(const LogSettings &other) const;
+    bool operator==(const LogSettings& other) const;
 
     void save();
 
     void reinitAll();
     void reinitCategories();
 
-    QString levelColors[LogLevel_NumLevels];
-    bool activeLevelGlobalFlag[LogLevel_NumLevels];
+    QVector<QString> levelColors;
+    QVector<bool> activeLevelGlobalFlag;
     QString logPattern;
 
-    bool showDate;
-    bool showLevel;
-    bool showCategory;
-    bool enableColor;
-    bool toFile;
+    bool showDate = false;
+    bool showLevel = false;
+    bool showCategory = false;
+    bool enableColor = false;
+    bool toFile = false;
     QString outputFile;
 
     // private:
@@ -93,16 +90,14 @@ public:
 
 class U2PRIVATE_EXPORT LogSettingsHolder {
 public:
-    const LogSettings &getSettings() const {
+    const LogSettings& getSettings() const {
         return settings;
     }
 
-    virtual void setSettings(const LogSettings &s);
+    virtual void setSettings(const LogSettings& s);
 
 protected:
     mutable LogSettings settings;
 };
 
 }  // namespace U2
-
-#endif
