@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PLUGINDESCRIPTOR_H_
-#define _U2_PLUGINDESCRIPTOR_H_
+#pragma once
 
 #include <QObject>
 
@@ -61,7 +60,7 @@ public:
 
     PlatformName name;
     PlatformArch arch;
-    bool operator==(const PlatformInfo &p) const {
+    bool operator==(const PlatformInfo& p) const {
         return name == p.name && arch == p.arch;
     }
 };
@@ -90,10 +89,10 @@ public:
     QList<DependsInfo> dependsList;
 
     bool isValid() const {
-        return !id.isEmpty() && !pluginVersion.text.isEmpty() && !ugeneVersion.text.isEmpty() && !libraryUrl.isEmpty();
+        return !id.isEmpty() && pluginVersion.isValid() && ugeneVersion.isValid() && !libraryUrl.isEmpty();
     }
 
-    bool operator==(const PluginDesc &pd) const;
+    bool operator==(const PluginDesc& pd) const;
 };
 
 class U2PRIVATE_EXPORT PluginDescriptorHelper : public QObject {
@@ -103,12 +102,10 @@ private:
     }
 
 public:
-    static PluginDesc readPluginDescriptor(const QString &url, QString &error);
+    static PluginDesc readPluginDescriptor(const QString& url, QString& error);
 
     // orders plugins by loading order
-    static QList<PluginDesc> orderPlugins(const QList<PluginDesc> &unordered, QString &err);
+    static QList<PluginDesc> orderPlugins(const QList<PluginDesc>& unordered, QString& err);
 };
 
 }  // namespace U2
-
-#endif
