@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,20 +21,22 @@
 
 #include "SettingsImpl.h"
 
+#include <QCryptographicHash>
 #include <QDir>
 #include <QProcess>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/CMDLineCoreOptions.h>
 #include <U2Core/CMDLineRegistry.h>
+#include <U2Core/U2SafePoints.h>
 #include <U2Core/Version.h>
 
 namespace U2 {
 
-static QString findKey(const QStringList &envList, const QString &key) {
+static QString findKey(const QStringList& envList, const QString& key) {
     QString prefix = key + "=";
     QString result;
-    foreach (const QString &var, envList) {
+    foreach (const QString& var, envList) {
         if (var.startsWith(prefix)) {
             result = var.mid(prefix.length());
             break;
@@ -43,7 +45,7 @@ static QString findKey(const QStringList &envList, const QString &key) {
     return result;
 }
 
-static QString preparePath(const QString &pathName) {
+static QString preparePath(const QString& pathName) {
     QString result = pathName.trimmed().replace("//", "/").replace("\\", "/");
     if (result.endsWith("/")) {
         result = result.left(result.length() - 1);
@@ -61,7 +63,7 @@ SettingsImpl::SettingsImpl(QSettings::Scope scope) {
         bool localCfg = false;
         QDir dir(QDir::current());
         QFileInfoList dirEntries = dir.entryInfoList();
-        foreach (const QFileInfo &entry, dirEntries) {
+        foreach (const QFileInfo& entry, dirEntries) {
             if (entry.fileName() == configFileName) {
                 fileName = entry.filePath();
                 localCfg = true;
@@ -77,11 +79,8 @@ SettingsImpl::SettingsImpl(QSettings::Scope scope) {
     } else {
         fileName = findKey(envList, U2_SYSTEM_INI);
     }
-#ifdef Q_OS_DARWIN
-    QSettings::Format format = QSettings::NativeFormat;
-#else
-    QSettings::Format format = QSettings::IniFormat;
-#endif
+    bool isInTestMode = qgetenv("UGENE_GUI_TEST") == "1";
+    QSettings::Format format = isInTestMode || !isOsMac() ? QSettings::IniFormat : QSettings::NativeFormat;
     if (fileName.isEmpty()) {
         settings = new QSettings(format, scope, U2_ORGANIZATION_NAME, U2_PRODUCT_NAME, this);
     } else {
@@ -93,58 +92,52 @@ SettingsImpl::~SettingsImpl() {
     settings->sync();
 }
 
-bool SettingsImpl::contains(const QString &pathName) const {
+bool SettingsImpl::contains(const QString& pathName) const {
     QMutexLocker lock(&threadSafityLock);
 
     QString key = preparePath(pathName);
     return settings->contains(key);
 }
 
-void SettingsImpl::remove(const QString &pathName) {
+void SettingsImpl::remove(const QString& pathName) {
     QMutexLocker lock(&threadSafityLock);
 
     QString key = preparePath(pathName);
     settings->remove(key);
 }
 
-QVariant SettingsImpl::getValue(const QString &pathName, const QVariant &defaultValue, bool versionedValue) const {
+QVariant SettingsImpl::getValue(const QString& pathName, const QVariant& defaultValue, bool versionedValue, bool pathValue) const {
+    SAFE_POINT(!pathValue || (pathValue && versionedValue), "'pathValue' must be 'versionedValue'!", defaultValue);
     QMutexLocker lock(&threadSafityLock);
 
-    QString path = pathName;
-    QString key = preparePath(path);
+    QString key = preparePath(pathName);
 
     if (versionedValue) {
-        // find versioned value in the key path
+        QString keyWithExtras = pathValue ? toPathKey(key) : toVersionKey(key);
+
         settings->beginGroup(key);
         QStringList allKeys = settings->allKeys();
         settings->endGroup();
 
-        QString versionedKey = toVersionKey(key);
-
-        bool found = false;
-        foreach (const QString &settingsKey, allKeys) {
-            if (QString(key + "/" + settingsKey) == versionedKey) {
-                found = true;
-                break;
+        foreach (const QString& settingsKey, allKeys) {
+            if (QString(key + "/" + settingsKey) == keyWithExtras) {
+                return settings->value(keyWithExtras, defaultValue);
             }
         }
-        if (!found) {
-            return defaultValue;
-        }
-
-        key = versionedKey;
+        return defaultValue;
     }
-
     return settings->value(key, defaultValue);
 }
 
-void SettingsImpl::setValue(const QString &pathName, const QVariant &value, bool versionedValue) {
+void SettingsImpl::setValue(const QString& pathName, const QVariant& value, bool versionedValue, bool pathValue) {
+    SAFE_POINT(!pathValue || (pathValue && versionedValue), "'pathValue' must be 'versionedValue'!", );
     QMutexLocker lock(&threadSafityLock);
 
-    QString path = pathName;
-    QString key = preparePath(path);
+    QString key = preparePath(pathName);
 
-    if (versionedValue) {
+    if (pathValue && versionedValue) {
+        key = toPathKey(key);
+    } else if (versionedValue) {
         // TODO: delete versioned keys?
 
         // create versioned key
@@ -154,25 +147,22 @@ void SettingsImpl::setValue(const QString &pathName, const QVariant &value, bool
     settings->setValue(key, value);
 }
 
-QString SettingsImpl::toVersionKey(const QString &key) const {
-    static QString VERSION_KEY_SUFFIX = "/" + Version::appVersion().text;
-
-    if (key.endsWith("/")) {
-        return key + VERSION_KEY_SUFFIX + "/";
-    }
-    return key + VERSION_KEY_SUFFIX;
+QString SettingsImpl::toVersionKey(const QString& key) const {
+    static QString VERSION_KEY_SUFFIX = "/" + Version::appVersion().toString();
+    return key + VERSION_KEY_SUFFIX + (key.endsWith("/") ? "/" : "");
 }
 
-QString SettingsImpl::toMinorVersionKey(const QString &key) const {
+QString SettingsImpl::toMinorVersionKey(const QString& key) const {
     static QString VERSION_KEY_SUFFIX = "/" + QString::number(Version::appVersion().major) + "." + QString::number(Version::appVersion().minor);
-
-    if (key.endsWith("/")) {
-        return key + VERSION_KEY_SUFFIX + "/";
-    }
-    return key + VERSION_KEY_SUFFIX;
+    return key + VERSION_KEY_SUFFIX + (key.endsWith("/") ? "/" : "");
 }
 
-QStringList SettingsImpl::getAllKeys(const QString &path) const {
+QString SettingsImpl::toPathKey(const QString& key) const {
+    static QString PATH_KEY_SUFFIX = "/" + QString(QCryptographicHash::hash(QCoreApplication::applicationDirPath().toUtf8(), QCryptographicHash::Md4).toHex());
+    return toVersionKey(key) + PATH_KEY_SUFFIX + (key.endsWith("/") ? "/" : "");
+}
+
+QStringList SettingsImpl::getAllKeys(const QString& path) const {
     QMutexLocker lock(&threadSafityLock);
 
     QString key = preparePath(path);
@@ -182,7 +172,7 @@ QStringList SettingsImpl::getAllKeys(const QString &path) const {
     return allKeys;
 }
 
-QStringList SettingsImpl::getChildGroups(const QString &path) const {
+QStringList SettingsImpl::getChildGroups(const QString& path) const {
     QMutexLocker lock(&threadSafityLock);
 
     QString key = preparePath(path);
@@ -192,7 +182,7 @@ QStringList SettingsImpl::getChildGroups(const QString &path) const {
     return allKeys;
 }
 
-void SettingsImpl::cleanSection(const QString &path) {
+void SettingsImpl::cleanSection(const QString& path) {
     QStringList keyList = getAllKeys(path);
     foreach (QString key, keyList) {
         remove(key);
