@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SETTINGS_IMPL
-#define _U2_SETTINGS_IMPL
+#pragma once
 
 #include <QMutex>
 #include <QSettings>
@@ -35,18 +34,21 @@ public:
     SettingsImpl(QSettings::Scope scope);
     ~SettingsImpl();
 
-    QStringList getAllKeys(const QString &path) const;
-    QStringList getChildGroups(const QString &path) const;
-    void cleanSection(const QString &path);
+    QStringList getAllKeys(const QString& path) const;
+    QStringList getChildGroups(const QString& path) const;
+    void cleanSection(const QString& path);
 
-    virtual bool contains(const QString &key) const;
-    virtual void remove(const QString &key);
+    virtual bool contains(const QString& key) const;
+    virtual void remove(const QString& key);
 
-    virtual QVariant getValue(const QString &key, const QVariant &defaultValue = QVariant(), bool versionedValue = false) const;
-    virtual void setValue(const QString &key, const QVariant &value, bool versionedValue = false);
+    virtual QVariant getValue(const QString& key, const QVariant& defaultValue = QVariant(), bool versionedValue = false, bool pathValue = false) const;
+    virtual void setValue(const QString& key, const QVariant& value, bool versionedValue = false, bool pathValue = false);
 
-    virtual QString toVersionKey(const QString &key) const;
-    virtual QString toMinorVersionKey(const QString &key) const;
+    virtual QString toVersionKey(const QString& key) const;
+    virtual QString toMinorVersionKey(const QString& key) const;
+
+    /* Add current ugene working directory path to key */
+    virtual QString toPathKey(const QString& key) const;
 
     virtual void sync();
 
@@ -54,7 +56,6 @@ public:
 
 private:
     mutable QMutex threadSafityLock;
-    QSettings *settings;
+    QSettings* settings;
 };
 }  // namespace U2
-#endif
