@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SLEEP_PREVENTER_MAC_H_
-#define _U2_SLEEP_PREVENTER_MAC_H_
+#pragma once
 
 #include "TaskSchedulerImpl.h"
 
@@ -37,7 +36,7 @@ public:
 
 private:
     class Private;
-    Private *d;
+    Private* d;
 
     int refCount;
     bool isActive;
@@ -51,5 +50,3 @@ class SleepPreventerMac : public SleepPreventer {
 #endif
 
 }  // namespace U2
-
-#endif  // _U2_SLEEP_PREVENTER_MAC_H_
