@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CRASH_HANDLER_H_
-#define _U2_CRASH_HANDLER_H_
+#pragma once
 
 #include <QCoreApplication>
 #include <QMutex>
@@ -61,23 +60,21 @@ public:
     static void setSendCrashReports(bool sendReports);
 
     static void releaseReserve();
-    static void handleException(const QString &exceptionType, const QString &dumpUrl = "");
+    static void handleException(const QString& exceptionType, const QString& dumpUrl = "");
 
 private:
     static void preallocateReservedSpace();
     static void setupLogCache();
     static void setupPrivateHandler();
 
-    static void getSubTasks(Task *t, QString &list, int lvl);
-    static void runMonitorProcess(const CrashHandlerArgsHelper &helper);
-    static QString generateReport(const QString &exceptionType, int maxReportSize);
+    static void getSubTasks(Task* t, QString& list, int lvl);
+    static void runMonitorProcess(const CrashHandlerArgsHelper& helper);
+    static QString generateReport(const QString& exceptionType, int maxReportSize);
 
-    static CrashHandlerPrivate *crashHandlerPrivate;
-    static char *buffer;
-    static LogCache *crashLogCache;
+    static CrashHandlerPrivate* crashHandlerPrivate;
+    static char* buffer;
+    static LogCache* crashLogCache;
     static bool sendCrashReports;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CRASH_HANDLER_H_
