@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -78,8 +78,8 @@ QStringList CrashHandlerArgsHelper::getArguments() const {
     }
 
     if (qgetenv(ENV_GUI_TEST).toInt() == 1) {
-        CMDLineRegistry *cmdLine = AppContext::getCMDLineRegistry();
-        if (nullptr != cmdLine) {
+        CMDLineRegistry* cmdLine = AppContext::getCMDLineRegistry();
+        if (cmdLine != nullptr) {
             QString testName = cmdLine->getParameterValue(CMDLineCoreOptions::LAUNCH_GUI_TEST);
             args << SILENT_SEND_FILE_ARG;
             args << FAILED_TEST_FILE_ARG << testName;
@@ -89,7 +89,7 @@ QStringList CrashHandlerArgsHelper::getArguments() const {
     return args;
 }
 
-void CrashHandlerArgsHelper::setReportData(const QString &data) {
+void CrashHandlerArgsHelper::setReportData(const QString& data) {
     if (useFile) {
         QByteArray bytes = data.toUtf8();
         file.write(bytes);
@@ -99,11 +99,11 @@ void CrashHandlerArgsHelper::setReportData(const QString &data) {
     }
 }
 
-void CrashHandlerArgsHelper::setDumpUrl(const QString &url) {
+void CrashHandlerArgsHelper::setDumpUrl(const QString& url) {
     dumpUrl = url;
 }
 
-QString CrashHandlerArgsHelper::findTempDir(U2OpStatus &os) {
+QString CrashHandlerArgsHelper::findTempDir(U2OpStatus& os) {
     if (FileAndDirectoryUtils::isDirectoryWritable(QDir::tempPath())) {
         return QDir::tempPath();
     }
@@ -114,7 +114,7 @@ QString CrashHandlerArgsHelper::findTempDir(U2OpStatus &os) {
     return "";
 }
 
-QString CrashHandlerArgsHelper::findFilePathToWrite(U2OpStatus &os) {
+QString CrashHandlerArgsHelper::findFilePathToWrite(U2OpStatus& os) {
     QString dirPath = findTempDir(os);
     CHECK_OP(os, "");
 
@@ -122,8 +122,8 @@ QString CrashHandlerArgsHelper::findFilePathToWrite(U2OpStatus &os) {
 }
 
 void CrashHandlerArgsHelper::shutdownSessionDatabase() {
-    U2DbiRegistry *dbiReg = AppContext::getDbiRegistry();
-    CHECK(nullptr != dbiReg, );
+    U2DbiRegistry* dbiReg = AppContext::getDbiRegistry();
+    CHECK(dbiReg != nullptr, );
 
     U2OpStatusImpl os;
     const QString url = dbiReg->shutdownSessionDbi(os);
