@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CRASH_HANDLER_PRIVATE_H_
-#define _U2_CRASH_HANDLER_PRIVATE_H_
+#pragma once
 
 #include <QString>
 
@@ -43,11 +42,9 @@ public:
     virtual QString getAdditionalInfo() const;
 
 protected:
-    static void handleException(const QString &exceptionType, const QString &dumpUrl);
+    static void handleException(const QString& exceptionType, const QString& dumpUrl);
 
-    google_breakpad::ExceptionHandler *breakpadHandler;
+    google_breakpad::ExceptionHandler* breakpadHandler;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CRASH_HANDLER_PRIVATE_H_
