@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -79,9 +79,9 @@ void CrashHandlerPrivateUnixNotMac::storeStackTrace() {
     sprintf(pid_buf, "%d", getpid());
     char name_buf[512];
     name_buf[readlink(path.toLatin1().data(), name_buf, 511)] = 0;
-    FILE *fp = fopen(STACKTRACE_FILE_PATH.toLocal8Bit().constData(), "w+");
-    stacktraceFileSucessfullyCreated = (nullptr != fp);
-    void *stackTrace[1024];
+    FILE* fp = fopen(STACKTRACE_FILE_PATH.toLocal8Bit().constData(), "w+");
+    stacktraceFileSucessfullyCreated = (fp != nullptr);
+    void* stackTrace[1024];
     int frames = backtrace(stackTrace, 1024);
     backtrace_symbols_fd(stackTrace, frames, fileno(fp));
     const int closed = fclose(fp);
@@ -114,15 +114,15 @@ QString CrashHandlerPrivateUnixNotMac::getAdditionalInfo() const {
     return info;
 }
 
-bool CrashHandlerPrivateUnixNotMac::breakpadCallback(const google_breakpad::MinidumpDescriptor &descriptor,
-                                                     void *context,
+bool CrashHandlerPrivateUnixNotMac::breakpadCallback(const google_breakpad::MinidumpDescriptor& descriptor,
+                                                     void* context,
                                                      bool succeeded) {
     QString dumpPath;
     if (succeeded) {
         dumpPath = QString::fromLocal8Bit(descriptor.path());
     }
 
-    CrashHandlerPrivateUnixNotMac *privateHandler = static_cast<CrashHandlerPrivateUnixNotMac *>(context);
+    auto privateHandler = static_cast<CrashHandlerPrivateUnixNotMac*>(context);
     privateHandler->dumpWasSuccessfullySaved = succeeded;
 
     handleException(privateHandler->lastExceptionText, dumpPath);
@@ -130,18 +130,18 @@ bool CrashHandlerPrivateUnixNotMac::breakpadCallback(const google_breakpad::Mini
     return true;
 }
 
-bool CrashHandlerPrivateUnixNotMac::crashContextCallback(const void *crash_context,
+bool CrashHandlerPrivateUnixNotMac::crashContextCallback(const void* crash_context,
                                                          size_t /*crash_context_size*/,
-                                                         void *context) {
-    CrashHandlerPrivateUnixNotMac *privateHandler = static_cast<CrashHandlerPrivateUnixNotMac *>(context);
-    const google_breakpad::ExceptionHandler::CrashContext *crashContext = static_cast<const google_breakpad::ExceptionHandler::CrashContext *>(crash_context);
+                                                         void* context) {
+    auto privateHandler = static_cast<CrashHandlerPrivateUnixNotMac*>(context);
+    auto crashContext = static_cast<const google_breakpad::ExceptionHandler::CrashContext*>(crash_context);
     privateHandler->lastExceptionText = getExceptionText(crashContext);
     return false;
 }
 
-QString CrashHandlerPrivateUnixNotMac::getExceptionText(const google_breakpad::ExceptionHandler::CrashContext *crashContext) {
+QString CrashHandlerPrivateUnixNotMac::getExceptionText(const google_breakpad::ExceptionHandler::CrashContext* crashContext) {
     QString exceptionText = "Unhandled exception";
-    CHECK(nullptr != crashContext, "C++ exception|" + exceptionText);
+    CHECK(crashContext != nullptr, "C++ exception|" + exceptionText);
 
     switch (crashContext->siginfo.si_signo) {
         case SIGBUS:
