@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CRASH_HANDLER_PRIVATE_UNIX_NOT_MAC_H_
-#define _U2_CRASH_HANDLER_PRIVATE_UNIX_NOT_MAC_H_
+#pragma once
 
 #include <qglobal.h>
 #if defined(Q_OS_UNIX) && !defined(Q_OS_DARWIN)
@@ -43,13 +42,13 @@ public:
     QString getAdditionalInfo() const;
 
 private:
-    static bool breakpadCallback(const google_breakpad::MinidumpDescriptor &descriptor,
-                                 void *context,
+    static bool breakpadCallback(const google_breakpad::MinidumpDescriptor& descriptor,
+                                 void* context,
                                  bool succeeded);
-    static bool crashContextCallback(const void *crash_context,
+    static bool crashContextCallback(const void* crash_context,
                                      size_t crash_context_size,
-                                     void *context);
-    static QString getExceptionText(const google_breakpad::ExceptionHandler::CrashContext *crashContext);
+                                     void* context);
+    static QString getExceptionText(const google_breakpad::ExceptionHandler::CrashContext* crashContext);
 
     QString lastExceptionText;
     bool stacktraceFileWasSucessfullyRemoved;
@@ -64,5 +63,3 @@ private:
 }  // namespace U2
 
 #endif
-
-#endif  // _U2_CRASH_HANDLER_PRIVATE_UNIX_NOT_MAC_H_
