@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,24 +21,17 @@
 
 #include <qglobal.h>
 #ifdef Q_OS_WIN
+#    ifndef _DEBUG
+#        include <QDir>
+#    endif
 
 #    include <client/windows/handler/exception_handler.h>
 
-#    include <QDir>
-
-#    include <U2Core/AppContext.h>
 #    include <U2Core/U2SafePoints.h>
 
-#    include "CrashHandler.h"
 #    include "CrashHandlerArgsHelper.h"
 #    include "CrashHandlerPrivateWin.h"
 
-#    if defined(Q_OS_WIN32)
-extern "C" {
-void rollbackStack();
-}
-#    endif
-
 namespace U2 {
 
 CrashHandlerPrivateWin::CrashHandlerPrivateWin()
@@ -85,18 +78,18 @@ QString CrashHandlerPrivateWin::getAdditionalInfo() const {
     return info;
 }
 
-bool CrashHandlerPrivateWin::breakpadCallback(const wchar_t *dump_path,
-                                              const wchar_t *minidump_id,
-                                              void *context,
-                                              EXCEPTION_POINTERS *exinfo,
-                                              MDRawAssertionInfo * /*assertion*/,
+bool CrashHandlerPrivateWin::breakpadCallback(const wchar_t* dump_path,
+                                              const wchar_t* minidump_id,
+                                              void* context,
+                                              EXCEPTION_POINTERS* exinfo,
+                                              MDRawAssertionInfo* /*assertion*/,
                                               bool succeeded) {
     QString dumpPath;
     if (succeeded) {
         dumpPath = QString::fromStdWString(dump_path) + "/" + QString::fromStdWString(minidump_id) + ".dmp";
     }
 
-    CrashHandlerPrivateWin *privateHandler = static_cast<CrashHandlerPrivateWin *>(context);
+    auto privateHandler = static_cast<CrashHandlerPrivateWin*>(context);
 #    ifdef Q_OS_WIN64
     privateHandler->walkStack(exinfo);
 #    endif
@@ -106,18 +99,13 @@ bool CrashHandlerPrivateWin::breakpadCallback(const wchar_t *dump_path,
     return true;
 }
 
-void CrashHandlerPrivateWin::walkStack(EXCEPTION_POINTERS *exinfo) {
-    if (exinfo->ExceptionRecord->ExceptionCode == EXCEPTION_STACK_OVERFLOW) {
-#    if defined(Q_OS_WIN32)
-        rollbackStack();  // TODO:need hack for x86_64
-#    endif
-    }
+void CrashHandlerPrivateWin::walkStack(EXCEPTION_POINTERS* exinfo) {
     st.ShowCallstack(OpenThread(READ_CONTROL, false, breakpadHandler->get_requesting_thread_id()), exinfo->ContextRecord);
 }
 
-QString CrashHandlerPrivateWin::getExceptionText(EXCEPTION_POINTERS *exinfo) {
+QString CrashHandlerPrivateWin::getExceptionText(EXCEPTION_POINTERS* exinfo) {
     QString exceptionText = "Unhandled exception";
-    CHECK(nullptr != exinfo, "C++ exception|" + exceptionText);
+    CHECK(exinfo != nullptr, "C++ exception|" + exceptionText);
 
     switch (exinfo->ExceptionRecord->ExceptionCode) {
         case EXCEPTION_ACCESS_VIOLATION:
