@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CRASH_LOG_CACHE_H_
-#define _U2_CRASH_LOG_CACHE_H_
+#pragma once
 
 #include <U2Core/LogCache.h>
 
@@ -29,7 +28,7 @@ namespace U2 {
 class CrashLogCache : public LogCache {
     Q_OBJECT
 public:
-    void onMessage(const LogMessage &msg);
+    void onMessage(const LogMessage& msg);
 
 private:
     QString formMemInfo();
@@ -38,5 +37,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_CRASH_LOG_CACHE_H_
