@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -49,8 +49,7 @@
  *
  **********************************************************************/
 
-#ifndef _STACK_WALKER_H_
-#define _STACK_WALKER_H_
+#pragma once
 
 #include <qglobal.h>
 
@@ -108,7 +107,7 @@ public:
     StackWalker(DWORD dwProcessId, HANDLE hProcess);
     virtual ~StackWalker();
 
-    typedef bool(__stdcall *PReadProcessMemoryRoutine)(
+    typedef bool(__stdcall* PReadProcessMemoryRoutine)(
         HANDLE hProcess,
         DWORD64 qwBaseAddress,
         PVOID lpBuffer,
@@ -121,7 +120,7 @@ public:
 
     bool ShowCallstack(
         HANDLE hThread = GetCurrentThread(),
-        const CONTEXT *context = nullptr,
+        const CONTEXT* context = nullptr,
         PReadProcessMemoryRoutine readMemoryFunction = nullptr,
         LPVOID pUserData = nullptr  // optional to identify some data in the 'readMemoryFunction'-callback
     );
@@ -157,11 +156,11 @@ protected:
 
     virtual void OnSymInit(LPCSTR szSearchPath, DWORD symOptions, LPCSTR szUserName);
     virtual void OnLoadModule(LPCSTR img, LPCSTR mod, DWORD64 baseAddr, DWORD size, DWORD result, LPCSTR symType, LPCSTR pdbName, ULONGLONG fileVersion);
-    virtual void OnCallstackEntry(CallstackEntryType eType, CallstackEntry &entry);
+    virtual void OnCallstackEntry(CallstackEntryType eType, CallstackEntry& entry);
     virtual void OnDbgHelpErr(LPCSTR szFuncName, DWORD gle, DWORD64 addr);
     virtual void OnOutput(LPCSTR szText);
 
-    StackWalkerInternal *m_sw;
+    StackWalkerInternal* m_sw;
     HANDLE m_hProcess;
     DWORD m_dwProcessId;
     BOOL m_modulesLoaded;
@@ -180,5 +179,3 @@ protected:
 }  // namespace U2
 
 #endif
-
-#endif
