@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -75,7 +75,7 @@ static ObjectType toObjectType(U2::GObjectType type) {
 
 extern "C" {
 
-U2SCRIPT_EXPORT void importFileToUgeneDb(const wchar_t *_url, UgeneDbHandle *resultObjects, int maxObjectCount) {
+U2SCRIPT_EXPORT void importFileToUgeneDb(const wchar_t* _url, UgeneDbHandle* resultObjects, int maxObjectCount) {
     using namespace U2;
 
     const QString url = QString::fromWCharArray(_url);
@@ -85,13 +85,13 @@ U2SCRIPT_EXPORT void importFileToUgeneDb(const wchar_t *_url, UgeneDbHandle *res
         return;
     }
     const GUrl adoptedUrl(url);
-    QList<DocumentFormat *> formatList = DocumentUtils::toFormats(
+    QList<DocumentFormat*> formatList = DocumentUtils::toFormats(
         DocumentUtils::detectFormat(adoptedUrl));
     CHECK_EXT(!formatList.isEmpty(), coreLog.error(QObject::tr("Could not detect file format")), );
-    DocumentFormat *format = formatList.first();
+    DocumentFormat* format = formatList.first();
 
     ioLog.info(QObject::tr("Importing objects from %1 [%2]").arg(url, format->getFormatName()));
-    IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(
+    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(
         IOAdapterUtils::url2io(adoptedUrl));
     QVariantMap hints;
     U2OpStatusImpl stateInfo;
@@ -100,7 +100,7 @@ U2SCRIPT_EXPORT void importFileToUgeneDb(const wchar_t *_url, UgeneDbHandle *res
     doc->setDocumentOwnsDbiResources(false);
 
     int objectCount = 0;
-    foreach (GObject *object, doc->getObjects()) {
+    foreach (GObject* object, doc->getObjects()) {
         resultObjects[objectCount] = object;
         if (++objectCount >= maxObjectCount) {
             break;
@@ -109,14 +109,14 @@ U2SCRIPT_EXPORT void importFileToUgeneDb(const wchar_t *_url, UgeneDbHandle *res
 }
 
 U2SCRIPT_EXPORT void releaseObject(UgeneDbHandle resultObject) {
-    U2::GObject *unwrappedObject = reinterpret_cast<U2::GObject *>(resultObject);
+    auto unwrappedObject = reinterpret_cast<U2::GObject*>(resultObject);
     delete unwrappedObject;  // TODO: make sure about db resources deallocation
 }
 
 U2SCRIPT_EXPORT UgeneDbHandle cloneObject(UgeneDbHandle object) {
-    U2::GObject *unwrappedObject = reinterpret_cast<U2::GObject *>(object);
-    U2::GObject *result = nullptr;
-    if (nullptr != unwrappedObject) {
+    auto unwrappedObject = reinterpret_cast<U2::GObject*>(object);
+    U2::GObject* result = nullptr;
+    if (unwrappedObject != nullptr) {
         U2::U2OpStatusImpl statusInfo;
         result = unwrappedObject->clone(unwrappedObject->getEntityRef().dbiRef, statusInfo);
         CHECK_OP(statusInfo, nullptr);
@@ -124,14 +124,14 @@ U2SCRIPT_EXPORT UgeneDbHandle cloneObject(UgeneDbHandle object) {
     return result;
 }
 
-U2SCRIPT_EXPORT void saveObjectsToFile(UgeneDbHandle *objects, int objectCount, const wchar_t *_url, FileFormat format) {
+U2SCRIPT_EXPORT void saveObjectsToFile(UgeneDbHandle* objects, int objectCount, const wchar_t* _url, FileFormat format) {
     using namespace U2;
 
-    CHECK(nullptr != objects && nullptr != _url, );
+    CHECK(objects != nullptr && _url != nullptr, );
 
-    DocumentFormat *docFormat = AppContext::getDocumentFormatRegistry()->getFormatById(
+    DocumentFormat* docFormat = AppContext::getDocumentFormatRegistry()->getFormatById(
         toDocumentFormatId(format));
-    CHECK_EXT(nullptr != docFormat, coreLog.error(QObject::tr("The unsupported format"
+    CHECK_EXT(docFormat != nullptr, coreLog.error(QObject::tr("The unsupported format"
                                                               " was provided")), );
     const QString url = QString::fromWCharArray(_url);
     QFileInfo fileInfo(url);
@@ -141,42 +141,42 @@ U2SCRIPT_EXPORT void saveObjectsToFile(UgeneDbHandle *objects, int objectCount,
     CHECK_OP_EXT(stateInfo, coreLog.error(QString("Could not prepare folder"
                                                   " according to supplied path \"%1\"")
                                               .arg(url)), );
-    Document *doc = docFormat->createNewLoadedDocument(IOAdapterUtils::get(
+    Document* doc = docFormat->createNewLoadedDocument(IOAdapterUtils::get(
                                                            BaseIOAdapters::LOCAL_FILE),
                                                        adoptedUrl,
                                                        stateInfo);
     for (int i = 0; i < objectCount; ++i) {
-        GObject *object = reinterpret_cast<GObject *>(objects[i]);
-        if (nullptr != object) {
+        auto object = reinterpret_cast<GObject*>(objects[i]);
+        if (object != nullptr) {
             doc->addObject(object);
         }
     }
-    Task *saveDoc = new SaveDocumentTask(doc, SaveDoc_Overwrite);
+    Task* saveDoc = new SaveDocumentTask(doc);
     AppContext::getTaskScheduler()->registerTopLevelTask(saveDoc);
 }
 
 U2SCRIPT_EXPORT ObjectType getObjectType(UgeneDbHandle object) {
-    U2::GObject *unwrappedObject = reinterpret_cast<U2::GObject *>(object);
+    auto unwrappedObject = reinterpret_cast<U2::GObject*>(object);
     U2::GObjectType result = U2::GObjectTypes::UNKNOWN;
-    if (nullptr != unwrappedObject) {
+    if (unwrappedObject != nullptr) {
         result = unwrappedObject->getGObjectType();
     }
     return toObjectType(result);
 }
 
-U2SCRIPT_EXPORT void getObjectName(UgeneDbHandle object, int expectedMaxNameLength, wchar_t *name) {
-    U2::GObject *unwrappedObject = reinterpret_cast<U2::GObject *>(object);
+U2SCRIPT_EXPORT void getObjectName(UgeneDbHandle object, int expectedMaxNameLength, wchar_t* name) {
+    auto unwrappedObject = reinterpret_cast<U2::GObject*>(object);
     QString result;
-    if (nullptr != unwrappedObject) {
+    if (unwrappedObject != nullptr) {
         result = unwrappedObject->getGObjectName();
     }
     U2ErrorType error = U2::TextConversionUtils::qstringToCstring(result, expectedMaxNameLength, name);
     Q_UNUSED(error);
 }
 
-U2SCRIPT_EXPORT void setObjectName(UgeneDbHandle object, const wchar_t *newName) {
-    U2::GObject *unwrappedObject = reinterpret_cast<U2::GObject *>(object);
-    if (nullptr != unwrappedObject && nullptr != newName) {
+U2SCRIPT_EXPORT void setObjectName(UgeneDbHandle object, const wchar_t* newName) {
+    auto unwrappedObject = reinterpret_cast<U2::GObject*>(object);
+    if (unwrappedObject != nullptr && newName != nullptr) {
         unwrappedObject->setGObjectName(QString::fromWCharArray(newName));
     }
 }
