@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentUtils.h>
 
-static U2Format fromFormatId(const U2::DocumentFormatId &id) {
+static U2Format fromFormatId(const U2::DocumentFormatId& id) {
     if (U2::BaseDocumentFormats::ABIF == id) {
         return U2_ABI;
     } else if (U2::BaseDocumentFormats::ACE == id) {
@@ -60,10 +60,10 @@ static U2Format fromFormatId(const U2::DocumentFormatId &id) {
 
 extern "C" {
 
-U2SCRIPT_EXPORT U2ErrorType detectFileFormat(const wchar_t *_pathToFile, U2Format *format) {
+U2SCRIPT_EXPORT U2ErrorType detectFileFormat(const wchar_t* _pathToFile, U2Format* format) {
     const QString pathToFile = QString::fromWCharArray(_pathToFile);
     QFileInfo info(pathToFile);
-    if (nullptr == pathToFile || !info.isFile() || !info.exists()) {
+    if (pathToFile == nullptr || !info.isFile() || !info.exists()) {
         return U2_INVALID_PATH;
     }
     *format = U2_UNSUPPORTED;
