@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _FORMAT_DETECTION_H_
-#define _FORMAT_DETECTION_H_
+#pragma once
 
 #include "globals.h"
 
@@ -59,11 +58,9 @@ typedef enum U2Format {
  * U2_INVALID_PATH -       the `pathToFile` does not exist or contains path to a folder
  *
  */
-U2SCRIPT_EXPORT U2ErrorType detectFileFormat(const wchar_t *pathToFile,
-                                             U2Format *format);
+U2SCRIPT_EXPORT U2ErrorType detectFileFormat(const wchar_t* pathToFile,
+                                             U2Format* format);
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif  // _FORMAT_DETECTION_H_
