@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,12 +19,11 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _SCHEME_HANDLE_H_
-#define _SCHEME_HANDLE_H_
+#pragma once
 
 #include "globals.h"
 
-typedef void *SchemeHandle;
+typedef void* SchemeHandle;
 
 #ifdef __cplusplus
 extern "C" {
@@ -55,8 +54,8 @@ extern "C" {
  * If returning value is not U2_OK the environment is not affected by the invocation.
  *
  */
-U2SCRIPT_EXPORT U2ErrorType createScheme(const wchar_t *pathToScheme,
-                                         SchemeHandle *scheme);
+U2SCRIPT_EXPORT U2ErrorType createScheme(const wchar_t* pathToScheme,
+                                         SchemeHandle* scheme);
 
 /*
  * This function creates a new object representing a Single Algorithm Scheme
@@ -85,10 +84,10 @@ U2SCRIPT_EXPORT U2ErrorType createScheme(const wchar_t *pathToScheme,
  * If returning value is not U2_OK the environment is not affected by the invocation.
  *
  */
-U2SCRIPT_EXPORT U2ErrorType createSas(const wchar_t *algorithmType,
-                                      const wchar_t *inputPath,
-                                      const wchar_t *outputPath,
-                                      SchemeHandle *scheme);
+U2SCRIPT_EXPORT U2ErrorType createSas(const wchar_t* algorithmType,
+                                      const wchar_t* inputPath,
+                                      const wchar_t* outputPath,
+                                      SchemeHandle* scheme);
 
 /*
  * This function adds to the computational scheme described by the `scheme` object
@@ -123,10 +122,10 @@ U2SCRIPT_EXPORT U2ErrorType createSas(const wchar_t *algorithmType,
  *
  */
 U2SCRIPT_EXPORT U2ErrorType addReaderToScheme(SchemeHandle scheme,
-                                              const wchar_t *readerType,
-                                              const wchar_t *inputFilePath,
+                                              const wchar_t* readerType,
+                                              const wchar_t* inputFilePath,
                                               int maxExpectedNameLength,
-                                              wchar_t *name);
+                                              wchar_t* name);
 
 /*
  * This function adds to the computational scheme described by the `scheme` object
@@ -154,10 +153,10 @@ U2SCRIPT_EXPORT U2ErrorType addReaderToScheme(SchemeHandle scheme,
  *
  */
 U2SCRIPT_EXPORT U2ErrorType addWriterToScheme(SchemeHandle scheme,
-                                              const wchar_t *writerType,
-                                              const wchar_t *outputFilePath,
+                                              const wchar_t* writerType,
+                                              const wchar_t* outputFilePath,
                                               int maxExpectedNameLength,
-                                              wchar_t *name);
+                                              wchar_t* name);
 
 /*
  * This function adds to the computational scheme described by the `scheme` object
@@ -184,9 +183,9 @@ U2SCRIPT_EXPORT U2ErrorType addWriterToScheme(SchemeHandle scheme,
  *
  */
 U2SCRIPT_EXPORT U2ErrorType addElementToScheme(SchemeHandle scheme,
-                                               const wchar_t *elementType,
+                                               const wchar_t* elementType,
                                                int maxExpectedNameLength,
-                                               wchar_t *name);
+                                               wchar_t* name);
 
 /*
  * This function sets attribute with name `attributeName` of the computational element
@@ -208,9 +207,9 @@ U2SCRIPT_EXPORT U2ErrorType addElementToScheme(SchemeHandle scheme,
  *
  */
 U2SCRIPT_EXPORT U2ErrorType setSchemeElementAttribute(SchemeHandle scheme,
-                                                      const wchar_t *elementName,
-                                                      const wchar_t *attributeName,
-                                                      const wchar_t *attributeValue);
+                                                      const wchar_t* elementName,
+                                                      const wchar_t* attributeName,
+                                                      const wchar_t* attributeValue);
 
 /*
  * This function writes the value of the attribute with name `attributeName` of the computational
@@ -232,10 +231,10 @@ U2SCRIPT_EXPORT U2ErrorType setSchemeElementAttribute(SchemeHandle scheme,
  *
  */
 U2SCRIPT_EXPORT U2ErrorType getSchemeElementAttribute(SchemeHandle scheme,
-                                                      const wchar_t *elementName,
-                                                      const wchar_t *attributeName,
+                                                      const wchar_t* elementName,
+                                                      const wchar_t* attributeName,
                                                       int maxExpectedNameLength,
-                                                      wchar_t *attributeValue);
+                                                      wchar_t* attributeValue);
 
 /*
  * This function sets binding between ports with `srcPortName` and `dstPortName` names
@@ -259,10 +258,10 @@ U2SCRIPT_EXPORT U2ErrorType getSchemeElementAttribute(SchemeHandle scheme,
  *
  */
 U2SCRIPT_EXPORT U2ErrorType addFlowToScheme(SchemeHandle scheme,
-                                            const wchar_t *srcElementName,
-                                            const wchar_t *srcPortName,
-                                            const wchar_t *dstElementName,
-                                            const wchar_t *dstPortName);
+                                            const wchar_t* srcElementName,
+                                            const wchar_t* srcPortName,
+                                            const wchar_t* dstElementName,
+                                            const wchar_t* dstPortName);
 
 /*
  * This function sets binding between slots with `srcSlotName` and `dstPortAndSlotNames` names
@@ -288,10 +287,10 @@ U2SCRIPT_EXPORT U2ErrorType addFlowToScheme(SchemeHandle scheme,
  *
  */
 U2SCRIPT_EXPORT U2ErrorType addSchemeActorsBinding(SchemeHandle scheme,
-                                                   const wchar_t *srcElementName,
-                                                   const wchar_t *srcSlotName,
-                                                   const wchar_t *dstElementName,
-                                                   const wchar_t *dstPortAndSlotNames);
+                                                   const wchar_t* srcElementName,
+                                                   const wchar_t* srcSlotName,
+                                                   const wchar_t* dstElementName,
+                                                   const wchar_t* dstPortAndSlotNames);
 
 /*
  * This function saves the computational scheme described by the `scheme` object to file
@@ -314,7 +313,7 @@ U2SCRIPT_EXPORT U2ErrorType addSchemeActorsBinding(SchemeHandle scheme,
  *
  */
 U2SCRIPT_EXPORT U2ErrorType saveSchemeToFile(SchemeHandle scheme,
-                                             const wchar_t *path);
+                                             const wchar_t* path);
 
 /*
  * This function deallocates all the resources acquired by the `scheme` object.
@@ -348,8 +347,8 @@ U2SCRIPT_EXPORT void releaseScheme(SchemeHandle scheme);
  *
  */
 U2SCRIPT_EXPORT U2ErrorType launchScheme(SchemeHandle scheme,
-                                         int *outputFilesCount,
-                                         wchar_t ***outputFileNames);
+                                         int* outputFilesCount,
+                                         wchar_t*** outputFileNames);
 
 /*
  * This function creates new Single Algorithm Scheme then runs it with Workflow Designer
@@ -380,14 +379,12 @@ U2SCRIPT_EXPORT U2ErrorType launchScheme(SchemeHandle scheme,
  * If returning value is not U2_OK the environment is not affected by the invocation.
  *
  */
-U2SCRIPT_EXPORT U2ErrorType launchSas(const wchar_t *algorithmType,
-                                      const wchar_t *inputPath,
-                                      const wchar_t *outputPath,
-                                      int *outputFilesCount,
-                                      wchar_t ***outputFileNames);
+U2SCRIPT_EXPORT U2ErrorType launchSas(const wchar_t* algorithmType,
+                                      const wchar_t* inputPath,
+                                      const wchar_t* outputPath,
+                                      int* outputFilesCount,
+                                      wchar_t*** outputFileNames);
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif  // _SCHEME_HANDLE_H_
