@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TEXT_CONVERSION_UTILS_H_
-#define _U2_TEXT_CONVERSION_UTILS_H_
+#pragma once
 
 #include <QString>
 
@@ -30,10 +29,8 @@ namespace U2 {
 
 class TextConversionUtils {
 public:
-    static U2ErrorType qstringToCstring(const QString &source, int maxExpectedLength, wchar_t *destination);
-    static U2ErrorType repeatLastConversion(int maxExpectedLength, wchar_t *destination, int *requiredSize);
+    static U2ErrorType qstringToCstring(const QString& source, int maxExpectedLength, wchar_t* destination);
+    static U2ErrorType repeatLastConversion(int maxExpectedLength, wchar_t* destination, int* requiredSize);
 };
 
 }  // namespace U2
-
-#endif  // _U2_TEXT_CONVERSION_UTILS_H_
