@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,14 +30,14 @@
 #include "SchemeWrapper.h"
 #include "UgeneContextWrapper.h"
 
-static U2::UgeneContextWrapper *GLOBAL_CONTEXT = nullptr;
+static U2::UgeneContextWrapper* GLOBAL_CONTEXT = nullptr;
 
-U2ErrorType processTask(U2::Task *task) {
-    if (nullptr == GLOBAL_CONTEXT) {  // when script interface was used from inside UGENE
+U2ErrorType processTask(U2::Task* task) {
+    if (GLOBAL_CONTEXT == nullptr) {  // when script interface was used from inside UGENE
         // now it's being used in unit tests
         CHECK(U2::UgeneContextWrapper::isAppContextInitialized(), U2_INVALID_CALL);
-        U2::TaskScheduler *scheduler = U2::AppContext::getTaskScheduler();
-        CHECK(nullptr != scheduler, U2_INVALID_CALL);
+        U2::TaskScheduler* scheduler = U2::AppContext::getTaskScheduler();
+        CHECK(scheduler != nullptr, U2_INVALID_CALL);
         scheduler->registerTopLevelTask(task);
     } else {
         GLOBAL_CONTEXT->processTask(task);
@@ -47,16 +47,16 @@ U2ErrorType processTask(U2::Task *task) {
 
 extern "C" {
 
-U2SCRIPT_EXPORT U2ErrorType initContext(const wchar_t *_workingDirectoryPath) {
+U2SCRIPT_EXPORT U2ErrorType initContext(const wchar_t* _workingDirectoryPath) {
     QString workingDirectoryPath = QString::fromWCharArray(_workingDirectoryPath);
     QFileInfo info(workingDirectoryPath);
-    if (nullptr == workingDirectoryPath || !info.isDir() || !info.exists()) {
+    if (workingDirectoryPath == nullptr || !info.isDir() || !info.exists()) {
         return U2_INVALID_PATH;
     }
-    if (nullptr == GLOBAL_CONTEXT) {
+    if (GLOBAL_CONTEXT == nullptr) {
         try {
             GLOBAL_CONTEXT = new U2::UgeneContextWrapper(workingDirectoryPath);
-        } catch (const std::bad_alloc &) {
+        } catch (const std::bad_alloc&) {
             delete GLOBAL_CONTEXT;
             return U2_NOT_ENOUGH_MEMORY;
         }
@@ -67,7 +67,7 @@ U2SCRIPT_EXPORT U2ErrorType initContext(const wchar_t *_workingDirectoryPath) {
 }
 
 U2SCRIPT_EXPORT U2ErrorType releaseContext() {
-    if (nullptr != GLOBAL_CONTEXT) {
+    if (GLOBAL_CONTEXT != nullptr) {
         delete GLOBAL_CONTEXT;
         GLOBAL_CONTEXT = nullptr;
     } else {
