@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -33,17 +33,12 @@
 #include <U2Algorithm/AlignmentAlgorithmsRegistry.h>
 #include <U2Algorithm/AssemblyConsensusAlgorithmRegistry.h>
 #include <U2Algorithm/CDSearchTaskFactoryRegistry.h>
-#include <U2Algorithm/CudaGpuRegistry.h>
 #include <U2Algorithm/DnaAssemblyAlgRegistry.h>
 #include <U2Algorithm/GenomeAssemblyRegistry.h>
 #include <U2Algorithm/MSAConsensusAlgorithmRegistry.h>
 #include <U2Algorithm/MSADistanceAlgorithmRegistry.h>
 #include <U2Algorithm/MolecularSurfaceFactoryRegistry.h>
 
-#ifdef OPENCL_SUPPORT
-#    include <U2Algorithm/OpenCLGpuRegistry.h>
-#endif
-
 #include <U2Algorithm/PWMConversionAlgorithmRegistry.h>
 #include <U2Algorithm/PhyTreeGeneratorRegistry.h>
 #include <U2Algorithm/RepeatFinderTaskFactoryRegistry.h>
@@ -98,8 +93,8 @@ namespace U2 {
 static void setDataSearchPaths() {
     // set search paths for data files
     QStringList dataSearchPaths;
-    const char *relativeDataDir = "/data";
-    const char *relativeDevDataDir = "/../../data";
+    const char* relativeDataDir = "/data";
+    const char* relativeDevDataDir = "/../../data";
 
     if (QDir(AppContext::getWorkingDirectoryPath() + relativeDataDir).exists()) {
         dataSearchPaths.push_back(AppContext::getWorkingDirectoryPath() + relativeDataDir);
@@ -115,14 +110,6 @@ static void setDataSearchPaths() {
 #endif
     }
 
-#if (defined(Q_OS_UNIX)) && defined(UGENE_DATA_DIR)
-    // using folder which is set during installation process on Linux
-    const QString ugene_data_dir(UGENE_DATA_DIR);
-    if (QDir(ugene_data_dir).exists()) {
-        dataSearchPaths.push_back(QString(UGENE_DATA_DIR));
-    }
-#endif
-
     if (dataSearchPaths.empty()) {
         dataSearchPaths.push_back("/");
     }
@@ -135,7 +122,7 @@ static void setSearchPaths() {
     setDataSearchPaths();
 }
 
-UgeneContextWrapper::UgeneContextWrapper(const QString &workingDirectoryPath)
+UgeneContextWrapper::UgeneContextWrapper(const QString& workingDirectoryPath)
     : app(ARGC, nullptr) {
     if (!Version::checkBuildAndRuntimeVersions()) {
         return;
@@ -243,17 +230,9 @@ UgeneContextWrapper::UgeneContextWrapper(const QString &workingDirectoryPath)
     sspar = new SecStructPredictAlgRegistry();
     appContext->setSecStructPedictAlgRegistry(sspar);
 
-    cgr = new CudaGpuRegistry();
-    appContext->setCudaGpuRegistry(cgr);
-
     alignmentAlgorithmRegistry = new AlignmentAlgorithmsRegistry();
     appContext->setAlignmentAlgorithmsRegistry(alignmentAlgorithmRegistry);
 
-#ifdef OPENCL_SUPPORT
-    oclgr = new OpenCLGpuRegistry();
-    appContext->setOpenCLGpuRegistry(oclgr);
-#endif
-
     rdc = new RecentlyDownloadedCache();
     appContext->setRecentlyDownloadedCache(rdc);
 
@@ -302,7 +281,7 @@ UgeneContextWrapper::UgeneContextWrapper(const QString &workingDirectoryPath)
 
     t1.stop();
     QObject::connect(psp, SIGNAL(si_allStartUpPluginsLoaded()), &app, SLOT(quit()));
-    app.exec();
+    QCoreApplication::exec();
 }
 
 UgeneContextWrapper::~UgeneContextWrapper() {
@@ -365,14 +344,6 @@ UgeneContextWrapper::~UgeneContextWrapper() {
     delete resTrack;
     appContext->setResourceTracker(nullptr);
 
-    delete cgr;
-    appContext->setCudaGpuRegistry(nullptr);
-
-#ifdef OPENCL_SUPPORT
-    delete oclgr;
-    appContext->setOpenCLGpuRegistry(nullptr);
-#endif
-
     delete appSettings;
     appContext->setAppSettings(nullptr);
 
@@ -422,12 +393,12 @@ UgeneContextWrapper::~UgeneContextWrapper() {
     delete alignmentAlgorithmRegistry;
 }
 
-int UgeneContextWrapper::processTask(Task *task) {
+int UgeneContextWrapper::processTask(Task* task) {
     coreLog.info(QObject::tr("%1-bit version of UGENE started")
                      .arg(Version::appArchitecture));
     ts->registerTopLevelTask(task);
-    QObject::connect(ts, SIGNAL(si_topLevelTaskUnregistered(Task *)), &app, SLOT(quit()));
-    return app.exec();
+    QObject::connect(ts, SIGNAL(si_topLevelTaskUnregistered(Task*)), &app, SLOT(quit()));
+    return QCoreApplication::exec();
 }
 
 // TODO: fix this dummy check
