@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _UGENE_CONTEXT_WRAPPER_H_
-#define _UGENE_CONTEXT_WRAPPER_H_
+#pragma once
 
 #include <QCoreApplication>
 
@@ -57,13 +56,8 @@ class SmithWatermanTaskFactoryRegistry;
 class MolecularSurfaceFactoryRegistry;
 class SWResultFilterRegistry;
 class SecStructPredictAlgRegistry;
-class CudaGpuRegistry;
 class AlignmentAlgorithmsRegistry;
-#ifdef OPENCL_SUPPORT
-class OpenCLGpuRegistry;
-#endif
 class RecentlyDownloadedCache;
-class DistributedComputingUtil;
 class VirtualFileSystemRegistry;
 class DnaAssemblyAlgRegistry;
 class GenomeAssemblyAlgRegistry;
@@ -79,66 +73,60 @@ class ScriptingToolRegistry;
 
 class UgeneContextWrapper {
 public:
-    UgeneContextWrapper(const QString &workingDirectoryPath);
+    UgeneContextWrapper(const QString& workingDirectoryPath);
     ~UgeneContextWrapper();
 
-    int processTask(Task *task);
+    int processTask(Task* task);
 
     static bool isAppContextInitialized();
 
 private:
     QCoreApplication app;
 
-    AppContextImpl *appContext;
-    CMDLineRegistry *cmdLineRegistry;
-    SettingsImpl *globalSettings;
-    SettingsImpl *settings;
-    AppSettings *appSettings;
-    UserAppsSettings *userAppSettings;
-    ResourceTracker *resTrack;
-    TaskSchedulerImpl *ts;
-    AnnotationSettingsRegistry *asr;
-    TestFramework *tf;
-    RepeatFinderTaskFactoryRegistry *rfr;
-    QDActorPrototypeRegistry *qpr;
-    PhyTreeGeneratorRegistry *phyreg;
-    ExternalToolRegistry *etr;
-    U2DbiRegistry *dbiRegistry;
-    DocumentFormatRegistryImpl *dfr;
-    PluginSupportImpl *psp;
-    ServiceRegistryImpl *sreg;
-    IOAdapterRegistryImpl *io;
-    DNATranslationRegistry *dtr;
-    DNAAlphabetRegistry *dal;
-    DBXRefRegistry *dbxrr;
-    MSAConsensusAlgorithmRegistry *msaConsReg;
-    MSADistanceAlgorithmRegistry *msaDistReg;
-    AssemblyConsensusAlgorithmRegistry *assemblyConsReg;
-    PWMConversionAlgorithmRegistry *pwmConvReg;
-    SubstMatrixRegistry *smr;
-    SmithWatermanTaskFactoryRegistry *swar;
-    MolecularSurfaceFactoryRegistry *msfr;
-    SWResultFilterRegistry *swrfr;
-    SecStructPredictAlgRegistry *sspar;
-    CudaGpuRegistry *cgr;
-    AlignmentAlgorithmsRegistry *alignmentAlgorithmRegistry;
-#ifdef OPENCL_SUPPORT
-    OpenCLGpuRegistry *oclgr;
-#endif
-    RecentlyDownloadedCache *rdc;
-    VirtualFileSystemRegistry *vfsReg;
-    DnaAssemblyAlgRegistry *assemblyReg;
-    GenomeAssemblyAlgRegistry *genomeAssemblyReg;
-    DataBaseRegistry *dbr;
-    CDSearchFactoryRegistry *cdsfr;
-    StructuralAlignmentAlgorithmRegistry *saar;
-    SplicedAlignmentTaskRegistry *splicedAlignmentTaskRegistry;
-    WorkflowScriptRegistry *workflowScriptRegistry;
-    AppFileStorage *appFileStorage;
-    U2DataPathRegistry *dpr;
-    ScriptingToolRegistry *str;
+    AppContextImpl* appContext;
+    CMDLineRegistry* cmdLineRegistry;
+    SettingsImpl* globalSettings;
+    SettingsImpl* settings;
+    AppSettings* appSettings;
+    UserAppsSettings* userAppSettings;
+    ResourceTracker* resTrack;
+    TaskSchedulerImpl* ts;
+    AnnotationSettingsRegistry* asr;
+    TestFramework* tf;
+    RepeatFinderTaskFactoryRegistry* rfr;
+    QDActorPrototypeRegistry* qpr;
+    PhyTreeGeneratorRegistry* phyreg;
+    ExternalToolRegistry* etr;
+    U2DbiRegistry* dbiRegistry;
+    DocumentFormatRegistryImpl* dfr;
+    PluginSupportImpl* psp;
+    ServiceRegistryImpl* sreg;
+    IOAdapterRegistryImpl* io;
+    DNATranslationRegistry* dtr;
+    DNAAlphabetRegistry* dal;
+    DBXRefRegistry* dbxrr;
+    MSAConsensusAlgorithmRegistry* msaConsReg;
+    MSADistanceAlgorithmRegistry* msaDistReg;
+    AssemblyConsensusAlgorithmRegistry* assemblyConsReg;
+    PWMConversionAlgorithmRegistry* pwmConvReg;
+    SubstMatrixRegistry* smr;
+    SmithWatermanTaskFactoryRegistry* swar;
+    MolecularSurfaceFactoryRegistry* msfr;
+    SWResultFilterRegistry* swrfr;
+    SecStructPredictAlgRegistry* sspar;
+    AlignmentAlgorithmsRegistry* alignmentAlgorithmRegistry;
+    RecentlyDownloadedCache* rdc;
+    VirtualFileSystemRegistry* vfsReg;
+    DnaAssemblyAlgRegistry* assemblyReg;
+    GenomeAssemblyAlgRegistry* genomeAssemblyReg;
+    DataBaseRegistry* dbr;
+    CDSearchFactoryRegistry* cdsfr;
+    StructuralAlignmentAlgorithmRegistry* saar;
+    SplicedAlignmentTaskRegistry* splicedAlignmentTaskRegistry;
+    WorkflowScriptRegistry* workflowScriptRegistry;
+    AppFileStorage* appFileStorage;
+    U2DataPathRegistry* dpr;
+    ScriptingToolRegistry* str;
 };
 
 }  // namespace U2
-
-#endif  // _UGENE_CONTEXT_WRAPPER_H_
