@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,9 +30,9 @@ namespace U2 {
 namespace Js {
 
 Persistent<Function> ActorWrap::CONSTRUCTOR;
-const char *ActorWrap::CLASS_NAME = "Actor";
+const char* ActorWrap::CLASS_NAME = "Actor";
 
-ActorWrap::ActorWrap(const Workflow::Actor *initActor)
+ActorWrap::ActorWrap(const Workflow::Actor* initActor)
     : actor(initActor) {
 }
 
@@ -56,7 +56,7 @@ void ActorWrap::init() {
     CONSTRUCTOR = Persistent<Function>::New(tpl->GetFunction());
 }
 
-Handle<Value> ActorWrap::newInstance(int argc, const Handle<Value> *argv) {
+Handle<Value> ActorWrap::newInstance(int argc, const Handle<Value>* argv) {
     HandleScope scope;
     const int requiredArgumentCount = 1;
     if (!NodeApiUtils::isArgumentCountCorrect(argc, requiredArgumentCount)) {
@@ -67,55 +67,55 @@ Handle<Value> ActorWrap::newInstance(int argc, const Handle<Value> *argv) {
     return scope.Close(instance);
 }
 
-Handle<Value> ActorWrap::newObject(const Arguments &args) {
+Handle<Value> ActorWrap::newObject(const Arguments& args) {
     HandleScope scope;
     if (!NodeApiUtils::isArgumentCountCorrect(args.Length(), 1)) {
         return scope.Close(Undefined());
     }
-    const Workflow::Actor *actor = reinterpret_cast<Workflow::Actor *>(args[0]->IntegerValue());
-    Q_ASSERT(nullptr != actor);
-    ActorWrap *obj = new ActorWrap(actor);
+    auto actor = reinterpret_cast<Workflow::Actor*>(args[0]->IntegerValue());
+    Q_ASSERT(actor != nullptr);
+    ActorWrap* obj = new ActorWrap(actor);
     obj->Wrap(args.This());
     return args.This();
 }
 
-Handle<Value> ActorWrap::id(const Arguments &args) {
+Handle<Value> ActorWrap::id(const Arguments& args) {
     HandleScope scope;
     if (!NodeApiUtils::isArgumentCountCorrect(args.Length(), 0)) {
         return scope.Close(Undefined());
     }
-    ActorWrap *obj = ObjectWrap::Unwrap<ActorWrap>(args.This());
+    ActorWrap* obj = ObjectWrap::Unwrap<ActorWrap>(args.This());
     return scope.Close(String::New(obj->actor->getId().toLocal8Bit().constData()));
 }
 
-Handle<Value> ActorWrap::label(const Arguments &args) {
+Handle<Value> ActorWrap::label(const Arguments& args) {
     HandleScope scope;
     if (!NodeApiUtils::isArgumentCountCorrect(args.Length(), 0)) {
         return scope.Close(Undefined());
     }
-    ActorWrap *obj = ObjectWrap::Unwrap<ActorWrap>(args.This());
+    ActorWrap* obj = ObjectWrap::Unwrap<ActorWrap>(args.This());
     return scope.Close(String::New(obj->actor->getLabel().toLocal8Bit().constData()));
 }
 
-Handle<Value> ActorWrap::isDone(const Arguments &args) {
+Handle<Value> ActorWrap::isDone(const Arguments& args) {
     HandleScope scope;
     if (!NodeApiUtils::isArgumentCountCorrect(args.Length(), 0)) {
         return scope.Close(Undefined());
     }
-    ActorWrap *obj = ObjectWrap::Unwrap<ActorWrap>(args.This());
-    LocalWorkflow::BaseWorker *worker = obj->actor->castPeer<LocalWorkflow::BaseWorker>();
-    Q_ASSERT(nullptr != worker);
+    ActorWrap* obj = ObjectWrap::Unwrap<ActorWrap>(args.This());
+    LocalWorkflow::BaseWorker* worker = obj->actor->castPeer<LocalWorkflow::BaseWorker>();
+    Q_ASSERT(worker != nullptr);
     return scope.Close(Boolean::New(worker->isDone()));
 }
 
-Handle<Value> ActorWrap::isReady(const Arguments &args) {
+Handle<Value> ActorWrap::isReady(const Arguments& args) {
     HandleScope scope;
     if (!NodeApiUtils::isArgumentCountCorrect(args.Length(), 0)) {
         return scope.Close(Undefined());
     }
-    ActorWrap *obj = ObjectWrap::Unwrap<ActorWrap>(args.This());
-    LocalWorkflow::BaseWorker *worker = obj->actor->castPeer<LocalWorkflow::BaseWorker>();
-    Q_ASSERT(nullptr != worker);
+    ActorWrap* obj = ObjectWrap::Unwrap<ActorWrap>(args.This());
+    LocalWorkflow::BaseWorker* worker = obj->actor->castPeer<LocalWorkflow::BaseWorker>();
+    Q_ASSERT(worker != nullptr);
     return scope.Close(Boolean::New(worker->isReady()));
 }
 
