@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ACTOR_WRAP_H_
-#define _U2_ACTOR_WRAP_H_
+#pragma once
 
 #include <node.h>
 
@@ -35,26 +34,24 @@ namespace Js {
 class ActorWrap : public node::ObjectWrap {
 public:
     static void init();
-    static Handle<Value> newInstance(int argc, const Handle<Value> *argv);
+    static Handle<Value> newInstance(int argc, const Handle<Value>* argv);
 
 private:
-    ActorWrap(const Workflow::Actor *initActor);
+    ActorWrap(const Workflow::Actor* initActor);
     ~ActorWrap();
 
-    static Handle<Value> newObject(const Arguments &args);
-    static Handle<Value> id(const Arguments &args);
-    static Handle<Value> label(const Arguments &args);
-    static Handle<Value> isDone(const Arguments &args);
-    static Handle<Value> isReady(const Arguments &args);
+    static Handle<Value> newObject(const Arguments& args);
+    static Handle<Value> id(const Arguments& args);
+    static Handle<Value> label(const Arguments& args);
+    static Handle<Value> isDone(const Arguments& args);
+    static Handle<Value> isReady(const Arguments& args);
 
     static Persistent<Function> CONSTRUCTOR;
-    static const char *CLASS_NAME;
+    static const char* CLASS_NAME;
 
-    const Workflow::Actor *actor;
+    const Workflow::Actor* actor;
 };
 
 }  // namespace Js
 
 }  // namespace U2
-
-#endif  // _U2_ACTOR_WRAP_H_
