@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_JS_SCHEDULER_H_
-#define _U2_JS_SCHEDULER_H_
+#pragma once
 
 #include <node.h>
 
@@ -34,10 +33,10 @@ namespace Js {
 
 class JsScheduler : public ScriptableScheduler {
 public:
-    JsScheduler(Workflow::Schema *scheme, const Local<Function> &callback);
+    JsScheduler(Workflow::Schema* scheme, const Local<Function>& callback);
     ~JsScheduler();
 
-    virtual Task *tick();
+    virtual Task* tick();
 
 private:
     Local<Function> schedulerCallback;
@@ -46,5 +45,3 @@ private:
 }  // namespace Js
 
 }  // namespace U2
-
-#endif  // _U2_JS_SCHEDULER_H_
