@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_NODE_API_UTILS_H_
-#define _U2_NODE_API_UTILS_H_
+#pragma once
 
 #include <node.h>
 
@@ -35,11 +34,9 @@ namespace Js {
 class NodeApiUtils {
 public:
     static bool isArgumentCountCorrect(int actualCount, int requiredCount);
-    static ScriptContext *getScriptContext();
+    static ScriptContext* getScriptContext();
 };
 
 }  // namespace Js
 
 }  // namespace U2
-
-#endif  // _U2_NODE_API_UTILS_H_
