@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TEST_FRAMWORK_COMPONENTS_
-#define _U2_TEST_FRAMWORK_COMPONENTS_
+#pragma once
 
 #include "GTest.h"
 
@@ -32,18 +31,18 @@ public:
     GTestFormatRegistry();
     ~GTestFormatRegistry();
 
-    bool registerTestFormat(GTestFormat *f);
+    bool registerTestFormat(GTestFormat* f);
 
-    bool unregisterTestFormat(GTestFormat *f);
+    bool unregisterTestFormat(GTestFormat* f);
 
-    QList<GTestFormat *> getFormats() const {
+    QList<GTestFormat*> getFormats() const {
         return formats;
     }
 
-    GTestFormat *findFormat(const GTestFormatId &id);
+    GTestFormat* findFormat(const GTestFormatId& id);
 
 private:
-    QList<GTestFormat *> formats;
+    QList<GTestFormat*> formats;
 };
 
 class U2TEST_EXPORT TestFramework {
@@ -57,7 +56,7 @@ private:
 
 public:
     TestFramework();
-    GTestFormatRegistry *getTestFormatRegistry() {
+    GTestFormatRegistry* getTestFormatRegistry() {
         return &formatRegistry;
     }
 
@@ -69,5 +68,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
