@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TEST_RUNNER_TASK_H_
-#define _U2_TEST_RUNNER_TASK_H_
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -38,40 +37,38 @@ class GTest;
 class U2TEST_EXPORT TestRunnerTask : public Task {
     Q_OBJECT
 public:
-    TestRunnerTask(const QList<GTestState *> &tests, const GTestEnvironment *env, int testSizeToRun = 5);
+    TestRunnerTask(const QList<GTestState*>& tests, const GTestEnvironment* env, int testSizeToRun = 5);
 
     virtual void cleanup();
 
-    const QMap<GTest *, GTestState *> &getStateByTestMap() const {
+    const QMap<GTest*, GTestState*>& getStateByTestMap() const {
         return stateByTest;
     }
 
 protected:
-    virtual QList<Task *> onSubTaskFinished(Task *subTask);
+    virtual QList<Task*> onSubTaskFinished(Task* subTask);
 
-    QMap<GTest *, GTestState *> stateByTest;
-    const GTestEnvironment *env;
+    QMap<GTest*, GTestState*> stateByTest;
+    const GTestEnvironment* env;
     int sizeToRun;
     int finishedTests;
     int totalTests;
-    QList<GTestState *> awaitingTests;
+    QList<GTestState*> awaitingTests;
 
     /** All tests environments created during the run. Will be deleted with the test. */
-    QList<GTestEnvironment *> allTestEnvironments;
+    QList<GTestEnvironment*> allTestEnvironments;
 };
 
 class U2TEST_EXPORT LoadTestTask : public Task {
     Q_OBJECT
 public:
-    LoadTestTask(GTestState *test);
+    LoadTestTask(GTestState* test);
 
     void run();
 
-    GTestState *testState;
+    GTestState* testState;
 
     QByteArray testData;
 };
 
 }  // namespace U2
-
-#endif
