@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_XML_TEST_FORMAT_H_
-#define _U2_XML_TEST_FORMAT_H_
+#pragma once
 
 #include "../GTest.h"
 
@@ -32,14 +31,14 @@ class XMLTestFormat;
 
 class U2TEST_EXPORT XMLTestFactory {
 public:
-    XMLTestFactory(const QString &_tagName)
+    XMLTestFactory(const QString& _tagName)
         : tagName(_tagName) {
     }
     virtual ~XMLTestFactory();
 
-    virtual GTest *createTest(XMLTestFormat *tf, const QString &testName, GTest *cp, const GTestEnvironment *env, const QList<GTest *> &subtasks, const QDomElement &el) = 0;
+    virtual GTest* createTest(XMLTestFormat* tf, const QString& testName, GTest* cp, const GTestEnvironment* env, const QList<GTest*>& subtasks, const QDomElement& el) = 0;
 
-    const QString &getTagName() const {
+    const QString& getTagName() const {
         return tagName;
     }
 
@@ -53,21 +52,19 @@ public:
     XMLTestFormat();
     virtual ~XMLTestFormat();
 
-    virtual GTest *createTest(const QString &name, GTest *cp, const GTestEnvironment *env, const QByteArray &testData, QString &err);
+    virtual GTest* createTest(const QString& name, GTest* cp, const GTestEnvironment* env, const QByteArray& testData, QString& err);
 
-    virtual GTest *createTest(const QString &name, GTest *cp, const GTestEnvironment *env, const QDomElement &el, QString &err);
+    virtual GTest* createTest(const QString& name, GTest* cp, const GTestEnvironment* env, const QDomElement& el, QString& err);
 
-    virtual bool registerTestFactory(XMLTestFactory *tf);
+    virtual bool registerTestFactory(XMLTestFactory* tf);
 
     /** Registers all factories from the list. Asserts that there are no duplicates in the registry as the result. */
-    void registerTestFactories(const QList<XMLTestFactory *> &factoryList);
+    void registerTestFactories(const QList<XMLTestFactory*>& factoryList);
 
-    virtual bool unregisterTestFactory(XMLTestFactory *tf);
+    virtual bool unregisterTestFactory(XMLTestFactory* tf);
 
 private:
-    QMap<QString, XMLTestFactory *> testFactories;
+    QMap<QString, XMLTestFactory*> testFactories;
 };
 
 }  // namespace U2
-
-#endif
