@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +26,7 @@
 #include <QFile>
 #include <QFileInfo>
 
+#include <U2Core/AppResources.h>
 #include <U2Core/GUrlUtils.h>
 #include <U2Core/U2SafePoints.h>
 
@@ -34,31 +35,31 @@ namespace U2 {
 const QString XmlTest::TRUE_VALUE = "true";
 const QString XmlTest::FALSE_VALUE = "false";
 
-XmlTest::XmlTest(const QString &taskName, GTest *cp, const GTestEnvironment *env, TaskFlags flags, const QList<GTest *> &subtasks)
+XmlTest::XmlTest(const QString& taskName, GTest* cp, const GTestEnvironment* env, TaskFlags flags, const QList<GTest*>& subtasks)
     : GTest(taskName, cp, env, flags, subtasks) {
 }
 
-void XmlTest::checkNecessaryAttributeExistence(const QDomElement &element, const QString &attribute) {
+void XmlTest::checkNecessaryAttributeExistence(const QDomElement& element, const QString& attribute) {
     CHECK_EXT(element.hasAttribute(attribute), failMissingValue(attribute), );
 }
 
-void XmlTest::checkAttribute(const QDomElement &element, const QString &attribute, const QStringList &acceptableValues, bool isNecessary) {
+void XmlTest::checkAttribute(const QDomElement& element, const QString& attribute, const QStringList& acceptableValues, bool isNecessary) {
     if (isNecessary) {
         checkNecessaryAttributeExistence(element, attribute);
         CHECK_OP(stateInfo, );
     }
 
     CHECK_EXT(!element.hasAttribute(attribute) || acceptableValues.contains(element.attribute(attribute)),
-              setError(QString("Attribute '%1' has inacceptable value. Acceptable values are: %2")
+              setError(QString("Attribute '%1' has unacceptable value. Acceptable values are: %2")
                            .arg(attribute)
                            .arg(acceptableValues.join(", "))), );
 }
 
-void XmlTest::checkBooleanAttribute(const QDomElement &element, const QString &attribute, bool isNecessary) {
+void XmlTest::checkBooleanAttribute(const QDomElement& element, const QString& attribute, bool isNecessary) {
     checkAttribute(element, attribute, QStringList({TRUE_VALUE, FALSE_VALUE}), isNecessary);
 }
 
-int XmlTest::getInt(const QDomElement &element, const QString &attribute) {
+int XmlTest::getInt(const QDomElement& element, const QString& attribute) {
     checkNecessaryAttributeExistence(element, attribute);
     CHECK_OP(stateInfo, 0);
 
@@ -68,7 +69,7 @@ int XmlTest::getInt(const QDomElement &element, const QString &attribute) {
     return result;
 }
 
-qint64 XmlTest::getInt64(const QDomElement &element, const QString &attribute) {
+qint64 XmlTest::getInt64(const QDomElement& element, const QString& attribute) {
     checkNecessaryAttributeExistence(element, attribute);
     CHECK_OP(stateInfo, 0);
 
@@ -78,7 +79,7 @@ qint64 XmlTest::getInt64(const QDomElement &element, const QString &attribute) {
     return result;
 }
 
-double XmlTest::getDouble(const QDomElement &element, const QString &attribute) {
+double XmlTest::getDouble(const QDomElement& element, const QString& attribute) {
     checkNecessaryAttributeExistence(element, attribute);
     CHECK_OP(stateInfo, 0);
 
@@ -98,8 +99,8 @@ const QString XMLTestUtils::EXPECTED_OUTPUT_DIR_PREFIX = "!expected!";
 
 const QString XMLTestUtils::CONFIG_FILE_PATH = "!config_file_path!";
 
-QList<XMLTestFactory *> XMLTestUtils::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> XMLTestUtils::createTestFactories() {
+    QList<XMLTestFactory*> res;
 
     res.append(XMLMultiTest::createFactory());
     res.append(GTest_DeleteTmpFile::createFactory());
@@ -109,7 +110,7 @@ QList<XMLTestFactory *> XMLTestUtils::createTestFactories() {
     return res;
 }
 
-void XMLTestUtils::replacePrefix(const GTestEnvironment *env, QString &path) {
+void XMLTestUtils::replacePrefix(const GTestEnvironment* env, QString& path) {
     QString result;
 
     // Determine which environment variable is required
@@ -128,7 +129,6 @@ void XMLTestUtils::replacePrefix(const GTestEnvironment *env, QString &path) {
         envVarName = "WORKFLOW_OUTPUT_DIR";
         prefix = WORKFLOW_OUTPUT_DIR_PREFIX;
     } else {
-        algoLog.details(QString("There are no known prefixes in the path: '%1', the path was not modified").arg(path));
         return;
     }
 
@@ -140,31 +140,24 @@ void XMLTestUtils::replacePrefix(const GTestEnvironment *env, QString &path) {
     int prefixSize = prefix.size();
     QStringList relativePaths = path.mid(prefixSize).split(";");
 
-    for (const QString &releativePath : qAsConst(relativePaths)) {
-        QString fullPath = prefixPath + releativePath;
+    for (const QString& relativePath : qAsConst(relativePaths)) {
+        QString fullPath = prefixPath + relativePath;
         result += fullPath + ";";
     }
 
     path = result.mid(0, result.size() - 1);  // without the last ';'
 }
 
-bool XMLTestUtils::parentTasksHaveError(Task *t) {
-    Task *parentTask = t->getParentTask();
-    CHECK(nullptr != parentTask, false);
-
-    bool result = false;
-    if (parentTask->hasError()) {
-        result = true;
-    } else {
-        result = parentTasksHaveError(parentTask);
-    }
-    return result;
+bool XMLTestUtils::parentTasksHaveError(Task* t) {
+    Task* parentTask = t->getParentTask();
+    CHECK(parentTask != nullptr, false);
+    return parentTask->hasError() || parentTasksHaveError(parentTask);
 }
 
 const QString XMLMultiTest::FAIL_ON_SUBTEST_FAIL = "fail-on-subtest-fail";
 const QString XMLMultiTest::LOCK_FOR_LOG_LISTENING = "lockForLogListening";
 
-void XMLMultiTest::init(XMLTestFormat *tf, const QDomElement &el) {
+void XMLMultiTest::init(XMLTestFormat* tf, const QDomElement& el) {
     // This attribute is used to avoid mixing log messages between different tests
     // Each test that listens to log should set this attribute to "true"
     // See also: GTestLogHelper
@@ -184,7 +177,7 @@ void XMLMultiTest::init(XMLTestFormat *tf, const QDomElement &el) {
     }
 
     QDomNodeList subtaskNodes = el.childNodes();
-    QList<Task *> subs;
+    QList<Task*> subs;
     for (int i = 0; i < subtaskNodes.size(); i++) {
         QDomNode n = subtaskNodes.item(i);
         if (!n.isElement()) {
@@ -193,7 +186,7 @@ void XMLMultiTest::init(XMLTestFormat *tf, const QDomElement &el) {
         QDomElement subEl = n.toElement();
         QString name = subEl.tagName();
         QString err;
-        GTest *subTest = tf->createTest(name, this, env, subEl, err);
+        GTest* subTest = tf->createTest(name, this, env, subEl, err);
         if (!err.isEmpty()) {
             stateInfo.setError(err);
             break;
@@ -203,13 +196,9 @@ void XMLMultiTest::init(XMLTestFormat *tf, const QDomElement &el) {
         subs.append(subTest);
     }
     if (!hasError()) {
-        if (lockForLogListening) {
-            addTaskResource(TaskResourceUsage(RESOURCE_LISTEN_LOG_IN_TESTS, TaskResourceUsage::Write, true));
-        } else {
-            addTaskResource(TaskResourceUsage(RESOURCE_LISTEN_LOG_IN_TESTS, TaskResourceUsage::Read, true));
-        }
-
-        foreach (Task *t, subs) {
+        auto lockTime = lockForLogListening ? AppResourceReadWriteLock::Write : AppResourceReadWriteLock::Read;
+        addTaskResource(TaskResourceUsage(UGENE_RESOURCE_ID_TEST_LOG_LISTENER, lockTime, TaskResourceStage::Prepare));
+        for (Task* t : qAsConst(subs)) {
             addSubTask(t);
         }
     }
@@ -217,7 +206,7 @@ void XMLMultiTest::init(XMLTestFormat *tf, const QDomElement &el) {
 
 Task::ReportResult XMLMultiTest::report() {
     if (!hasError()) {
-        Task *t = getSubtaskWithErrors();
+        Task* t = getSubtaskWithErrors();
         if (t != nullptr) {
             stateInfo.setError(t->getError());
         }
@@ -225,7 +214,7 @@ Task::ReportResult XMLMultiTest::report() {
     return ReportResult_Finished;
 }
 
-void GTest_Fail::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_Fail::init(XMLTestFormat*, const QDomElement& el) {
     msg = el.attribute("msg");
 }
 
@@ -234,7 +223,7 @@ Task::ReportResult GTest_Fail::report() {
     return ReportResult_Finished;
 }
 
-void GTest_DeleteTmpFile::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_DeleteTmpFile::init(XMLTestFormat*, const QDomElement& el) {
     url = el.attribute("file");
     if (url.isEmpty()) {
         failMissingValue("url");
@@ -252,7 +241,7 @@ Task::ReportResult GTest_DeleteTmpFile::report() {
     return ReportResult_Finished;
 }
 
-void GTest_CreateTmpFolder::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_CreateTmpFolder::init(XMLTestFormat*, const QDomElement& el) {
     url = el.attribute("folder");
     if (url.isEmpty()) {
         failMissingValue("folder");
