@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,119 +29,120 @@
 
 #include <U2Gui/GUIUtils.h>
 
-#include "ov_msa/MaCollapseModel.h"
-
 namespace U2 {
 
-MsaUndoRedoFramework::MsaUndoRedoFramework(QObject *p, MultipleAlignmentObject *_maObj)
-    : QObject(p),
-      maObj(_maObj),
-      stateComplete(true),
-      undoStepsAvailable(0),
-      redoStepsAvailable(0) {
-    SAFE_POINT(maObj != nullptr, "NULL MSA Object!", );
+MaUndoRedoFramework::MaUndoRedoFramework(QObject* parent, MultipleAlignmentObject* _maObject)
+    : QObject(parent),
+      maObject(_maObject) {
+    SAFE_POINT(maObject != nullptr, "NULL MSA Object!", );
 
-    undoAction = new QAction(this);
-    undoAction->setText(tr("Undo"));
-    undoAction->setIcon(QIcon(":core/images/undo.png"));
+    undoAction = new QAction(QIcon(":core/images/undo.png"), tr("Undo"), this);
+    undoAction->setObjectName("msa_action_undo");
     undoAction->setShortcut(QKeySequence::Undo);
     GUIUtils::updateActionToolTip(undoAction);
 
-    redoAction = new QAction(this);
-    redoAction->setText(tr("Redo"));
-    redoAction->setIcon(QIcon(":core/images/redo.png"));
+    redoAction = new QAction(QIcon(":core/images/redo.png"), tr("Redo"), this);
+    redoAction->setObjectName("msa_action_redo");
     redoAction->setShortcut(QKeySequence::Redo);
     GUIUtils::updateActionToolTip(redoAction);
 
     checkUndoRedoEnabled();
 
-    connect(maObj, SIGNAL(si_alignmentChanged(const MultipleAlignment &, const MaModificationInfo &)), SLOT(sl_updateUndoRedoState()));
-    connect(maObj, SIGNAL(si_completeStateChanged(bool)), SLOT(sl_completeStateChanged(bool)));
-    connect(maObj, SIGNAL(si_lockedStateChanged()), SLOT(sl_updateUndoRedoState()));
+    connect(maObject, SIGNAL(si_alignmentChanged(const MultipleAlignment&, const MaModificationInfo&)), SLOT(sl_updateUndoRedoState()));
+    connect(maObject, SIGNAL(si_completeStateChanged(bool)), SLOT(sl_completeStateChanged(bool)));
+    connect(maObject, SIGNAL(si_lockedStateChanged()), SLOT(sl_updateUndoRedoState()));
     connect(undoAction, SIGNAL(triggered()), this, SLOT(sl_undo()));
     connect(redoAction, SIGNAL(triggered()), this, SLOT(sl_redo()));
 }
 
-void MsaUndoRedoFramework::sl_completeStateChanged(bool _stateComplete) {
+void MaUndoRedoFramework::sl_completeStateChanged(bool _stateComplete) {
     stateComplete = _stateComplete;
 }
 
-void MsaUndoRedoFramework::sl_updateUndoRedoState() {
+void MaUndoRedoFramework::sl_updateUndoRedoState() {
     checkUndoRedoEnabled();
 }
 
-void MsaUndoRedoFramework::checkUndoRedoEnabled() {
-    SAFE_POINT(maObj != nullptr, "NULL MSA Object!", );
+void MaUndoRedoFramework::checkUndoRedoEnabled() {
+    SAFE_POINT(maObject != nullptr, "NULL MSA Object!", );
 
-    if (maObj->isStateLocked() || !stateComplete) {
+    if (maObject->isStateLocked() || !stateComplete) {
         undoAction->setEnabled(false);
         redoAction->setEnabled(false);
         return;
     }
 
     U2OpStatus2Log os;
-    DbiConnection con(maObj->getEntityRef().dbiRef, os);
+    DbiConnection con(maObject->getEntityRef().dbiRef, os);
     SAFE_POINT_OP(os, );
 
-    U2ObjectDbi *objDbi = con.dbi->getObjectDbi();
-    SAFE_POINT(nullptr != objDbi, "NULL Object Dbi!", );
+    U2ObjectDbi* objDbi = con.dbi->getObjectDbi();
+    SAFE_POINT(objDbi != nullptr, "NULL Object Dbi!", );
 
-    bool enableUndo = objDbi->canUndo(maObj->getEntityRef().entityId, os);
+    bool enableUndo = objDbi->canUndo(maObject->getEntityRef().entityId, os);
     SAFE_POINT_OP(os, );
-    bool enableRedo = objDbi->canRedo(maObj->getEntityRef().entityId, os);
+    bool enableRedo = objDbi->canRedo(maObject->getEntityRef().entityId, os);
     SAFE_POINT_OP(os, );
 
     undoAction->setEnabled(enableUndo);
     redoAction->setEnabled(enableRedo);
     if (!enableUndo) {
-        maObj->setModified(false);
+        maObject->setModified(false);
     }
 }
 
-void MsaUndoRedoFramework::sl_undo() {
-    SAFE_POINT(maObj != nullptr, "NULL MSA Object!", );
+void MaUndoRedoFramework::sl_undo() {
+    SAFE_POINT(maObject != nullptr, "NULL MSA Object!", );
 
     U2OpStatus2Log os;
-    U2EntityRef msaRef = maObj->getEntityRef();
+    U2EntityRef msaRef = maObject->getEntityRef();
 
     assert(stateComplete);
-    assert(!maObj->isStateLocked());
+    assert(!maObject->isStateLocked());
 
     DbiConnection con(msaRef.dbiRef, os);
     SAFE_POINT_OP(os, );
 
-    U2ObjectDbi *objDbi = con.dbi->getObjectDbi();
-    SAFE_POINT(nullptr != objDbi, "NULL Object Dbi!", );
+    U2ObjectDbi* objDbi = con.dbi->getObjectDbi();
+    SAFE_POINT(objDbi != nullptr, "NULL Object Dbi!", );
 
     objDbi->undo(msaRef.entityId, os);
     SAFE_POINT_OP(os, );
 
     MaModificationInfo modInfo;
     modInfo.type = MaModificationType_Undo;
-    maObj->updateCachedMultipleAlignment(modInfo);
+    maObject->updateCachedMultipleAlignment(modInfo);
 }
 
-void MsaUndoRedoFramework::sl_redo() {
-    SAFE_POINT(maObj != nullptr, "NULL MSA Object!", );
+void MaUndoRedoFramework::sl_redo() {
+    SAFE_POINT(maObject != nullptr, "NULL MSA Object!", );
 
     U2OpStatus2Log os;
-    U2EntityRef msaRef = maObj->getEntityRef();
+    U2EntityRef msaRef = maObject->getEntityRef();
 
     assert(stateComplete);
-    assert(!maObj->isStateLocked());
+    assert(!maObject->isStateLocked());
 
     DbiConnection con(msaRef.dbiRef, os);
     SAFE_POINT_OP(os, );
 
-    U2ObjectDbi *objDbi = con.dbi->getObjectDbi();
-    SAFE_POINT(nullptr != objDbi, "NULL Object Dbi!", );
+    U2ObjectDbi* objDbi = con.dbi->getObjectDbi();
+    SAFE_POINT(objDbi != nullptr, "NULL Object Dbi!", );
 
     objDbi->redo(msaRef.entityId, os);
     SAFE_POINT_OP(os, );
 
     MaModificationInfo modInfo;
     modInfo.type = MaModificationType_Redo;
-    maObj->updateCachedMultipleAlignment(modInfo);
+    maObject->updateCachedMultipleAlignment(modInfo);
+}
+
+QAction* MaUndoRedoFramework::getUndoAction() const {
+    return undoAction;
+}
+
+QAction* MaUndoRedoFramework::getRedoAction() const {
+    return redoAction;
 }
 
 }  // namespace U2
