@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_WEB_WINDOW_H_
-#define _U2_WEB_WINDOW_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -38,9 +37,8 @@ namespace U2 {
 class U2VIEW_EXPORT WebWindow : public MWMDIWindow {
     Q_OBJECT
 public:
-    WebWindow(const QString &title, const QString &htmlContent);
-    QTextBrowser *textBrowser;
+    WebWindow(const QString& title, const QString& htmlContent);
+    QTextBrowser* textBrowser;
 };
 
 }  // namespace U2
-#endif
