@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _ASSEMBLY_ANNOTATIONS_AREA_
-#define _ASSEMBLY_ANNOTATIONS_AREA_
+#pragma once
 
 #include <QWidget>
 
@@ -33,16 +32,14 @@ class AssemblyVariantRowManager;
 class AssemblyAnnotationsArea : public QWidget {
     Q_OBJECT
 public:
-    AssemblyAnnotationsArea(AssemblyBrowserUi *ui);
+    AssemblyAnnotationsArea(AssemblyBrowserUi* ui);
     virtual ~AssemblyAnnotationsArea();
 
 signals:
-    void si_mouseMovedToPos(const QPoint &);
+    void si_mouseMovedToPos(const QPoint&);
 
 private:
-    AssemblyVariantRowManager *variantRowManager;
+    AssemblyVariantRowManager* variantRowManager;
 };
 
 }  // namespace U2
-
-#endif  // _ASSEMBLY_ANNOTATIONS_AREA_
