@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -37,6 +37,7 @@
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/DocumentModel.h>
+#include <U2Core/FileFilters.h>
 #include <U2Core/GObjectSelection.h>
 #include <U2Core/GUrlUtils.h>
 #include <U2Core/L10n.h>
@@ -56,7 +57,6 @@
 
 #include <U2Formats/ConvertAssemblyToSamTask.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/ExportImageDialog.h>
 #include <U2Gui/GUIUtils.h>
 #include <U2Gui/LastUsedDirHelper.h>
@@ -93,20 +93,22 @@ namespace U2 {
 const double AssemblyBrowser::ZOOM_MULT = 1.25;
 const double AssemblyBrowser::INITIAL_ZOOM_FACTOR = 1.;
 
-AssemblyBrowser::AssemblyBrowser(QString viewName, AssemblyObject *o)
-    : GObjectView(AssemblyBrowserFactory::ID, viewName), ui(nullptr),
+AssemblyBrowser::AssemblyBrowser(const QString& viewName, AssemblyObject* o)
+    : GObjectViewController(AssemblyBrowserFactory::ID, viewName), ui(nullptr),
       gobject(o), model(nullptr), zoomFactor(INITIAL_ZOOM_FACTOR), xOffsetInAssembly(0), yOffsetInAssembly(0), coverageReady(false),
       cellRendererRegistry(new AssemblyCellRendererFactoryRegistry(this)),
       zoomInAction(nullptr), zoomOutAction(nullptr), posSelectorAction(nullptr), posSelector(nullptr), showCoordsOnRulerAction(nullptr), saveScreenShotAction(nullptr),
       exportToSamAction(nullptr), setReferenceAction(nullptr), extractAssemblyRegionAction(nullptr), loadReferenceTask(nullptr) {
     GCOUNTER(cvar, "AssemblyBrowser");
+    optionsPanelController = new OptionsPanelController(this);
     initFont();
     setupActions();
 
+
     if (gobject) {
         objects.append(o);
         requiredObjects.append(o);
-        const U2EntityRef &ref = gobject->getEntityRef();
+        const U2EntityRef& ref = gobject->getEntityRef();
         model = QSharedPointer<AssemblyModel>(new AssemblyModel(DbiConnection(ref.dbiRef, dbiOpStatus)));
         connect(model.data(), SIGNAL(si_referenceChanged()), SLOT(sl_referenceChanged()));
         assemblyLoaded();
@@ -117,7 +119,7 @@ AssemblyBrowser::AssemblyBrowser(QString viewName, AssemblyObject *o)
 
 void AssemblyBrowser::removeReferenceSequence() {
     // Only one sequence object can be in assembly browser, it is a reference
-    foreach (GObject *o, objects) {
+    foreach (GObject* o, objects) {
         if (o->getGObjectType() == GObjectTypes::SEQUENCE) {
             removeObjectFromView(o);
             return;
@@ -128,14 +130,14 @@ void AssemblyBrowser::removeReferenceSequence() {
 void AssemblyBrowser::sl_referenceChanged() {
     removeReferenceSequence();
 
-    U2SequenceObject *so = model->getRefObj();
+    U2SequenceObject* so = model->getRefObj();
     if (so != nullptr) {
         addObjectToView(so);
     }
     setReferenceAction->setEnabled(!model->isLoadingReference());
 }
 
-bool AssemblyBrowser::checkValid(U2OpStatus &os) {
+bool AssemblyBrowser::checkValid(U2OpStatus& os) {
     if (dbiOpStatus.hasError()) {
         os.setError(tr("Error opening open assembly browser for %1, assembly %2")
                         .arg(gobject->getDocument()->getURLString())
@@ -155,9 +157,8 @@ bool AssemblyBrowser::checkValid(U2OpStatus &os) {
     return true;
 }
 
-QWidget *AssemblyBrowser::createWidget() {
-    optionsPanel = new OptionsPanel(this);
-    ui = new AssemblyBrowserUi(this);
+QWidget* AssemblyBrowser::createViewWidget(QWidget* parent) {
+    ui = new AssemblyBrowserUi(this, parent);
 
     const QString objectName = "assembly_browser_" + getName();
     ui->setObjectName(objectName);
@@ -175,27 +176,23 @@ QWidget *AssemblyBrowser::createWidget() {
 }
 
 QVariantMap AssemblyBrowser::saveState() {
-    if (nullptr != ui && ui->isCorrectView()) {
+    if (ui != nullptr && ui->isCorrectView()) {
         return AssemblyBrowserState::buildStateMap(this);
     } else {
         return QVariantMap();
     }
 }
 
-Task *AssemblyBrowser::updateViewTask(const QString &stateName, const QVariantMap &stateData) {
+Task* AssemblyBrowser::updateViewTask(const QString& stateName, const QVariantMap& stateData) {
     return new UpdateAssemblyBrowserTask(this, stateName, stateData);
 }
 
-OptionsPanel *AssemblyBrowser::getOptionsPanel() {
-    return optionsPanel;
-}
-
-bool AssemblyBrowser::eventFilter(QObject *o, QEvent *e) {
+bool AssemblyBrowser::eventFilter(QObject* o, QEvent* e) {
     if (o == ui) {
         if (e->type() == QEvent::DragEnter || e->type() == QEvent::Drop) {
-            QDropEvent *de = (QDropEvent *)e;
-            const QMimeData *md = de->mimeData();
-            const GObjectMimeData *gomd = qobject_cast<const GObjectMimeData *>(md);
+            QDropEvent* de = (QDropEvent*)e;
+            const QMimeData* md = de->mimeData();
+            auto gomd = qobject_cast<const GObjectMimeData*>(md);
             if (gomd != nullptr) {
                 if (e->type() == QEvent::DragEnter) {
                     de->acceptProposedAction();
@@ -212,21 +209,21 @@ bool AssemblyBrowser::eventFilter(QObject *o, QEvent *e) {
     return false;
 }
 
-QString AssemblyBrowser::tryAddObject(GObject *obj) {
-    Document *objDoc = obj->getDocument();
-    SAFE_POINT(nullptr != objDoc, "", tr("Internal error: only object with document can be added to browser"));
+QString AssemblyBrowser::tryAddObject(GObject* obj) {
+    Document* objDoc = obj->getDocument();
+    SAFE_POINT(objDoc != nullptr, "", tr("Internal error: only object with document can be added to browser"));
 
     static const QString unacceptableObjectError = tr("Only a nucleotide sequence or a variant track objects can be added to the Assembly Browser.");
 
     if (GObjectTypes::SEQUENCE == obj->getGObjectType()) {
-        U2SequenceObject *seqObj = qobject_cast<U2SequenceObject *>(obj);
-        CHECK(nullptr != seqObj, tr("Internal error: broken sequence object"));
-        SAFE_POINT(nullptr != objDoc->getDocumentFormat(), "", tr("Internal error: empty document format"));
+        auto seqObj = qobject_cast<U2SequenceObject*>(obj);
+        CHECK(seqObj != nullptr, tr("Internal error: broken sequence object"));
+        SAFE_POINT(objDoc->getDocumentFormat() != nullptr, "", tr("Internal error: empty document format"));
 
         bool setRef = !isAssemblyObjectLocked(true) && !model->isLoadingReference();
         setRef &= model->checkPermissions(QFile::WriteUser, setRef);
         if (setRef) {
-            const DNAAlphabet *alphabet = seqObj->getAlphabet();
+            const DNAAlphabet* alphabet = seqObj->getAlphabet();
             if (!alphabet->isNucleic()) {
                 return unacceptableObjectError;
             }
@@ -249,7 +246,7 @@ QString AssemblyBrowser::tryAddObject(GObject *obj) {
             if (seqObj->getEntityRef().dbiRef == model->getDbiConnection().dbi->getDbiRef()) {
                 refId = seqObj->getEntityRef().entityId;
             } else {
-                U2CrossDatabaseReferenceDbi *crossDbi = model->getDbiConnection().dbi->getCrossDatabaseReferenceDbi();
+                U2CrossDatabaseReferenceDbi* crossDbi = model->getDbiConnection().dbi->getCrossDatabaseReferenceDbi();
                 U2CrossDatabaseReference crossDbRef;
                 // Cannot simply use seqObj->getSequenceRef(), since it points to a temporary dbi
                 // TODO: make similar method seqObj->getPersistentSequenctRef()
@@ -266,12 +263,12 @@ QString AssemblyBrowser::tryAddObject(GObject *obj) {
             model->associateWithReference(refId);
         }
     } else if (GObjectTypes::VARIANT_TRACK == obj->getGObjectType()) {
-        VariantTrackObject *trackObj = qobject_cast<VariantTrackObject *>(obj);
-        CHECK(nullptr != trackObj, tr("Internal error: broken variant track object"));
+        auto trackObj = qobject_cast<VariantTrackObject*>(obj);
+        CHECK(trackObj != nullptr, tr("Internal error: broken variant track object"));
 
         model->addTrackObject(trackObj);
         addObjectToView(obj);
-        connect(model.data(), SIGNAL(si_trackRemoved(VariantTrackObject *)), SLOT(sl_trackRemoved(VariantTrackObject *)));
+        connect(model.data(), SIGNAL(si_trackRemoved(VariantTrackObject*)), SLOT(sl_trackRemoved(VariantTrackObject*)));
     } else {
         return unacceptableObjectError;
     }
@@ -287,7 +284,7 @@ bool AssemblyBrowser::isAssemblyObjectLocked(bool showDialog) const {
     return isLocked;
 }
 
-void AssemblyBrowser::buildStaticToolbar(QToolBar *staticToolBar) {
+void AssemblyBrowser::buildStaticToolbar(QToolBar* staticToolBar) {
     U2OpStatusImpl os;
     if (model->hasReads(os)) {
         staticToolBar->addAction(zoomInAction);
@@ -322,16 +319,16 @@ void AssemblyBrowser::buildStaticToolbar(QToolBar *staticToolBar) {
         staticToolBar->addAction(extractAssemblyRegionAction);
         staticToolBar->addAction(saveScreenShotAction);
     }
-    GObjectView::buildStaticToolbar(staticToolBar);
+    GObjectViewController::buildStaticToolbar(staticToolBar);
 }
 
 void AssemblyBrowser::sl_onPosChangeRequest(int pos) {
     setXOffsetInAssembly(normalizeXoffset(pos - 1));
     ui->getReadsArea()->setFocus();
 }
-void AssemblyBrowser::buildMenu(QMenu *menu, const QString &type) {
+void AssemblyBrowser::buildMenu(QMenu* menu, const QString& type) {
     if (type != GObjectViewMenuType::STATIC) {
-        GObjectView::buildMenu(menu, type);
+        GObjectViewController::buildMenu(menu, type);
         return;
     }
     U2OpStatusImpl os;
@@ -343,7 +340,7 @@ void AssemblyBrowser::buildMenu(QMenu *menu, const QString &type) {
         menu->addAction(extractAssemblyRegionAction);
         menu->addAction(setReferenceAction);
     }
-    GObjectView::buildMenu(menu, type);
+    GObjectViewController::buildMenu(menu, type);
     GUIUtils::disableEmptySubmenus(menu);
 }
 
@@ -383,13 +380,13 @@ QList<CoveredRegion> AssemblyBrowser::getCoveredRegions() const {
     return QList<CoveredRegion>();
 }
 
-void AssemblyBrowser::setLocalCoverageCache(CoverageInfo coverage) {
+void AssemblyBrowser::setLocalCoverageCache(const CoverageInfo& coverage) {
     SAFE_POINT(coverage.region.length == coverage.coverageInfo.size(),
                "Coverage info with region not equal to coverage array size (not precise coverage) cannot be used as local coverage cache", );
     localCoverageCache = coverage;
 }
 
-bool AssemblyBrowser::isInLocalCoverageCache(qint64 position) {
+bool AssemblyBrowser::isInLocalCoverageCache(qint64 position) const {
     return localCoverageCache.region.contains(position);
 }
 
@@ -409,15 +406,15 @@ qint32 AssemblyBrowser::getCoverageAtPos(qint64 pos) {
     }
 }
 
-bool AssemblyBrowser::intersectsLocalCoverageCache(U2Region region) {
+bool AssemblyBrowser::intersectsLocalCoverageCache(const U2Region& region) const {
     return !localCoverageCache.region.isEmpty() && localCoverageCache.region.intersects(region);
 }
 
-bool AssemblyBrowser::isInLocalCoverageCache(U2Region region) {
+bool AssemblyBrowser::isInLocalCoverageCache(const U2Region& region) {
     return localCoverageCache.region.contains(region);
 }
 
-CoverageInfo AssemblyBrowser::extractFromLocalCoverageCache(U2Region region) {
+CoverageInfo AssemblyBrowser::extractFromLocalCoverageCache(const U2Region& region) {
     CoverageInfo ci;
     ci.region = region;
     ci.coverageInfo.resize(region.length);
@@ -616,7 +613,7 @@ void AssemblyBrowser::setFocusToPosSelector() {
     posSelector->getPosEdit()->setFocus();
 }
 
-void AssemblyBrowser::navigateToRegion(const U2Region &region) {
+void AssemblyBrowser::navigateToRegion(const U2Region& region) {
     int requiredCellSize = qMax(1, qRound((double)ui->getReadsArea()->width() / region.length));
     zoomToSize(requiredCellSize);
 
@@ -644,9 +641,9 @@ void AssemblyBrowser::setupActions() {
     zoomOutAction = new QAction(QIcon(":core/images/zoom_out.png"), tr("Zoom out"), this);
     connect(zoomOutAction, SIGNAL(triggered()), SLOT(sl_zoomOut()));
 
-    QAction *linearScaleAction = new QAction(tr("Linear"), this);
+    QAction* linearScaleAction = new QAction(tr("Linear"), this);
     linearScaleAction->setCheckable(true);
-    QAction *logScaleAction = new QAction(tr("Logarithmic"), this);
+    QAction* logScaleAction = new QAction(tr("Logarithmic"), this);
     logScaleAction->setCheckable(true);
     connect(linearScaleAction, SIGNAL(triggered()), SLOT(sl_changeOverviewType()));
     connect(logScaleAction, SIGNAL(triggered()), SLOT(sl_changeOverviewType()));
@@ -681,7 +678,7 @@ void AssemblyBrowser::setupActions() {
 }
 
 void AssemblyBrowser::sl_saveScreenshot() {
-    QWidget *p = (QWidget *)AppContext::getMainWindow()->getQMainWindow();
+    QWidget* p = (QWidget*)AppContext::getMainWindow()->getQMainWindow();
     QString fileName = GUrlUtils::fixFileName(gobject->getGObjectName());
     QObjectScopedPointer<ExportImageDialog> dialog = new ExportImageDialog(ui, ExportImageDialog::AssemblyView, fileName, ExportImageDialog::NoScaling, p);
     dialog->exec();
@@ -696,7 +693,7 @@ void AssemblyBrowser::sl_exportToSam() {
     CHECK(!dialog.isNull(), );
 
     if (QDialog::Accepted == dialogResult) {
-        ConvertAssemblyToSamTask *convertTask = new ConvertAssemblyToSamTask(&(model->getDbiConnection()), dialog->getSamFileUrl());
+        ConvertAssemblyToSamTask* convertTask = new ConvertAssemblyToSamTask(&(model->getDbiConnection()), dialog->getSamFileUrl());
         AppContext::getTaskScheduler()->registerTopLevelTask(convertTask);
     }
 }
@@ -708,7 +705,7 @@ void AssemblyBrowser::sl_exportCoverage() {
     CHECK(!d.isNull(), );
 
     if (QDialog::Accepted == dialogResult) {
-        Task *exportTask = nullptr;
+        Task* exportTask = nullptr;
         switch (d->getFormat()) {
             case ExportCoverageSettings::Histogram:
                 exportTask = new ExportCoverageHistogramTask(getModel()->getDbiConnection().dbi->getDbiRef(), assembly.id, d->getSettings());
@@ -747,7 +744,7 @@ void AssemblyBrowser::sl_onReadHintEnabledChanged(bool checked) {
 }
 
 void AssemblyBrowser::sl_changeOverviewType() {
-    QAction *a = qobject_cast<QAction *>(sender());
+    auto a = qobject_cast<QAction*>(sender());
     if (a == nullptr) {
         assert(false);
         return;
@@ -786,7 +783,7 @@ void AssemblyBrowser::updateOverviewTypeActions() {
     overviewScaleTypeActions[1]->setChecked(t == AssemblyBrowserSettings::Scale_Logarithmic);
 }
 
-void AssemblyBrowser::sl_zoomIn(const QPoint &pos) {
+void AssemblyBrowser::sl_zoomIn(const QPoint& pos) {
     if (!canPerformZoomIn()) {
         return;
     }
@@ -822,7 +819,7 @@ void AssemblyBrowser::sl_zoomIn(const QPoint &pos) {
     emit si_zoomOperationPerformed();
 }
 
-void AssemblyBrowser::sl_zoomOut(const QPoint &pos) {
+void AssemblyBrowser::sl_zoomOut(const QPoint& pos) {
     if (!canPerformZoomOut()) {
         return;
     }
@@ -905,12 +902,12 @@ void AssemblyBrowser::zoomToSize(int reqCellSize) {
     emit si_zoomOperationPerformed();
 }
 
-void AssemblyBrowser::onObjectRenamed(GObject *, const QString &) {
+void AssemblyBrowser::onObjectRenamed(GObject*, const QString&) {
     OpenAssemblyBrowserTask::updateTitle(this);
 }
 
 bool AssemblyBrowser::onCloseEvent() {
-    if (nullptr != loadReferenceTask) {
+    if (loadReferenceTask != nullptr) {
         loadReferenceTask->cancel();
     }
     return true;
@@ -932,12 +929,12 @@ void AssemblyBrowser::sl_coveredRegionClicked(const QString link) {
 void AssemblyBrowser::assemblyLoaded() {
     GTIMER(c1, t1, "AssemblyBrowser::assemblyLoaded");
     LOG_OP(dbiOpStatus);
-    U2Dbi *dbi = model->getDbiConnection().dbi;
-    CHECK(nullptr != dbi, );
+    U2Dbi* dbi = model->getDbiConnection().dbi;
+    CHECK(dbi != nullptr, );
 
     assert(U2DbiState_Ready == dbi->getState());
 
-    U2AssemblyDbi *assmDbi = dbi->getAssemblyDbi();
+    U2AssemblyDbi* assmDbi = dbi->getAssemblyDbi();
 
     U2DataId objectId = gobject->getEntityRef().entityId;
     U2Assembly assm = dbi->getAssemblyDbi()->getAssemblyObject(objectId, dbiOpStatus);
@@ -946,25 +943,25 @@ void AssemblyBrowser::assemblyLoaded() {
     model->setAssembly(assmDbi, assm);
 }
 
-void AssemblyBrowser::addObjectToView(GObject *o) {
+void AssemblyBrowser::addObjectToView(GObject* o) {
     objects.append(o);
     onObjectAdded(o);
     emit si_objectAdded(this, o);
 }
 
-void AssemblyBrowser::removeObjectFromView(GObject *o) {
+void AssemblyBrowser::removeObjectFromView(GObject* o) {
     objects.removeAll(o);
     emit si_objectRemoved(this, o);
 }
 
-void AssemblyBrowser::sl_trackRemoved(VariantTrackObject *obj) {
+void AssemblyBrowser::sl_trackRemoved(VariantTrackObject* obj) {
     removeObjectFromView(obj);
 }
 
 namespace {
-QList<GObject *> extractSequenceObjects(const QList<GObject *> &objects) {
-    QList<GObject *> result;
-    foreach (GObject *object, objects) {
+QList<GObject*> extractSequenceObjects(const QList<GObject*>& objects) {
+    QList<GObject*> result;
+    foreach (GObject* object, objects) {
         if (object->getGObjectType() == GObjectTypes::SEQUENCE) {
             result << object;
         }
@@ -972,17 +969,17 @@ QList<GObject *> extractSequenceObjects(const QList<GObject *> &objects) {
     return result;
 }
 
-const char *REFERENCE_URL_PROPERTY = "reference-url";
+const char* REFERENCE_URL_PROPERTY = "reference-url";
 
-QString getReferenceUrl(Task *loadReferenceTask) {
+QString getReferenceUrl(Task* loadReferenceTask) {
     return loadReferenceTask->property(REFERENCE_URL_PROPERTY).toString();
 }
 
-void prepareLoadReferenceTask(const QString &referenceUrl, Task *loadReferenceTask) {
+void prepareLoadReferenceTask(const QString& referenceUrl, Task* loadReferenceTask) {
     loadReferenceTask->setProperty(REFERENCE_URL_PROPERTY, referenceUrl);
 }
 
-Task *createLoadReferenceTask(const QString &url) {
+Task* createLoadReferenceTask(const QString& url) {
     QVariantMap hints;
     hints[ProjectLoaderHint_LoadWithoutView] = true;
     return AppContext::getProjectLoader()->openWithProjectTask(QList<GUrl>() << url, hints);
@@ -990,15 +987,15 @@ Task *createLoadReferenceTask(const QString &url) {
 }  // namespace
 
 QString AssemblyBrowser::chooseReferenceUrl() const {
-    const QString filter = DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::SEQUENCE, true);
+    QString filter = FileFilters::createFileFilterByObjectTypes({GObjectTypes::SEQUENCE});
     LastUsedDirHelper lod;
-    const QString url = U2FileDialog::getOpenFileName(ui, tr("Open file with a sequence"), lod.dir, filter);
+    QString url = U2FileDialog::getOpenFileName(ui, tr("Open file with a sequence"), lod.dir, filter);
     CHECK(!url.isEmpty(), "");
     lod.url = url;
     return url;
 }
 
-void AssemblyBrowser::showReferenceLoadingError(const QList<GObject *> &sequenceObjects, const QString &url) const {
+void AssemblyBrowser::showReferenceLoadingError(const QList<GObject*>& sequenceObjects, const QString& url) const {
     QString message;
     if (sequenceObjects.isEmpty()) {
         message = tr("An error occurred while setting reference to \"%1\" assembly. The selected file \"%2\" does not contain sequences.").arg(gobject->getGObjectName()).arg(url);
@@ -1020,14 +1017,14 @@ void AssemblyBrowser::loadReferenceFromFile() {
     bool loadInProgress = false;
     if (ProjectUtils::hasUnloadedDocument(url)) {
         loadReferenceTask = ProjectUtils::findLoadTask(url);
-        if (nullptr == loadReferenceTask) {
+        if (loadReferenceTask == nullptr) {
             loadReferenceTask = new LoadUnloadedDocumentTask(ProjectUtils::findDocument(url));
         } else {
             loadInProgress = true;
         }
     } else {
         loadReferenceTask = createLoadReferenceTask(url);
-        CHECK(nullptr != loadReferenceTask, );
+        CHECK(loadReferenceTask != nullptr, );
     }
 
     prepareLoadReferenceTask(url, loadReferenceTask);
@@ -1040,9 +1037,9 @@ void AssemblyBrowser::loadReferenceFromFile() {
     }
 }
 
-void AssemblyBrowser::setReference(const Document *doc) {
-    CHECK(nullptr != doc, );
-    const QList<GObject *> objects = doc->findGObjectByType(GObjectTypes::SEQUENCE);
+void AssemblyBrowser::setReference(const Document* doc) {
+    CHECK(doc != nullptr, );
+    const QList<GObject*> objects = doc->findGObjectByType(GObjectTypes::SEQUENCE);
 
     if (1 == objects.size()) {
         tryAddObject(objects.first());
@@ -1052,11 +1049,11 @@ void AssemblyBrowser::setReference(const Document *doc) {
 }
 
 void AssemblyBrowser::sl_setReference() {
-    const ProjectView *projectView = AppContext::getProjectView();
-    SAFE_POINT(nullptr != projectView, L10N::nullPointerError("ProjectView"), );
+    const ProjectView* projectView = AppContext::getProjectView();
+    SAFE_POINT_NN(projectView, );
 
-    const GObjectSelection *selection = projectView->getGObjectSelection();
-    const QList<GObject *> objects = extractSequenceObjects(selection->getSelectedObjects());
+    const GObjectSelection* selection = projectView->getGObjectSelection();
+    const QList<GObject*> objects = extractSequenceObjects(selection->getSelectedObjects());
 
     if (objects.isEmpty()) {
         loadReferenceFromFile();
@@ -1084,8 +1081,8 @@ void AssemblyBrowser::sl_extractAssemblyRegion() {
 }
 
 void AssemblyBrowser::sl_onReferenceLoaded() {
-    Task *task = loadReferenceTask;
-    CHECK(nullptr != task, );
+    Task* task = loadReferenceTask;
+    CHECK(task != nullptr, );
     CHECK(task->isFinished(), );
 
     loadReferenceTask = nullptr;
@@ -1096,8 +1093,8 @@ void AssemblyBrowser::sl_onReferenceLoaded() {
     const QString url = getReferenceUrl(task);
     CHECK(!url.isEmpty(), );
 
-    const Project *project = AppContext::getProject();
-    CHECK(nullptr != project, );
+    const Project* project = AppContext::getProject();
+    CHECK(project != nullptr, );
 
     setReference(project->findDocumentByURL(url));
 }
@@ -1106,15 +1103,15 @@ void AssemblyBrowser::sl_onReferenceLoaded() {
 // AssemblyBrowserUi
 //==============================================================================
 
-AssemblyBrowserUi::AssemblyBrowserUi(AssemblyBrowser *browser_)
-    : browser(browser_), zoomableOverview(0),
+AssemblyBrowserUi::AssemblyBrowserUi(AssemblyBrowser* browser_, QWidget* parent)
+    : QWidget(parent), browser(browser_), zoomableOverview(0),
       referenceArea(0), coverageGraph(0), ruler(0), readsArea(0), annotationsArea(0), nothingToVisualize(true) {
     U2OpStatusImpl os;
     if (browser->getModel()->hasReads(os)) {  // has mapped reads -> show rich visualization
         setMinimumSize(300, 200);
 
-        QScrollBar *readsHBar = new QScrollBar(Qt::Horizontal);
-        QScrollBar *readsVBar = new QScrollBar(Qt::Vertical);
+        QScrollBar* readsHBar = new QScrollBar(Qt::Horizontal);
+        QScrollBar* readsVBar = new QScrollBar(Qt::Vertical);
 
         zoomableOverview = new ZoomableAssemblyOverview(this, true);  // zooming temporarily disabled -iefremov
         referenceArea = new AssemblyReferenceArea(this);
@@ -1124,12 +1121,12 @@ AssemblyBrowserUi::AssemblyBrowserUi(AssemblyBrowser *browser_)
         readsArea = new AssemblyReadsArea(this, readsHBar, readsVBar);
         annotationsArea = new AssemblyAnnotationsArea(this);
 
-        QVBoxLayout *mainLayout = new QVBoxLayout();
+        QVBoxLayout* mainLayout = new QVBoxLayout();
         mainLayout->setMargin(0);
         mainLayout->setSpacing(2);
         mainLayout->addWidget(zoomableOverview);
 
-        QGridLayout *readsLayout = new QGridLayout();
+        QGridLayout* readsLayout = new QGridLayout();
         readsLayout->setMargin(0);
         readsLayout->setSpacing(0);
 
@@ -1143,20 +1140,20 @@ AssemblyBrowserUi::AssemblyBrowserUi(AssemblyBrowser *browser_)
         readsLayout->addWidget(readsVBar, 5, 1, 1, 1);
         readsLayout->addWidget(readsHBar, 5, 0);
 
-        QWidget *readsLayoutWidget = new QWidget;
+        QWidget* readsLayoutWidget = new QWidget;
         readsLayoutWidget->setLayout(readsLayout);
         mainLayout->addWidget(readsLayoutWidget);
         mainLayout->addWidget(readsHBar);
 
-        OPWidgetFactoryRegistry *opWidgetFactoryRegistry = AppContext::getOPWidgetFactoryRegistry();
-        OptionsPanel *optionsPanel = browser->getOptionsPanel();
+        OPWidgetFactoryRegistry* opWidgetFactoryRegistry = AppContext::getOPWidgetFactoryRegistry();
+        OptionsPanelController* optionsPanel = browser->getOptionsPanelController();
 
-        QList<OPFactoryFilterVisitorInterface *> filters;
+        QList<OPFactoryFilterVisitorInterface*> filters;
         filters.append(new OPFactoryFilterVisitor(ObjViewType_AssemblyBrowser));
 
-        QList<OPWidgetFactory *> opWidgetFactoriesForAssBr =
+        QList<OPWidgetFactory*> opWidgetFactoriesForAssBr =
             opWidgetFactoryRegistry->getRegisteredFactories(filters);
-        foreach (OPWidgetFactory *factory, opWidgetFactoriesForAssBr) {
+        foreach (OPWidgetFactory* factory, opWidgetFactoriesForAssBr) {
             optionsPanel->addGroup(factory);
         }
 
@@ -1166,11 +1163,11 @@ AssemblyBrowserUi::AssemblyBrowserUi(AssemblyBrowser *browser_)
         nothingToVisualize = false;
 
         connect(readsArea, SIGNAL(si_heightChanged()), zoomableOverview, SLOT(sl_visibleAreaChanged()));
-        connect(readsArea, SIGNAL(si_mouseMovedToPos(const QPoint &)), ruler, SLOT(sl_handleMoveToPos(const QPoint &)));
-        connect(referenceArea, SIGNAL(si_mouseMovedToPos(const QPoint &)), ruler, SLOT(sl_handleMoveToPos(const QPoint &)));
-        connect(consensusArea, SIGNAL(si_mouseMovedToPos(const QPoint &)), ruler, SLOT(sl_handleMoveToPos(const QPoint &)));
-        connect(coverageGraph, SIGNAL(si_mouseMovedToPos(const QPoint &)), ruler, SLOT(sl_handleMoveToPos(const QPoint &)));
-        connect(annotationsArea, SIGNAL(si_mouseMovedToPos(const QPoint &)), ruler, SLOT(sl_handleMoveToPos(const QPoint &)));
+        connect(readsArea, SIGNAL(si_mouseMovedToPos(const QPoint&)), ruler, SLOT(sl_handleMoveToPos(const QPoint&)));
+        connect(referenceArea, SIGNAL(si_mouseMovedToPos(const QPoint&)), ruler, SLOT(sl_handleMoveToPos(const QPoint&)));
+        connect(consensusArea, SIGNAL(si_mouseMovedToPos(const QPoint&)), ruler, SLOT(sl_handleMoveToPos(const QPoint&)));
+        connect(coverageGraph, SIGNAL(si_mouseMovedToPos(const QPoint&)), ruler, SLOT(sl_handleMoveToPos(const QPoint&)));
+        connect(annotationsArea, SIGNAL(si_mouseMovedToPos(const QPoint&)), ruler, SLOT(sl_handleMoveToPos(const QPoint&)));
         connect(browser, SIGNAL(si_offsetsChanged()), readsArea, SLOT(sl_hideHint()));
         connect(browser->getModel().data(), SIGNAL(si_referenceChanged()), referenceArea, SLOT(sl_redraw()));
         connect(browser->getModel().data(), SIGNAL(si_referenceChanged()), readsArea, SLOT(sl_redraw()));
@@ -1180,9 +1177,9 @@ AssemblyBrowserUi::AssemblyBrowserUi(AssemblyBrowser *browser_)
     }
     // do not how to show them
     else {
-        QVBoxLayout *mainLayout = new QVBoxLayout();
+        QVBoxLayout* mainLayout = new QVBoxLayout();
         QString msg = tr("Assembly has no mapped reads. Nothing to visualize.");
-        QLabel *infoLabel = new QLabel(QString("<table align=\"center\"><tr><td>%1</td></tr></table>").arg(msg), this);
+        QLabel* infoLabel = new QLabel(QString("<table align=\"center\"><tr><td>%1</td></tr></table>").arg(msg), this);
         infoLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
         mainLayout->addWidget(infoLabel);
         setLayout(mainLayout);
