@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -41,18 +41,18 @@ namespace U2 {
 // OpenAssemblyBrowserTask - open new view
 //==============================================================================
 
-OpenAssemblyBrowserTask::OpenAssemblyBrowserTask(AssemblyObject *obj)
+OpenAssemblyBrowserTask::OpenAssemblyBrowserTask(AssemblyObject* obj)
     : ObjectViewTask(AssemblyBrowserFactory::ID) {
     selectedObjects.append(obj);
 }
 
-OpenAssemblyBrowserTask::OpenAssemblyBrowserTask(UnloadedObject *unloadedObj)
+OpenAssemblyBrowserTask::OpenAssemblyBrowserTask(UnloadedObject* unloadedObj)
     : ObjectViewTask(AssemblyBrowserFactory::ID),
       unloadedObjRef(unloadedObj) {
     documentsToLoad.append(unloadedObj->getDocument());
 }
 
-OpenAssemblyBrowserTask::OpenAssemblyBrowserTask(Document *doc)
+OpenAssemblyBrowserTask::OpenAssemblyBrowserTask(Document* doc)
     : ObjectViewTask(AssemblyBrowserFactory::ID) {
     assert(!doc->isLoaded());
     documentsToLoad.append(doc);
@@ -65,25 +65,25 @@ void OpenAssemblyBrowserTask::open() {
 
     if (selectedObjects.isEmpty()) {
         assert(documentsToLoad.size() == 1);
-        Document *doc = documentsToLoad.first();
-        QList<GObject *> objects;
+        Document* doc = documentsToLoad.first();
+        QList<GObject*> objects;
         if (unloadedObjRef.isValid()) {
             // To do: replace the object finding to "GObject* obj = doc->findGObjectByName(unloadedObjRef.objName);" after fixing of UGENE-4904
-            QList<GObject *> objs = doc->findGObjectByType(unloadedObjRef.objType);
-            GObject *obj = nullptr;
-            foreach (GObject *curObj, objs) {
+            QList<GObject*> objs = doc->findGObjectByType(unloadedObjRef.objType);
+            GObject* obj = nullptr;
+            foreach (GObject* curObj, objs) {
                 if (curObj->getGObjectName() == unloadedObjRef.objName) {
                     obj = curObj;
                     break;
                 }
             }
             if (obj != nullptr && obj->getGObjectType() == GObjectTypes::ASSEMBLY) {
-                selectedObjects.append(qobject_cast<AssemblyObject *>(obj));
+                selectedObjects.append(qobject_cast<AssemblyObject*>(obj));
             }
         } else {
-            QList<GObject *> assemblyObjects = doc->findGObjectByType(GObjectTypes::ASSEMBLY, UOF_LoadedAndUnloaded);
+            QList<GObject*> assemblyObjects = doc->findGObjectByType(GObjectTypes::ASSEMBLY, UOF_LoadedAndUnloaded);
             if (!assemblyObjects.isEmpty()) {
-                selectedObjects.append(qobject_cast<AssemblyObject *>(assemblyObjects.first()));
+                selectedObjects.append(qobject_cast<AssemblyObject*>(assemblyObjects.first()));
             }
         }
         if (selectedObjects.isEmpty()) {
@@ -93,7 +93,7 @@ void OpenAssemblyBrowserTask::open() {
     }
 
     foreach (QPointer<GObject> po, selectedObjects) {
-        AssemblyObject *o = qobject_cast<AssemblyObject *>(po);
+        auto o = qobject_cast<AssemblyObject*>(po);
 
         SAFE_POINT(o, "Invalid assembly object!", );
 
@@ -102,25 +102,25 @@ void OpenAssemblyBrowserTask::open() {
     }
 }
 
-void OpenAssemblyBrowserTask::updateTitle(AssemblyBrowser *ab) {
-    const QString &oldViewName = ab->getName();
-    GObjectViewWindow *w = GObjectViewUtils::findViewByName(oldViewName);
+void OpenAssemblyBrowserTask::updateTitle(AssemblyBrowser* ab) {
+    const QString& oldViewName = ab->getName();
+    GObjectViewWindow* w = GObjectViewUtils::findViewByName(oldViewName);
     if (w != nullptr) {
-        AssemblyObject *aObj = ab->getAssemblyObject();
+        AssemblyObject* aObj = ab->getAssemblyObject();
         QString newViewName = GObjectViewUtils::genUniqueViewName(aObj->getDocument(), aObj);
         ab->setName(newViewName);
         w->setWindowTitle(newViewName);
     }
 }
 
-AssemblyBrowser *OpenAssemblyBrowserTask::openBrowserForObject(AssemblyObject *obj, QString viewName, bool persistent) {
-    AssemblyBrowser *v = new AssemblyBrowser(viewName, obj);
+AssemblyBrowser* OpenAssemblyBrowserTask::openBrowserForObject(AssemblyObject* obj, const QString& viewName, bool persistent) {
+    AssemblyBrowser* v = new AssemblyBrowser(viewName, obj);
     U2OpStatus2Notification os;
     if (!v->checkValid(os)) {
         delete v;
         return nullptr;
     }
-    GObjectViewWindow *w = new GObjectViewWindow(v, viewName, persistent);
+    GObjectViewWindow* w = new GObjectViewWindow(v, viewName, persistent);
     AppContext::getMainWindow()->getMDIManager()->addMDIWindow(w);
     return v;
 }
@@ -129,11 +129,11 @@ AssemblyBrowser *OpenAssemblyBrowserTask::openBrowserForObject(AssemblyObject *o
 // OpenSavedAssemblyBrowserTask - restore a new view from saved state
 //==============================================================================
 
-OpenSavedAssemblyBrowserTask::OpenSavedAssemblyBrowserTask(const QString &viewName, const QVariantMap &stateData)
+OpenSavedAssemblyBrowserTask::OpenSavedAssemblyBrowserTask(const QString& viewName, const QVariantMap& stateData)
     : ObjectViewTask(AssemblyBrowserFactory::ID, viewName, stateData) {
     AssemblyBrowserState state(stateData);
     GObjectReference ref = state.getGObjectRef();
-    Document *doc = AppContext::getProject()->findDocumentByURL(ref.docUrl);
+    Document* doc = AppContext::getProject()->findDocumentByURL(ref.docUrl);
     if (doc == nullptr) {
         doc = createDocumentAndAddToProject(ref.docUrl, AppContext::getProject(), stateInfo);
         CHECK_OP_EXT(stateInfo, stateIsIllegal = true, );
@@ -148,34 +148,31 @@ void OpenSavedAssemblyBrowserTask::open() {
 
     AssemblyBrowserState state(stateData);
     GObjectReference ref = state.getGObjectRef();
-    Document *doc = AppContext::getProject()->findDocumentByURL(ref.docUrl);
+    Document* doc = AppContext::getProject()->findDocumentByURL(ref.docUrl);
     if (doc == nullptr) {
         stateIsIllegal = true;
         stateInfo.setError(L10N::errorDocumentNotFound(ref.docUrl));
         return;
     }
-    GObject *obj = nullptr;
-    if (doc->isDatabaseConnection() && ref.entityRef.isValid()) {
-        obj = doc->getObjectById(ref.entityRef.entityId);
-    } else {
-        // To do: replace the object finding to "GObject* obj = doc->findGObjectByName(unloadedObjRef.objName);" after fixing of UGENE-4904
-        QList<GObject *> objs = doc->findGObjectByType(ref.objType);
-        foreach (GObject *curObj, objs) {
-            if (curObj->getGObjectName() == ref.objName) {
-                obj = curObj;
-                break;
-            }
+    GObject* obj = nullptr;
+    // To do: replace the object finding to "GObject* obj = doc->findGObjectByName(unloadedObjRef.objName);" after fixing of UGENE-4904
+    QList<GObject*> objs = doc->findGObjectByType(ref.objType);
+    foreach (GObject* curObj, objs) {
+        if (curObj->getGObjectName() == ref.objName) {
+            obj = curObj;
+            break;
         }
     }
+
     if (obj == nullptr || obj->getGObjectType() != GObjectTypes::ASSEMBLY) {
         stateIsIllegal = true;
         stateInfo.setError(tr("Assembly object not found: %1").arg(ref.objName));
         return;
     }
-    AssemblyObject *asmObj = qobject_cast<AssemblyObject *>(obj);
+    auto asmObj = qobject_cast<AssemblyObject*>(obj);
     SAFE_POINT(asmObj != nullptr, "Object has type ASSEMBLY, but cannot cast to AssemblyObject", );
 
-    AssemblyBrowser *ab = OpenAssemblyBrowserTask::openBrowserForObject(asmObj, viewName, true);
+    AssemblyBrowser* ab = OpenAssemblyBrowserTask::openBrowserForObject(asmObj, viewName, true);
     CHECK(ab != nullptr, );
     state.restoreState(ab);
 }
@@ -189,7 +186,7 @@ void UpdateAssemblyBrowserTask::update() {
         return;  // view was closed;
     }
 
-    AssemblyBrowser *ab = qobject_cast<AssemblyBrowser *>(view.data());
+    auto ab = qobject_cast<AssemblyBrowser*>(view.data());
     SAFE_POINT(ab != nullptr, "UpdateAssemblyBrowserTask::update: view is not AssemblyBrowser", );
 
     AssemblyBrowserState(stateData).restoreState(ab);
