@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_BROSER_TASKS_H_
-#define _U2_ASSEMBLY_BROSER_TASKS_H_
+#pragma once
 
 #include <U2Core/GObjectReference.h>
 
@@ -36,12 +35,12 @@ class AssemblyBrowser;
 class OpenAssemblyBrowserTask : public ObjectViewTask {
     Q_OBJECT
 public:
-    OpenAssemblyBrowserTask(AssemblyObject *obj);
-    OpenAssemblyBrowserTask(UnloadedObject *obj);
-    OpenAssemblyBrowserTask(Document *doc);
+    OpenAssemblyBrowserTask(AssemblyObject* obj);
+    OpenAssemblyBrowserTask(UnloadedObject* obj);
+    OpenAssemblyBrowserTask(Document* doc);
     virtual void open();
-    static void updateTitle(AssemblyBrowser *ab);
-    static AssemblyBrowser *openBrowserForObject(AssemblyObject *obj, QString viewName, bool persistent);
+    static void updateTitle(AssemblyBrowser* ab);
+    static AssemblyBrowser* openBrowserForObject(AssemblyObject* obj, const QString& viewName, bool persistent);
 
 private:
     GObjectReference unloadedObjRef;
@@ -50,14 +49,14 @@ private:
 class OpenSavedAssemblyBrowserTask : public ObjectViewTask {
     Q_OBJECT
 public:
-    OpenSavedAssemblyBrowserTask(const QString &viewName, const QVariantMap &stateData);
+    OpenSavedAssemblyBrowserTask(const QString& viewName, const QVariantMap& stateData);
     virtual void open();
 };
 
 class UpdateAssemblyBrowserTask : public ObjectViewTask {
     Q_OBJECT
 public:
-    UpdateAssemblyBrowserTask(GObjectView *v, const QString &stateName, const QVariantMap &stateData)
+    UpdateAssemblyBrowserTask(GObjectViewController* v, const QString& stateName, const QVariantMap& stateData)
         : ObjectViewTask(v, stateName, stateData) {
     }
 
@@ -65,5 +64,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
