@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __ASSEMBLY_CELL_RENDERER__
-#define __ASSEMBLY_CELL_RENDERER__
+#pragma once
 
 #include <QColor>
 #include <QFont>
@@ -41,31 +40,31 @@ public:
     }
 
     /** Render pixmaps into cache */
-    virtual void render(const QSize &size, int devicePixelRatio, bool text, const QFont &font) = 0;
+    virtual void render(const QSize& size, int devicePixelRatio, bool text, const QFont& font) = 0;
 
     /** @returns cached cell pixmap */
     virtual QPixmap cellImage(char c) = 0;
-    virtual QPixmap cellImage(const U2AssemblyRead &read, char c) = 0;
-    virtual QPixmap cellImage(const U2AssemblyRead &read, char c, char ref) = 0;
+    virtual QPixmap cellImage(const U2AssemblyRead& read, char c) = 0;
+    virtual QPixmap cellImage(const U2AssemblyRead& read, char c, char ref) = 0;
 
 protected:
-    static void drawCell(QPixmap &img, const QSize &size, const QColor &topColor, const QColor &bottomColor, bool text, char c, const QFont &font, const QColor &textColor);
-    static void drawCell(QPixmap &img, const QSize &size, const QColor &color, bool text, char c, const QFont &font, const QColor &textColor) {
+    static void drawCell(QPixmap& img, const QSize& size, const QColor& topColor, const QColor& bottomColor, bool text, char c, const QFont& font, const QColor& textColor);
+    static void drawCell(QPixmap& img, const QSize& size, const QColor& color, bool text, char c, const QFont& font, const QColor& textColor) {
         drawCell(img, size, color, color, text, c, font, textColor);
     }
 };
 
 class AssemblyCellRendererFactory {
 public:
-    AssemblyCellRendererFactory(const QString &_id, const QString &_name);
+    AssemblyCellRendererFactory(const QString& _id, const QString& _name);
     virtual ~AssemblyCellRendererFactory() {
     }
-    virtual AssemblyCellRenderer *create() = 0;
+    virtual AssemblyCellRenderer* create() = 0;
 
-    const QString &getId() const {
+    const QString& getId() const {
         return id;
     }
-    const QString &getName() const {
+    const QString& getName() const {
         return name;
     }
 
@@ -82,21 +81,19 @@ private:
 class AssemblyCellRendererFactoryRegistry : public QObject {
     Q_OBJECT
 public:
-    AssemblyCellRendererFactoryRegistry(QObject *parent = 0);
-    const QList<AssemblyCellRendererFactory *> &getFactories() const {
+    AssemblyCellRendererFactoryRegistry(QObject* parent = 0);
+    const QList<AssemblyCellRendererFactory*>& getFactories() const {
         return factories;
     }
-    AssemblyCellRendererFactory *getFactoryById(const QString &id) const;
-    void addFactory(AssemblyCellRendererFactory *f);
+    AssemblyCellRendererFactory* getFactoryById(const QString& id) const;
+    void addFactory(AssemblyCellRendererFactory* f);
 
     virtual ~AssemblyCellRendererFactoryRegistry();
 
 private:
     void initBuiltInRenderers();
 
-    QList<AssemblyCellRendererFactory *> factories;
+    QList<AssemblyCellRendererFactory*> factories;
 };
 
 }  // namespace U2
-
-#endif
