@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_CONSENSUS_TASK_H_
-#define _U2_ASSEMBLY_CONSENSUS_TASK_H_
+#pragma once
 
 #include <U2Algorithm/AssemblyConsensusAlgorithm.h>
 
@@ -50,7 +49,7 @@ struct U2VIEW_EXPORT AssemblyConsensusTaskSettings {
 class AssemblyConsensusTask : public BackgroundTask<ConsensusInfo> {
     Q_OBJECT
 public:
-    AssemblyConsensusTask(const AssemblyConsensusTaskSettings &settings);
+    AssemblyConsensusTask(const AssemblyConsensusTaskSettings& settings);
     virtual void run();
 
 private:
@@ -65,7 +64,7 @@ public:
     virtual bool hasNext() = 0;
     virtual AssemblyConsensusTaskSettings getNextSettings() = 0;
     virtual int count() = 0;
-    virtual void reportResult(const ConsensusInfo &result) = 0;
+    virtual void reportResult(const ConsensusInfo& result) = 0;
 };
 
 /**
@@ -75,13 +74,11 @@ public:
 class AssemblyConsensusWorker : public Task {
     Q_OBJECT
 public:
-    AssemblyConsensusWorker(ConsensusSettingsQueue *settingsQueue);
+    AssemblyConsensusWorker(ConsensusSettingsQueue* settingsQueue);
     virtual void run();
 
 private:
-    ConsensusSettingsQueue *settingsQueue;
+    ConsensusSettingsQueue* settingsQueue;
 };
 
 }  // namespace U2
-
-#endif  // _U2_ASSEMBLY_CONSENSUS_H_
