@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __ASSEMBLY_COVERAGE_GRAPH_H__
-#define __ASSEMBLY_COVERAGE_GRAPH_H__
+#pragma once
 
 #include <QSharedPointer>
 #include <QWidget>
@@ -35,14 +34,14 @@ class AssemblyBrowser;
 class AssemblyCoverageGraph : public QWidget {
     Q_OBJECT
 public:
-    AssemblyCoverageGraph(AssemblyBrowserUi *ui);
+    AssemblyCoverageGraph(AssemblyBrowserUi* ui);
 
 protected:
-    void paintEvent(QPaintEvent *e);
-    void mouseMoveEvent(QMouseEvent *e);
+    void paintEvent(QPaintEvent* e);
+    void mouseMoveEvent(QMouseEvent* e);
 
 signals:
-    void si_mouseMovedToPos(const QPoint &);
+    void si_mouseMovedToPos(const QPoint&);
 
 private slots:
     void sl_coverageReady();
@@ -53,10 +52,10 @@ private:
     void connectSlots();
     void doRedraw();
     void drawAll();
-    void drawGraph(QPainter &p, const CoverageInfo &ci, int alpha = 255);
+    void drawGraph(QPainter& p, const CoverageInfo& ci, int alpha = 255);
 
-    AssemblyBrowserUi *ui;
-    AssemblyBrowser *browser;
+    AssemblyBrowserUi* ui;
+    AssemblyBrowser* browser;
     QSharedPointer<AssemblyModel> model;
 
     QPixmap cachedView;
@@ -71,5 +70,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
