@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __U2_ASSEMBLY_BROWSER_MODEL_H__
-#define __U2_ASSEMBLY_BROWSER_MODEL_H__
+#pragma once
 
 #include <QFile>
 #include <QMutex>
@@ -41,70 +40,70 @@ class U2VIEW_EXPORT AssemblyModel : public QObject {
     Q_OBJECT
 public:
     // TODO refactor
-    AssemblyModel(const DbiConnection &dbiConnection);
+    AssemblyModel(const DbiConnection& dbiConnection);
     ~AssemblyModel();
 
     bool isEmpty() const;
 
-    QList<U2AssemblyRead> getReadsFromAssembly(const U2Region &r, qint64 minRow, qint64 maxRow, U2OpStatus &os);
-    U2DbiIterator<U2AssemblyRead> *getReads(const U2Region &r, U2OpStatus &os);
+    QList<U2AssemblyRead> getReadsFromAssembly(const U2Region& r, qint64 minRow, qint64 maxRow, U2OpStatus& os);
+    U2DbiIterator<U2AssemblyRead>* getReads(const U2Region& r, U2OpStatus& os);
 
-    void calculateCoverageStat(const U2Region &r, U2AssemblyCoverageStat &coverageStat, U2OpStatus &os);
+    void calculateCoverageStat(const U2Region& r, U2AssemblyCoverageStat& coverageStat, U2OpStatus& os);
 
-    const U2AssemblyCoverageStat &getCoverageStat(U2OpStatus &os);
+    const U2AssemblyCoverageStat& getCoverageStat(U2OpStatus& os);
 
     // returns true if calling getCoverageStat will not cause recomputation and is safe from main thread
     bool hasCachedCoverageStat();
 
     U2Region getGlobalRegion();
 
-    qint64 getModelLength(U2OpStatus &os);
+    qint64 getModelLength(U2OpStatus& os);
 
-    QByteArray getReferenceMd5(U2OpStatus &os);
+    QByteArray getReferenceMd5(U2OpStatus& os);
 
-    QByteArray getReferenceSpecies(U2OpStatus &os);
+    QByteArray getReferenceSpecies(U2OpStatus& os);
 
-    QString getReferenceUri(U2OpStatus &os);
+    QString getReferenceUri(U2OpStatus& os);
 
-    qint64 getModelHeight(U2OpStatus &os);
+    qint64 getModelHeight(U2OpStatus& os);
 
-    void setAssembly(U2AssemblyDbi *dbi, const U2Assembly &assm);
+    void setAssembly(U2AssemblyDbi* dbi, const U2Assembly& assm);
     U2Assembly getAssembly() {
         return assembly;
     }
-    U2SequenceObject *getRefObj() const;
+    U2SequenceObject* getRefObj() const;
 
     bool hasReference() const;
     bool referenceAssociated() const;
 
-    void setReference(U2SequenceObject *seqObj);
+    void setReference(U2SequenceObject* seqObj);
     U2EntityRef getRefereneceEntityRef();
 
-    QByteArray getReferenceRegion(const U2Region &region, U2OpStatus &os);
-    QByteArray getReferenceRegionOrEmpty(const U2Region &region);
+    QByteArray getReferenceRegion(const U2Region& region, U2OpStatus& os);
+    QByteArray getReferenceRegionOrEmpty(const U2Region& region);
 
-    const DbiConnection &getDbiConnection() const {
+    const DbiConnection& getDbiConnection() const {
         return dbiHandle;
     }
 
-    void associateWithReference(const U2DataId &refId);
+    void associateWithReference(const U2DataId& refId);
 
     bool isLoadingReference() const {
         return loadingReference;
     }
     void setLoadingReference(bool value);
 
-    qint64 getReadsNumber(U2OpStatus &os);
-    bool hasReads(U2OpStatus &os);
+    qint64 getReadsNumber(U2OpStatus& os);
+    bool hasReads(U2OpStatus& os);
 
-    QList<U2AssemblyRead> findMateReads(U2AssemblyRead read, U2OpStatus &os);
+    QList<U2AssemblyRead> findMateReads(U2AssemblyRead read, U2OpStatus& os);
 
-    const QList<VariantTrackObject *> &getTrackList() const;
-    void addTrackObject(VariantTrackObject *trackObj);
+    const QList<VariantTrackObject*>& getTrackList() const;
+    void addTrackObject(VariantTrackObject* trackObj);
     bool checkPermissions(QFile::Permission permission, bool showDialog = true) const;
     void dissociateReference();
 
-    bool isDbLocked(int timeout = 0);
+    bool isDbLocked(int timeout = 0) const;
 
 private:
     /**
@@ -112,26 +111,26 @@ private:
         association in ugenedb still exists
     */
     void unsetReference();
-    void startLoadReferenceTask(Task *t);
-    Task *createLoadReferenceAndAddToProjectTask(const U2CrossDatabaseReference &ref);
+    void startLoadReferenceTask(Task* t);
+    Task* createLoadReferenceAndAddToProjectTask(const U2CrossDatabaseReference& ref);
     void onReferenceRemoved();
-    void removeCrossDatabaseReference(const U2DataId &refId);
+    void removeCrossDatabaseReference(const U2DataId& refId) const;
 
 signals:
     void si_referenceChanged();
-    void si_trackAdded(VariantTrackObject *trackObj);
-    void si_trackRemoved(VariantTrackObject *trackObj);
+    void si_trackAdded(VariantTrackObject* trackObj);
+    void si_trackRemoved(VariantTrackObject* trackObj);
 
 public slots:
-    void sl_trackObjRemoved(GObject *o);
+    void sl_trackObjRemoved(GObject* o);
 
 private slots:
     void sl_referenceLoaded();
     void sl_referenceLoadingFailed();
     void sl_referenceDocLoadedStateChanged();
-    void sl_docRemoved(Document *);
-    void sl_docAdded(Document *);
-    void sl_referenceObjRemoved(GObject *o);
+    void sl_docRemoved(Document*);
+    void sl_docAdded(Document*);
+    void sl_referenceObjRemoved(GObject* o);
 
 private:
     const static qint64 NO_VAL = -1;
@@ -141,12 +140,12 @@ private:
     qint64 cachedModelHeight;
 
     U2Assembly assembly;
-    U2AssemblyDbi *assemblyDbi;
+    U2AssemblyDbi* assemblyDbi;
     DbiConnection dbiHandle;
 
     bool loadingReference;
-    U2SequenceObject *refObj;
-    QList<VariantTrackObject *> trackObjList;
+    U2SequenceObject* refObj;
+    QList<VariantTrackObject*> trackObjList;
 
     QByteArray referenceMd5;
     bool md5Retrieved;
@@ -165,5 +164,3 @@ private:
 };  // AssemblyModel
 
 }  // namespace U2
-
-#endif  // __U2_ASSEMBLY_BROWSER_MODEL_H__
