@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __ASSEMBLY_NAVIGATION_WIDGET_H__
-#define __ASSEMBLY_NAVIGATION_WIDGET_H__
+#pragma once
 
 #include <QLabel>
 
@@ -35,21 +34,21 @@ class PositionSelector;
 class AssemblyNavigationWidget : public QWidget {
     Q_OBJECT
 public:
-    AssemblyNavigationWidget(AssemblyBrowser *browser, QWidget *p = nullptr);
+    AssemblyNavigationWidget(AssemblyBrowser* browser, QWidget* p = nullptr);
 
 public slots:
     void sl_updateZoomingState();
 
 private:
-    AssemblyBrowser *browser;
-    PositionSelector *posSelector;
+    AssemblyBrowser* browser;
+    PositionSelector* posSelector;
     U2SavableWidget savableTab;
 };
 
 class U2VIEW_EXPORT CoveredRegionsLabel : public QLabel {
     Q_OBJECT
 public:
-    CoveredRegionsLabel(AssemblyBrowser *browser, QWidget *p = nullptr);
+    CoveredRegionsLabel(AssemblyBrowser* browser, QWidget* p = nullptr);
 
     void setAdditionalText(QString prefix, QString postfix);
 
@@ -57,7 +56,7 @@ public slots:
     void sl_updateContent();
 
 private:
-    AssemblyBrowser *browser;
+    AssemblyBrowser* browser;
     QString prefix;
     QString postfix;
 };
@@ -67,7 +66,7 @@ class U2VIEW_EXPORT AssemblyNavigationWidgetFactory : public OPWidgetFactory {
 public:
     AssemblyNavigationWidgetFactory();
 
-    QWidget *createWidget(GObjectView *objView, const QVariantMap &options) override;
+    QWidget* createWidget(GObjectViewController* objView, const QVariantMap& options) override;
 
     OPGroupParameters getOPGroupParameters() override;
 
@@ -78,5 +77,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // __ASSEMBLY_NAVIGATION_WIDGET_H__
