@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -40,8 +40,8 @@ namespace U2 {
 static const int ITEMS_SPACING = 10;
 static const int TITLE_SPACING = 5;
 
-static inline QVBoxLayout *initLayout(QWidget *w) {
-    QVBoxLayout *layout = new QVBoxLayout;
+static inline QVBoxLayout* initLayout(QWidget* w) {
+    QVBoxLayout* layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(5);
 
@@ -49,24 +49,24 @@ static inline QVBoxLayout *initLayout(QWidget *w) {
     return layout;
 }
 
-AssemblySettingsWidget::AssemblySettingsWidget(AssemblyBrowserUi *ui_)
+AssemblySettingsWidget::AssemblySettingsWidget(AssemblyBrowserUi* ui_)
     : QWidget(ui_), ui(ui_), savableTab(this, GObjectViewUtils::findViewByName(ui_->getWindow()->getName())) {
-    QVBoxLayout *mainLayout = initLayout(this);
+    QVBoxLayout* mainLayout = initLayout(this);
     mainLayout->setSpacing(0);
 
-    QWidget *readsGroup = new ShowHideSubgroupWidget("READS", tr("Reads Area"), createReadsSettings(), true);
+    QWidget* readsGroup = new ShowHideSubgroupWidget("READS", tr("Reads Area"), createReadsSettings(), true);
     mainLayout->addWidget(readsGroup);
 
-    QWidget *consensusGroup = new ShowHideSubgroupWidget("CONSENSUS", tr("Consensus Area"), createConsensusSettings(), true);
+    QWidget* consensusGroup = new ShowHideSubgroupWidget("CONSENSUS", tr("Consensus Area"), createConsensusSettings(), true);
     mainLayout->addWidget(consensusGroup);
 
-    QWidget *rulerGroup = new ShowHideSubgroupWidget("RULER", tr("Ruler"), createRulerSettings(), true);
+    QWidget* rulerGroup = new ShowHideSubgroupWidget("RULER", tr("Ruler"), createRulerSettings(), true);
     mainLayout->addWidget(rulerGroup);
 
     U2WidgetStateStorage::restoreWidgetState(savableTab);
 }
 
-static inline void createTwoWayBinding(QCheckBox *checkBox, QAction *action) {
+static inline void createTwoWayBinding(QCheckBox* checkBox, QAction* action) {
     QObject::connect(action, SIGNAL(toggled(bool)), checkBox, SLOT(setChecked(bool)));
     QObject::connect(checkBox, SIGNAL(toggled(bool)), action, SLOT(setChecked(bool)));
     checkBox->setChecked(action->isChecked());
@@ -74,10 +74,10 @@ static inline void createTwoWayBinding(QCheckBox *checkBox, QAction *action) {
 
 // ------- Reads ----------
 
-QWidget *AssemblySettingsWidget::createReadsSettings() {
-    QWidget *group = new QWidget(this);
-    QVBoxLayout *layout = initLayout(group);
-    AssemblyReadsArea *readsArea = ui->getReadsArea();
+QWidget* AssemblySettingsWidget::createReadsSettings() {
+    QWidget* group = new QWidget(this);
+    QVBoxLayout* layout = initLayout(group);
+    AssemblyReadsArea* readsArea = ui->getReadsArea();
     hint = new QLabel("", group);
     hint->setObjectName("HINT_HIGHLIGHTNING");
     hint->setWordWrap(true);
@@ -91,12 +91,12 @@ QWidget *AssemblySettingsWidget::createReadsSettings() {
 
     readsHighlightCombo = new QComboBox(group);
     readsHighlightCombo->setObjectName("READS_HIGHLIGHTNING_COMBO");
-    foreach (QAction *a, readsArea->getCellRendererActions()) {
+    foreach (QAction* a, readsArea->getCellRendererActions()) {
         readsHighlightCombo->addItem(a->text());
         connect(a, SIGNAL(triggered()), SLOT(sl_cellRendererChanged()));
         if (a->isChecked()) {
             readsHighlightCombo->setCurrentIndex(readsHighlightCombo->count() - 1);
-            AssemblyCellRendererFactory *factory = ui->getWindow()->getCellRendererRegistry()->getFactoryById(AssemblyCellRendererFactory::DIFF_NUCLEOTIDES);
+            AssemblyCellRendererFactory* factory = ui->getWindow()->getCellRendererRegistry()->getFactoryById(AssemblyCellRendererFactory::DIFF_NUCLEOTIDES);
             if (a->text() == factory->getName()) {
                 hint->setText(tr("You should add reference  first for correct displaying of this highlighting"));
                 hint->show();
@@ -110,20 +110,20 @@ QWidget *AssemblySettingsWidget::createReadsSettings() {
     layout->addWidget(readsHighlightCombo);
     layout->addWidget(hint);
 
-    QLabel *aboutScrolling = new QLabel(tr("Scrolling can be optimized by drawing only reads' positions without content while scrolling:"));
+    QLabel* aboutScrolling = new QLabel(tr("Scrolling can be optimized by drawing only reads' positions without content while scrolling:"));
     aboutScrolling->setWordWrap(true);
     aboutScrolling->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
     layout->addWidget(aboutScrolling);
 
-    QCheckBox *optimizeScroll = new QCheckBox(tr("Optimize scrolling"), group);
-    QAction *optimizeAction = readsArea->getOptimizeRenderAction();
+    QCheckBox* optimizeScroll = new QCheckBox(tr("Optimize scrolling"), group);
+    QAction* optimizeAction = readsArea->getOptimizeRenderAction();
     createTwoWayBinding(optimizeScroll, optimizeAction);
     layout->addWidget(optimizeScroll);
 
     layout->addSpacing(ITEMS_SPACING);
 
-    QCheckBox *showHint = new QCheckBox(tr("Show pop-up hint"), group);
-    QAction *hintAct = ui->getWindow()->getReadHintEnabledAction();
+    QCheckBox* showHint = new QCheckBox(tr("Show pop-up hint"), group);
+    QAction* hintAct = ui->getWindow()->getReadHintEnabledAction();
     createTwoWayBinding(showHint, hintAct);
     layout->addWidget(showHint);
 
@@ -131,19 +131,19 @@ QWidget *AssemblySettingsWidget::createReadsSettings() {
 }
 
 void AssemblySettingsWidget::sl_cellRendererChanged() {
-    QAction *action = qobject_cast<QAction *>(sender());
+    auto action = qobject_cast<QAction*>(sender());
     int index = ui->getReadsArea()->getCellRendererActions().indexOf(action);
     SAFE_POINT(index >= 0, "cell renderer action not found", );
     readsHighlightCombo->setCurrentIndex(index);
 }
 
 void AssemblySettingsWidget::sl_changeCellRenderer(int index) {
-    QList<QAction *> actions = ui->getReadsArea()->getCellRendererActions();
+    QList<QAction*> actions = ui->getReadsArea()->getCellRendererActions();
     CHECK(index >= 0, );
     SAFE_POINT(index <= actions.count(), "too big cell renderer action index", );
-    QAction *selected = actions.at(index);
+    QAction* selected = actions.at(index);
     selected->trigger();
-    AssemblyCellRendererFactory *factory = ui->getWindow()->getCellRendererRegistry()->getFactoryById(AssemblyCellRendererFactory::DIFF_NUCLEOTIDES);
+    AssemblyCellRendererFactory* factory = ui->getWindow()->getCellRendererRegistry()->getFactoryById(AssemblyCellRendererFactory::DIFF_NUCLEOTIDES);
     if (selected->text() == factory->getName()) {
         hint->setText(tr("You should add a reference first for correct displaying of selected highlighting"));
         hint->show();
@@ -155,10 +155,10 @@ void AssemblySettingsWidget::sl_changeCellRenderer(int index) {
 
 // ------- Consensus ----------
 
-QWidget *AssemblySettingsWidget::createConsensusSettings() {
-    QWidget *group = new QWidget(this);
-    QVBoxLayout *layout = initLayout(group);
-    AssemblyConsensusArea *consensusArea = ui->getConsensusArea();
+QWidget* AssemblySettingsWidget::createConsensusSettings() {
+    QWidget* group = new QWidget(this);
+    QVBoxLayout* layout = initLayout(group);
+    AssemblyConsensusArea* consensusArea = ui->getConsensusArea();
 
     layout->addSpacing(TITLE_SPACING);
 
@@ -166,7 +166,7 @@ QWidget *AssemblySettingsWidget::createConsensusSettings() {
 
     algorithmCombo = new QComboBox(group);
     algorithmCombo->setObjectName("consensusAlgorithmCombo");
-    foreach (QAction *a, consensusArea->getAlgorithmActions()) {
+    foreach (QAction* a, consensusArea->getAlgorithmActions()) {
         algorithmCombo->addItem(a->text());
         connect(a, SIGNAL(triggered()), SLOT(sl_consensusAlgorithmChanged()));
         if (a->isChecked()) {
@@ -178,8 +178,8 @@ QWidget *AssemblySettingsWidget::createConsensusSettings() {
 
     layout->addSpacing(ITEMS_SPACING);
 
-    QCheckBox *showDiff = new QCheckBox(tr("Difference from reference"), group);
-    QAction *diffAct = consensusArea->getDiffAction();
+    QCheckBox* showDiff = new QCheckBox(tr("Difference from reference"), group);
+    QAction* diffAct = consensusArea->getDiffAction();
     createTwoWayBinding(showDiff, diffAct);
     layout->addWidget(showDiff);
 
@@ -187,14 +187,14 @@ QWidget *AssemblySettingsWidget::createConsensusSettings() {
 }
 
 void AssemblySettingsWidget::sl_consensusAlgorithmChanged() {
-    QAction *action = qobject_cast<QAction *>(sender());
+    auto action = qobject_cast<QAction*>(sender());
     int index = ui->getConsensusArea()->getAlgorithmActions().indexOf(action);
     SAFE_POINT(index >= 0, "consensus algorithm action not found", );
     algorithmCombo->setCurrentIndex(index);
 }
 
 void AssemblySettingsWidget::sl_changeConsensusAlgorithm(int index) {
-    QList<QAction *> actions = ui->getConsensusArea()->getAlgorithmActions();
+    QList<QAction*> actions = ui->getConsensusArea()->getAlgorithmActions();
     CHECK(index >= 0, );
     SAFE_POINT(index <= actions.count(), "too big consensus algorithm action index", );
     actions.at(index)->trigger();
@@ -202,22 +202,22 @@ void AssemblySettingsWidget::sl_changeConsensusAlgorithm(int index) {
 
 // ------- Ruler ----------
 
-QWidget *AssemblySettingsWidget::createRulerSettings() {
-    QWidget *group = new QWidget(this);
-    QVBoxLayout *layout = initLayout(group);
-    AssemblyBrowser *browser = ui->getWindow();
+QWidget* AssemblySettingsWidget::createRulerSettings() {
+    QWidget* group = new QWidget(this);
+    QVBoxLayout* layout = initLayout(group);
+    AssemblyBrowser* browser = ui->getWindow();
 
     layout->addSpacing(TITLE_SPACING);
 
-    QCheckBox *showCoords = new QCheckBox(tr("Show coordinates"), group);
-    QAction *coordAct = browser->getCoordsOnRulerAction();
+    QCheckBox* showCoords = new QCheckBox(tr("Show coordinates"), group);
+    QAction* coordAct = browser->getCoordsOnRulerAction();
     createTwoWayBinding(showCoords, coordAct);
     layout->addWidget(showCoords);
 
     layout->addSpacing(ITEMS_SPACING);
 
-    QCheckBox *showCoverage = new QCheckBox(tr("Show coverage under cursor"), group);
-    QAction *coverageAct = browser->getCoverageOnRulerAction();
+    QCheckBox* showCoverage = new QCheckBox(tr("Show coverage under cursor"), group);
+    QAction* coverageAct = browser->getCoverageOnRulerAction();
     createTwoWayBinding(showCoverage, coverageAct);
     layout->addWidget(showCoverage);
 
@@ -235,12 +235,12 @@ AssemblySettingsWidgetFactory::AssemblySettingsWidgetFactory() {
     objectViewOfWidget = ObjViewType_AssemblyBrowser;
 }
 
-QWidget *AssemblySettingsWidgetFactory::createWidget(GObjectView *objView, const QVariantMap & /*options*/) {
+QWidget* AssemblySettingsWidgetFactory::createWidget(GObjectViewController* objView, const QVariantMap& /*options*/) {
     SAFE_POINT(objView != nullptr,
                QString("Internal error: unable to create widget for group '%1', object view is NULL.").arg(GROUP_ID),
                nullptr);
 
-    AssemblyBrowser *assemblyBrowser = qobject_cast<AssemblyBrowser *>(objView);
+    auto assemblyBrowser = qobject_cast<AssemblyBrowser*>(objView);
     SAFE_POINT(assemblyBrowser != nullptr,
                QString("Internal error: unable to cast object view to Assembly Browser for group '%1'.").arg(GROUP_ID),
                nullptr);
