@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __ASSEMBLY_SETTINGS_WIDGET_H__
-#define __ASSEMBLY_SETTINGS_WIDGET_H__
+#pragma once
 
 #include <QWidget>
 
@@ -37,7 +36,7 @@ class AssemblyBrowserUi;
 class AssemblySettingsWidget : public QWidget {
     Q_OBJECT
 public:
-    AssemblySettingsWidget(AssemblyBrowserUi *ui);
+    AssemblySettingsWidget(AssemblyBrowserUi* ui);
 
 private slots:
     void sl_cellRendererChanged();
@@ -47,17 +46,17 @@ private slots:
     void sl_changeConsensusAlgorithm(int newIndex);
 
 private:
-    QWidget *createReadsSettings();
-    QWidget *createRulerSettings();
-    QWidget *createConsensusSettings();
+    QWidget* createReadsSettings();
+    QWidget* createRulerSettings();
+    QWidget* createConsensusSettings();
 
-    AssemblyBrowserUi *ui;
+    AssemblyBrowserUi* ui;
 
     // Reads
-    QComboBox *readsHighlightCombo;
+    QComboBox* readsHighlightCombo;
     // Consensus
-    QComboBox *algorithmCombo;
-    QLabel *hint;
+    QComboBox* algorithmCombo;
+    QLabel* hint;
 
     U2SavableWidget savableTab;
 };
@@ -69,7 +68,7 @@ public:
     virtual ~AssemblySettingsWidgetFactory() {
     }
 
-    QWidget *createWidget(GObjectView *objView, const QVariantMap &options) override;
+    QWidget* createWidget(GObjectViewController* objView, const QVariantMap& options) override;
 
     OPGroupParameters getOPGroupParameters() override;
 
@@ -80,5 +79,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // #ifndef __ASSEMBLY_SETTINGS_WIDGET_H__
