@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,15 +27,15 @@
 
 namespace U2 {
 
-AssemblyVariantHint::AssemblyVariantHint(QWidget *parent)
+AssemblyVariantHint::AssemblyVariantHint(QWidget* parent)
     : AssemblyReadsAreaHint(parent) {
 }
 
-void AssemblyVariantHint::setData(const QList<U2Variant> &varList) {
+void AssemblyVariantHint::setData(const QList<U2Variant>& varList) {
     QString text;
     QListIterator<U2Variant> it(varList);
     while (it.hasNext()) {
-        const U2Variant &v = it.next();
+        const U2Variant& v = it.next();
         text += "<table cellspacing=\"0\" cellpadding=\"0\" align=\"left\" width=\"20%\">";
 
         if (!v.publicId.isEmpty()) {
@@ -61,16 +61,16 @@ void AssemblyVariantHint::setData(const QList<U2Variant> &varList) {
     this->setMaximumHeight(layout()->minimumSize().height());
 }
 
-void AssemblyVariantHint::leaveEvent(QEvent *) {
-    AssemblyVariantRow *p = qobject_cast<AssemblyVariantRow *>(parent());
+void AssemblyVariantHint::leaveEvent(QEvent*) {
+    auto p = qobject_cast<AssemblyVariantRow*>(parent());
     QPoint curInParentCoords = p->mapFromGlobal(QCursor::pos());
     if (!p->rect().contains(curInParentCoords)) {
         p->sl_hideHint();
     }
 }
 
-void AssemblyVariantHint::mouseMoveEvent(QMouseEvent *e) {
-    AssemblyVariantRow *p = qobject_cast<AssemblyVariantRow *>(parent());
+void AssemblyVariantHint::mouseMoveEvent(QMouseEvent* e) {
+    auto p = qobject_cast<AssemblyVariantRow*>(parent());
     p->sl_hideHint();
     QFrame::mouseMoveEvent(e);
 }
