@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _ASSEMBLY_VARIANT_HINT_
-#define _ASSEMBLY_VARIANT_HINT_
+#pragma once
 
 #include <U2Core/U2Variant.h>
 
@@ -31,14 +30,12 @@ namespace U2 {
 class AssemblyVariantHint : public AssemblyReadsAreaHint {
     Q_OBJECT
 public:
-    AssemblyVariantHint(QWidget *parent);
-    void setData(const QList<U2Variant> &varList);
+    AssemblyVariantHint(QWidget* parent);
+    void setData(const QList<U2Variant>& varList);
 
 protected:
-    virtual void leaveEvent(QEvent *event);
-    virtual void mouseMoveEvent(QMouseEvent *event);
+    virtual void leaveEvent(QEvent* event);
+    virtual void mouseMoveEvent(QMouseEvent* event);
 };
 
 }  // namespace U2
-
-#endif  // _ASSEMBLY_VARIANT_HINT_
