@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef __COVERED_REGIONS_MANAGER_H__
-#define __COVERED_REGIONS_MANAGER_H__
+#pragma once
 
 #include <QVector>
 
@@ -33,7 +32,7 @@ namespace U2 {
  * intersecting the region.
  */
 struct CoveredRegion {
-    CoveredRegion(const U2Region &region_, qint64 coverage_)
+    CoveredRegion(const U2Region& region_, qint64 coverage_)
         : region(region_), coverage(coverage_) {
     }
     U2Region region;
@@ -47,7 +46,7 @@ class CoveredRegionsManager {
 public:
     CoveredRegionsManager() {
     }
-    CoveredRegionsManager(const U2Region &visibleRegion_, const U2AssemblyCoverageStat &coverageInfo_);
+    CoveredRegionsManager(const U2Region& visibleRegion_, const U2AssemblyCoverageStat& coverageInfo_);
 
     inline bool isEmpty() const {
         return allRegions.empty();
@@ -75,5 +74,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
