@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,15 +19,14 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_CONSENSUS_DIALOG_H__
-#define _U2_EXPORT_CONSENSUS_DIALOG_H__
-
-#include <ui_ExportConsensusDialog.h>
+#pragma once
 
 #include <QDialog>
 
 #include "ExportConsensusTask.h"
 
+#include <ui_ExportConsensusDialog.h>
+
 namespace U2 {
 
 class SaveDocumentController;
@@ -36,11 +35,11 @@ class RegionSelector;
 class ExportConsensusDialog : public QDialog, Ui_ExportConsensusDialog {
     Q_OBJECT
 public:
-    ExportConsensusDialog(QWidget *p, const ExportConsensusTaskSettings &settings, const U2Region &visibleRegion);
+    ExportConsensusDialog(QWidget* p, const ExportConsensusTaskSettings& settings, const U2Region& visibleRegion);
 
     virtual void accept();
 
-    const ExportConsensusTaskSettings &getSettings() const {
+    const ExportConsensusTaskSettings& getSettings() const {
         return settings;
     }
 
@@ -48,10 +47,8 @@ private:
     void initSaveController();
 
     ExportConsensusTaskSettings settings;
-    SaveDocumentController *saveController;
-    RegionSelector *regionSelector;
+    SaveDocumentController* saveController;
+    RegionSelector* regionSelector;
 };
 
 }  // namespace U2
-
-#endif  // _U2_EXPORT_CONSENSUS_DIALOG_H__
