@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -38,14 +38,17 @@
 
 namespace U2 {
 
-ExportConsensusTask::ExportConsensusTask(const ExportConsensusTaskSettings &settings_)
+ExportConsensusTask::ExportConsensusTask(const ExportConsensusTaskSettings& settings_)
     : DocumentProviderTask("", TaskFlags_NR_FOSE_COSC),
       settings(settings_),
       consensusTask(nullptr) {
-    setTaskName(tr("Export consensus of assembly '%1' to '%2'")
-                    .arg(settings.model->getAssembly().visualName)
-                    .arg(QFileInfo(settings.fileName).fileName()));
-    setMaxParallelSubtasks(1);
+    if (settings.saveToFile) {
+        QString fileName = QFileInfo(settings.fileName).fileName();
+        setTaskName(tr("Export consensus of assembly '%1' to '%2'").arg(settings.model->getAssembly().visualName).arg(fileName));
+        SAFE_POINT(!fileName.isEmpty(), "No file provided for export: " + fileName, );
+    } else {
+        setTaskName(tr("Export consensus of assembly '%1'").arg(settings.model->getAssembly().visualName));
+    }
 }
 
 void ExportConsensusTask::prepare() {
@@ -53,10 +56,10 @@ void ExportConsensusTask::prepare() {
     if (settings.saveToFile) {
         SAFE_POINT_EXT(!settings.fileName.isEmpty(), setError(tr("File name cannot be empty")), );
 
-        DocumentFormat *df = AppContext::getDocumentFormatRegistry()->getFormatById(settings.formatId);
+        DocumentFormat* df = AppContext::getDocumentFormatRegistry()->getFormatById(settings.formatId);
         SAFE_POINT_EXT(df != nullptr, setError(tr("Internal: couldn't find document format with id '%1'").arg(settings.formatId)), );
 
-        IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(settings.fileName));
+        IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(settings.fileName));
         resultDocument = df->createNewLoadedDocument(iof, settings.fileName, stateInfo);
         CHECK_OP(stateInfo, );
 
@@ -93,10 +96,9 @@ void ExportConsensusTask::prepare() {
     CHECK_OP(stateInfo, );
 
     if (settings.saveToFile) {
-        SaveDocFlags saveFlags = SaveDoc_Overwrite;
-        addSubTask(new SaveDocumentTask(resultDocument, saveFlags));
+        addSubTask(new SaveDocumentTask(resultDocument));
 
-        Project *p = AppContext::getProject();
+        Project* p = AppContext::getProject();
         if (p != nullptr && p->findDocumentByURL(resultDocument->getURL()) != nullptr) {
             // if already has such document in project, do not add
             settings.addToProject = false;
@@ -108,8 +110,8 @@ void ExportConsensusTask::prepare() {
     }
 }
 
-QList<Task *> ExportConsensusTask::onSubTaskFinished(Task *finished) {
-    QList<Task *> newSubTasks;
+QList<Task*> ExportConsensusTask::onSubTaskFinished(Task* finished) {
+    QList<Task*> newSubTasks;
     if (finished->hasError() || finished->isCanceled()) {
         return newSubTasks;
     }
@@ -118,7 +120,7 @@ QList<Task *> ExportConsensusTask::onSubTaskFinished(Task *finished) {
         resultSequence = seqImporter.finalizeSequence(stateInfo);
         CHECK_OP(stateInfo, newSubTasks);
         if (settings.saveToFile) {
-            U2SequenceObject *seqObj = new U2SequenceObject(resultSequence.visualName, U2EntityRef(resultDocument->getDbiRef(), resultSequence.id));
+            U2SequenceObject* seqObj = new U2SequenceObject(resultSequence.visualName, U2EntityRef(resultDocument->getDbiRef(), resultSequence.id));
             resultDocument->addObject(seqObj);
         }
     }
@@ -131,7 +133,7 @@ AssemblyConsensusTaskSettings ExportConsensusTask::getNextSettings() {
     return iterSettings;
 }
 
-void ExportConsensusTask::reportResult(const ConsensusInfo &result) {
+void ExportConsensusTask::reportResult(const ConsensusInfo& result) {
     QByteArray consensus = result.consensus;
 
     if (!settings.keepGaps) {
