@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@
 
 namespace U2 {
 
-ExportConsensusVariationsTask::ExportConsensusVariationsTask(const ExportConsensusVariationsTaskSettings &settings_)
+ExportConsensusVariationsTask::ExportConsensusVariationsTask(const ExportConsensusVariationsTaskSettings& settings_)
     : DocumentProviderTask("", TaskFlags_NR_FOSE_COSC), settings(settings_), consensusTask(nullptr), varTrackObject(nullptr) {
     setTaskName(tr("Export consensus variations of assembly '%1' to '%2'")
                     .arg(settings.model->getAssembly().visualName)
@@ -50,10 +50,10 @@ ExportConsensusVariationsTask::ExportConsensusVariationsTask(const ExportConsens
 void ExportConsensusVariationsTask::prepare() {
     SAFE_POINT_EXT(!settings.fileName.isEmpty(), setError(tr("File name cannot be empty")), );
 
-    DocumentFormat *df = AppContext::getDocumentFormatRegistry()->getFormatById(settings.formatId);
+    DocumentFormat* df = AppContext::getDocumentFormatRegistry()->getFormatById(settings.formatId);
     SAFE_POINT_EXT(df != nullptr, setError(tr("Internal: couldn't find document format with id '%1'").arg(settings.formatId)), );
 
-    IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(settings.fileName));
+    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(settings.fileName));
     resultDocument = df->createNewLoadedDocument(iof, settings.fileName, stateInfo);
     CHECK_OP(stateInfo, );
 
@@ -87,10 +87,9 @@ void ExportConsensusVariationsTask::prepare() {
     U2EntityRef trackRef(resultDocument->getDbiRef(), track.id);
     varTrackObject = new VariantTrackObject(settings.seqObjName, trackRef);
 
-    SaveDocFlags saveFlags = SaveDoc_Overwrite;
-    addSubTask(new SaveDocumentTask(resultDocument, saveFlags));
+    addSubTask(new SaveDocumentTask(resultDocument));
 
-    Project *p = AppContext::getProject();
+    Project* p = AppContext::getProject();
     if (p != nullptr && p->findDocumentByURL(resultDocument->getURL()) != nullptr) {
         // if already has such document in project, do not add
         settings.addToProject = false;
@@ -101,8 +100,8 @@ void ExportConsensusVariationsTask::prepare() {
     }
 }
 
-QList<Task *> ExportConsensusVariationsTask::onSubTaskFinished(Task *finished) {
-    QList<Task *> newSubTasks;
+QList<Task*> ExportConsensusVariationsTask::onSubTaskFinished(Task* finished) {
+    QList<Task*> newSubTasks;
     if (finished == consensusTask) {
         SAFE_POINT(varTrackObject != nullptr, "Variant track object is null", newSubTasks);
         resultDocument->addObject(varTrackObject);
@@ -116,7 +115,7 @@ AssemblyConsensusTaskSettings ExportConsensusVariationsTask::getNextSettings() {
     return iterSettings;
 }
 
-void ExportConsensusVariationsTask::reportResult(const ConsensusInfo &result) {
+void ExportConsensusVariationsTask::reportResult(const ConsensusInfo& result) {
     SAFE_POINT(varTrackObject != nullptr, "Variant track object is null", );
     SAFE_POINT(settings.refSeq.isValid(), "Reference to sequence is invalid", );
 
@@ -125,7 +124,7 @@ void ExportConsensusVariationsTask::reportResult(const ConsensusInfo &result) {
     DbiConnection con(settings.refSeq.dbiRef, stateInfo);
     CHECK_OP(stateInfo, );
 
-    U2SequenceDbi *seqDbi = con.dbi->getSequenceDbi();
+    U2SequenceDbi* seqDbi = con.dbi->getSequenceDbi();
     QByteArray refSeqData = seqDbi->getSequenceData(settings.refSeq.entityId, result.region, stateInfo);
     CHECK_OP(stateInfo, );
     CHECK(!refSeqData.isEmpty(), );
