@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_CONSENSUS_VARIATIONS_TASK_H_
-#define _U2_EXPORT_CONSENSUS_VARIATIONS_TASK_H_
+#pragma once
 
 #include <QQueue>
 
@@ -45,10 +44,10 @@ struct ExportConsensusVariationsTaskSettings : public AssemblyConsensusTaskSetti
 class ExportConsensusVariationsTask : public DocumentProviderTask, ConsensusSettingsQueue {
     Q_OBJECT
 public:
-    ExportConsensusVariationsTask(const ExportConsensusVariationsTaskSettings &settings_);
+    ExportConsensusVariationsTask(const ExportConsensusVariationsTaskSettings& settings_);
 
     virtual void prepare();
-    virtual QList<Task *> onSubTaskFinished(Task *subTask);
+    virtual QList<Task*> onSubTaskFinished(Task* subTask);
 
     // implement ConsensusSettingsQueue interface
     virtual int count() {
@@ -58,12 +57,12 @@ public:
         return !consensusRegions.isEmpty();
     }
     virtual AssemblyConsensusTaskSettings getNextSettings();
-    virtual void reportResult(const ConsensusInfo &result);
+    virtual void reportResult(const ConsensusInfo& result);
 
 private:
     ExportConsensusVariationsTaskSettings settings;
-    AssemblyConsensusWorker *consensusTask;
-    VariantTrackObject *varTrackObject;
+    AssemblyConsensusWorker* consensusTask;
+    VariantTrackObject* varTrackObject;
 
     // A region to analyze at a time
     static const qint64 REGION_TO_ANALAYZE = 1000000;
@@ -73,5 +72,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  //_U2_EXPORT_CONSENSUS_VARIATIONS_TASK_H_
