@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -50,15 +50,15 @@ const QList<char> ExportCoverageTask::EXTENDED_CHARACTERS = QList<char>() << 'W'
 void GetAssemblyVisibleNameTask::run() {
     DbiConnection con(dbiRef, stateInfo);
     CHECK_OP(stateInfo, );
-    U2AssemblyDbi *assemblyDbi = con.dbi->getAssemblyDbi();
-    SAFE_POINT_EXT(nullptr != assemblyDbi, setError(tr("Assembly DBI is NULL")), );
+    U2AssemblyDbi* assemblyDbi = con.dbi->getAssemblyDbi();
+    SAFE_POINT_EXT(assemblyDbi != nullptr, setError(tr("Assembly DBI is NULL")), );
 
     const U2Assembly assembly = assemblyDbi->getAssemblyObject(assemblyId, stateInfo);
     CHECK_OP(stateInfo, );
     assemblyName = assembly.visualName;
 }
 
-ExportCoverageTask::ExportCoverageTask(const U2DbiRef &dbiRef, const U2DataId &assemblyId, const ExportCoverageSettings &settings, TaskFlags flags)
+ExportCoverageTask::ExportCoverageTask(const U2DbiRef& dbiRef, const U2DataId& assemblyId, const ExportCoverageSettings& settings, TaskFlags flags)
     : Task(tr("Export assembly coverage per base"), flags),
       dbiRef(dbiRef),
       assemblyId(assemblyId),
@@ -79,14 +79,14 @@ void ExportCoverageTask::prepare() {
 
     QDir().mkpath(QFileInfo(settings.url).absoluteDir().absolutePath());
     if (settings.compress) {
-        IOAdapterFactory *ioAdapterFactory = IOAdapterUtils::get(BaseIOAdapters::GZIPPED_LOCAL_FILE);
-        SAFE_POINT_EXT(nullptr != ioAdapterFactory, setError(tr("Can't write the compressed file: IOAdapterFactory is NULL")), );
+        IOAdapterFactory* ioAdapterFactory = IOAdapterUtils::get(BaseIOAdapters::GZIPPED_LOCAL_FILE);
+        SAFE_POINT_EXT(ioAdapterFactory != nullptr, setError(tr("Can't write the compressed file: IOAdapterFactory is NULL")), );
         ioAdapter.reset(ioAdapterFactory->createIOAdapter());
         bool isSuccess = ioAdapter->open(settings.url, IOAdapterMode_Write);
         CHECK_EXT(isSuccess, setError(L10N::errorOpeningFileWrite(settings.url)), );
     } else {
-        IOAdapterFactory *ioAdapterFactory = IOAdapterUtils::get(BaseIOAdapters::LOCAL_FILE);
-        SAFE_POINT_EXT(nullptr != ioAdapterFactory, setError(tr("Can't write the file: IOAdapterFactory is NULL")), );
+        IOAdapterFactory* ioAdapterFactory = IOAdapterUtils::get(BaseIOAdapters::LOCAL_FILE);
+        SAFE_POINT_EXT(ioAdapterFactory != nullptr, setError(tr("Can't write the file: IOAdapterFactory is NULL")), );
         ioAdapter.reset(ioAdapterFactory->createIOAdapter());
         bool isSuccess = ioAdapter->open(settings.url, IOAdapterMode_Write);
         CHECK_EXT(isSuccess, setError(L10N::errorOpeningFileWrite(settings.url)), );
@@ -98,26 +98,26 @@ void ExportCoverageTask::prepare() {
     addSubTask(calculateTask);
 }
 
-QList<Task *> ExportCoverageTask::onSubTaskFinished(Task *subTask) {
+QList<Task*> ExportCoverageTask::onSubTaskFinished(Task* subTask) {
     if (subTask == getAssemblyNameTask) {
         assemblyName = getAssemblyNameTask->getAssemblyVisibleName();
     }
-    return QList<Task *>();
+    return QList<Task*>();
 }
 Task::ReportResult ExportCoverageTask::report() {
-    if (nullptr != calculateTask) {
+    if (calculateTask != nullptr) {
         SAFE_POINT_EXT(!calculateTask->areThereUnprocessedResults(), setError(tr("Not all regions were processed")), ReportResult_Finished);
     }
     return ReportResult_Finished;
 }
 
-const QString &ExportCoverageTask::getUrl() const {
+const QString& ExportCoverageTask::getUrl() const {
     return settings.url;
 }
 
 void ExportCoverageTask::sl_regionIsProcessed(qint64 startPos) {
     if (alreadyProcessed == startPos) {
-        QVector<CoveragePerBaseInfo> *regionCoverage = calculateTask->takeResult(startPos);
+        QVector<CoveragePerBaseInfo>* regionCoverage = calculateTask->takeResult(startPos);
         if (startPos == 0) {
             identifyAlphabet(regionCoverage);
             writeHeader();
@@ -131,11 +131,11 @@ void ExportCoverageTask::sl_regionIsProcessed(qint64 startPos) {
         }
     }
 }
-void ExportCoverageTask::identifyAlphabet(QVector<CoveragePerBaseInfo> *regionCoverage) {
+void ExportCoverageTask::identifyAlphabet(QVector<CoveragePerBaseInfo>* regionCoverage) {
     CHECK(alphabetChars.size() == 4, );
-    foreach (const CoveragePerBaseInfo &info, *regionCoverage) {
+    foreach (const CoveragePerBaseInfo& info, *regionCoverage) {
         QList<char> chars = info.basesCount.keys();
-        foreach (char curChar, chars) {
+        for (char curChar : qAsConst(chars)) {
             if (EXTENDED_CHARACTERS.contains(curChar)) {
                 alphabetChars.append(EXTENDED_CHARACTERS);
                 return;
@@ -147,12 +147,12 @@ void ExportCoverageTask::identifyAlphabet(QVector<CoveragePerBaseInfo> *regionCo
 void ExportCoverageTask::writeHeader() {
 }
 
-void ExportCoverageTask::write(const QByteArray &dataToWrite) {
+void ExportCoverageTask::write(const QByteArray& dataToWrite) {
     qint64 bytesWritten = ioAdapter->writeBlock(dataToWrite);
     CHECK_EXT(bytesWritten == dataToWrite.length(), setError(L10N::errorWritingFile(ioAdapter->getURL())), );
 }
 
-ExportCoverageHistogramTask::ExportCoverageHistogramTask(const U2DbiRef &dbiRef, const U2DataId &assemblyId, const ExportCoverageSettings &settings)
+ExportCoverageHistogramTask::ExportCoverageHistogramTask(const U2DbiRef& dbiRef, const U2DataId& assemblyId, const ExportCoverageSettings& settings)
     : ExportCoverageTask(dbiRef, assemblyId, settings, TaskFlags_FOSE_COSC) {
     GCOUNTER(c, "ExportCoverageHistogramTask");
 }
@@ -160,8 +160,8 @@ ExportCoverageHistogramTask::ExportCoverageHistogramTask(const U2DbiRef &dbiRef,
 void ExportCoverageHistogramTask::run() {
     DbiConnection con(dbiRef, stateInfo);
     CHECK_OP(stateInfo, );
-    U2AttributeDbi *attributeDbi = con.dbi->getAttributeDbi();
-    SAFE_POINT_EXT(nullptr != attributeDbi, setError(tr("Attribute DBI is NULL")), );
+    U2AttributeDbi* attributeDbi = con.dbi->getAttributeDbi();
+    SAFE_POINT_EXT(attributeDbi != nullptr, setError(tr("Attribute DBI is NULL")), );
 
     const U2IntegerAttribute lengthAttribute = U2AttributeUtils::findIntegerAttribute(attributeDbi, assemblyId, U2BaseAttributeName::reference_length, stateInfo);
     CHECK_OP(stateInfo, );
@@ -178,8 +178,8 @@ void ExportCoverageHistogramTask::run() {
     }
 }
 
-void ExportCoverageHistogramTask::processRegion(const QVector<CoveragePerBaseInfo> *regionCoverage) {
-    foreach (const CoveragePerBaseInfo &info, *regionCoverage) {
+void ExportCoverageHistogramTask::processRegion(const QVector<CoveragePerBaseInfo>* regionCoverage) {
+    foreach (const CoveragePerBaseInfo& info, *regionCoverage) {
         histogramData[info.coverage] = histogramData.value(info.coverage, 0) + 1;
         alreadyProcessed++;
     }
@@ -193,12 +193,12 @@ QByteArray ExportCoverageHistogramTask::toByteArray(int coverage, qint64 assembl
            SEPARATOR + QByteArray::number((double)histogramData.value(coverage, 0) / assemblyLength) + "\n";
 }
 
-ExportCoveragePerBaseTask::ExportCoveragePerBaseTask(const U2DbiRef &dbiRef, const U2DataId &assemblyId, const ExportCoverageSettings &settings)
+ExportCoveragePerBaseTask::ExportCoveragePerBaseTask(const U2DbiRef& dbiRef, const U2DataId& assemblyId, const ExportCoverageSettings& settings)
     : ExportCoverageTask(dbiRef, assemblyId, settings) {
     GCOUNTER(c, "ExportCoveragePerBaseTask");
 }
 
-void ExportCoveragePerBaseTask::processRegion(const QVector<CoveragePerBaseInfo> *regionCoverage) {
+void ExportCoveragePerBaseTask::processRegion(const QVector<CoveragePerBaseInfo>* regionCoverage) {
     writeResult(regionCoverage);
 }
 
@@ -218,7 +218,7 @@ void ExportCoveragePerBaseTask::writeHeader() {
     write(comments + "\n");
 }
 
-QByteArray ExportCoveragePerBaseTask::toByteArray(const CoveragePerBaseInfo &info, int pos) const {
+QByteArray ExportCoveragePerBaseTask::toByteArray(const CoveragePerBaseInfo& info, int pos) const {
     QByteArray result = assemblyName.toLocal8Bit() + SEPARATOR + QByteArray::number(pos);
 
     if (settings.exportCoverage) {
@@ -234,18 +234,18 @@ QByteArray ExportCoveragePerBaseTask::toByteArray(const CoveragePerBaseInfo &inf
     return result + "\n";
 }
 
-void ExportCoveragePerBaseTask::writeResult(const QVector<CoveragePerBaseInfo> *data) {
-    CHECK(nullptr != data, );
+void ExportCoveragePerBaseTask::writeResult(const QVector<CoveragePerBaseInfo>* data) {
+    CHECK(data != nullptr, );
 
-    foreach (const CoveragePerBaseInfo &info, *data) {
+    foreach (const CoveragePerBaseInfo& info, *data) {
         alreadyProcessed++;
 
-        const bool coverageSatisfy = settings.exportCoverage && (settings.threshold <= info.coverage);
+        bool coverageSatisfy = settings.exportCoverage && (settings.threshold <= info.coverage);
         int baseCountsScore = 0;
-        foreach (char curChar, alphabetChars) {
+        for (char curChar : qAsConst(alphabetChars)) {
             baseCountsScore += info.basesCount.value(curChar, 0);
         }
-        const bool basesCountSatisfy = settings.exportBasesCount && (settings.threshold <= baseCountsScore);
+        bool basesCountSatisfy = settings.exportBasesCount && (settings.threshold <= baseCountsScore);
         if (!coverageSatisfy && !basesCountSatisfy) {
             continue;
         }
@@ -255,24 +255,24 @@ void ExportCoveragePerBaseTask::writeResult(const QVector<CoveragePerBaseInfo> *
     }
 }
 
-ExportCoverageBedgraphTask::ExportCoverageBedgraphTask(const U2DbiRef &dbiRef, const U2DataId &assemblyId, const ExportCoverageSettings &settings)
+ExportCoverageBedgraphTask::ExportCoverageBedgraphTask(const U2DbiRef& dbiRef, const U2DataId& assemblyId, const ExportCoverageSettings& settings)
     : ExportCoverageTask(dbiRef, assemblyId, settings),
       currentCoverage(U2Region(), -1) {
     GCOUNTER(c, "ExportCoverageBedgraphTask");
 }
 
-QList<Task *> ExportCoverageBedgraphTask::onSubTaskFinished(Task *subTask) {
-    CHECK_OP(stateInfo, QList<Task *>());
+QList<Task*> ExportCoverageBedgraphTask::onSubTaskFinished(Task* subTask) {
+    CHECK_OP(stateInfo, QList<Task*>());
     if (subTask == getAssemblyNameTask) {
         assemblyName = getAssemblyNameTask->getAssemblyVisibleName();
     } else {
         writeRegion();
     }
-    return QList<Task *>();
+    return QList<Task*>();
 }
 
-void ExportCoverageBedgraphTask::processRegion(const QVector<CoveragePerBaseInfo> *regionCoverage) {
-    foreach (const CoveragePerBaseInfo &info, *regionCoverage) {
+void ExportCoverageBedgraphTask::processRegion(const QVector<CoveragePerBaseInfo>* regionCoverage) {
+    foreach (const CoveragePerBaseInfo& info, *regionCoverage) {
         if (currentCoverage.second == info.coverage) {
             currentCoverage.first.length++;
         } else {
