@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,15 +19,14 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_READS_DIALOG_H__
-#define _U2_EXPORT_READS_DIALOG_H__
-
-#include <ui_ExportReadsDialog.h>
+#pragma once
 
 #include <QDialog>
 
 #include <U2Core/global.h>
 
+#include <ui_ExportReadsDialog.h>
+
 namespace U2 {
 
 class SaveDocumentController;
@@ -41,17 +40,15 @@ struct ExportReadsDialogModel {
 class ExportReadsDialog : public QDialog, Ui_ExportReadsDialog {
     Q_OBJECT
 public:
-    ExportReadsDialog(QWidget *p, const QList<DocumentFormatId> &formats);
+    ExportReadsDialog(QWidget* p, const QList<DocumentFormatId>& formats);
 
     void accept();
 
     ExportReadsDialogModel getModel() const;
 
 private:
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
 
 };  // ExportReadsDialog
 
 }  // namespace U2
-
-#endif  // _U2_EXPORT_READS_DIALOG_H__
