@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,21 +24,14 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QMessageBox>
-#include <QPushButton>
-
-#include <U2Core/U2OpStatusUtils.h>
 
 #include <U2Gui/HelpButton.h>
 #include <U2Gui/RegionSelector.h>
 #include <U2Gui/SaveDocumentController.h>
 
-#include <U2View/AssemblyModel.h>
-
-#include "ExtractAssemblyRegionDialog.h"
-
 namespace U2 {
 
-ExtractAssemblyRegionDialog::ExtractAssemblyRegionDialog(QWidget *p, ExtractAssemblyRegionTaskSettings *settings)
+ExtractAssemblyRegionDialog::ExtractAssemblyRegionDialog(QWidget* p, ExtractAssemblyRegionTaskSettings* settings)
     : QDialog(p), settings(settings) {
     setupUi(this);
 
@@ -51,14 +44,14 @@ ExtractAssemblyRegionDialog::ExtractAssemblyRegionDialog(QWidget *p, ExtractAsse
     QList<RegionPreset> presets = QList<RegionPreset>() << RegionPreset(tr("Visible"), settings->regionToExtract);
     regionSelector = new RegionSelector(this, settings->assemblyLength, false, nullptr, false, presets);
     regionSelector->setCurrentPreset(tr("Visible"));
-    regionSelector->removePreset(RegionSelector::WHOLE_SEQUENCE);
+    regionSelector->removePreset(RegionPreset::WHOLE_SEQUENCE());
     regionSelectorWidget->layout()->addWidget(regionSelector);
 
     setMaximumHeight(layout()->minimumSize().height());
-    connect(regionSelector, SIGNAL(si_regionChanged(const U2Region &)), SLOT(sl_regionChanged(const U2Region &)));
+    connect(regionSelector, SIGNAL(si_regionChanged(const U2Region&)), SLOT(sl_regionChanged(const U2Region&)));
 }
 
-void ExtractAssemblyRegionDialog::sl_regionChanged(const U2Region &newRegion) {
+void ExtractAssemblyRegionDialog::sl_regionChanged(const U2Region& newRegion) {
     QString filePath = saveController->getSaveFileName();
     QFileInfo fi(filePath);
     U2Region prevRegion = settings->regionToExtract;
