@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXTRACT_ASSEMBLY_REGION_DIALOG_H_
-#define _U2_EXTRACT_ASSEMBLY_REGION_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -39,21 +38,19 @@ class RegionSelector;
 class ExtractAssemblyRegionDialog : public QDialog, public Ui_ExtractAssemblyRegionDialog {
     Q_OBJECT
 public:
-    ExtractAssemblyRegionDialog(QWidget *p, ExtractAssemblyRegionTaskSettings *settings);
+    ExtractAssemblyRegionDialog(QWidget* p, ExtractAssemblyRegionTaskSettings* settings);
 
     virtual void accept();
 
 private slots:
-    void sl_regionChanged(const U2Region &newRegion);
+    void sl_regionChanged(const U2Region& newRegion);
 
 private:
     void initSaveController();
 
-    SaveDocumentController *saveController;
-    RegionSelector *regionSelector;
-    ExtractAssemblyRegionTaskSettings *settings;
+    SaveDocumentController* saveController;
+    RegionSelector* regionSelector;
+    ExtractAssemblyRegionTaskSettings* settings;
 };
 
 }  // namespace U2
-
-#endif
