@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@
 
 namespace U2 {
 
-ExtractAssemblyRegionAndOpenViewTask::ExtractAssemblyRegionAndOpenViewTask(const ExtractAssemblyRegionTaskSettings &settings)
+ExtractAssemblyRegionAndOpenViewTask::ExtractAssemblyRegionAndOpenViewTask(const ExtractAssemblyRegionTaskSettings& settings)
     : Task(tr("Extract Assembly Region And Open View Task"), TaskFlags_NR_FOSE_COSC), settings(settings), extractTask(nullptr) {
 }
 
@@ -56,23 +56,23 @@ void ExtractAssemblyRegionAndOpenViewTask::prepare() {
     addSubTask(extractTask);
 }
 
-QList<Task *> ExtractAssemblyRegionAndOpenViewTask::onSubTaskFinished(Task *subTask) {
-    QList<Task *> result;
-    CHECK(nullptr != subTask, result);
+QList<Task*> ExtractAssemblyRegionAndOpenViewTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> result;
+    CHECK(subTask != nullptr, result);
 
     if (subTask->hasError() || subTask->isCanceled()) {
         return result;
     }
 
     if (extractTask == subTask && settings.addToProject) {
-        Task *openTask = AppContext::getProjectLoader()->openWithProjectTask(settings.fileUrl);
+        Task* openTask = AppContext::getProjectLoader()->openWithProjectTask(settings.fileUrl);
         CHECK(openTask != nullptr, result);
         result.append(openTask);
     }
     return result;
 }
 
-ExtractAssemblyRegionTask::ExtractAssemblyRegionTask(const ExtractAssemblyRegionTaskSettings &settings)
+ExtractAssemblyRegionTask::ExtractAssemblyRegionTask(const ExtractAssemblyRegionTaskSettings& settings)
     : Task(tr("Extract Assembly Region Task"), TaskFlag_None), settings(settings) {
     tpm = Task::Progress_Manual;
 }
@@ -81,9 +81,9 @@ void ExtractAssemblyRegionTask::run() {
     taskLog.details("Start extracting regions to assembly");
 
     if (settings.fileFormat == BaseDocumentFormats::BAM || settings.fileFormat == BaseDocumentFormats::SAM) {
-        QList<GObject *> objects;
+        QList<GObject*> objects;
         objects.append(settings.obj);
-        BAMUtils::writeObjects(objects, GUrl(settings.fileUrl), settings.fileFormat, stateInfo, settings.regionToExtract);
+        BAMUtils::writeObjects(objects, settings.fileUrl, settings.fileFormat, stateInfo, settings.regionToExtract);
     } else if (settings.fileFormat == BaseDocumentFormats::UGENEDB) {
         const U2DbiRef dbiRef = U2DbiRef(SQLITE_DBI_ID, settings.fileUrl);
         SAFE_POINT_OP(stateInfo, );
