@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXTRACT_ASSEMBLY_TASK_H_
-#define _U2_EXTRACT_ASSEMBLY_TASK_H_
+#pragma once
 
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/Task.h>
@@ -33,7 +32,7 @@ class DocumentProviderTask;
 class ExtractAssemblyRegionTask;
 
 struct ExtractAssemblyRegionTaskSettings {
-    ExtractAssemblyRegionTaskSettings(QString fileUrl, int assemblyLength, AssemblyObject *o)
+    ExtractAssemblyRegionTaskSettings(QString fileUrl, int assemblyLength, AssemblyObject* o)
         : fileUrl(fileUrl), regionToExtract(U2_REGION_MAX),
           fileFormat(BaseDocumentFormats::UGENEDB), assemblyLength(assemblyLength), obj(o), addToProject(false) {
     }
@@ -41,28 +40,28 @@ struct ExtractAssemblyRegionTaskSettings {
     U2Region regionToExtract;
     DocumentFormatId fileFormat;
     int assemblyLength;
-    AssemblyObject *obj;
+    AssemblyObject* obj;
     bool addToProject;
 };
 
 class ExtractAssemblyRegionAndOpenViewTask : public Task {
     Q_OBJECT
 public:
-    ExtractAssemblyRegionAndOpenViewTask(const ExtractAssemblyRegionTaskSettings &settings);
+    ExtractAssemblyRegionAndOpenViewTask(const ExtractAssemblyRegionTaskSettings& settings);
 
     void prepare();
 
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
 
 private:
     ExtractAssemblyRegionTaskSettings settings;
-    ExtractAssemblyRegionTask *extractTask;
+    ExtractAssemblyRegionTask* extractTask;
 };
 
 class ExtractAssemblyRegionTask : public Task {
     Q_OBJECT
 public:
-    ExtractAssemblyRegionTask(const ExtractAssemblyRegionTaskSettings &settings);
+    ExtractAssemblyRegionTask(const ExtractAssemblyRegionTaskSettings& settings);
 
     void run();
 
@@ -71,5 +70,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
