@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +21,6 @@
 
 #include "ColorSchemaDialogController.h"
 
-#include <QColorDialog>
 #include <QMessageBox>
 #include <QPainter>
 
@@ -36,12 +35,13 @@
 #include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/U2SafePoints.h>
 
+#include <U2Gui/DialogUtils.h>
 #include <U2Gui/HelpButton.h>
 #include <U2Gui/U2FileDialog.h>
 
 namespace U2 {
 
-ColorSchemaDialogController::ColorSchemaDialogController(QMap<char, QColor> &colors)
+ColorSchemaDialogController::ColorSchemaDialogController(QMap<char, QColor>& colors)
     : QDialog(),
       alphabetColorsView(nullptr),
       newColors(colors),
@@ -66,7 +66,7 @@ ColorSchemaDialogController::~ColorSchemaDialogController() {
     delete alphabetColorsView;
 }
 
-void ColorSchemaDialogController::paintEvent(QPaintEvent *) {
+void ColorSchemaDialogController::paintEvent(QPaintEvent*) {
     QPainter dialogPainter(this);
     const int columns = 6;
 
@@ -155,22 +155,15 @@ void ColorSchemaDialogController::sl_onRestore() {
     update();
 }
 
-void ColorSchemaDialogController::mouseReleaseEvent(QMouseEvent *event) {
+void ColorSchemaDialogController::mouseReleaseEvent(QMouseEvent* event) {
     QMapIterator<char, QRect> it(charsPlacement);
 
     while (it.hasNext()) {
         it.next();
         if (it.value().contains(event->pos().x() - alphabetColorsFrame->geometry().x(), event->pos().y() - alphabetColorsFrame->geometry().y())) {
-            QObjectScopedPointer<QColorDialog> d = new QColorDialog(this);
-#ifdef Q_OS_DARWIN
-            // A workaround because of UGENE-2263
-            // Another way should be found.
-            // I suppose, that it is bug in the Qt libraries (Qt-4.8.5 for mac)
-            d->setOption(QColorDialog::DontUseNativeDialog);
-#endif
-            const int res = d->exec();
+            QObjectScopedPointer<QColorDialog> d = new U2ColorDialog(this);
+            int res = d->exec();
             CHECK(!d.isNull(), );
-
             if (res == QDialog::Accepted) {
                 newColors[it.key()] = d->selectedColor();
             }
@@ -183,7 +176,7 @@ void ColorSchemaDialogController::mouseReleaseEvent(QMouseEvent *event) {
 
 /*Create MSA scheme dialog*/
 
-CreateColorSchemaDialog::CreateColorSchemaDialog(ColorSchemeData *_newSchema, QStringList _usedNames)
+CreateColorSchemaDialog::CreateColorSchemaDialog(ColorSchemeData* _newSchema, QStringList _usedNames)
     : usedNames(_usedNames), newSchema(_newSchema) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65929623");
@@ -199,25 +192,25 @@ CreateColorSchemaDialog::CreateColorSchemaDialog(ColorSchemeData *_newSchema, QS
     validLabel->setVisible(false);
     adjustSize();
 
-    connect(schemeName, SIGNAL(textEdited(const QString &)), SLOT(sl_schemaNameEdited(const QString &)));
+    connect(schemeName, SIGNAL(textEdited(const QString&)), SLOT(sl_schemaNameEdited(const QString&)));
 
     buttonBox->button(QDialogButtonBox::Ok)->setText(tr("OK"));
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
-    QPushButton *createButton = buttonBox->button(QDialogButtonBox::Ok);
-    QPushButton *cancelButton = buttonBox->button(QDialogButtonBox::Cancel);
+    QPushButton* createButton = buttonBox->button(QDialogButtonBox::Ok);
+    QPushButton* cancelButton = buttonBox->button(QDialogButtonBox::Cancel);
 
     connect(createButton, SIGNAL(clicked()), this, SLOT(sl_createSchema()));
     connect(cancelButton, SIGNAL(clicked()), this, SLOT(sl_cancel()));
 
     QSet<QString> excluded;
-    foreach (const QString &usedName, usedNames) {
+    foreach (const QString& usedName, usedNames) {
         excluded.insert(usedName);
     }
     schemeName->setText(GUrlUtils::rollFileName("Custom color scheme", excluded));
 }
 
-bool CreateColorSchemaDialog::isNameExist(const QString &text) {
-    foreach (const QString &usedName, usedNames) {
+bool CreateColorSchemaDialog::isNameExist(const QString& text) {
+    foreach (const QString& usedName, usedNames) {
         if (usedName == text) {
             return true;
         }
@@ -225,7 +218,7 @@ bool CreateColorSchemaDialog::isNameExist(const QString &text) {
     return false;
 }
 
-bool CreateColorSchemaDialog::isSchemaNameValid(const QString &text, QString &description) {
+bool CreateColorSchemaDialog::isSchemaNameValid(const QString& text, QString& description) {
     if (text.isEmpty()) {
         description = tr("Name of scheme is empty.");
         return false;
@@ -254,7 +247,7 @@ bool CreateColorSchemaDialog::isSchemaNameValid(const QString &text, QString &de
     return true;
 }
 
-void CreateColorSchemaDialog::sl_schemaNameEdited(const QString &text) {
+void CreateColorSchemaDialog::sl_schemaNameEdited(const QString& text) {
     QString description;
     const bool isNameValid = isSchemaNameValid(text, description);
     validLabel->setVisible(!isNameValid);
@@ -332,7 +325,7 @@ void CreateColorSchemaDialog::sl_cancel() {
     reject();
 }
 
-ColorSchemaSettingsPageWidget::ColorSchemaSettingsPageWidget(ColorSchemaSettingsPageController *) {
+ColorSchemaSettingsPageWidget::ColorSchemaSettingsPageWidget(ColorSchemaSettingsPageController*) {
     setupUi(this);
 
     connect(colorsDirButton, SIGNAL(clicked()), SLOT(sl_onColorsDirButton()));
@@ -344,20 +337,20 @@ ColorSchemaSettingsPageWidget::ColorSchemaSettingsPageWidget(ColorSchemaSettings
     sl_schemaChanged(colorSchemas->currentRow());
 }
 
-void ColorSchemaSettingsPageWidget::setState(AppSettingsGUIPageState *s) {
-    ColorSchemaSettingsPageState *state = qobject_cast<ColorSchemaSettingsPageState *>(s);
+void ColorSchemaSettingsPageWidget::setState(AppSettingsGUIPageState* s) {
+    auto state = qobject_cast<ColorSchemaSettingsPageState*>(s);
     colorsDirEdit->setText(state->colorsDir);
     customSchemas = state->customSchemas;
     removedCustomSchemas = state->removedCustomSchemas;
     colorSchemas->clear();
 
-    foreach (const ColorSchemeData &customSchema, customSchemas) {
+    foreach (const ColorSchemeData& customSchema, customSchemas) {
         colorSchemas->addItem(new QListWidgetItem(customSchema.name, colorSchemas));
     }
     update();
 }
 
-AppSettingsGUIPageState *ColorSchemaSettingsPageWidget::getState(QString &err) const {
+AppSettingsGUIPageState* ColorSchemaSettingsPageWidget::getState(QString& err) const {
     QString colorsDir = colorsDirEdit->text();
     U2OpStatusImpl os;
     GUrlUtils::prepareDirLocation(colorsDir, os);
@@ -365,7 +358,7 @@ AppSettingsGUIPageState *ColorSchemaSettingsPageWidget::getState(QString &err) c
         err = os.getError();
         return nullptr;
     }
-    ColorSchemaSettingsPageState *state = new ColorSchemaSettingsPageState();
+    ColorSchemaSettingsPageState* state = new ColorSchemaSettingsPageState();
     state->colorsDir = colorsDir;
     state->customSchemas = customSchemas;
     state->removedCustomSchemas = removedCustomSchemas;
@@ -404,7 +397,7 @@ void ColorSchemaSettingsPageWidget::sl_onColorsDirButton() {
 
 void ColorSchemaSettingsPageWidget::sl_onAddColorSchema() {
     QStringList usedNames;
-    foreach (const ColorSchemeData &customScheme, customSchemas) {
+    foreach (const ColorSchemeData& customScheme, customSchemas) {
         usedNames << customScheme.name;
     }
     ColorSchemeData schema;
@@ -424,14 +417,14 @@ void ColorSchemaSettingsPageWidget::sl_onAddColorSchema() {
 void ColorSchemaSettingsPageWidget::sl_onChangeColorSchema() {
     QMap<char, QColor> alpColors;
 
-    QListWidgetItem *item = colorSchemas->currentItem();
+    QListWidgetItem* item = colorSchemas->currentItem();
     if (item == nullptr) {
         return;
     }
 
     QString schemaName = item->text();
     for (int i = 0; i < customSchemas.size(); ++i) {
-        ColorSchemeData &customSchema = customSchemas[i];
+        ColorSchemeData& customSchema = customSchemas[i];
         if (customSchema.name == schemaName) {
             alpColors = customSchema.alpColors;
             QObjectScopedPointer<ColorSchemaDialogController> controller = new ColorSchemaDialogController(alpColors);
@@ -453,12 +446,12 @@ void ColorSchemaSettingsPageWidget::sl_onChangeColorSchema() {
 }
 
 void ColorSchemaSettingsPageWidget::sl_onDeleteColorSchema() {
-    QListWidgetItem *item = colorSchemas->currentItem();
+    QListWidgetItem* item = colorSchemas->currentItem();
     SAFE_POINT(item != nullptr, "current item for deletion is NULL", );
 
     QString schemaName = item->text();
     for (int i = 0; i < customSchemas.size(); ++i) {
-        ColorSchemeData &customSchema = customSchemas[i];
+        ColorSchemeData& customSchema = customSchemas[i];
         if (customSchema.name == schemaName) {
             removedCustomSchemas.append(customSchemas[i]);
             customSchemas.removeAt(i);
@@ -467,7 +460,7 @@ void ColorSchemaSettingsPageWidget::sl_onDeleteColorSchema() {
             return;
         }
     }
-    FAIL("something wrong causes color scheme deletion, this code must be unreacheble", );
+    FAIL("something wrong causes color scheme deletion, this code must be unreachable", );
 }
 
 }  // namespace U2
