@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _DELETE_GAPS_DIALOG_
-#define _DELETE_GAPS_DIALOG_
+#pragma once
 
 #include <QDialog>
 
@@ -37,7 +36,7 @@ enum DeleteMode {
 class DeleteGapsDialog : public QDialog {
     Q_OBJECT
 public:
-    DeleteGapsDialog(QWidget *parent, int alignmentLen);
+    DeleteGapsDialog(QWidget* parent, int alignmentLen);
     ~DeleteGapsDialog();
     DeleteMode getDeleteMode() const {
         return deleteMode;
@@ -53,9 +52,7 @@ private slots:
 private:
     DeleteMode deleteMode;
     int value;
-    Ui_DeleteGapsDialog *ui;
+    Ui_DeleteGapsDialog* ui;
 };
 
 }  // namespace U2
-
-#endif
