@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,12 +34,12 @@
 #include <U2Gui/SaveDocumentController.h>
 
 #include "ov_msa/MSAEditorSequenceArea.h"
-#include "ov_msa/view_rendering/MaEditorSelection.h"
+#include "ov_msa/MaEditorSelection.h"
 #include "ui_ExportHighlightedDialog.h"
 
 namespace U2 {
 
-ExportHighligtingDialogController::ExportHighligtingDialogController(MaEditorWgt *msaui_, QWidget *p)
+ExportHighligtingDialogController::ExportHighligtingDialogController(MaEditorWgt* msaui_, QWidget* p)
     : QDialog(p),
       msaui(msaui_),
       saveController(nullptr),
@@ -52,19 +52,19 @@ ExportHighligtingDialogController::ExportHighligtingDialogController(MaEditorWgt
 
     CHECK(AppContext::getAppSettings(), );
     CHECK(AppContext::getAppSettings()->getUserAppsSettings(), );
-    const MaEditor *editor = msaui->getEditor();
+    const MaEditor* editor = msaui->getEditor();
     CHECK(editor, );
 
     initSaveController();
 
     int alignLength = editor->getAlignmentLen();
-    const MaEditorSelection &selection = editor->getSelection();
+    const MaEditorSelection& selection = editor->getSelection();
 
     if (selection.isEmpty() || selection.isSingleColumnSelection()) {
         startPos = 1;
         endPos = alignLength;
     } else {
-        const QRect &selectionRect = selection.getRectList()[0];
+        const QRect& selectionRect = selection.getRectList()[0];
         startPos = selectionRect.x() + 1;
         endPos = selectionRect.x() + selectionRect.width();
     }
