@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_HIGHLIGHTING_DIALOG_CONTROLLER_H_
-#define _U2_EXPORT_HIGHLIGHTING_DIALOG_CONTROLLER_H_
+#pragma once
 
 #include <QDialog>
 
@@ -35,7 +34,7 @@ class SaveDocumentController;
 class ExportHighligtingDialogController : public QDialog {
     Q_OBJECT
 public:
-    ExportHighligtingDialogController(MaEditorWgt *msaui_, QWidget *p);
+    ExportHighligtingDialogController(MaEditorWgt* msaui_, QWidget* p);
     ~ExportHighligtingDialogController();
 
     virtual void accept();
@@ -55,11 +54,9 @@ private slots:
 private:
     void initSaveController();
 
-    MaEditorWgt *msaui;
-    SaveDocumentController *saveController;
-    Ui_ExportHighlightedDialog *ui;
+    MaEditorWgt* msaui;
+    SaveDocumentController* saveController;
+    Ui_ExportHighlightedDialog* ui;
 };
 
 }  // namespace U2
-
-#endif
