@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,13 +19,13 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_H_
-#define _U2_MSA_EDITOR_H_
+#pragma once
 
 #include <U2Core/MultipleSequenceAlignmentObject.h>
 #include <U2Core/U2Msa.h>
 
 #include "MaEditor.h"
+#include "MsaEditorMultilineWgt.h"
 #include "MsaEditorWgt.h"
 #include "phy_tree/MSAEditorTreeManager.h"
 
@@ -40,7 +40,7 @@ public:
         : firstSequenceId(U2MsaRow::INVALID_ROW_ID),
           secondSequenceId(U2MsaRow::INVALID_ROW_ID), inNewWindow(true),
           showSequenceWidget(true), showAlgorithmWidget(false),
-          showOutputWidget(false), sequenceSelectionModeOn(false) {
+          showOutputWidget(false) {
     }
 
     qint64 firstSequenceId;
@@ -52,7 +52,6 @@ public:
     bool showSequenceWidget;
     bool showAlgorithmWidget;
     bool showOutputWidget;
-    bool sequenceSelectionModeOn;
 
     QVariantMap customSettings;
 };
@@ -78,34 +77,33 @@ class U2VIEW_EXPORT MSAEditor : public MaEditor {
     friend class SequenceWithChromatogramAreaRenderer;
 
 public:
-    MSAEditor(const QString &viewName, MultipleSequenceAlignmentObject *obj);
-    ~MSAEditor();
+    MSAEditor(const QString& viewName, MultipleSequenceAlignmentObject* obj);
+    ~MSAEditor() override;
 
     QString getSettingsRoot() const override {
         return MSAE_SETTINGS_ROOT;
     }
 
-    MultipleSequenceAlignmentObject *getMaObject() const override {
-        return qobject_cast<MultipleSequenceAlignmentObject *>(maObject);
+    MultipleSequenceAlignmentObject* getMaObject() const override {
+        return qobject_cast<MultipleSequenceAlignmentObject*>(maObject);
     }
 
     /** Returns selection controller instance. The instance is always defined and is never null. */
-    MaEditorSelectionController *getSelectionController() const override;
+    MaEditorSelectionController* getSelectionController() const override;
 
-    void buildStaticToolbar(QToolBar *tb) override;
+    void buildStaticToolbar(QToolBar* tb) override;
 
-    void buildMenu(QMenu *m, const QString &type) override;
-
-    MsaEditorWgt *getUI() const override;
+    void buildMenu(QMenu* m, const QString& type) override;
+    void fillMenu(QMenu* m, const QString& type);
 
     // Return alignment row that is displayed on target line in MSAEditor
     MultipleSequenceAlignmentRow getRowByViewRowIndex(int viewRowIndex) const;
 
-    PairwiseAlignmentWidgetsSettings *getPairwiseAlignmentWidgetsSettings() const {
+    PairwiseAlignmentWidgetsSettings* getPairwiseAlignmentWidgetsSettings() const {
         return pairwiseAlignmentWidgetsSettings;
     }
 
-    MSAEditorTreeManager *getTreeManager() {
+    MSAEditorTreeManager* getTreeManager() {
         return &treeManager;
     }
 
@@ -115,7 +113,7 @@ public:
 
     char getReferenceCharAt(int pos) const override;
 
-    void sortSequences(const MultipleAlignment::SortType &sortType, const MultipleAlignment::Order &sortOrder);
+    void sortSequences(const MultipleAlignment::SortType& sortType, const MultipleAlignment::Order& sortOrder);
 
     /** Forces complete re-computation of the active collapse model based on the current MSA editor state. */
     void updateCollapseModel();
@@ -123,29 +121,58 @@ public:
     void setRowOrderMode(MaEditorRowOrderMode mode) override;
 
     /** Returns current set of free-mode markers. */
-    const QSet<QObject *> &getFreeModeMasterMarkersSet() const;
+    const QSet<QObject*>& getFreeModeMasterMarkersSet() const;
 
     /** Adds new marker object into freeModeMasterMarkersSet. */
-    void addFreeModeMasterMarker(QObject *marker);
+    void addFreeModeMasterMarker(QObject* marker);
 
     /** Removes the given marker object from the freeModeMasterMarkersSet. */
-    void removeFreeModeMasterMarker(QObject *marker);
+    void removeFreeModeMasterMarker(QObject* marker);
+
+    /**
+     * Maximum supported length of MSA object.
+     * The MSA Editor uses by-value caches (QVector/QList) that are proportional to the MSA length which can't grow above 2Gb limit.
+     */
+    static constexpr int MAX_SUPPORTED_MSA_OBJECT_LENGTH = 100 * 1000 * 1000;
+
+    MaEditorMultilineWgt* getUI() const override {
+        return getMaEditorMultilineWgt();
+    }
+
+    MaEditorWgt* getMaEditorWgt(int index = 0) const override {
+        return qobject_cast<MsaEditorWgt*>(getUI()->getUI(index));
+    }
+
+    // Return multiline widget (parent of the all sequences' widget
+    // Can be nullptr if widget is not yet created, but is used in for example
+    // in font metric calculating in MaEditor
+    // Don't want to update MaEditor
+    MaEditorMultilineWgt* getMaEditorMultilineWgt() const override {
+        return qobject_cast<MsaEditorMultilineWgt*>(ui);
+    }
+
+    void initChildrenActionsAndSignals() override;
 
 protected slots:
-    void sl_onContextMenuRequested(const QPoint &pos) override;
+    void sl_onContextMenuRequested(const QPoint& pos) override;
 
     void sl_buildTree();
     void sl_align();
-    void sl_addToAlignment();
+
+    /** Shows 'add-to-alignment' menu. */
+    void sl_alignNewSequencesToAlignment();
+
+    /** Shows 're-align-selection-to-alignment' menu. */
+    void sl_alignSelectedSequencesToAlignment();
+
     void sl_searchInSequences();
     void sl_searchInSequenceNames();
-    void sl_realignSomeSequences();
     void sl_setSeqAsReference();
     void sl_unsetReferenceSeq();
 
     void sl_showTreeOP();
     void sl_hideTreeOP();
-    void sl_rowsRemoved(const QList<qint64> &rowIds);
+    void sl_rowsRemoved(const QList<qint64>& rowIds);
     void sl_updateRealignAction();
     void sl_showCustomSettings();
     void sl_sortSequencesByName();
@@ -170,69 +197,88 @@ protected slots:
     /** Shows 'Export Image' dialog. */
     void sl_exportImage();
 
-protected:
-    QWidget *createWidget() override;
-    bool eventFilter(QObject *o, QEvent *e) override;
-    bool onObjectRemoved(GObject *obj) override;
-    void onObjectRenamed(GObject *obj, const QString &oldName) override;
-    bool onCloseEvent() override;
+    void sl_multilineViewAction() override;
 
-    void addCopyPasteMenu(QMenu *m) override;
-    void addEditMenu(QMenu *m) override;
-    void addSortMenu(QMenu *m);
-    void addExportMenu(QMenu *m) override;
-    void addAppearanceMenu(QMenu *m);
-    void addColorsMenu(QMenu *m);
-    void addHighlightingMenu(QMenu *m);
-    void addNavigationMenu(QMenu *m);
-    void addTreeMenu(QMenu *m);
-    void addAdvancedMenu(QMenu *m);
-    void addStatisticsMenu(QMenu *m);
+    bool setMultilineMode(bool newmode) override {
+        multilineMode = newmode;
+        return getUI()->setMultilineMode(multilineMode);
+    }
+
+protected:
+    QWidget* createViewWidget(QWidget* parent) override;
+    void onAfterViewWindowInit() override;
+
+    void initActions() override;
+    bool eventFilter(QObject* o, QEvent* e) override;
+    bool onObjectRemoved(GObject* obj) override;
+    void onObjectRenamed(GObject* obj, const QString& oldName) override;
+
+    void addCopyPasteMenu(QMenu* m, int uiIndex) override;
+    void addEditMenu(QMenu* m) override;
+    void addSortMenu(QMenu* m);
+    void addAlignMenu(QMenu* m);
+    void addExportMenu(QMenu* m) override;
+    void addAppearanceMenu(QMenu* m, int uiIndex);
+    void addColorsMenu(QMenu* m, int index) const;
+    void addHighlightingMenu(QMenu* m) const;
+    void addNavigationMenu(QMenu* m) const;
+    void addTreeMenu(QMenu* m) const;
+    void addAdvancedMenu(QMenu* m) const;
+    void addStatisticsMenu(QMenu* m);
 
     void updateActions() override;
 
-    void initDragAndDropSupport();
+    void initDragAndDropSupport(MaEditorWgt* wgt);
 
 public:
-    QAction *buildTreeAction = nullptr;
-    QAction *alignAction = nullptr;
-    QAction *alignSequencesToAlignmentAction = nullptr;
-    QAction *realignSomeSequenceAction = nullptr;
-    QAction *setAsReferenceSequenceAction = nullptr;
-    QAction *unsetReferenceSequenceAction = nullptr;
-    QAction *gotoAction = nullptr;
-    QAction *searchInSequencesAction = nullptr;
-    QAction *searchInSequenceNamesAction = nullptr;
-    QAction *openCustomSettingsAction = nullptr;
-    QAction *sortByNameAscendingAction = nullptr;
-    QAction *sortByNameDescendingAction = nullptr;
-    QAction *sortByLengthAscendingAction = nullptr;
-    QAction *sortByLengthDescendingAction = nullptr;
-    QAction *sortByLeadingGapAscendingAction = nullptr;
-    QAction *sortByLeadingGapDescendingAction = nullptr;
+    QAction* buildTreeAction = nullptr;
+    QAction* alignAction = nullptr;
+
+    /** Aligns new sequences (from an external file) to the current alignment. */
+    QAction* alignNewSequencesToAlignmentAction = nullptr;
+
+    /** Aligns selected sequences (from the current alignment) to the current rest of the alignment. */
+    QAction* alignSelectedSequencesToAlignmentAction = nullptr;
+
+    QAction* setAsReferenceSequenceAction = nullptr;
+    QAction* unsetReferenceSequenceAction = nullptr;
+    QAction* gotoAction = nullptr;
+    QAction* searchInSequencesAction = nullptr;
+    QAction* searchInSequenceNamesAction = nullptr;
+    QAction* openCustomSettingsAction = nullptr;
+    QAction* sortByNameAscendingAction = nullptr;
+    QAction* sortByNameDescendingAction = nullptr;
+    QAction* sortByLengthAscendingAction = nullptr;
+    QAction* sortByLengthDescendingAction = nullptr;
+    QAction* sortByLeadingGapAscendingAction = nullptr;
+    QAction* sortByLeadingGapDescendingAction = nullptr;
 
     /** Initiates a dialog to export the alignment using some image format. */
-    QAction *saveScreenshotAction = nullptr;
+    QAction* saveScreenshotAction = nullptr;
 
     /**
      * Sorts collapsing groups by number of sequences in ascending order.
      * The action is only enabled in 'MaEditorRowOrderMode::Sequence' mode when there are groups of length >=2.
      */
-    QAction *sortGroupsBySizeAscendingAction = nullptr;
+    QAction* sortGroupsBySizeAscendingAction = nullptr;
 
     /**
      * Sorts collapsing groups by number of sequences in descending descending order.
      * The action is only enabled in 'MaEditorRowOrderMode::Sequence' mode when there are groups of length >=2.
      */
-    QAction *sortGroupsBySizeDescendingAction = nullptr;
+    QAction* sortGroupsBySizeDescendingAction = nullptr;
 
-    QAction *convertDnaToRnaAction = nullptr;
-    QAction *convertRnaToDnaAction = nullptr;
-    QAction *convertRawToDnaAction = nullptr;
-    QAction *convertRawToAminoAction = nullptr;
+    QAction* convertDnaToRnaAction = nullptr;
+    QAction* convertRnaToDnaAction = nullptr;
+    QAction* convertRawToDnaAction = nullptr;
+    QAction* convertRawToAminoAction = nullptr;
 
 private:
-    PairwiseAlignmentWidgetsSettings *pairwiseAlignmentWidgetsSettings = nullptr;
+    MsaEditorWgt* createChildWidget(int index,
+                                    MaEditorOverviewArea* overview = nullptr,
+                                    MaEditorStatusBar* statusbar = nullptr);
+
+    PairwiseAlignmentWidgetsSettings* pairwiseAlignmentWidgetsSettings = nullptr;
     MSAEditorTreeManager treeManager;
 
     /**
@@ -250,10 +296,16 @@ private:
      *
      * MSAEditor can any time reset this set and switch to 'Original' or 'Sequence' mode.
      */
-    QSet<QObject *> freeModeMasterMarkersSet;
+    QSet<QObject*> freeModeMasterMarkersSet;
 
     /** Selection state controller. */
-    MaEditorSelectionController *selectionController;
+    MaEditorSelectionController* selectionController;
+
+    // Main windows toolbar and menu
+    // we need to save it for recreating actions while switching singleline <-> multiline modes
+    QToolBar* staticToolBar;
+    QMenu* staticMenu;
+    QString staticMenuType;
 };
 
 /** Set of custom menu actions in MSA editor. */
@@ -262,10 +314,15 @@ public:
     /** "Align" button menu identifier. */
     const static QString ALIGN;
 
-    /** "Align sequence(s) to this alignment" menu identifier. */
-    const static QString ALIGN_SEQUENCES_TO_ALIGNMENT;
+    /** "Align new sequence(s) to the current alignment menu identifier. */
+    const static QString ALIGN_NEW_SEQUENCES_TO_ALIGNMENT;
+
+    /** "Align another alignment to the current alignment menu identifier. */
+
+    const static QString ALIGN_NEW_ALIGNMENT_TO_ALIGNMENT;
+
+    /** "Align selected sequences to the  alignment menu identifier. */
+    const static QString ALIGN_SELECTED_SEQUENCES_TO_ALIGNMENT;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_EDITOR_H_
