@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_CONSENSUS_CACHE_H_
-#define _U2_MSA_EDITOR_CONSENSUS_CACHE_H_
+#pragma once
 
 #include <QBitArray>
 #include <QObject>
@@ -43,25 +42,25 @@ class U2VIEW_EXPORT MSAEditorConsensusCache : public QObject {
     Q_OBJECT
     Q_DISABLE_COPY(MSAEditorConsensusCache)
 public:
-    MSAEditorConsensusCache(QObject *p, MultipleAlignmentObject *aliObj, MSAConsensusAlgorithmFactory *algo);
+    MSAEditorConsensusCache(QObject* p, MultipleAlignmentObject* aliObj, MSAConsensusAlgorithmFactory* algo);
     ~MSAEditorConsensusCache();
 
     char getConsensusChar(int pos);
 
     int getConsensusCharPercent(int pos);
-    QList<int> getConsensusPercents(const U2Region &region);
+    QList<int> getConsensusPercents(const U2Region& region);
 
     int getConsensusLength() const {
         return cache.size();
     }
 
-    void setConsensusAlgorithm(MSAConsensusAlgorithmFactory *algo);
+    void setConsensusAlgorithm(MSAConsensusAlgorithmFactory* algo);
 
-    MSAConsensusAlgorithm *getConsensusAlgorithm() const {
+    MSAConsensusAlgorithm* getConsensusAlgorithm() const {
         return algorithm;
     }
 
-    QByteArray getConsensusLine(const U2Region &region, bool withGaps);
+    QByteArray getConsensusLine(const U2Region& region, bool withGaps);
     QByteArray getConsensusLine(bool withGaps);
 
 signals:
@@ -87,10 +86,8 @@ private:
     int curCacheSize;
     QVector<CacheItem> cache;
     QBitArray updateMap;
-    MultipleAlignmentObject *aliObj;
-    MSAConsensusAlgorithm *algorithm;
+    MultipleAlignmentObject* aliObj;
+    MSAConsensusAlgorithm* algorithm;
 };
 
 }  // namespace U2
-
-#endif
