@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,88 +30,93 @@
 #include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/U2SafePoints.h>
 
+#include "DrawHelper.h"
 #include "MSAEditor.h"
 #include "MSAEditorOffsetsView.h"
 #include "MSAEditorSequenceArea.h"
 #include "MaEditorNameList.h"
-#include "McaEditor.h"
-#include "helpers/DrawHelper.h"
-#include "helpers/RowHeightController.h"
-#include "helpers/ScrollController.h"
+#include "RowHeightController.h"
+#include "ScrollController.h"
+#include "ov_mca/McaEditor.h"
 
 namespace U2 {
 
 #define SETTINGS_SHOW_OFFSETS "show_offsets"
 
-MSAEditorOffsetsViewController::MSAEditorOffsetsViewController(MaEditorWgt *maEditorUi, MaEditor *ed, MaEditorSequenceArea *sa)
+MSAEditorOffsetsViewController::MSAEditorOffsetsViewController(MaEditorWgt* maEditorUi, MaEditor* ed, MaEditorSequenceArea* sa)
     : QObject(maEditorUi) {
     seqArea = sa;
     editor = ed;
+    ui = maEditorUi;
 
-    leftWidget = new MSAEditorOffsetsViewWidget(maEditorUi, ed, seqArea, true);
+    leftWidget = new MSAEditorOffsetsViewWidget(ui, ed, seqArea, true);
     leftWidget->setObjectName("msa_editor_offsets_view_widget_left");
-    rightWidget = new MSAEditorOffsetsViewWidget(maEditorUi, ed, seqArea, false);
+    rightWidget = new MSAEditorOffsetsViewWidget(ui, ed, seqArea, false);
     rightWidget->setObjectName("msa_editor_offsets_view_widget_right");
 
-    connect(maEditorUi->getScrollController(), SIGNAL(si_visibleAreaChanged()), SLOT(sl_updateOffsets()));
-    connect(editor, SIGNAL(si_fontChanged(const QFont &)), SLOT(sl_updateOffsets()));
+    connect(ui->getScrollController(), SIGNAL(si_visibleAreaChanged()), SLOT(sl_updateOffsets()));
+    connect(editor, SIGNAL(si_fontChanged(const QFont&)), SLOT(sl_updateOffsets()));
 
-    MultipleAlignmentObject *mobj = editor->getMaObject();
-    SAFE_POINT(nullptr != mobj, L10N::nullPointerError("multiple alignment object"), );
-    connect(mobj, SIGNAL(si_alignmentChanged(const MultipleAlignment &, const MaModificationInfo &)), SLOT(sl_updateOffsets()));
+    MultipleAlignmentObject* mobj = editor->getMaObject();
+    SAFE_POINT_NN(mobj, );
+    connect(mobj, SIGNAL(si_alignmentChanged(const MultipleAlignment&, const MaModificationInfo&)), SLOT(sl_updateOffsets()));
 
     seqArea->installEventFilter(this);
 
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
     bool showOffsets = s->getValue(editor->getSettingsRoot() + SETTINGS_SHOW_OFFSETS, true).toBool();
 
     toggleColumnsViewAction = new QAction(tr("Show offsets"), this);
     toggleColumnsViewAction->setObjectName("show_offsets");
     toggleColumnsViewAction->setCheckable(true);
     toggleColumnsViewAction->setChecked(showOffsets);
-    connect(toggleColumnsViewAction, SIGNAL(triggered(bool)), SLOT(sl_showOffsets(bool)));
+
+    connect(toggleColumnsViewAction, SIGNAL(triggered(bool)), editor, SIGNAL(si_showOffsets(bool)));
+    connect(editor, SIGNAL(si_showOffsets(bool)), SLOT(sl_showOffsets(bool)));
     connect(editor, SIGNAL(si_referenceSeqChanged(qint64)), SLOT(sl_updateOffsets()));
     connect(editor, SIGNAL(si_completeUpdate()), SLOT(sl_updateOffsets()));
-    updateOffsets();
+
+    updateOffsets(toggleColumnsViewAction->isChecked());
 }
 
 void MSAEditorOffsetsViewController::sl_updateOffsets() {
-    updateOffsets();
+    updateOffsets(toggleColumnsViewAction->isChecked());
 }
 
-bool MSAEditorOffsetsViewController::eventFilter(QObject *o, QEvent *e) {
+bool MSAEditorOffsetsViewController::eventFilter(QObject* o, QEvent* e) {
     if (o == seqArea) {
         if (e->type() == QEvent::Resize || e->type() == QEvent::Show) {
-            updateOffsets();
+            updateOffsets(toggleColumnsViewAction->isChecked());
         }
     }
     return false;
 }
 
 void MSAEditorOffsetsViewController::sl_showOffsets(bool show) {
-    updateOffsets();
-    Settings *s = AppContext::getSettings();
+    updateOffsets(show);
+    Settings* s = AppContext::getSettings();
     SAFE_POINT(s != nullptr, "AppContext settings is NULL", );
     s->setValue(editor->getSettingsRoot() + SETTINGS_SHOW_OFFSETS, show);
 }
 
-void MSAEditorOffsetsViewController::updateOffsets() {
+void MSAEditorOffsetsViewController::updateOffsets(bool show) {
     if (leftWidget->parentWidget() != nullptr) {
-        const bool vis = toggleColumnsViewAction->isChecked();
-        leftWidget->setVisible(vis);
-        rightWidget->setVisible(vis);
+        toggleColumnsViewAction->setChecked(show);
+        leftWidget->setVisible(show);
+        rightWidget->setVisible(show);
     }
 
     leftWidget->updateView();
     rightWidget->updateView();
 }
 
-MSAEditorOffsetsViewWidget::MSAEditorOffsetsViewWidget(MaEditorWgt *maEditorUi, MaEditor *ed, MaEditorSequenceArea *sa, bool sp)
+MSAEditorOffsetsViewWidget::MSAEditorOffsetsViewWidget(MaEditorWgt* maEditorUi, MaEditor* ed, MaEditorSequenceArea* sa, bool sp)
     : seqArea(sa),
       editor(ed),
+      ui(maEditorUi),
       showStartPos(sp),
       completeRedraw(true) {
-    connect(maEditorUi, SIGNAL(si_completeRedraw()), SLOT(sl_completeRedraw()));
+    connect(ui, SIGNAL(si_completeRedraw()), SLOT(sl_completeRedraw()));
 }
 
 void MSAEditorOffsetsViewWidget::sl_completeRedraw() {
@@ -121,10 +126,9 @@ void MSAEditorOffsetsViewWidget::sl_completeRedraw() {
 
 #define OFFS_WIDGET_BORDER 3
 void MSAEditorOffsetsViewWidget::updateView() {
-    const int aliLen = editor->getMaObject()->getLength();
     QFont f = getOffsetsFont();
     QFontMetrics fm(f, this);
-    int aliLenStrLen = int(log10((double)aliLen)) + 1;
+    int aliLenStrLen = getWidthInBases();
     int w = OFFS_WIDGET_BORDER + fm.width('X') * aliLenStrLen + OFFS_WIDGET_BORDER;
     w += (showStartPos ? fm.width('[') : fm.width(']'));
     setFixedWidth(w);
@@ -132,7 +136,13 @@ void MSAEditorOffsetsViewWidget::updateView() {
     update();
 }
 
-void MSAEditorOffsetsViewWidget::paintEvent(QPaintEvent *) {
+int MSAEditorOffsetsViewWidget::getWidthInBases() const {
+    qint64 alignmentLength = editor->getMaObject()->getLength();
+    int alignmentLengthStringLength = int(log10((double)alignmentLength)) + 1;
+    return alignmentLengthStringLength;
+}
+
+void MSAEditorOffsetsViewWidget::paintEvent(QPaintEvent*) {
     SAFE_POINT(isVisible(), "Attempting to paint an invisible widget", );
     const QSize s = size() * devicePixelRatio();
     if (s != cachedView.size()) {
@@ -156,15 +166,18 @@ QFont MSAEditorOffsetsViewWidget::getOffsetsFont() {
 }
 
 int MSAEditorOffsetsViewWidget::getBaseCounts(int seqNum, int aliPos, bool inclAliPos) const {
-    const MultipleAlignmentRow &row = editor->getMaObject()->getRow(seqNum);
+    const MultipleAlignmentRow& row = editor->getMaObject()->getRow(seqNum);
     const int endPos = inclAliPos ? aliPos + 1 : aliPos;
 
     return (endPos < row->getCoreStart()) ? 0 : row->getBaseCount(endPos);
 }
 
-void MSAEditorOffsetsViewWidget::drawAll(QPainter &painter) {
+void MSAEditorOffsetsViewWidget::drawAll(QPainter& painter) {
     QLinearGradient gradient(0, 0, width(), 0);
-    QColor lg(0xDA, 0xDA, 0xDA);
+    // ichebyki: if you want gradient border just change the lg value
+    // QColor lg(0xDA, 0xDA, 0xDA);
+    QColor lg = Qt::white;
+
     QColor dg(0x4A, 0x4A, 0x4A);
     gradient.setColorAt(0.00, lg);
     gradient.setColorAt(0.25, Qt::white);
@@ -178,11 +191,13 @@ void MSAEditorOffsetsViewWidget::drawAll(QPainter &painter) {
     QFontMetrics fm(font, this);
     painter.setFont(font);
 
-    MaEditorWgt *ui = editor->getUI();
     int alignmentLength = editor->getMaObject()->getLength();
     int lbw = fm.width('[');
     int rbw = fm.width(']');
-    int pos = showStartPos ? ui->getScrollController()->getFirstVisibleBase(true) : ui->getScrollController()->getLastVisibleBase(seqArea->width(), true);
+    ScrollController* scrollController = ui->getScrollController();
+    int pos = showStartPos
+                  ? scrollController->getFirstVisibleBase(true)
+                  : scrollController->getLastVisibleBase(seqArea->width(), true);
 
     QList<int> visibleRows = ui->getDrawHelper()->getVisibleMaRowIndexes(height());
 
@@ -221,7 +236,7 @@ void MSAEditorOffsetsViewWidget::drawAll(QPainter &painter) {
     }
 }
 
-void MSAEditorOffsetsViewWidget::drawRefSequence(QPainter &p, const QRect &r) {
+void MSAEditorOffsetsViewWidget::drawRefSequence(QPainter& p, const QRect& r) {
     p.fillRect(r, QColor("#9999CC"));
 }
 
