@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_OFFSETS_VIEW_H_
-#define _U2_MSA_EDITOR_OFFSETS_VIEW_H_
+#pragma once
 
 #include <QWidget>
 
@@ -38,24 +37,25 @@ class MultipleSequenceAlignmentObject;
 class U2VIEW_EXPORT MSAEditorOffsetsViewController : public QObject {
     Q_OBJECT
 public:
-    MSAEditorOffsetsViewController(MaEditorWgt *maEditorUi, MaEditor *editor, MaEditorSequenceArea *seqArea);
+    MSAEditorOffsetsViewController(MaEditorWgt* maEditorUi, MaEditor* editor, MaEditorSequenceArea* seqArea);
 
-    bool eventFilter(QObject *o, QEvent *e) override;
+    bool eventFilter(QObject* o, QEvent* e) override;
 
 private slots:
     void sl_updateOffsets();
     void sl_showOffsets(bool);
 
 private:
-    void updateOffsets();
+    void updateOffsets(bool show);
 
-    MaEditorSequenceArea *seqArea;
-    MaEditor *editor;
+    MaEditorSequenceArea* seqArea;
+    MaEditor* editor;
+    MaEditorWgt* ui = nullptr;
 
 public:
-    MSAEditorOffsetsViewWidget *leftWidget;
-    MSAEditorOffsetsViewWidget *rightWidget;
-    QAction *toggleColumnsViewAction;
+    MSAEditorOffsetsViewWidget* leftWidget;
+    MSAEditorOffsetsViewWidget* rightWidget;
+    QAction* toggleColumnsViewAction;
 };
 
 class MSAEditorOffsetsViewWidget : public QWidget {
@@ -63,28 +63,30 @@ class MSAEditorOffsetsViewWidget : public QWidget {
     friend class MSAEditorOffsetsViewController;
 
 public:
-    MSAEditorOffsetsViewWidget(MaEditorWgt *maEditorUi, MaEditor *editor, MaEditorSequenceArea *seqArea, bool showStartPos);
+    MSAEditorOffsetsViewWidget(MaEditorWgt* maEditorUi, MaEditor* editor, MaEditorSequenceArea* seqArea, bool showStartPos);
+
+    /** Returns number of characters needed to draw offsets. */
+    int getWidthInBases() const;
 
 private slots:
     void sl_completeRedraw();
 
 protected:
-    void paintEvent(QPaintEvent *e);
+    void paintEvent(QPaintEvent* e) override;
     void updateView();
-    void drawAll(QPainter &p);
+    void drawAll(QPainter& p);
     QFont getOffsetsFont();
-    void drawRefSequence(QPainter &p, const QRect &r);
+    void drawRefSequence(QPainter& p, const QRect& r);
 
 private:
     int getBaseCounts(int seqNum, int aliPos, bool inclAliPos) const;
 
-    MaEditorSequenceArea *seqArea;
-    MaEditor *editor;
+    MaEditorSequenceArea* seqArea;
+    MaEditor* editor;
+    MaEditorWgt* ui = nullptr;
     bool showStartPos;
     bool completeRedraw;
     QPixmap cachedView;
 };
 
 }  // namespace U2
-
-#endif
