@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,18 +19,15 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_OVERVIEW_H_
-#define _U2_MSA_EDITOR_OVERVIEW_H_
+#pragma once
 
 #include <QAction>
-#include <QWidget>
-
-#include <U2Core/global.h>
 
 #include "overview/MaEditorOverviewArea.h"
 
 namespace U2 {
 
+class MsaEditorMultilineWgt;
 class MaEditorWgt;
 class MaSimpleOverview;
 class MaGraphOverview;
@@ -39,23 +36,30 @@ class MaOverviewContextMenu;
 class U2VIEW_EXPORT MSAEditorOverviewArea : public MaEditorOverviewArea {
     Q_OBJECT
 public:
-    MSAEditorOverviewArea(MaEditorWgt *ui);
+    MSAEditorOverviewArea(MsaEditorMultilineWgt* ui);
 
-    void contextMenuEvent(QContextMenuEvent *event) override;
-
-    void cancelRendering() override;
+    void contextMenuEvent(QContextMenuEvent* event) override;
 
     static const QString OVERVIEW_AREA_OBJECT_NAME;
 
-private slots:
-    void sl_show() override;
+    void setVisible(bool isVisible) override;
+
+    MaGraphOverview* getGraphOverview() {
+        return graphOverview;
+    }
+    MaSimpleOverview* getSimpleOverview() {
+        return simpleOverview;
+    }
 
 private:
-    MaGraphOverview *graphOverview = nullptr;
-    MaSimpleOverview *simpleOverview = nullptr;
-    MaOverviewContextMenu *contextMenu = nullptr;
+    bool eventFilter(QObject* watched, QEvent* event) override;
+
+    /** Updates fixed-height value of the widget. Recomputes the new height by checking children visibility. */
+    void updateFixedHeightGeometry();
+
+    MaGraphOverview* graphOverview = nullptr;
+    MaSimpleOverview* simpleOverview = nullptr;
+    MaOverviewContextMenu* contextMenu = nullptr;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_EDITOR_OVERVIEW_H_
