@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_SEQUENCE_AREA_H_
-#define _U2_MSA_EDITOR_SEQUENCE_AREA_H_
+#pragma once
 
 #include <QMenu>
 #include <QToolBar>
@@ -33,13 +32,12 @@
 #include "DeleteGapsDialog.h"
 #include "ExportHighlightedDialogController.h"
 #include "MaCollapseModel.h"
+#include "MaEditorSequenceArea.h"
 #include "MsaEditorUserModStepController.h"
-#include "SaveSelectedSequenceFromMSADialogController.h"
-#include "view_rendering/MaEditorSequenceArea.h"
 
 namespace U2 {
 
-class GObjectView;
+class GObjectViewController;
 class MsaColorScheme;
 class MsaColorSchemeFactory;
 class MsaColorSchemeRegistry;
@@ -64,7 +62,7 @@ public:
         : type(_type) {
     }
 
-    ModificationType operator+(const ModificationType &another) {
+    ModificationType operator+(const ModificationType& another) {
         switch (type + another.type) {
             case NoType + NoType:
                 return ModificationType(NoType);
@@ -94,7 +92,7 @@ public:
         return type;
     }
 
-    bool operator==(const ModificationType &another) {
+    bool operator==(const ModificationType& another) {
         return type == another.type;
     }
 
@@ -102,7 +100,7 @@ public:
         return type == _type;
     }
 
-    bool operator!=(const ModificationType &another) {
+    bool operator!=(const ModificationType& another) {
         return type != another.type;
     }
 
@@ -110,7 +108,7 @@ public:
         return type != _type;
     }
 
-    ModificationType &operator=(int _type) {
+    ModificationType& operator=(int _type) {
         type = _type;
         return *this;
     }
@@ -126,16 +124,16 @@ class U2VIEW_EXPORT MSAEditorSequenceArea : public MaEditorSequenceArea {
     friend class SequenceWithChromatogramAreaRenderer;
 
 public:
-    MSAEditorSequenceArea(MaEditorWgt *ui, GScrollBar *hb, GScrollBar *vb);
+    MSAEditorSequenceArea(MaEditorWgt* ui, GScrollBar* hb, GScrollBar* vb);
 
-    MSAEditor *getEditor() const;
+    MSAEditor* getEditor() const;
 
     bool hasAminoAlphabet();
 
 public slots:
 
     /** Switches between Original and Sequence row orders. */
-    void sl_toggleSequenceRowOrder(bool isOrderBySequence);
+    void sl_toggleSequenceRowOrder(bool isOrderBySequence) override;
 
     void sl_copySelectionFormatted();
 
@@ -146,22 +144,24 @@ public:
      * TODO: rework to use sequence IDs. Multiple same-name sequences can be present in the list.
      * TODO: move this method to MSAEditor class.
      */
-    void enableFreeRowOrderMode(QObject *marker, const QList<QStringList> &);
+    void enableFreeRowOrderMode(QObject* marker, const QList<QStringList>&);
 
     /**
      * Removes 'marker' object from a 'Free' mode locks (See 'freeModeMasterMarkersSet').
      * When all 'markers' for the Free mode are removed the view is automatically switched to the Original mode.
      */
-    void disableFreeRowOrderMode(QObject *marker);
+    void disableFreeRowOrderMode(QObject* marker);
 
 protected:
-    void focusOutEvent(QFocusEvent *fe) override;
-
-    void focusInEvent(QFocusEvent *fe) override;
+    void focusOutEvent(QFocusEvent* fe) override;
+    void focusInEvent(QFocusEvent* fe) override;
+    void wheelEvent(QWheelEvent* we) override;
+    QSize sizeHint() const override;
+    QSize minimumSizeHint() const override;
 
 private slots:
-    void sl_buildMenu(GObjectView *v, QMenu *m, const QString &menuType);
-    void sl_buildStaticToolbar(GObjectView *v, QToolBar *t);
+    void sl_buildMenu(GObjectViewController* v, QMenu* m, const QString& menuType);
+    void sl_buildStaticToolbar(GObjectViewController* v, QToolBar* t);
     void sl_lockedStateChanged();
     void sl_addSeqFromFile();
     void sl_addSeqFromProject();
@@ -172,11 +172,10 @@ private slots:
     void sl_cutSelection();
 
     /** Takes data from the pasteTask and runs AddSequencesFromDocumentsToAlignmentTask. */
-    void sl_pasteTaskFinished(Task *pasteTask);
+    void sl_pasteTaskFinished(Task* pasteTask);
 
-    void sl_addSequencesToAlignmentFinished(Task *task);
+    void sl_addSequencesToAlignmentFinished(Task* task);
     void sl_delCol();
-    void sl_goto();
     void sl_removeAllGaps();
 
     /**
@@ -193,61 +192,60 @@ private slots:
 
     void sl_createSubalignment();
 
-    void sl_saveSequence();
-
-    void sl_modelChanged();
+    void sl_modelChanged() override;
 
     void sl_fontChanged(QFont font);
 
-    void sl_alphabetChanged(const MaModificationInfo &mi, const DNAAlphabet *prevAlphabet);
+    void sl_alphabetChanged(const MaModificationInfo& mi, const DNAAlphabet* prevAlphabet);
 
-    void sl_updateActions();
+    void sl_updateActions() override;
 
 private:
-    void initRenderer();
+    void initRenderer() override;
     void runPasteTask(bool isPasteBefore);
 
     /** Updates enabled/checked states of row-ordering actions based on the current row-order-mode in MSA. */
     void updateRowOrderActionsState();
 
-    void buildMenu(QMenu *m);
+    void buildMenu(QMenu* m, bool isContextMenu);
 
-    void reverseComplementModification(ModificationType &type);
+    void reverseComplementModification(ModificationType& type);
 
-    void updateCollapseModel(const MaModificationInfo &modInfo) override;
+    void updateCollapseModel(const MaModificationInfo& modInfo) override;
 
-    QAction *delColAction;
-    QAction *removeAllGapsAction;
+    void copySelection(U2OpStatus& os);
 
-    QAction *createSubaligniment;
-    QAction *saveSequence;
-    QAction *addSeqFromFileAction;
-    QAction *addSeqFromProjectAction;
+    QAction* delColAction;
+    QAction* removeAllGapsAction;
+
+    QAction* createSubaligniment;
+    QAction* addSeqFromFileAction;
+    QAction* addSeqFromProjectAction;
 
     /**
      * Switches between Sequence and Original row ordering modes.
      * When checked the Sequence mode is ON.
      * TODO: this is a global action for MA editor. Move it to the M(S)AEditor.h
      */
-    QAction *toggleSequenceRowOrderAction;
+    QAction* toggleSequenceRowOrderAction;
 
     /**
      * The action is enabled only in Sequence row ordering mode and triggers recompute of sequence order/groups by content.
      * TODO: this is a global action for MA editor. Move it to M(S)AEditor.h
      * TODO: this action has no use today, because in Sequence mode MA editor automatically adjusts order/groups on every MA update.
      */
-    QAction *refreshSequenceRowOrder;
+    QAction* refreshSequenceRowOrder;
 
-    QAction *reverseComplementAction;
-    QAction *reverseAction;
-    QAction *complementAction;
+    QAction* reverseComplementAction;
+    QAction* reverseAction;
+    QAction* complementAction;
 };
 
 // SANGER_TODO: move to EditorTasks?
 class U2VIEW_EXPORT ExportHighlightingTask : public Task {
     Q_OBJECT
 public:
-    ExportHighlightingTask(ExportHighligtingDialogController *dialog, MaEditor *editor);
+    ExportHighlightingTask(ExportHighligtingDialogController* dialog, MaEditor* editor);
 
     void run() override;
     QString generateReport() const override;
@@ -264,8 +262,7 @@ private:
     bool dots;
     bool transpose;
     GUrl url;
-    MSAEditor *msaEditor;
+    MSAEditor* msaEditor;
 };
 
 }  // namespace U2
-#endif
