@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,6 +21,8 @@
 
 #include "MaEditor.h"
 
+#include <QApplication>
+#include <QDesktopWidget>
 #include <QFontDialog>
 
 #include <U2Algorithm/MsaHighlightingScheme.h>
@@ -42,12 +44,15 @@
 #include <U2View/MSAEditorOffsetsView.h>
 #include <U2View/MSAEditorOverviewArea.h>
 #include <U2View/MSAEditorSequenceArea.h>
+#include <U2View/McaEditor.h>
+#include <U2View/UndoRedoFramework.h>
 
 #include "MaCollapseModel.h"
+#include "MaEditorSelection.h"
 #include "MaEditorState.h"
 #include "MaEditorTasks.h"
-#include "helpers/ScrollController.h"
-#include "view_rendering/MaEditorSelection.h"
+#include "MultilineScrollController.h"
+#include "ScrollController.h"
 
 namespace U2 {
 
@@ -57,8 +62,10 @@ SNPSettings::SNPSettings()
 
 const float MaEditor::zoomMult = 1.25;
 
-MaEditor::MaEditor(GObjectViewFactoryId factoryId, const QString &viewName, MultipleAlignmentObject *obj)
-    : GObjectView(factoryId, viewName),
+const double MaEditor::FONT_BOX_TO_CELL_BOX_MULTIPLIER = 1.25;
+
+MaEditor::MaEditor(const GObjectViewFactoryId& factoryId, const QString& viewName, MultipleAlignmentObject* obj)
+    : GObjectViewController(factoryId, viewName),
       ui(nullptr),
       resizeMode(ResizeMode_FontAndContent),
       minimumFontPointSize(6),
@@ -67,12 +74,10 @@ MaEditor::MaEditor(GObjectViewFactoryId factoryId, const QString &viewName, Mult
       cachedColumnWidth(0),
       cursorPosition(QPoint(0, 0)),
       rowOrderMode(MaEditorRowOrderMode::Original),
-      collapseModel(new MaCollapseModel(this, obj->getRowIds())),
-      exportHighlightedAction(nullptr),
-      clearSelectionAction(nullptr) {
+      collapseModel(new MaCollapseModel(this, obj->getRowIds())) {
     GCOUNTER(cvar, factoryId);
 
-    maObject = qobject_cast<MultipleAlignmentObject *>(obj);
+    maObject = qobject_cast<MultipleAlignmentObject*>(obj);
     objects.append(maObject);
 
     onObjectAdded(maObject);
@@ -84,6 +89,10 @@ MaEditor::MaEditor(GObjectViewFactoryId factoryId, const QString &viewName, Mult
         maObject->setTrackMod(os, TrackOnUpdate);
     }
 
+    undoRedoFramework = new MaUndoRedoFramework(this, obj);
+    undoAction = undoRedoFramework->getUndoAction();
+    redoAction = undoRedoFramework->getRedoAction();
+
     // SANGER_TODO: move to separate method
     // do that in createWidget along with initActions?
     saveAlignmentAction = new QAction(QIcon(":core/images/msa_save.png"), tr("Save alignment"), this);
@@ -125,19 +134,29 @@ MaEditor::MaEditor(GObjectViewFactoryId factoryId, const QString &viewName, Mult
     copyConsensusWithGapsAction = new QAction(tr("Copy consensus with gaps"), this);
     copyConsensusWithGapsAction->setObjectName("Copy consensus with gaps");
 
+    gotoSelectedReadAction = new QAction(tr("Go to selected read"), this);
+    gotoSelectedReadAction->setObjectName("center-read-start-end-action");
+    gotoSelectedReadAction->setEnabled(false);
+    connect(gotoSelectedReadAction, &QAction::triggered, this, &MaEditor::sl_gotoSelectedRead);
+
+    multilineViewAction = new QAction(QIcon(":core/images/multiline_view.png"), tr("Wrap mode"), this);
+    multilineViewAction->setObjectName("multilineView");
+    multilineViewAction->setCheckable(true);
+    multilineViewAction->setChecked(false);
+    connect(multilineViewAction, SIGNAL(triggered()), SLOT(sl_multilineViewAction()));
+
     connect(maObject, SIGNAL(si_lockedStateChanged()), SLOT(sl_lockedStateChanged()));
     connect(maObject,
-            SIGNAL(si_alignmentChanged(const MultipleAlignment &, const MaModificationInfo &)),
-            SLOT(sl_onAlignmentChanged(const MultipleAlignment &, const MaModificationInfo &)));
-    connect(this, SIGNAL(si_zoomOperationPerformed(bool)), SLOT(sl_resetColumnWidthCache()));
-    connect(this, SIGNAL(si_fontChanged(QFont)), SLOT(sl_resetColumnWidthCache()));
+            SIGNAL(si_alignmentChanged(const MultipleAlignment&, const MaModificationInfo&)),
+            SLOT(sl_onAlignmentChanged(const MultipleAlignment&, const MaModificationInfo&)));
+    connect(this, SIGNAL(si_fontChanged(QFont)), SLOT(resetColumnWidthCache()));
 }
 
-void MaEditor::sl_onAlignmentChanged(const MultipleAlignment &, const MaModificationInfo &) {
+void MaEditor::sl_onAlignmentChanged(const MultipleAlignment&, const MaModificationInfo&) {
     updateActions();
 }
 
-void MaEditor::sl_selectionChanged(const MaEditorSelection &, const MaEditorSelection &) {
+void MaEditor::sl_selectionChanged(const MaEditorSelection&, const MaEditorSelection&) {
     updateActions();
 }
 
@@ -145,7 +164,7 @@ QVariantMap MaEditor::saveState() {
     return MaEditorState::saveState(this);
 }
 
-Task *MaEditor::updateViewTask(const QString &stateName, const QVariantMap &stateData) {
+Task* MaEditor::updateViewTask(const QString& stateName, const QVariantMap& stateData) {
     return new UpdateMaEditorTask(this, stateName, stateData);
 }
 
@@ -154,14 +173,14 @@ int MaEditor::getAlignmentLen() const {
 }
 
 int MaEditor::getNumSequences() const {
-    return maObject->getNumRows();
+    return maObject->getRowCount();
 }
 
 bool MaEditor::isAlignmentEmpty() const {
     return getAlignmentLen() == 0 || getNumSequences() == 0;
 }
 
-const MaEditorSelection &MaEditor::getSelection() const {
+const MaEditorSelection& MaEditor::getSelection() const {
     return getSelectionController()->getSelection();
 }
 
@@ -169,22 +188,30 @@ int MaEditor::getRowContentIndent(int) const {
     return 0;
 }
 
-int MaEditor::getSequenceRowHeight() const {
+int MaEditor::getRowHeight() const {
     QFontMetrics fm(font, ui);
-    return fm.height() * zoomMult;
+    return qRound(fm.height() * FONT_BOX_TO_CELL_BOX_MULTIPLIER);
 }
 
 int MaEditor::getColumnWidth() const {
     if (cachedColumnWidth == 0) {
-        cachedColumnWidth = getUnifiedSequenceFontCharRect(font).width() * zoomMult;
-
-        cachedColumnWidth = (int)(cachedColumnWidth * zoomFactor);
-        cachedColumnWidth = qMax(cachedColumnWidth, MOBJECT_MIN_COLUMN_WIDTH);
+        double columnWidth;
+        if (resizeMode == ResizeMode_FontAndContent) {
+            columnWidth = getUnifiedSequenceFontCharRect(font).width() * FONT_BOX_TO_CELL_BOX_MULTIPLIER * zoomFactor;
+        } else {
+            columnWidth = getUnifiedSequenceFontCharRect(font).width() * FONT_BOX_TO_CELL_BOX_MULTIPLIER;
+            double rolledZoomFactor = zoomFactor;
+            while (rolledZoomFactor <= 1 && columnWidth > MOBJECT_MIN_COLUMN_WIDTH) {
+                rolledZoomFactor *= zoomMult;
+                columnWidth = columnWidth / zoomMult;
+            }
+        }
+        cachedColumnWidth = qMax((int)(columnWidth), MOBJECT_MIN_COLUMN_WIDTH);
     }
     return cachedColumnWidth;
 }
 
-QVariantMap MaEditor::getHighlightingSettings(const QString &highlightingFactoryId) const {
+QVariantMap MaEditor::getHighlightingSettings(const QString& highlightingFactoryId) const {
     const QVariant v = snp.highlightSchemeSettings.value(highlightingFactoryId);
     if (v.isNull()) {
         return QVariantMap();
@@ -193,7 +220,7 @@ QVariantMap MaEditor::getHighlightingSettings(const QString &highlightingFactory
     return v.toMap();
 }
 
-void MaEditor::saveHighlightingSettings(const QString &highlightingFactoryId, const QVariantMap &settingsMap /* = QVariant()*/) {
+void MaEditor::saveHighlightingSettings(const QString& highlightingFactoryId, const QVariantMap& settingsMap /* = QVariant()*/) {
     snp.highlightSchemeSettings.insert(highlightingFactoryId, QVariant(settingsMap));
 }
 
@@ -219,88 +246,139 @@ void MaEditor::resetCollapseModel() {
 
 void MaEditor::sl_zoomIn() {
     GCounter::increment("Zoom in", getFactoryId());
-    int pSize = font.pointSize();
 
+    ResizeMode oldResizeMode = resizeMode;
     if (resizeMode == ResizeMode_OnlyContent) {
-        setZoomFactor(zoomFactor * zoomMult);
-    } else if (pSize < maximumFontPointSize && resizeMode == ResizeMode_FontAndContent) {
-        font.setPointSize(pSize + 1);
-        setFont(font);
-    }
-
-    bool resizeModeChanged = false;
-
-    if (zoomFactor >= 1) {
-        ResizeMode oldMode = resizeMode;
-        resizeMode = ResizeMode_FontAndContent;
-        resizeModeChanged = resizeMode != oldMode;
+        setZoomFactor(qMax(zoomFactor * zoomMult, 1.0));
+    } else {
+        int pSize = font.pointSize();
+        if (pSize < maximumFontPointSize) {
+            font.setPointSize(pSize + 1);
+            setFont(font);
+        }
         setZoomFactor(1);
     }
     updateActions();
 
+    bool resizeModeChanged = resizeMode != oldResizeMode;
     emit si_zoomOperationPerformed(resizeModeChanged);
 }
 
 void MaEditor::sl_zoomOut() {
     GCounter::increment("Zoom out", getFactoryId());
+
+    ResizeMode oldResizeMode = resizeMode;
     int fontPointSize = font.pointSize();
-
-    bool resizeModeChanged = false;
-
     if (fontPointSize > minimumFontPointSize) {
         font.setPointSize(fontPointSize - 1);
         setFont(font);
+        setZoomFactor(1);
     } else {
-        SAFE_POINT(zoomMult > 0, QString("Incorrect value of MSAEditor::zoomMult"), );
         setZoomFactor(zoomFactor / zoomMult);
-        ResizeMode oldMode = resizeMode;
-        resizeMode = ResizeMode_OnlyContent;
-        resizeModeChanged = resizeMode != oldMode;
     }
     updateActions();
 
+    bool resizeModeChanged = resizeMode != oldResizeMode;
     emit si_zoomOperationPerformed(resizeModeChanged);
 }
 
 void MaEditor::sl_zoomToSelection() {
     ResizeMode oldMode = resizeMode;
-    int seqAreaWidth = ui->getSequenceArea()->width();
-    const MaEditorSelection &selection = getSelection();
-    CHECK(!selection.isEmpty(), )
-    QRect selectionRect = selection.getRectList()[0];  // We need width (equal on all rects) + top-left of the first rect.
-    float pixelsPerBase = (seqAreaWidth / float(selectionRect.width())) * zoomMult;
-    int fontPointSize = int(pixelsPerBase / fontPixelToPointSize);
-    if (fontPointSize >= minimumFontPointSize) {
-        fontPointSize = qMin(fontPointSize, maximumFontPointSize);
-        font.setPointSize(fontPointSize);
+    QRect selectionRect = getSelection().toRect();
+    CHECK(!selectionRect.isEmpty(), )
+
+    MaEditorSequenceArea* sequenceArea = getMaEditorWgt(0)->getSequenceArea();
+    double viewWidth = sequenceArea->width();
+    double viewHeight = sequenceArea->height();
+
+    // Adjust selection width in bases with offsets view data:
+    // Offsets view shares the same font and its width may grow in size if sequence view font is increased.
+    // If offsets view grows the sequence view will reduce it width by the same amount of characters.
+    MSAEditorOffsetsViewController* offsetsViewController = getMaEditorWgt(0)->getOffsetsViewController();
+    int basesInOffsetsView = offsetsViewController->leftWidget->getWidthInBases() + offsetsViewController->rightWidget->getWidthInBases();
+    int adjustedSelectionWidth = selectionRect.width() + basesInOffsetsView;
+
+    // Expected pixelsPerBase to fit the selection. Using int because getColumnWidth() returns int.
+    int targetPixelsPerBaseX = (int)(viewWidth / (adjustedSelectionWidth * FONT_BOX_TO_CELL_BOX_MULTIPLIER));
+    int targetPixelsPerBaseY = (int)(viewHeight / (selectionRect.height() * FONT_BOX_TO_CELL_BOX_MULTIPLIER));
+
+    QDesktopWidget* desktopWidget = QApplication::desktop();
+    double pixelToPointX = 72.0 / desktopWidget->logicalDpiX();  // 72 points == 1 inch (https://en.wikipedia.org/wiki/Point_(typography)).
+    double pixelToPointY = 72.0 / desktopWidget->logicalDpiY();
+    int targetFontPointSize = qMin(
+        // Prefer the min value, so the font size will be smaller and selection will always fit.
+        (int)qMin(targetPixelsPerBaseX * pixelToPointX, targetPixelsPerBaseY * pixelToPointY),
+        maximumFontPointSize);
+    if (targetFontPointSize >= minimumFontPointSize) {
+        font.setPointSize(targetFontPointSize);
         setFont(font);
-        resizeMode = ResizeMode_FontAndContent;
         setZoomFactor(1);
     } else {
         if (font.pointSize() != minimumFontPointSize) {
             font.setPointSize(minimumFontPointSize);
             setFont(font);
         }
-        setZoomFactor(pixelsPerBase / (minimumFontPointSize * fontPixelToPointSize));
-        resizeMode = ResizeMode_OnlyContent;
+        // Rendering mode with no characters shown because column width becomes too narrow.
+        // Column height remains at minimum font height.
+        double newZoomFactor = 1;
+        double selectedAreaWidth = selectionRect.width() * minimumFontPointSize / pixelToPointX;
+        while (selectedAreaWidth > viewWidth && selectedAreaWidth / selectionRect.width() > MOBJECT_MIN_COLUMN_WIDTH) {
+            newZoomFactor /= zoomMult;
+            selectedAreaWidth /= zoomMult;
+        }
+        setZoomFactor(newZoomFactor);
     }
-    ui->getScrollController()->setFirstVisibleBase(selectionRect.x());
-    ui->getScrollController()->setFirstVisibleViewRow(selectionRect.y());
+    updateActions();
+    emit si_zoomOperationPerformed(resizeMode != oldMode);
+
+    // Wait util UI restructuring is finished and sequence view gets it final dims.
+    // UI is restructured due to the font/zoom change.
+    // Center the zoomed region next.
+    QTimer::singleShot(200, this, [&]() { scrollSelectionIntoView(); });
+}
+
+void MaEditor::scrollSelectionIntoView() {
+    QRect selectionRect = getSelection().toRect();
+    CHECK(!selectionRect.isEmpty(), );
+    MaEditorSequenceArea* sequenceArea = getMaEditorWgt(0)->getSequenceArea();
+
+    double viewWidth = sequenceArea->width();
+    double viewHeight = sequenceArea->height();
+    double pixelsPerCellX = getColumnWidth();
+    double pixelsPerCellY = getRowHeight();
+    SAFE_POINT(pixelsPerCellX > 0 && pixelsPerCellY > 0, "Invalid pixels per base/row", );
+
+    int basesPerViewWidth = (int)(viewWidth / (double)pixelsPerCellX);
+    int rowsPerViewHeight = (int)(viewHeight / (double)pixelsPerCellY);
+    int basesOffset = 0;
+    int rowsOffset = 0;
+    if (basesPerViewWidth > selectionRect.width() && rowsPerViewHeight > selectionRect.height()) {
+        basesOffset = -(basesPerViewWidth - selectionRect.width()) / 2;
+        rowsOffset = -(rowsPerViewHeight - selectionRect.height()) / 2;
+    }
+    int firstVisibleBaseIndex = selectionRect.x() + basesOffset;
+    int firstVisibleRowIndex = selectionRect.y() + rowsOffset;
+    auto scrollController = getMaEditorMultilineWgt()->getScrollController();
+    scrollController->setFirstVisibleBase(firstVisibleBaseIndex);
+    scrollController->setFirstVisibleViewRow(firstVisibleRowIndex);
 
     updateActions();
-
-    emit si_zoomOperationPerformed(resizeMode != oldMode);
 }
 
 void MaEditor::sl_resetZoom() {
     GCounter::increment("Reset zoom", getFactoryId());
     QFont f = getFont();
-    f.setPointSize(MOBJECT_DEFAULT_FONT_SIZE);
-    setFont(f);
+    CHECK(f.pointSize() != MOBJECT_DEFAULT_FONT_SIZE || zoomFactor != MOBJECT_DEFAULT_ZOOM_FACTOR, );
+
+    ResizeMode oldResizeMode = resizeMode;
+    if (f.pointSize() != MOBJECT_DEFAULT_FONT_SIZE) {
+        f.setPointSize(MOBJECT_DEFAULT_FONT_SIZE);
+        setFont(f);
+    }
     setZoomFactor(MOBJECT_DEFAULT_ZOOM_FACTOR);
-    ResizeMode oldMode = resizeMode;
+
     resizeMode = ResizeMode_FontAndContent;
-    emit si_zoomOperationPerformed(resizeMode != oldMode);
+    emit si_zoomOperationPerformed(resizeMode != oldResizeMode);
 
     updateActions();
 }
@@ -310,7 +388,7 @@ void MaEditor::sl_saveAlignment() {
 }
 
 void MaEditor::sl_saveAlignmentAs() {
-    Document *srcDoc = maObject->getDocument();
+    Document* srcDoc = maObject->getDocument();
     if (srcDoc == nullptr) {
         return;
     }
@@ -318,7 +396,7 @@ void MaEditor::sl_saveAlignmentAs() {
         return;
     }
 
-    QObjectScopedPointer<ExportDocumentDialogController> dialog = new ExportDocumentDialogController(srcDoc, ui);
+    QObjectScopedPointer<ExportDocumentDialogController> dialog = new ExportDocumentDialogController(srcDoc, getUI());
     dialog->setAddToProjectFlag(true);
     dialog->setWindowTitle(tr("Save Alignment"));
     ExportObjectUtils::export2Document(dialog);
@@ -328,7 +406,7 @@ void MaEditor::sl_changeFont() {
     bool ok = false;
     GCounter::increment("Change of the characters font", getFactoryId());
     // QFontDialog::DontUseNativeDialog - no color selector, affects only Mac OS
-    QFont f = QFontDialog::getFont(&ok, font, widget, tr("Characters Font"), QFontDialog::DontUseNativeDialog);
+    QFont f = QFontDialog::getFont(&ok, font, viewWidget, tr("Characters Font"), QFontDialog::DontUseNativeDialog);
     if (!ok) {
         return;
     }
@@ -342,7 +420,7 @@ void MaEditor::sl_lockedStateChanged() {
 }
 
 void MaEditor::sl_exportHighlighted() {
-    QObjectScopedPointer<ExportHighligtingDialogController> d = new ExportHighligtingDialogController(ui, (QWidget *)AppContext::getMainWindow()->getQMainWindow());
+    QObjectScopedPointer<ExportHighligtingDialogController> d = new ExportHighligtingDialogController(getMaEditorWgt(0), (QWidget*)AppContext::getMainWindow()->getQMainWindow());
     d->exec();
     CHECK(!d.isNull(), );
 
@@ -351,7 +429,7 @@ void MaEditor::sl_exportHighlighted() {
     }
 }
 
-void MaEditor::sl_resetColumnWidthCache() {
+void MaEditor::resetColumnWidthCache() {
     cachedColumnWidth = 0;
 }
 
@@ -360,30 +438,33 @@ void MaEditor::initActions() {
     showOverviewAction->setObjectName("Show overview");
     showOverviewAction->setCheckable(true);
     showOverviewAction->setChecked(true);
-    connect(showOverviewAction, SIGNAL(triggered()), ui->getOverviewArea(), SLOT(sl_show()));
+    connect(showOverviewAction, &QAction::triggered, getMaEditorWgt(0)->getOverviewArea(), &QWidget::setVisible);
     ui->addAction(showOverviewAction);
-
-    MaEditorSelectionController *selectionController = getSelectionController();
     clearSelectionAction = new QAction(tr("Clear selection"), this);
     clearSelectionAction->setShortcut(Qt::Key_Escape);
     clearSelectionAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     connect(clearSelectionAction, SIGNAL(triggered()), SLOT(sl_onClearActionTriggered()));
     ui->addAction(clearSelectionAction);
 
-    connect(selectionController,
-            SIGNAL(si_selectionChanged(const MaEditorSelection &, const MaEditorSelection &)),
-            SLOT(sl_selectionChanged(const MaEditorSelection &, const MaEditorSelection &)));
+    connect(getSelectionController(),
+            SIGNAL(si_selectionChanged(const MaEditorSelection&, const MaEditorSelection&)),
+            SLOT(sl_selectionChanged(const MaEditorSelection&, const MaEditorSelection&)));
+
+    connect(undoAction, &QAction::triggered, [this]() { GCounter::increment("Undo", factoryId); });
+    connect(redoAction, &QAction::triggered, [this]() { GCounter::increment("Redo", factoryId); });
+    ui->addAction(undoAction);
+    ui->addAction(redoAction);
 }
 
 void MaEditor::initZoom() {
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
     SAFE_POINT(s != nullptr, "AppContext is NULL", );
     zoomFactor = s->getValue(getSettingsRoot() + MOBJECT_SETTINGS_ZOOM_FACTOR, MOBJECT_DEFAULT_ZOOM_FACTOR).toFloat();
     updateResizeMode();
 }
 
 void MaEditor::initFont() {
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
     SAFE_POINT(s != nullptr, "AppContext is NULL", );
     font.setFamily(s->getValue(getSettingsRoot() + MOBJECT_SETTINGS_FONT_FAMILY, MOBJECT_DEFAULT_FONT_FAMILY).toString());
     font.setPointSize(s->getValue(getSettingsRoot() + MOBJECT_SETTINGS_FONT_SIZE, MOBJECT_DEFAULT_FONT_SIZE).toInt());
@@ -394,19 +475,20 @@ void MaEditor::initFont() {
 }
 
 void MaEditor::updateResizeMode() {
-    resizeMode = font.pointSize() >= minimumFontPointSize && zoomFactor < 1.0f ? ResizeMode_OnlyContent : ResizeMode_FontAndContent;
+    SAFE_POINT(font.pointSize() >= minimumFontPointSize, "Illegal font point size", );
+    resizeMode = zoomFactor < 1.0f ? ResizeMode_OnlyContent : ResizeMode_FontAndContent;
 }
 
-void MaEditor::addCopyPasteMenu(QMenu *m) {
-    QMenu *cm = m->addMenu(tr("Copy/Paste"));
+void MaEditor::addCopyPasteMenu(QMenu* m, int) {
+    QMenu* cm = m->addMenu(tr("Copy/Paste"));
     cm->menuAction()->setObjectName(MSAE_MENU_COPY);
 }
 
-void MaEditor::addExportMenu(QMenu *m) {
-    QMenu *em = m->addMenu(tr("Export"));
+void MaEditor::addExportMenu(QMenu* m) {
+    QMenu* em = m->addMenu(tr("Export"));
     em->menuAction()->setObjectName(MSAE_MENU_EXPORT);
     em->addAction(exportHighlightedAction);
-    if (!ui->getSequenceArea()->getCurrentHighlightingScheme()->getFactory()->isRefFree() &&
+    if (!getMaEditorWgt(0)->getSequenceArea()->getCurrentHighlightingScheme()->getFactory()->isRefFree() &&
         getReferenceRowId() != U2MsaRow::INVALID_ROW_ID) {
         exportHighlightedAction->setEnabled(true);
     } else {
@@ -414,37 +496,32 @@ void MaEditor::addExportMenu(QMenu *m) {
     }
 }
 
-void MaEditor::addLoadMenu(QMenu *m) {
-    QMenu *lsm = m->addMenu(tr("Add"));
+void MaEditor::addLoadMenu(QMenu* m) {
+    QMenu* lsm = m->addMenu(tr("Add"));
     lsm->menuAction()->setObjectName(MSAE_MENU_LOAD);
 }
 
-void MaEditor::addAlignMenu(QMenu *m) {
-    QMenu *em = m->addMenu(tr("Align"));
-    em->setIcon(QIcon(":core/images/align.png"));
-    em->menuAction()->setObjectName(MSAE_MENU_ALIGN);
-}
-
-void MaEditor::setFont(const QFont &f) {
+void MaEditor::setFont(const QFont& f) {
     int pSize = f.pointSize();
     font = f;
+    resetColumnWidthCache();
     updateFontMetrics();
     font.setPointSize(qBound(minimumFontPointSize, pSize, maximumFontPointSize));
     updateResizeMode();
+    if (qobject_cast<McaEditorWgt*>(getUI())) {
+        qobject_cast<McaEditorWgt*>(getUI())->getScrollController()->updateScrollBarsOnFontOrZoomChange();
+    }
     emit si_fontChanged(font);
 
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
     s->setValue(getSettingsRoot() + MOBJECT_SETTINGS_FONT_FAMILY, f.family());
     s->setValue(getSettingsRoot() + MOBJECT_SETTINGS_FONT_SIZE, f.pointSize());
     s->setValue(getSettingsRoot() + MOBJECT_SETTINGS_FONT_ITALIC, f.italic());
     s->setValue(getSettingsRoot() + MOBJECT_SETTINGS_FONT_BOLD, f.bold());
-    widget->update();
+    viewWidget->update();
 }
 
 void MaEditor::updateFontMetrics() {
-    QFontInfo fontInfo(font);
-    fontPixelToPointSize = fontInfo.pixelSize() / fontInfo.pointSizeF();
-
     // Re-calculate the minimumFontPointSize based on the current font.
     // The minimum font size is computed using the similar logic with Assembly Browser:
     // it is equal to maximum font size value that can safely be rendered in the pre-defined on-screen cell of width = 7px.
@@ -456,7 +533,7 @@ void MaEditor::updateFontMetrics() {
     const int minimumSafeFontPointSize = 8;  // This value was historically used in UGENE as minimum with no known issues.
     QFont fontToEstimate = font;
     int estimatedMinimumFontPointSize = minimumSafeFontPointSize;  // Start with a safe value and estimate smaller values.
-    while (fontToEstimate.pointSize() > 0) {
+    while (fontToEstimate.pointSize() > 1) {
         int charWidth = getUnifiedSequenceFontCharRect(fontToEstimate).width();
         if (charWidth < minimumFontCharWidthInsideCell) {
             // The estimated char size is too small. Stop on the previous value.
@@ -468,34 +545,48 @@ void MaEditor::updateFontMetrics() {
     minimumFontPointSize = estimatedMinimumFontPointSize;
 }
 
-void MaEditor::setFirstVisiblePosSeq(int firstPos, int firstSeq) {
-    if (ui->getSequenceArea()->isPosInRange(firstPos)) {
-        ui->getScrollController()->setFirstVisibleBase(firstPos);
-        ui->getScrollController()->setFirstVisibleMaRow(firstSeq);
+void MaEditor::setFirstVisiblePosSeq(int firstPos, int firstSeq) const {
+    if (getMaEditorWgt(0)->getSequenceArea()->isPosInRange(firstPos)) {
+        if (isMultilineMode()) {
+            getMaEditorMultilineWgt()->getScrollController()->setFirstVisibleBase(firstPos);
+            getMaEditorMultilineWgt()->getScrollController()->setFirstVisibleMaRow(firstSeq);
+        } else {
+            getMaEditorWgt(0)->getScrollController()->setFirstVisibleBase(firstPos);
+            getMaEditorWgt(0)->getScrollController()->setFirstVisibleMaRow(firstSeq);
+        }
     }
 }
 
 void MaEditor::setZoomFactor(double newZoomFactor) {
+    CHECK(zoomFactor != newZoomFactor, );
     zoomFactor = newZoomFactor;
     updateResizeMode();
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
     s->setValue(getSettingsRoot() + MOBJECT_SETTINGS_ZOOM_FACTOR, zoomFactor);
-    sl_resetColumnWidthCache();
+    resetColumnWidthCache();
 }
 
 void MaEditor::updateActions() {
     zoomInAction->setEnabled(font.pointSize() < maximumFontPointSize);
     zoomOutAction->setEnabled(getColumnWidth() > MOBJECT_MIN_COLUMN_WIDTH);
     zoomToSelectionAction->setEnabled(font.pointSize() < maximumFontPointSize);
+
+    bool isDefaultZoomAndFontSize = getFont().pointSize() == MOBJECT_DEFAULT_FONT_SIZE && zoomFactor == MOBJECT_DEFAULT_ZOOM_FACTOR;
+    resetZoomAction->setEnabled(!isDefaultZoomAndFontSize);
+
     changeFontAction->setEnabled(resizeMode == ResizeMode_FontAndContent);
+
+    MaEditorSelection selection = getSelection();
+    gotoSelectedReadAction->setEnabled(!selection.isEmpty());
+
     emit si_updateActions();
 }
 
-const QPoint &MaEditor::getCursorPosition() const {
+const QPoint& MaEditor::getCursorPosition() const {
     return cursorPosition;
 }
 
-void MaEditor::setCursorPosition(const QPoint &newCursorPosition) {
+void MaEditor::setCursorPosition(const QPoint& newCursorPosition) {
     CHECK(cursorPosition != newCursorPosition, );
     int x = newCursorPosition.x(), y = newCursorPosition.y();
     CHECK(x >= 0 && y >= 0 && x < getAlignmentLen() && y < getNumSequences(), );
@@ -508,10 +599,10 @@ QList<qint64> MaEditor::getMaRowIds() const {
 }
 
 void MaEditor::selectRows(int firstViewRowIndex, int numberOfRows) {
-    ui->getSequenceArea()->setSelectionRect(QRect(0, firstViewRowIndex, getAlignmentLen(), numberOfRows));
+    getMaEditorWgt(0)->getSequenceArea()->setSelectionRect(QRect(0, firstViewRowIndex, getAlignmentLen(), numberOfRows));
 }
 
-QRect MaEditor::getUnifiedSequenceFontCharRect(const QFont &sequenceFont) const {
+QRect MaEditor::getUnifiedSequenceFontCharRect(const QFont& sequenceFont) const {
     QFontMetrics fontMetrics(sequenceFont, ui);
     return fontMetrics.boundingRect('W');
 }
@@ -525,7 +616,7 @@ void MaEditor::setRowOrderMode(MaEditorRowOrderMode mode) {
 }
 
 void MaEditor::sl_onClearActionTriggered() {
-    MaEditorSequenceArea *sequenceArea = ui->getSequenceArea();
+    MaEditorSequenceArea* sequenceArea = getMaEditorWgt(0)->getSequenceArea();
     if (sequenceArea->getMode() != MaEditorSequenceArea::ViewMode) {
         sequenceArea->exitFromEditCharacterMode();
         return;
@@ -533,7 +624,41 @@ void MaEditor::sl_onClearActionTriggered() {
     getSelectionController()->clearSelection();
 }
 
-MaCollapseModel *MaEditor::getCollapseModel() const {
+void MaEditor::sl_gotoSelectedRead() {
+    GCOUNTER(cvar, "MAEditor:gotoSelectedRead");
+    MaEditorSelection selection = getSelection();
+    CHECK(!selection.isEmpty(), );
+
+    QRect selectionRect = selection.toRect();
+    int viewRowIndex = selectionRect.y();
+
+    int maRowIndex = collapseModel->getMaRowIndexByViewRowIndex(viewRowIndex);
+    CHECK(maRowIndex >= 0 && maRowIndex < maObject->getRowCount(), );
+
+    MultipleAlignmentRow maRow = maObject->getRow(maRowIndex);
+    int posToCenter = maRow->isComplemented() ? maRow->getCoreEnd() - 1 : maRow->getCoreStart();
+    MaEditorSequenceArea* sequenceArea = getMaEditorWgt(0)->getSequenceArea();
+    if (sequenceArea->isPositionCentered(posToCenter)) {
+        posToCenter = maRow->isComplemented() ? maRow->getCoreStart() : maRow->getCoreEnd() - 1;
+    }
+    sequenceArea->centerPos(posToCenter);
+}
+
+MaCollapseModel* MaEditor::getCollapseModel() const {
     return collapseModel;
 }
+
+MaUndoRedoFramework* MaEditor::getUndoRedoFramework() const {
+    return undoRedoFramework;
+}
+
+bool MaEditor::isMultilineMode() const {
+    return multilineMode;
+}
+
+bool MaEditor::setMultilineMode(bool newmode) {
+    Q_UNUSED(newmode);
+    return false;
+}
+
 }  // namespace U2
