@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,9 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MA_EDITOR_H_
-#define _U2_MA_EDITOR_H_
+#pragma once
+
+#include <U2Core/U2SafePoints.h>
 
 #include <U2Gui/ObjectViewModel.h>
 
@@ -41,6 +42,8 @@ namespace U2 {
 #define MSAE_MENU_ADVANCED "MSAE_MENU_ADVANCED"
 #define MSAE_MENU_LOAD "MSAE_MENU_LOAD_SEQ"
 
+#define MSAE_MULTILINE_MODE "multiline_mode"
+
 #define MOBJECT_MIN_COLUMN_WIDTH 1
 
 #define MOBJECT_SETTINGS_COLOR_NUCL "color_nucl"
@@ -55,13 +58,18 @@ namespace U2 {
 #define MOBJECT_DEFAULT_FONT_SIZE 10
 #define MOBJECT_DEFAULT_ZOOM_FACTOR 1.0
 
+class MaCollapseModel;
 class MaEditorWgt;
+class MaEditorMultilineWgt;
+class MaEditorOverviewArea;
 class MultipleAlignmentObject;
 class MaEditorSelection;
 class MaEditorSelectionController;
-class MultipleAlignment;
-class MaCollapseModel;
+class MaEditorWgt;
 class MaModificationInfo;
+class MaUndoRedoFramework;
+class MultipleAlignment;
+class MultipleAlignmentObject;
 
 class SNPSettings {
 public:
@@ -96,7 +104,7 @@ enum class MaEditorRowOrderMode {
     Free
 };
 
-class U2VIEW_EXPORT MaEditor : public GObjectView {
+class U2VIEW_EXPORT MaEditor : public GObjectViewController {
     Q_OBJECT
     friend class OpenSavedMaEditorTask;
     friend class MaEditorState;
@@ -108,30 +116,33 @@ public:
     };
     static const float zoomMult;  // SANGER_TODO: should be dependable on the view
 
+    /** Extra space share around a rendered character in a cell relative to the actual font size. */
+    static const double FONT_BOX_TO_CELL_BOX_MULTIPLIER;
+
 public:
-    MaEditor(GObjectViewFactoryId factoryId, const QString &viewName, MultipleAlignmentObject *obj);
+    MaEditor(const GObjectViewFactoryId& factoryId, const QString& viewName, MultipleAlignmentObject* obj);
 
     virtual QVariantMap saveState();
 
-    virtual Task *updateViewTask(const QString &stateName, const QVariantMap &stateData);
+    virtual Task* updateViewTask(const QString& stateName, const QVariantMap& stateData);
 
     virtual QString getSettingsRoot() const = 0;
 
-    virtual MultipleAlignmentObject *getMaObject() const {
+    virtual MultipleAlignmentObject* getMaObject() const {
         return maObject;
     }
 
     QList<qint64> getMaRowIds() const;
 
-    virtual MaEditorWgt *getUI() const {
+    virtual QWidget* getUI() const {
         return ui;
     }
 
-    virtual OptionsPanel *getOptionsPanel() {
-        return optionsPanel;
-    }
+    virtual MaEditorWgt* getMaEditorWgt(int) const = 0;
 
-    const QFont &getFont() const {
+    virtual MaEditorMultilineWgt* getMaEditorMultilineWgt() const = 0;
+
+    const QFont& getFont() const {
         return font;
     }
 
@@ -146,19 +157,19 @@ public:
     bool isAlignmentEmpty() const;
 
     /* Returns current selection controller. */
-    virtual MaEditorSelectionController *getSelectionController() const = 0;
+    virtual MaEditorSelectionController* getSelectionController() const = 0;
 
     /* Returns current selection. */
-    const MaEditorSelection &getSelection() const;
+    const MaEditorSelection& getSelection() const;
 
     virtual int getRowContentIndent(int rowId) const;
-    int getSequenceRowHeight() const;  // SANGER_TODO: order the methods
+    int getRowHeight() const;  // SANGER_TODO: order the methods
 
     int getColumnWidth() const;
 
-    QVariantMap getHighlightingSettings(const QString &highlightingFactoryId) const;
+    QVariantMap getHighlightingSettings(const QString& highlightingFactoryId) const;
 
-    void saveHighlightingSettings(const QString &highlightingFactoryId, const QVariantMap &settingsMap = QVariantMap());
+    void saveHighlightingSettings(const QString& highlightingFactoryId, const QVariantMap& settingsMap = QVariantMap());
 
     qint64 getReferenceRowId() const {
         return snp.seqId;
@@ -180,16 +191,16 @@ public:
     }
 
     /** Returns current cursor position. */
-    const QPoint &getCursorPosition() const;
+    const QPoint& getCursorPosition() const;
 
     /** Sets new cursor position. Emits si_cursorPositionChanged() signal. */
-    void setCursorPosition(const QPoint &cursorPosition);
+    void setCursorPosition(const QPoint& cursorPosition);
 
     /** Sets selection to the given view rows. */
     virtual void selectRows(int firstViewRowIndex, int numberOfRows);
 
     /** Returns a unified bounding rect for a single sequence character for the given font. */
-    QRect getUnifiedSequenceFontCharRect(const QFont &sequenceFont) const;
+    QRect getUnifiedSequenceFontCharRect(const QFont& sequenceFont) const;
 
     /** Returns active row ordering mode. See docs for 'MaEditorRowOrderMode' enum for details. */
     MaEditorRowOrderMode getRowOrderMode() const;
@@ -201,19 +212,35 @@ public:
     virtual void setRowOrderMode(MaEditorRowOrderMode mode);
 
     /** Returns collapse model instance. The returned value is never null. */
-    MaCollapseModel *getCollapseModel() const;
+    MaCollapseModel* getCollapseModel() const;
+
+    /** Returns undo-redo framework. The returned value is never null. */
+    MaUndoRedoFramework* getUndoRedoFramework() const;
+
+    /**
+     * Centers selection on the screen if possible. Otherwise scrolls one of the selection corners into the view.
+     * Does not perform zoom/font-change operations.
+     */
+    void scrollSelectionIntoView();
+
+    virtual void initActionsAndSignals() {};
+    virtual void initChildrenActionsAndSignals() {};
+
+    virtual bool isMultilineMode() const;
+    virtual bool setMultilineMode(bool newmode);
 
 signals:
-    void si_fontChanged(const QFont &f);
+    void si_fontChanged(const QFont& f);
     void si_zoomOperationPerformed(bool resizeModeChanged);
     void si_referenceSeqChanged(qint64 referenceId);
     void si_sizeChanged(int newHeight, bool isMinimumSize, bool isMaximumSize);
     void si_completeUpdate();
     void si_updateActions();
-    void si_cursorPositionChanged(const QPoint &cursorPosition);
+    void si_cursorPositionChanged(const QPoint& cursorPosition);
+    void si_showOffsets(bool);
 
 protected slots:
-    virtual void sl_onContextMenuRequested(const QPoint &pos) = 0;
+    virtual void sl_onContextMenuRequested(const QPoint& pos) = 0;
 
     void sl_zoomIn();
     void sl_zoomOut();
@@ -230,39 +257,44 @@ protected slots:
     void sl_onClearActionTriggered();
 
     /** The slot is called each time alignment is changed. By default calls 'updateActions'. */
-    virtual void sl_onAlignmentChanged(const MultipleAlignment &ma, const MaModificationInfo &modInfo);
+    virtual void sl_onAlignmentChanged(const MultipleAlignment& ma, const MaModificationInfo& modInfo);
 
     /** The slot is called each time selection is changed. By default calls 'updateActions'. */
-    virtual void sl_selectionChanged(const MaEditorSelection &ma, const MaEditorSelection &modInfo);
+    virtual void sl_selectionChanged(const MaEditorSelection& ma, const MaEditorSelection& modInfo);
+
+    /** Callback for the 'gotoSelectedReadAction' action. See docs for 'gotoSelectedReadAction'. */
+    void sl_gotoSelectedRead();
+
+    virtual void sl_multilineViewAction() {
+        SAFE_POINT(false, "The function sl_multilineViewAction() must be overriden", );
+    };
 
 private slots:
-    void sl_resetColumnWidthCache();
+    void resetColumnWidthCache();
 
 protected:
-    virtual QWidget *createWidget() = 0;
     virtual void initActions();
-    virtual void initZoom();
-    virtual void initFont();
+    void initZoom();
+    void initFont();
     void updateResizeMode();
 
-    virtual void addCopyPasteMenu(QMenu *m);
-    virtual void addEditMenu(QMenu *m) = 0;
-    virtual void addExportMenu(QMenu *m);
-    void addLoadMenu(QMenu *m);
-    void addAlignMenu(QMenu *m);  // SANGER_TODO: should the align menu exist in MCA?
+    virtual void addCopyPasteMenu(QMenu* m, int uiIndex);
+    virtual void addEditMenu(QMenu* m) = 0;
+    virtual void addExportMenu(QMenu* m);
+    void addLoadMenu(QMenu* m);
 
-    void setFont(const QFont &f);
+    void setFont(const QFont& f);
 
     /** Updates font metrics like fontPixelToPointSize, minimum-font-size. Called on every font update. */
     void updateFontMetrics();
 
-    void setFirstVisiblePosSeq(int firstPos, int firstSeq);
+    void setFirstVisiblePosSeq(int firstPos, int firstSeq) const;
     void setZoomFactor(double newZoomFactor);
 
     virtual void updateActions();
 
-    MultipleAlignmentObject *maObject;
-    MaEditorWgt *ui;
+    MultipleAlignmentObject* maObject;
+    QWidget* ui = nullptr;
 
     QFont font;
     ResizeMode resizeMode;
@@ -279,7 +311,6 @@ protected:
 
     SNPSettings snp;
     double zoomFactor;
-    double fontPixelToPointSize;
     mutable int cachedColumnWidth;
 
     /** Current cursor position: 'x' is offset in alignment (0...len) and 'y' is a sequence index in the aligment. */
@@ -289,26 +320,49 @@ protected:
     MaEditorRowOrderMode rowOrderMode;
 
     /** Collapse model instance. Created in the constructor and is never changed. */
-    MaCollapseModel *const collapseModel;
+    MaCollapseModel* const collapseModel;
+
+    /** Undo-redo support. */
+    MaUndoRedoFramework* undoRedoFramework = nullptr;
+
+    bool multilineMode = false;
 
 public:
-    QAction *saveAlignmentAction;
-    QAction *saveAlignmentAsAction;
-    QAction *zoomInAction;
-    QAction *zoomOutAction;
-    QAction *zoomToSelectionAction;
-    QAction *showOverviewAction;
-    QAction *changeFontAction;
-    QAction *resetZoomAction;
-    QAction *exportHighlightedAction;
+    QAction* saveAlignmentAction = nullptr;
+    QAction* saveAlignmentAsAction = nullptr;
+    QAction* zoomInAction = nullptr;
+    QAction* zoomOutAction = nullptr;
+    QAction* zoomToSelectionAction = nullptr;
+    QAction* showOverviewAction = nullptr;
+    QAction* changeFontAction = nullptr;
+    QAction* resetZoomAction = nullptr;
+    QAction* exportHighlightedAction = nullptr;
+    QAction* multilineViewAction = nullptr;
 
     /** Clears selection in normal mode or exits from editing mode in the edit mode. */
-    QAction *clearSelectionAction;
+    QAction* clearSelectionAction = nullptr;
 
-    QAction *copyConsensusAction;
-    QAction *copyConsensusWithGapsAction;
+    QAction* copyConsensusAction = nullptr;
+    QAction* copyConsensusWithGapsAction = nullptr;
+
+    /**
+     * When activated MA editor moves start of the currently selected read into the view.
+     * If the selection contains multiple reads - selects the first one.
+     *
+     * The start of the direct reads (reads located on 3'-5' strand) is the same with their visual start on the screen -
+     *  direct reads are read from the left to the right direction.
+     * The start of the complement reads is they visual end position: such read sequences are read from the right to the left.
+     * This way the action works the same as annotation selection in the sequence view.
+     *
+     * When the action is triggered for the already selected read it tries to center the opposite side of the read: 'start' -> 'end', 'end' -> 'start'.
+     */
+    QAction* gotoSelectedReadAction = nullptr;
+
+    /** Undo action in MA Editor. Never null after the initialization. */
+    QAction* undoAction = nullptr;
+
+    /** Redo action. Never null after the initialization.*/
+    QAction* redoAction = nullptr;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MA_EDITOR_H_
