@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MA_EDITOR_CONSENSUS_AREA_SETTINGS_H_
-#define _U2_MA_EDITOR_CONSENSUS_AREA_SETTINGS_H_
+#pragma once
 
 #include <QFont>
 #include <QMap>
@@ -41,8 +40,8 @@ public:
 
     bool isVisible(const MaEditorConsElement element) const;
 
-    const QFont &getRulerFont() const;
-    void setRulerFont(const QFont &font);
+    const QFont& getRulerFont() const;
+    void setRulerFont(const QFont& font);
 
     QFont font;
     QList<MaEditorConsElement> order;
@@ -56,5 +55,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_MA_EDITOR_CONSENSUS_AREA_SETTINGS_H_
