@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,10 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MA_EDITOR_FACTORY_H_
-#define _U2_MA_EDITOR_FACTORY_H_
+#pragma once
 
 #include <U2Core/GObjectTypes.h>
+#include <U2Core/U2OpStatus.h>
 
 #include <U2Gui/ObjectViewModel.h>
 
@@ -41,22 +41,22 @@ class U2VIEW_EXPORT MaEditorFactory : public GObjectViewFactory {
 public:
     MaEditorFactory(GObjectType type, GObjectViewFactoryId id);
 
-    virtual bool canCreateView(const MultiGSelection &multiSelection);
+    virtual bool canCreateView(const MultiGSelection& multiSelection);
 
-    virtual Task *createViewTask(const MultiGSelection &multiSelection, bool single = false);
+    virtual Task* createViewTask(const MultiGSelection& multiSelection, bool single = false);
 
-    virtual bool isStateInSelection(const MultiGSelection &multiSelection, const QVariantMap &stateData);
+    virtual bool isStateInSelection(const MultiGSelection& multiSelection, const QVariantMap& stateData);
 
-    virtual Task *createViewTask(const QString &viewName, const QVariantMap &stateData);
+    virtual Task* createViewTask(const QString& viewName, const QVariantMap& stateData);
 
     virtual bool supportsSavedStates() const;
 
-    virtual MaEditor *getEditor(const QString &viewName, GObject *obj) = 0;
+    virtual MaEditor* getEditor(const QString& viewName, GObject* obj, U2OpStatus& os) = 0;
 
 protected:
-    virtual OpenMaEditorTask *getOpenMaEditorTask(MultipleAlignmentObject *obj) = 0;
-    virtual OpenMaEditorTask *getOpenMaEditorTask(UnloadedObject *obj) = 0;
-    virtual OpenMaEditorTask *getOpenMaEditorTask(Document *doc) = 0;
+    virtual OpenMaEditorTask* getOpenMaEditorTask(MultipleAlignmentObject* obj) = 0;
+    virtual OpenMaEditorTask* getOpenMaEditorTask(UnloadedObject* obj) = 0;
+    virtual OpenMaEditorTask* getOpenMaEditorTask(Document* doc) = 0;
 
     GObjectType type;
 };
@@ -69,7 +69,7 @@ class U2VIEW_EXPORT MsaEditorFactory : public MaEditorFactory {
 public:
     MsaEditorFactory();
 
-    MaEditor *getEditor(const QString &viewName, GObject *obj);
+    MaEditor* getEditor(const QString& viewName, GObject* obj, U2OpStatus& os) override;
 
     static const GObjectViewFactoryId ID;
 
@@ -80,9 +80,9 @@ public:
     void registerMsaEditorViewFeatures();
 
 private:
-    OpenMaEditorTask *getOpenMaEditorTask(MultipleAlignmentObject *obj);
-    OpenMaEditorTask *getOpenMaEditorTask(UnloadedObject *obj);
-    OpenMaEditorTask *getOpenMaEditorTask(Document *doc);
+    OpenMaEditorTask* getOpenMaEditorTask(MultipleAlignmentObject* obj);
+    OpenMaEditorTask* getOpenMaEditorTask(UnloadedObject* obj);
+    OpenMaEditorTask* getOpenMaEditorTask(Document* doc);
 };
 
 /************************************************************************/
@@ -93,16 +93,14 @@ class U2VIEW_EXPORT McaEditorFactory : public MaEditorFactory {
 public:
     McaEditorFactory();
 
-    MaEditor *getEditor(const QString &viewName, GObject *obj);
+    MaEditor* getEditor(const QString& viewName, GObject* obj, U2OpStatus& os) override;
 
     static const GObjectViewFactoryId ID;
 
 private:
-    OpenMaEditorTask *getOpenMaEditorTask(MultipleAlignmentObject *obj);
-    OpenMaEditorTask *getOpenMaEditorTask(UnloadedObject *obj);
-    OpenMaEditorTask *getOpenMaEditorTask(Document *doc);
+    OpenMaEditorTask* getOpenMaEditorTask(MultipleAlignmentObject* obj);
+    OpenMaEditorTask* getOpenMaEditorTask(UnloadedObject* obj);
+    OpenMaEditorTask* getOpenMaEditorTask(Document* doc);
 };
 
 }  // namespace U2
-
-#endif  // _U2_MA_EDITOR_FACTORY_H_
