@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MA_EDITOR_STATE_H_
-#define _U2_MA_EDITOR_STATE_H_
+#pragma once
 
 #include <QVariant>
 
@@ -33,22 +32,21 @@ class MaEditor;
 
 class U2VIEW_EXPORT MaEditorState {
 public:
-    MaEditorState() {
-    }
+    MaEditorState() = default;
 
-    MaEditorState(const QVariantMap &_stateData)
+    MaEditorState(const QVariantMap& _stateData)
         : stateData(_stateData) {
     }
 
-    static QVariantMap saveState(MaEditor *v);
+    static QVariantMap saveState(MaEditor* v);
 
     bool isValid() const;
 
     GObjectReference getMaObjectRef() const;
-    void setMaObjectRef(const GObjectReference &ref);
+    void setMaObjectRef(const GObjectReference& ref);
 
     QFont getFont() const;
-    void setFont(const QFont &f);
+    void setFont(const QFont& f);
 
     int getFirstPos() const;
     void setFirstPos(int y);
@@ -63,5 +61,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
