@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,14 +26,14 @@
 #include <U2Core/MultipleSequenceAlignmentObject.h>
 
 #include "MSAEditorSequenceArea.h"
-#include "ov_msa/view_rendering/MaEditorSelection.h"
+#include "MaEditorSelection.h"
 
 namespace U2 {
 
 const QString MaEditorStatusBar::NONE_MARK = "-";
 const QString MaEditorStatusBar::GAP_MARK = "gap";
 
-MaEditorStatusBar::TwoArgPatternLabel::TwoArgPatternLabel(const QString &textPattern, const QString &tooltipPattern, const QString &objectName, QWidget *parent)
+MaEditorStatusBar::TwoArgPatternLabel::TwoArgPatternLabel(const QString& textPattern, const QString& tooltipPattern, const QString& objectName, QWidget* parent)
     : QLabel(textPattern, parent),
       textPattern(textPattern),
       tooltipPattern(tooltipPattern),
@@ -42,18 +42,18 @@ MaEditorStatusBar::TwoArgPatternLabel::TwoArgPatternLabel(const QString &textPat
     setAlignment(Qt::AlignCenter);
 }
 
-void MaEditorStatusBar::TwoArgPatternLabel::setPatterns(const QString &newTextPattern, const QString &newTooltipPattern) {
+void MaEditorStatusBar::TwoArgPatternLabel::setPatterns(const QString& newTextPattern, const QString& newTooltipPattern) {
     this->textPattern = newTextPattern;
     this->tooltipPattern = newTooltipPattern;
 }
 
-void MaEditorStatusBar::TwoArgPatternLabel::update(const QString &firstArg, int minWidth) {
+void MaEditorStatusBar::TwoArgPatternLabel::update(const QString& firstArg, int minWidth) {
     setText(textPattern.arg(firstArg));
     setToolTip(tooltipPattern.arg(firstArg));
     setMinimumWidth(minWidth);
 }
 
-void MaEditorStatusBar::TwoArgPatternLabel::update(const QString &firstArg, const QString &secondArg) {
+void MaEditorStatusBar::TwoArgPatternLabel::update(const QString& firstArg, const QString& secondArg) {
     setText(textPattern.arg(firstArg).arg(secondArg));
     setToolTip(tooltipPattern.arg(firstArg).arg(secondArg));
     setMinimumWidth(10 + fm.width(textPattern.arg(secondArg).arg(secondArg)));
@@ -63,7 +63,7 @@ void MaEditorStatusBar::TwoArgPatternLabel::updateMinWidth(QString maxLenArg) {
     setMinimumWidth(10 + fm.width(textPattern.arg(maxLenArg).arg(maxLenArg)));
 }
 
-MaEditorStatusBar::MaEditorStatusBar(MaEditor *_editor)
+MaEditorStatusBar::MaEditorStatusBar(MaEditor* _editor)
     : editor(_editor),
       lockedIcon(":core/images/lock.png"),
       unlockedIcon(":core/images/lock_open.png") {
@@ -83,16 +83,26 @@ MaEditorStatusBar::MaEditorStatusBar(MaEditor *_editor)
     setLayout(layout);
 
     connect(editor->getSelectionController(),
-            SIGNAL(si_selectionChanged(const MaEditorSelection &, const MaEditorSelection &)),
-            SLOT(sl_update()));
-    MultipleAlignmentObject *maObject = editor->getMaObject();
-    connect(maObject, SIGNAL(si_alignmentChanged(const MultipleAlignment &, const MaModificationInfo &)), SLOT(sl_update()));
+            SIGNAL(si_selectionChanged(const MaEditorSelection&, const MaEditorSelection&)),
+            SLOT(sl_updateStatusBar()));
+    MultipleAlignmentObject* maObject = editor->getMaObject();
+    connect(maObject, SIGNAL(si_alignmentChanged(const MultipleAlignment&, const MaModificationInfo&)), SLOT(sl_updateStatusBar()));
     connect(maObject, SIGNAL(si_lockedStateChanged()), SLOT(sl_lockStateChanged()));
+    // Workaround
+    // updateLabels() must be called after all queued signals,
+    // so we use Qt::QueuedConnection and signal si_updateStatusBar2()
+    // which is emitted in intermediate signal si_updateStatusBar()
+    connect(this, &MaEditorStatusBar::si_updateStatusBar2, this, &MaEditorStatusBar::sl_updateStatusBar2, Qt::QueuedConnection);
 
     updateLock();
 }
 
-void MaEditorStatusBar::sl_update() {
+void MaEditorStatusBar::sl_updateStatusBar() {
+    // See comments in constructor
+    emit si_updateStatusBar2();
+}
+
+void MaEditorStatusBar::sl_updateStatusBar2() {
     updateLabels();
 }
 
@@ -101,7 +111,7 @@ void MaEditorStatusBar::sl_lockStateChanged() {
 }
 
 QPair<QString, QString> MaEditorStatusBar::getGappedPositionInfo() const {
-    const MaEditorSelection &selection = editor->getSelection();
+    const MaEditorSelection& selection = editor->getSelection();
     if (!selection.isSingleBaseSelection()) {
         return {NONE_MARK, NONE_MARK};
     }
@@ -123,7 +133,7 @@ void MaEditorStatusBar::updateLock() {
 
 void MaEditorStatusBar::updateLineLabel() {
     QString currentLineText = NONE_MARK;
-    const MaEditorSelection &selection = editor->getSelection();
+    const MaEditorSelection& selection = editor->getSelection();
     if (selection.isSingleRowSelection()) {
         qint64 selectedViewRowIndex = selection.getRectList()[0].y();
         currentLineText = QString::number(selectedViewRowIndex + 1);
@@ -139,7 +149,7 @@ void MaEditorStatusBar::updatePositionLabel() {
 }
 
 void MaEditorStatusBar::updateColumnLabel() {
-    const MaEditorSelection &selection = editor->getSelection();
+    const MaEditorSelection& selection = editor->getSelection();
     columnLabel->update(selection.isSingleColumnSelection()
                             ? QString::number(selection.getColumnRegion().startPos + 1)
                             : NONE_MARK,
@@ -147,8 +157,8 @@ void MaEditorStatusBar::updateColumnLabel() {
 }
 
 void MaEditorStatusBar::updateSelectionLabel() {
-    const MaEditorSelection &selection = editor->getSelection();
-    const QList<QRect> &selectionRects = selection.getRectList();
+    const MaEditorSelection& selection = editor->getSelection();
+    const QList<QRect>& selectionRects = selection.getRectList();
     QString selSize = selectionRects.isEmpty()
                           ? tr("none")
                           : QString("%1 x %2")
