@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,31 +19,30 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_NAME_LIST_H_
-#define _U2_MSA_EDITOR_NAME_LIST_H_
+#pragma once
 
 #include "MaEditorNameList.h"
 
 namespace U2 {
 
+class MSAEditor;
+
 class MsaEditorNameList : public MaEditorNameList {
     Q_OBJECT
 public:
-    MsaEditorNameList(MaEditorWgt *ui, QScrollBar *nhBar);
-
-protected:
-    /** Double-click in MSA editor is bound to 'rename-sequence' action. */
-    void mouseDoubleClickEvent(QMouseEvent *e) override;
+    MsaEditorNameList(MaEditorWgt* ui, QScrollBar* nhBar);
 
 private slots:
-    void sl_buildMenu(GObjectView *view, QMenu *menu, const QString &type);
+    void sl_buildMenu(GObjectViewController* view, QMenu* menu, const QString& type);
 
 private:
-    void buildMenu(QMenu *menu);
+    void buildMenu(QMenu* menu);
 
-    MSAEditor *getEditor() const;
+    MSAEditor* getEditor() const;
+
+protected:
+    QSize sizeHint() const override;
+    QSize minimumSizeHint() const override;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_EDITOR_NAME_LIST_H_
