@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_STATUS_BAR_H_
-#define _U2_MSA_EDITOR_STATUS_BAR_H_
+#pragma once
 
 #include "MaEditorStatusBar.h"
 
@@ -31,7 +30,7 @@ class MSAEditor;
 class MsaEditorStatusBar : public MaEditorStatusBar {
     Q_OBJECT
 public:
-    MsaEditorStatusBar(MSAEditor *msaEditor);
+    MsaEditorStatusBar(MSAEditor* msaEditor);
 
 private:
     /** Set ups initial layout of the status bar. Called as a part of the constructor. */
@@ -41,5 +40,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_EDITOR_STATUS_BAR_H_
