@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,9 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_WGT_H_
-#define _U2_MSA_EDITOR_WGT_H_
+#pragma once
 
-#include "view_rendering/MaEditorWgt.h"
+#include "MaEditorWgt.h"
 
 namespace U2 {
 
@@ -31,6 +30,7 @@ class MSADistanceMatrix;
 class MSAEditor;
 class MsaEditorAlignmentDependentWidget;
 class MSAEditorMultiTreeViewer;
+class MSAEditorOverviewArea;
 class MsaEditorSimilarityColumn;
 class MSAEditorTreeViewer;
 class SimilarityStatisticsSettings;
@@ -42,28 +42,38 @@ class U2VIEW_EXPORT MsaEditorWgt : public MaEditorWgt {
     friend class MsaEditorSimilarityColumn;
 
 public:
-    MsaEditorWgt(MSAEditor *editor);
+    MsaEditorWgt(MSAEditor* editor,
+                 QWidget* parent,
+                 MaEditorOverviewArea* overview = nullptr,
+                 MaEditorStatusBar* statusbar = nullptr);
 
-    MSAEditor *getEditor() const;
+    MSAEditor* getEditor() const;
 
-    MSAEditorSequenceArea *getSequenceArea() const;
+    MSAEditorSequenceArea* getSequenceArea() const;
 
-    void createDistanceColumn(MSADistanceMatrix *matrix);
+    void createDistanceColumn(MSADistanceMatrix* matrix);
 
-    void addTreeView(GObjectViewWindow *treeView);
+    void addTreeView(GObjectViewWindow* treeView);
 
-    void setSimilaritySettings(const SimilarityStatisticsSettings *settings);
+    void setSimilaritySettings(const SimilarityStatisticsSettings* settings);
+    const SimilarityStatisticsSettings* getSimilaritySettings();
 
     void refreshSimilarityColumn();
 
     void showSimilarity();
     void hideSimilarity();
 
-    const MsaEditorAlignmentDependentWidget *getSimilarityWidget();
+    MsaEditorAlignmentDependentWidget* getSimilarityWidget() const;
 
-    MSAEditorTreeViewer *getCurrentTree() const;
+    MSAEditorTreeViewer* getCurrentTree() const;
 
-    MSAEditorMultiTreeViewer *getMultiTreeViewer();
+    MSAEditorMultiTreeViewer* getMultiTreeViewer() const;
+
+    void initOverviewArea(MaEditorOverviewArea* overviewArea = nullptr) override;
+    void initStatusBar(MaEditorStatusBar* statusBar = nullptr) override;
+
+    QSize sizeHint() const override;
+    QSize minimumSizeHint() const override;
 
 private slots:
     void sl_onTabsCountChanged(int tabsCount);
@@ -72,19 +82,14 @@ signals:
     void si_hideTreeOP();
 
 protected:
-    void initSeqArea(GScrollBar *shBar, GScrollBar *cvBar);
-    void initOverviewArea();
-    void initNameList(QScrollBar *nhBar);
-    void initConsensusArea();
-    void initStatusBar();
+    void initSeqArea(GScrollBar* shBar, GScrollBar* cvBar) override;
+    void initNameList(QScrollBar* nhBar) override;
+    void initConsensusArea() override;
 
 private:
-    MsaEditorSimilarityColumn *dataList;
-    MSAEditorMultiTreeViewer *multiTreeViewer;
-    MsaEditorAlignmentDependentWidget *similarityStatistics;
-    MSAEditorTreeViewer *treeViewer;
+    MsaEditorSimilarityColumn* dataList = nullptr;
+    MSAEditorMultiTreeViewer* multiTreeViewer = nullptr;
+    MsaEditorAlignmentDependentWidget* similarityStatistics = nullptr;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MSA_EDITOR_WGT_H_
