@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_SELECT_WIDGET_CONTROLLER
-#define _U2_SEQUENCE_SELECT_WIDGET_CONTROLLER
+#pragma once
 
 #include <U2Gui/SuggestCompleter.h>
 
@@ -33,7 +32,7 @@ namespace U2 {
 class SequenceSelectorWidgetController : public QWidget, Ui_SequenceSelectorWidget {
     Q_OBJECT
 public:
-    SequenceSelectorWidgetController(MSAEditor *_msa);
+    SequenceSelectorWidgetController(MSAEditor* _msa);
     ~SequenceSelectorWidgetController();
 
     QString text() const;
@@ -46,7 +45,7 @@ signals:
 
 private slots:
     void sl_seqLineEditEditingFinished();
-    void sl_seqLineEditEditingFinished(const MultipleAlignment &, const MaModificationInfo &);
+    void sl_seqLineEditEditingFinished(const MultipleAlignment&, const MaModificationInfo&);
     void sl_addSeqClicked();
     void sl_deleteSeqClicked();
     void sl_setDefaultLineEditValue();
@@ -54,13 +53,11 @@ private slots:
 private:
     void updateCompleter();
 
-    MSAEditor *msa;
-    MSACompletionFiller *filler;
-    BaseCompleter *completer;
+    MSAEditor* msa;
+    MSACompletionFiller* filler;
+    BaseCompleter* completer;
     QString defaultSeqName;
     qint64 seqId;
 };
 
 };  // namespace U2
-
-#endif
