@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,7 +32,6 @@
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNATranslation.h>
 #include <U2Core/DocumentUtils.h>
-#include <U2Core/Log.h>
 #include <U2Core/ProjectModel.h>
 #include <U2Core/TaskWatchdog.h>
 #include <U2Core/TextUtils.h>
@@ -43,7 +42,6 @@
 
 #include <U2Formats/FastaFormat.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/GUIUtils.h>
 #include <U2Gui/ObjectViewModel.h>
 #include <U2Gui/ShowHideSubgroupWidget.h>
@@ -53,6 +51,7 @@
 
 #include "FindPatternMsaTask.h"
 #include "ov_msa/MaCollapseModel.h"
+#include "ov_msa/MultilineScrollController.h"
 #include "ov_sequence/find_pattern/FindPatternWidget.h"
 
 namespace U2 {
@@ -66,7 +65,7 @@ const int FindPatternMsaWidget::REG_EXP_MAX_RESULT_SINGLE_STEP = 20;
 
 class PatternWalker {
 public:
-    PatternWalker(const QString &patternsString, int cursor = 0)
+    PatternWalker(const QString& patternsString, int cursor = 0)
         : patternsString(patternsString.toLatin1()), cursor(cursor), current(-1) {
     }
 
@@ -133,7 +132,7 @@ private:
 /** Last used search mode. Stored per session only. */
 static int isSearchInNamesModeByDefault = false;
 
-FindPatternMsaWidget::FindPatternMsaWidget(MSAEditor *msaEditor, TriState isSearchInNamesModeTriState)
+FindPatternMsaWidget::FindPatternMsaWidget(MSAEditor* msaEditor, TriState isSearchInNamesModeTriState)
     : msaEditor(msaEditor),
       currentResultIndex(-1),
       searchTask(nullptr),
@@ -287,13 +286,13 @@ void FindPatternMsaWidget::initMaxResultLenContainer() {
     layoutRegExpLen->setSizeConstraint(QLayout::SetMinAndMaxSize);
     useMaxResultLenContainer->setLayout(layoutRegExpLen);
 
-    QHBoxLayout *layoutUseMaxResultLen = new QHBoxLayout();
+    QHBoxLayout* layoutUseMaxResultLen = new QHBoxLayout();
     layoutUseMaxResultLen->setSpacing(10);
     layoutUseMaxResultLen->setSizeConstraint(QLayout::SetMinAndMaxSize);
 
     boxUseMaxResultLen = new QCheckBox();
     boxUseMaxResultLen->setObjectName("boxUseMaxResultLen");
-    QLabel *labelUseMaxResultLen = new QLabel(tr("Results no longer than:"));
+    QLabel* labelUseMaxResultLen = new QLabel(tr("Results no longer than:"));
     labelUseMaxResultLen->setWordWrap(true);
     layoutUseMaxResultLen->addWidget(boxUseMaxResultLen, 0);
     layoutUseMaxResultLen->addWidget(labelUseMaxResultLen, 1);
@@ -324,9 +323,9 @@ void FindPatternMsaWidget::connectSlots() {
     connect(editEnd, SIGNAL(textChanged(QString)), SLOT(sl_onRegionValueEdited()));
     connect(boxMaxResult, SIGNAL(valueChanged(int)), SLOT(sl_onMaxResultChanged(int)));
     connect(removeOverlapsBox, SIGNAL(stateChanged(int)), SLOT(sl_validateStateAndStartNewSearch()));
-    MultipleSequenceAlignmentObject *msaObject = msaEditor->getMaObject();
-    connect(msaObject, SIGNAL(si_alignmentChanged(const MultipleAlignment &, const MaModificationInfo &)), this, SLOT(sl_onMsaModified()));
-    connect(msaObject, SIGNAL(si_alphabetChanged(const MaModificationInfo &, const DNAAlphabet *)), this, SLOT(sl_onMsaModified()));
+    MultipleSequenceAlignmentObject* msaObject = msaEditor->getMaObject();
+    connect(msaObject, SIGNAL(si_alignmentChanged(const MultipleAlignment&, const MaModificationInfo&)), this, SLOT(sl_onMsaModified()));
+    connect(msaObject, SIGNAL(si_alphabetChanged(const MaModificationInfo&, const DNAAlphabet*)), this, SLOT(sl_onMsaModified()));
     connect(msaObject, SIGNAL(si_lockedStateChanged()), SLOT(sl_msaStateChanged()));
     connect(prevPushButton, SIGNAL(clicked()), SLOT(sl_prevButtonClicked()));
     connect(nextPushButton, SIGNAL(clicked()), SLOT(sl_nextButtonClicked()));
@@ -334,8 +333,8 @@ void FindPatternMsaWidget::connectSlots() {
     connect(spinMatch, SIGNAL(valueChanged(int)), SLOT(sl_validateStateAndStartNewSearch()));
 
     connect(msaEditor->getSelectionController(),
-            SIGNAL(si_selectionChanged(const MaEditorSelection &, const MaEditorSelection &)),
-            SLOT(sl_onSelectedRegionChanged(const MaEditorSelection &, const MaEditorSelection &)));
+            SIGNAL(si_selectionChanged(const MaEditorSelection&, const MaEditorSelection&)),
+            SLOT(sl_onSelectedRegionChanged(const MaEditorSelection&, const MaEditorSelection&)));
 
     connect(searchContextComboBox, SIGNAL(currentIndexChanged(int)), SLOT(sl_searchModeChanged()));
 }
@@ -376,7 +375,7 @@ void FindPatternMsaWidget::sl_onRegionValueEdited() {
 }
 
 void FindPatternMsaWidget::updateActions() {
-    MultipleSequenceAlignmentObject *msaObject = msaEditor->getMaObject();
+    MultipleSequenceAlignmentObject* msaObject = msaEditor->getMaObject();
     groupResultsButton->setEnabled(!msaObject->isStateLocked());
 }
 
@@ -419,7 +418,7 @@ void FindPatternMsaWidget::updateLayout() {
     }
 }
 
-void FindPatternMsaWidget::setMessageFlag(const MessageFlag &messageFlag, bool show, const QString &additionalMsg) {
+void FindPatternMsaWidget::setMessageFlag(const MessageFlag& messageFlag, bool show, const QString& additionalMsg) {
     if (show) {
         messageFlagMap.insert(messageFlag, additionalMsg);
     } else {
@@ -432,7 +431,7 @@ void FindPatternMsaWidget::updateErrorLabelState() {
     QString text = "";
     QList<MessageFlag> messageFlags = messageFlagMap.keys();
 
-    for (const MessageFlag &flag : qAsConst(messageFlags)) {
+    for (const MessageFlag& flag : qAsConst(messageFlags)) {
         QString customErrorMessage = messageFlagMap[flag];
         text += text.isEmpty() ? "" : "<br>";
         switch (flag) {
@@ -440,7 +439,7 @@ void FindPatternMsaWidget::updateErrorLabelState() {
                 QString message = tr("Warning: input value contains characters that"
                                      " do not match the active alphabet!");
                 text += tr("<b><font color=%1>%2</font><br></br></b>").arg(Theme::warningColorLabelHtmlStr()).arg(message);
-                GUIUtils::setWidgetWarning(textPattern, true);
+                GUIUtils::setWidgetWarningStyle(textPattern, true);
                 break;
             }
             case PatternsWithBadAlphabetInFile: {
@@ -462,28 +461,6 @@ void FindPatternMsaWidget::updateErrorLabelState() {
                 text = QString("<b><font color=%1>%2</font><br></br></b>").arg(Theme::infoColorLabelHtmlStr()).arg(message);
                 break;
             }
-            case AnnotationNotValidName: {
-                QString message = tr("Warning: annotation name or annotation group name are invalid. ");
-                text += tr("<b><font color=%1>%2</font><br></br></b>").arg(Theme::errorColorLabelHtmlStr()).arg(message);
-                if (!customErrorMessage.isEmpty()) {
-                    text += tr("<b><font color=%1>%2</font></b>").arg(Theme::errorColorLabelHtmlStr()).arg(tr("Reason: "));
-                    text += tr("<b><font color=%1>%2</font><br></br></b>").arg(Theme::errorColorLabelHtmlStr()).arg(customErrorMessage);
-                }
-                QString msg = tr(" Please input valid annotation names. ");
-                text += tr("<b><font color=%1>%2</font><br></br></b>").arg(Theme::errorColorLabelHtmlStr()).arg(msg);
-                break;
-            }
-            case AnnotationNotValidFastaParsedName: {
-                QString message = tr("Warning: annotation names are invalid. ");
-                text += tr("<b><font color=%1>%2</font><br></br></b>").arg(Theme::errorColorLabelHtmlStr()).arg(message);
-                if (!customErrorMessage.isEmpty()) {
-                    text += tr("<b><font color=%1>%2</font></b>").arg(Theme::errorColorLabelHtmlStr()).arg(tr("Reason: "));
-                    text += tr("<b><font color=%1>%2</font><br></br></b>").arg(Theme::errorColorLabelHtmlStr()).arg(customErrorMessage);
-                }
-                QString msg = tr(" It will be automatically changed to acceptable name if 'Get annotations' button is pressed. ");
-                text += tr("<b><font color=%1>%2</font><br></br></b>").arg(Theme::errorColorLabelHtmlStr()).arg(msg);
-                break;
-            }
             case NoPatternToSearch: {
                 QString message = tr("Warning: there is no pattern to search. ");
                 text += tr("<b><font color=%1>%2</font></b>").arg(Theme::errorColorLabelHtmlStr()).arg(message);
@@ -499,7 +476,7 @@ void FindPatternMsaWidget::updateErrorLabelState() {
             case PatternWrongRegExp: {
                 QString message = tr("Warning: the input regular expression is invalid! ");
                 text += tr("<b><font color=%1>%2</font><br></br></b>").arg(Theme::errorColorLabelHtmlStr()).arg(message);
-                GUIUtils::setWidgetWarning(textPattern, true);
+                GUIUtils::setWidgetWarningStyle(textPattern, true);
                 break;
             }
             case SequenceIsTooBig: {
@@ -515,7 +492,7 @@ void FindPatternMsaWidget::updateErrorLabelState() {
     lblErrorMessage->setText(text);
     bool hasNoErrors = messageFlags.isEmpty() || (messageFlags.size() == 1 && messageFlags.contains(PleaseInputAtLeastOneSearchPatternTip));
     if (hasNoErrors) {
-        GUIUtils::setWidgetWarning(textPattern, false);
+        GUIUtils::setWidgetWarningStyle(textPattern, false);
     }
 }
 
@@ -524,7 +501,15 @@ void FindPatternMsaWidget::sl_onSearchPatternChanged() {
 }
 
 void FindPatternMsaWidget::sl_validateStateAndStartNewSearch(bool activatedByOutsideChanges) {
+    stopCurrentSearchTask();
+    clearResults();
+
     setCorrectPatternsString();
+    if (searchTask != nullptr) {
+        // A new search task was started as the result of the recursive
+        // 'setCorrectPatternsString' method call.
+        return;
+    }
     enableDisableMatchSpin();
     checkStateAndUpdateStatus();
     if (!messageFlagMap.isEmpty()) {
@@ -534,8 +519,6 @@ void FindPatternMsaWidget::sl_validateStateAndStartNewSearch(bool activatedByOut
     U2OpStatusImpl os;
     QStringList newPatterns = getPatternsFromTextPatternField(os);
     CHECK_OP(os, )
-    stopCurrentSearchTask();
-    clearResults();
     currentResultIndex = -1;
     if (isSearchInNamesMode) {
         runSearchInSequenceNames(newPatterns);
@@ -587,7 +570,7 @@ void FindPatternMsaWidget::setCorrectPatternsString() {
         }
 
         if (textPattern->toPlainText() != walker.getString()) {
-            textPattern->setText(walker.getString());
+            textPattern->setPlainText(walker.getString());
             cursorInTextEdit.setPosition(walker.getCursor());
             textPattern->setTextCursor(cursorInTextEdit);
         }
@@ -647,12 +630,12 @@ void FindPatternMsaWidget::checkStateAndUpdateStatus() {
     hideAllMessages();
     updateCurrentResultLabel();
 
-    GUIUtils::setWidgetWarning(textPattern, false);
+    GUIUtils::setWidgetWarningStyle(textPattern, false);
 
     QString searchRegionError = checkSearchRegion();
-    GUIUtils::setWidgetWarning(editStart, !searchRegionError.isEmpty());
-    GUIUtils::setWidgetWarning(editEnd, !searchRegionError.isEmpty());
-    GUIUtils::setWidgetWarning(textPattern, !searchRegionError.isEmpty() && !patternString.isEmpty());
+    GUIUtils::setWidgetWarningStyle(editStart, !searchRegionError.isEmpty());
+    GUIUtils::setWidgetWarningStyle(editEnd, !searchRegionError.isEmpty());
+    GUIUtils::setWidgetWarningStyle(textPattern, !searchRegionError.isEmpty() && !patternString.isEmpty());
     setMessageFlag(SearchRegionIncorrect, !searchRegionError.isEmpty(), searchRegionError);
 
     // Make extra checks for search-in-sequence mode.
@@ -684,19 +667,12 @@ U2Region FindPatternMsaWidget::getSearchRegion() const {
     return resultRegion;
 }
 
-int FindPatternMsaWidget::getMaxError(const QString &pattern) const {
-    if (selectedAlgorithm == FindAlgorithmPatternSettings_Exact) {
-        return 0;
-    }
-    return int((float)(1 - float(spinMatch->value()) / 100) * pattern.length());
-}
-
-QStringList FindPatternMsaWidget::getPatternsFromTextPatternField(U2OpStatus &os) const {
+QStringList FindPatternMsaWidget::getPatternsFromTextPatternField(U2OpStatus& os) const {
     QString inputText = textPattern->toPlainText();
     QList<NamePattern> nameList = FastaFormat::getSequencesAndNamesFromUserInput(inputText, os);
     if (!nameList.isEmpty()) {
         QStringList result;
-        foreach (const NamePattern &namePattern, nameList) {
+        foreach (const NamePattern& namePattern, nameList) {
             result << namePattern.second;
         }
         return result;
@@ -706,7 +682,7 @@ QStringList FindPatternMsaWidget::getPatternsFromTextPatternField(U2OpStatus &os
 
 #define FIND_PATTER_LAST_DIR "Find_msa_pattern_last_dir"
 
-void FindPatternMsaWidget::startFindPatternInMsaTask(const QStringList &patterns) {
+void FindPatternMsaWidget::startFindPatternInMsaTask(const QStringList& patterns) {
     currentSearchPatternList = patterns;
     CHECK(!patterns.isEmpty(), );
 
@@ -716,7 +692,7 @@ void FindPatternMsaWidget::startFindPatternInMsaTask(const QStringList &patterns
     }
 
     FindPatternMsaSettings settings;
-    foreach (const QString &pattern, patterns) {
+    foreach (const QString& pattern, patterns) {
         settings.patterns << NamePattern("", pattern);
     }
 
@@ -771,18 +747,15 @@ void FindPatternMsaWidget::sl_searchModeChanged() {
 }
 
 void FindPatternMsaWidget::sl_findPatternTaskStateChanged() {
-    FindPatternMsaTask *findTask = static_cast<FindPatternMsaTask *>(sender());
-    CHECK(findTask != nullptr, );
-    if (findTask != searchTask) {
-        return;
-    }
+    auto findTask = qobject_cast<FindPatternMsaTask*>(sender());
+    CHECK(findTask != nullptr && findTask == searchTask, );
     if (!findTask->isFinished() && !findTask->isCanceled() && !findTask->hasError()) {
         return;
     }
     allSearchResults.clear();
-    const QList<FindPatternInMsaResult> &findTaskResultList = findTask->getResults();
+    const QList<FindPatternInMsaResult>& findTaskResultList = findTask->getResults();
     for (int i = 0; i < findTaskResultList.size(); i++) {
-        const FindPatternInMsaResult &findTaskResult = findTaskResultList[i];
+        const FindPatternInMsaResult& findTaskResult = findTaskResultList[i];
         for (int j = 0; j < findTaskResult.regions.length(); j++) {
             allSearchResults << FindPatternWidgetResult(findTaskResult.rowId, -1, findTaskResult.regions[j]);
         }
@@ -808,8 +781,8 @@ void FindPatternMsaWidget::postProcessAllSearchResults() {
     }
 }
 
-bool FindPatternMsaWidget::checkAlphabet(const QString &pattern) {
-    const DNAAlphabet *alphabet = msaEditor->getMaObject()->getAlphabet();
+bool FindPatternMsaWidget::checkAlphabet(const QString& pattern) {
+    const DNAAlphabet* alphabet = msaEditor->getMaObject()->getAlphabet();
     if (selectedAlgorithm == FindAlgorithmPatternSettings_RegExp) {
         return true;
     }
@@ -817,16 +790,18 @@ bool FindPatternMsaWidget::checkAlphabet(const QString &pattern) {
 }
 
 QString FindPatternMsaWidget::checkSearchRegion() const {
+    CHECK(!isSearchInNamesMode, "");
+
     U2Region region = getSearchRegion();
-    if (region.isEmpty()) {
-        return tr("Warning: Invalid search region.");
-    }
+    CHECK(!region.isEmpty(), tr("Warning: Invalid search region."));
 
     CHECK(selectedAlgorithm != FindAlgorithmPatternSettings_RegExp, "");
+
     QStringList patternLines = textPattern->toPlainText().split("\n", QString::SkipEmptyParts);
     CHECK(!patternLines.isEmpty(), "");
+
     int minPatternLength = INT_MAX;
-    for (const QString &line : qAsConst(patternLines)) {
+    for (const QString& line : qAsConst(patternLines)) {
         minPatternLength = qMin(minPatternLength, line.length());
     }
     if (region.length < minPatternLength) {
@@ -835,7 +810,7 @@ QString FindPatternMsaWidget::checkSearchRegion() const {
     return "";
 }
 
-void FindPatternMsaWidget::sl_onSelectedRegionChanged(const MaEditorSelection &currentSelection, const MaEditorSelection &prev) {
+void FindPatternMsaWidget::sl_onSelectedRegionChanged(const MaEditorSelection& currentSelection, const MaEditorSelection& prev) {
     Q_UNUSED(prev);
     int boxRegionData = boxRegion->itemData(boxRegion->currentIndex()).toInt();
     bool isSearchInSelectionOn = boxRegionData == RegionSelectionIndex_CurrentSelectedRegion;
@@ -869,32 +844,32 @@ void FindPatternMsaWidget::updatePatternText(int previousAlgorithm) {
 
     // Set a new state.
     if (selectedAlgorithm == FindAlgorithmPatternSettings_RegExp) {
-        textPattern->setText(patternRegExp);
+        textPattern->setPlainText(patternRegExp);
     } else {
-        textPattern->setText(patternString);
+        textPattern->setPlainText(patternString);
     }
     setCorrectPatternsString();
 }
 
-void FindPatternMsaWidget::runSearchInSequenceNames(const QStringList &patterns) {
+void FindPatternMsaWidget::runSearchInSequenceNames(const QStringList& patterns) {
     currentSearchPatternList = patterns;
 
-    const MultipleAlignment &multipleAlignment = msaEditor->getMaObject()->getMultipleAlignment();
+    const MultipleAlignment& multipleAlignment = msaEditor->getMaObject()->getMultipleAlignment();
     U2Region wholeRowRegion(0, msaEditor->getAlignmentLen());
     QSet<int> resultRowIndexSet;
-    foreach (const QString &pattern, currentSearchPatternList) {
+    foreach (const QString& pattern, currentSearchPatternList) {
         if (pattern.isEmpty()) {
             continue;
         }
-        for (int i = 0, n = multipleAlignment->getNumRows(); i < n; i++) {
-            const MultipleAlignmentRow &row = multipleAlignment->getRow(i);
+        for (int i = 0, n = multipleAlignment->getRowCount(); i < n; i++) {
+            const MultipleAlignmentRow& row = multipleAlignment->getRow(i);
             if (row->getName().contains(pattern, Qt::CaseInsensitive)) {
                 resultRowIndexSet << i;
             }
         }
     }
     foreach (int rowIndex, resultRowIndexSet) {
-        const MultipleAlignmentRow &row = multipleAlignment->getRow(rowIndex);
+        const MultipleAlignmentRow& row = multipleAlignment->getRow(rowIndex);
         allSearchResults << FindPatternWidgetResult(row->getRowId(), -1, wholeRowRegion);
     }
     postProcessAllSearchResults();
@@ -924,11 +899,19 @@ void FindPatternMsaWidget::sl_nextButtonClicked() {
 
 void FindPatternMsaWidget::selectCurrentResult() {
     CHECK(currentResultIndex >= 0 && currentResultIndex < visibleSearchResults.length(), );
-    const FindPatternWidgetResult &result = visibleSearchResults[currentResultIndex];
-    MaEditorSequenceArea *seqArea = msaEditor->getUI()->getSequenceArea();
+    const FindPatternWidgetResult& result = visibleSearchResults[currentResultIndex];
+
+    auto mui = qobject_cast<MsaEditorMultilineWgt*>(msaEditor->getUI());
+    SAFE_POINT(mui != nullptr, "FindPatternMsaWidget: MsaEditorMultilineWgt is not found", );
     QRect selection(result.region.startPos, result.viewRowIndex, result.region.length, 1);
+    MaEditorSequenceArea* seqArea = mui->getUI(0)->getSequenceArea();
     seqArea->setSelectionRect(selection);
-    seqArea->centerPos(selection.topLeft());
+    if (msaEditor->getUI()->getMultilineMode()) {
+        // mui->getScrollController()->setCenterVisibleBase(selection.topLeft().x());
+        mui->getScrollController()->scrollToPoint(selection.topLeft());
+    } else {
+        seqArea->centerPos(selection.topLeft());
+    }
     updateCurrentResultLabel();
 }
 
@@ -982,16 +965,16 @@ void FindPatternMsaWidget::startProgressAnimation() {
 }
 
 struct SearchResultsComparator {
-    bool operator()(const FindPatternWidgetResult &r1, const FindPatternWidgetResult &r2) const {
+    bool operator()(const FindPatternWidgetResult& r1, const FindPatternWidgetResult& r2) const {
         return r1.viewRowIndex != r2.viewRowIndex ? r1.viewRowIndex < r2.viewRowIndex : r1.region.startPos < r2.region.startPos;
     }
 };
 
 void FindPatternMsaWidget::resortResultsByViewState() {
-    MaCollapseModel *collapseModel = msaEditor->getCollapseModel();
+    MaCollapseModel* collapseModel = msaEditor->getCollapseModel();
     visibleSearchResults.clear();
     for (int i = 0; i < allSearchResults.size(); i++) {
-        FindPatternWidgetResult &result = allSearchResults[i];
+        FindPatternWidgetResult& result = allSearchResults[i];
         result.viewRowIndex = collapseModel->getViewRowIndexByMaRowId(result.rowId);
         if (result.viewRowIndex >= 0) {
             visibleSearchResults << result;
@@ -1002,14 +985,14 @@ void FindPatternMsaWidget::resortResultsByViewState() {
 }
 
 int FindPatternMsaWidget::findCurrentResultIndexFromSelection() const {
-    const MaEditorSelection &selection = msaEditor->getSelection();
+    const MaEditorSelection& selection = msaEditor->getSelection();
     QRect selectionRect = selection.toRect();
     if (visibleSearchResults.isEmpty() || selection.isEmpty() || selectionRect.height() != 1) {
         return -1;
     }
     U2Region selectedXRegion = U2Region::fromXRange(selectionRect);
     for (int i = 0; i < visibleSearchResults.size(); i++) {
-        const FindPatternWidgetResult &result = visibleSearchResults[i];
+        const FindPatternWidgetResult& result = visibleSearchResults[i];
         if (result.viewRowIndex == selectionRect.y() && result.region == selectedXRegion) {
             return i;
         }
@@ -1021,12 +1004,12 @@ int FindPatternMsaWidget::getNextOrPrevResultIndexFromSelection(bool isNext) {
     int resultsCount = visibleSearchResults.size();
     CHECK(resultsCount > 0, -1);
 
-    const MaEditorSelection &selection = msaEditor->getSelection();
+    const MaEditorSelection& selection = msaEditor->getSelection();
     CHECK(!selection.isEmpty(), 0);
 
     int resultIndex = 0;
     for (; resultIndex < resultsCount; resultIndex++) {
-        const FindPatternWidgetResult &result = visibleSearchResults[resultIndex];
+        const FindPatternWidgetResult& result = visibleSearchResults[resultIndex];
         QRect selectionRect = selection.toRect();
         bool inTheNextRow = result.viewRowIndex > selectionRect.y();
         bool inTheSameRowAndNext = result.viewRowIndex == selectionRect.y() && result.region.startPos >= selectionRect.x();
@@ -1042,12 +1025,12 @@ int FindPatternMsaWidget::getNextOrPrevResultIndexFromSelection(bool isNext) {
 }
 
 bool FindPatternMsaWidget::isResultSelected() const {
-    const MaEditorSelection &selection = msaEditor->getSelection();
+    const MaEditorSelection& selection = msaEditor->getSelection();
     QRect selectionRect = selection.toRect();
     if (selectionRect.height() != 1 || currentResultIndex < 0 || currentResultIndex >= visibleSearchResults.size()) {
         return false;
     }
-    const FindPatternWidgetResult &result = visibleSearchResults[currentResultIndex];
+    const FindPatternWidgetResult& result = visibleSearchResults[currentResultIndex];
     return selectionRect.y() == result.viewRowIndex && result.region == U2Region(selectionRect.x(), selectionRect.width());
 }
 
@@ -1062,14 +1045,14 @@ void FindPatternMsaWidget::updateCurrentResultLabel() {
 
 void FindPatternMsaWidget::sl_groupResultsButtonClicked() {
     CHECK(!allSearchResults.isEmpty(), )
-    MultipleSequenceAlignmentObject *maObject = msaEditor->getMaObject();
+    MultipleSequenceAlignmentObject* maObject = msaEditor->getMaObject();
     CHECK(!maObject->isStateLocked(), );
 
     // Switch to the Original row order mode.
-    msaEditor->getUI()->getSequenceArea()->sl_toggleSequenceRowOrder(false);
+    msaEditor->getUI()->sl_toggleSequenceRowOrder(false);
 
     QSet<qint64> resultUidSet;
-    for (const FindPatternWidgetResult &result : qAsConst(allSearchResults)) {
+    for (const FindPatternWidgetResult& result : qAsConst(allSearchResults)) {
         resultUidSet << result.rowId;
     }
     const QList<qint64> allRowIds = msaEditor->getMaRowIds();
@@ -1112,7 +1095,7 @@ void FindPatternMsaWidget::sl_groupResultsButtonClicked() {
 }
 
 bool FindPatternMsaWidget::isAmino() const {
-    const DNAAlphabet *alphabet = msaEditor->getMaObject()->getAlphabet();
+    const DNAAlphabet* alphabet = msaEditor->getMaObject()->getAlphabet();
     return alphabet->isAmino();
 }
 
@@ -1120,7 +1103,7 @@ void FindPatternMsaWidget::sl_msaStateChanged() {
     updateActions();
 }
 
-FindPatternWidgetResult::FindPatternWidgetResult(qint64 rowId, int viewRowIndex, const U2Region &region)
+FindPatternWidgetResult::FindPatternWidgetResult(qint64 rowId, int viewRowIndex, const U2Region& region)
     : rowId(rowId), viewRowIndex(viewRowIndex), region(region) {
 }
 
