@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,15 +19,14 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_PATTERN_MSA_WIDGET_H_
-#define _U2_FIND_PATTERN_MSA_WIDGET_H_
+#pragma once
 
 #include <U2Core/U2Region.h>
 
 #include <U2View/MSAEditor.h>
 
 #include "FindPatternMsaWidgetSavableTab.h"
-#include "ov_msa/view_rendering/MaEditorSelection.h"
+#include "ov_msa/MaEditorSelection.h"
 #include "ui_FindPatternMsaForm.h"
 
 namespace U2 {
@@ -42,7 +41,7 @@ class U2OpStatus;
 
 /** Find algorithm results with view positioning info. */
 struct FindPatternWidgetResult {
-    FindPatternWidgetResult(qint64 rowId, int viewRowIndex, const U2Region &region);
+    FindPatternWidgetResult(qint64 rowId, int viewRowIndex, const U2Region& region);
 
     /** MA sequence row id. */
     qint64 rowId;
@@ -62,15 +61,13 @@ public:
         PatternsWithBadAlphabetInFile,
         PatternsWithBadRegionInFile,
         PleaseInputAtLeastOneSearchPatternTip,
-        AnnotationNotValidName,
-        AnnotationNotValidFastaParsedName,
         NoPatternToSearch,
         SearchRegionIncorrect,
         PatternWrongRegExp,
         SequenceIsTooBig
     };
     /** Creates a new widget. Activates search-in-name mode if isSearchInNamesMode is yes. Uses the last saved state if isSearchInNamesMode is Unknown. */
-    FindPatternMsaWidget(MSAEditor *msaEditor, TriState isSearchInNamesModeTriState = TriState_Unknown);
+    FindPatternMsaWidget(MSAEditor* msaEditor, TriState isSearchInNamesModeTriState = TriState_Unknown);
 
     int getTargetMsaLength() const;
 
@@ -90,7 +87,7 @@ private slots:
     void sl_onMsaModified();
     void sl_msaStateChanged();
 
-    void sl_onSelectedRegionChanged(const MaEditorSelection &currentSelection, const MaEditorSelection &prev);
+    void sl_onSelectedRegionChanged(const MaEditorSelection& currentSelection, const MaEditorSelection& prev);
     void sl_prevButtonClicked();
     void sl_nextButtonClicked();
 
@@ -98,6 +95,10 @@ private slots:
     void sl_onShiftEnterPressed();
     void sl_collapseModelChanged();
 
+    /**
+     * Clears current search results first, validations the new pattern
+     * and runs a new search if the were no validation errors.
+     */
     void sl_validateStateAndStartNewSearch(bool activatedByOutsideChanges = false);
 
 private:
@@ -114,8 +115,6 @@ private:
     /** Returns true if the alignment alphabet is Amino. */
     bool isAmino() const;
 
-    int getMaxError(const QString &pattern) const;
-
     /** Assigns valid viewRowIndex value to all results & resorts them based on the view position. */
     void resortResultsByViewState();
 
@@ -156,14 +155,14 @@ private:
     void enableDisableMatchSpin();
 
     /** Toggles error message flag and updates additional error message. Does not trigger re-rendering of the error label. */
-    void setMessageFlag(const MessageFlag &messageFlag, bool show, const QString &additionalMsg = QString());
+    void setMessageFlag(const MessageFlag& messageFlag, bool show, const QString& additionalMsg = QString());
 
     /** Updates visual error label state based on the curent error flags state. */
     void updateErrorLabelState();
 
     /** Checks pattern alphabet and sets error message if needed. Returns false on error or true if no error found */
     bool verifyPatternAlphabet();
-    bool checkAlphabet(const QString &pattern);
+    bool checkAlphabet(const QString& pattern);
     void showTooLongSequenceError();
     void hideAllMessages();
 
@@ -171,25 +170,25 @@ private:
     void setRegionToWholeSequence();
 
     /** Performs in-main thread search in sequence names. */
-    void runSearchInSequenceNames(const QStringList &patterns);
+    void runSearchInSequenceNames(const QStringList& patterns);
 
     /** Checks current UI state and returns either a valid or an empty (invalid) region. */
     U2Region getSearchRegion() const;
 
-    void startFindPatternInMsaTask(const QStringList &patterns);
+    void startFindPatternInMsaTask(const QStringList& patterns);
 
     /**
      * Checks if there are several patterns in textPattern which are separated by new line symbol,
      * parses them out and returns with their names (if they're exist).
      */
-    QStringList getPatternsFromTextPatternField(U2OpStatus &os) const;
+    QStringList getPatternsFromTextPatternField(U2OpStatus& os) const;
 
     void updatePatternText(int previousAlgorithm);
 
     /** Post processes allSearchResults list after search task is finished. */
     void postProcessAllSearchResults();
 
-    MSAEditor *msaEditor;
+    MSAEditor* msaEditor;
     int selectedAlgorithm;
     QString patternString;
     QString patternRegExp;
@@ -198,15 +197,15 @@ private:
     QMap<MessageFlag, QString> messageFlagMap;
 
     /** Widgets in the Algorithm group */
-    QHBoxLayout *layoutMismatch;
-    QVBoxLayout *layoutRegExpLen;
+    QHBoxLayout* layoutMismatch;
+    QVBoxLayout* layoutRegExpLen;
 
-    QLabel *lblMatch;
-    QSpinBox *spinMatch;
+    QLabel* lblMatch;
+    QSpinBox* spinMatch;
 
-    QWidget *useMaxResultLenContainer;
-    QCheckBox *boxUseMaxResultLen;
-    QSpinBox *boxMaxResultLen;
+    QWidget* useMaxResultLenContainer;
+    QCheckBox* boxUseMaxResultLen;
+    QSpinBox* boxMaxResultLen;
 
     static const int DEFAULT_RESULTS_NUM_LIMIT;
     static const int DEFAULT_REGEXP_RESULT_LENGTH_LIMIT;
@@ -224,20 +223,18 @@ private:
     /** Index of the currently selected result. */
     int currentResultIndex;
 
-    Task *searchTask;
+    Task* searchTask;
     int previousMaxResult;
     QStringList currentSearchPatternList;
-    QMovie *progressMovie;
+    QMovie* progressMovie;
     bool setSelectionToTheFirstResult;
     bool isSearchInNamesMode;
 
     FindPatternMsaWidgetSavableTab savableWidget;
 
-    ShowHideSubgroupWidget *algorithmSubgroup;
-    ShowHideSubgroupWidget *searchInSubgroup;
-    ShowHideSubgroupWidget *otherSettingsSubgroup;
+    ShowHideSubgroupWidget* algorithmSubgroup;
+    ShowHideSubgroupWidget* searchInSubgroup;
+    ShowHideSubgroupWidget* otherSettingsSubgroup;
 };
 
 }  // namespace U2
-
-#endif  // _U2_FIND_PATTERN_WIDGET_H_
