@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_PATTERN_MSA_WIDGET_SAVABLE_TAB_H_
-#define _U2_FIND_PATTERN_MSA_WIDGET_SAVABLE_TAB_H_
+#pragma once
 
 #include <QStringList>
 
@@ -30,16 +29,14 @@ namespace U2 {
 
 class FindPatternMsaWidgetSavableTab : public U2SavableWidget {
 public:
-    FindPatternMsaWidgetSavableTab(QWidget *wrappedWidget, MWMDIWindow *contextWindow);
+    FindPatternMsaWidgetSavableTab(QWidget* wrappedWidget, MWMDIWindow* contextWindow);
     ~FindPatternMsaWidgetSavableTab();
 
-    void setChildValue(const QString &childId, const QVariant &value);
-    void setRegionWidgetIds(const QStringList &s);
+    void setChildValue(const QString& childId, const QVariant& value);
+    void setRegionWidgetIds(const QStringList& s);
 
 private:
     QStringList regionWidgetIds;
 };
 
 }  // namespace U2
-
-#endif
