@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_HIGHLIGHTING_SAVABLE_TAB_H_
-#define _U2_MSA_HIGHLIGHTING_SAVABLE_TAB_H_
+#pragma once
 
 #include <QStringList>
 
@@ -30,18 +29,16 @@ namespace U2 {
 
 class MsaHighlightingSavableTab : public MsaOpSavableTab {
 public:
-    MsaHighlightingSavableTab(QWidget *wrappedWidget, MWMDIWindow *contextWindow);
+    MsaHighlightingSavableTab(QWidget* wrappedWidget, MWMDIWindow* contextWindow);
     ~MsaHighlightingSavableTab();
 
-    void disableSavingForWidgets(const QStringList &s);
+    void disableSavingForWidgets(const QStringList& s);
 
 protected:
-    bool childCanBeSaved(QWidget *child) const;
+    bool childCanBeSaved(QWidget* child) const;
 
 private:
     QStringList widgetsNotToSave;
 };
 
 }  // namespace U2
-
-#endif
