@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,13 +24,12 @@
 #include <QVBoxLayout>
 
 #include "MaGraphOverview.h"
-#include "ov_msa/view_rendering/MaEditorWgt.h"
+#include "ov_msa/MaEditorWgt.h"
 
 namespace U2 {
 
-MaEditorOverviewArea::MaEditorOverviewArea(MaEditorWgt *ui, const QString &objectName)
-    : QWidget(ui),
-      isWidgetResizable(false) {
+MaEditorOverviewArea::MaEditorOverviewArea(QWidget* ui, const QString& objectName)
+    : QWidget(ui) {
     setObjectName(objectName);
 
     layout = new QVBoxLayout();
@@ -38,22 +37,10 @@ MaEditorOverviewArea::MaEditorOverviewArea(MaEditorWgt *ui, const QString &objec
     layout->setSpacing(0);
     setLayout(layout);
 
-    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
     setContextMenuPolicy(Qt::PreventContextMenu);
 }
 
-void MaEditorOverviewArea::cancelRendering() {
-}
-
-bool MaEditorOverviewArea::isResizable() const {
-    return isWidgetResizable;
-}
-
-void MaEditorOverviewArea::sl_show() {
-    setVisible(!isVisible());
-}
-
-void MaEditorOverviewArea::addOverview(QWidget *overviewWgt) {
+void MaEditorOverviewArea::addOverview(QWidget* overviewWgt) {
     layout->addWidget(overviewWgt);
 }
 
