@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_EDITOR_SORT_SEQUENCES_WIDGET_H_
-#define _U2_MSA_EDITOR_SORT_SEQUENCES_WIDGET_H_
+#pragma once
 
 #include <QComboBox>
 #include <QPushButton>
@@ -34,19 +33,17 @@ class MsaEditorSortSequencesWidget : public QWidget {
     Q_OBJECT;
 
 public:
-    MsaEditorSortSequencesWidget(QWidget *parent, MSAEditor *msaEditor);
+    MsaEditorSortSequencesWidget(QWidget* parent, MSAEditor* msaEditor);
 
 private slots:
     void sl_sortClicked();
     void sl_msaObjectStateChanged();
 
 private:
-    MSAEditor *msaEditor;
-    QComboBox *sortByCombo;
-    QComboBox *sortOrderCombo;
-    QPushButton *sortButton;
+    MSAEditor* msaEditor;
+    QComboBox* sortByCombo;
+    QComboBox* sortOrderCombo;
+    QPushButton* sortButton;
 };
 
 }  // namespace U2
-
-#endif
