@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TREE_VIEWER_FACTORY_H_
-#define _U2_TREE_VIEWER_FACTORY_H_
+#pragma once
 
 #include <U2Gui/ObjectViewModel.h>
 
@@ -33,15 +32,15 @@ class U2VIEW_EXPORT TreeViewerFactory : public GObjectViewFactory {
 public:
     TreeViewerFactory();
 
-    virtual bool canCreateView(const MultiGSelection &multiSelection);
+    bool canCreateView(const MultiGSelection& multiSelection) override;
 
-    virtual Task *createViewTask(const MultiGSelection &multiSelection, bool single = false);
+    Task* createViewTask(const MultiGSelection& multiSelection, bool single = false) override;
 
-    virtual bool isStateInSelection(const MultiGSelection &multiSelection, const QVariantMap &stateData);
+    bool isStateInSelection(const MultiGSelection& multiSelection, const QVariantMap& stateData) override;
 
-    virtual Task *createViewTask(const QString &viewName, const QVariantMap &stateData);
+    Task* createViewTask(const QString& viewName, const QVariantMap& stateData) override;
 
-    virtual bool supportsSavedStates() const {
+    bool supportsSavedStates() const override {
         return true;
     }
 
@@ -49,5 +48,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
