@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,9 +32,7 @@ namespace U2 {
 
 #define VIEW_ID QString("view_id")
 #define PHY_OBJ QString("phy_obj_ref")
-#define V_ZOOM QString("vertical_zoom")
-#define H_ZOOM QString("horizontal_zoom")
-#define TRANSFORM QString("transform")
+#define ZOOM_LEVEL QString("zoom_level")
 
 bool TreeViewerState::isValid() const {
     return stateData.value(VIEW_ID) == TreeViewerFactory::ID;
@@ -44,63 +42,20 @@ GObjectReference TreeViewerState::getPhyObject() const {
     return stateData.contains(PHY_OBJ) ? stateData[PHY_OBJ].value<GObjectReference>() : GObjectReference();
 }
 
-void TreeViewerState::setPhyObject(const GObjectReference &ref) {
-    stateData[PHY_OBJ] = QVariant::fromValue<GObjectReference>(ref);
+double TreeViewerState::getZoomLevel() const {
+    QVariant v = stateData.value(ZOOM_LEVEL);
+    return v.isValid() ? v.value<double>() : 1.0;
 }
 
-qreal TreeViewerState::getVerticalZoom() const {
-    QVariant v = stateData.value(V_ZOOM);
-    if (v.isValid()) {
-        return v.value<qreal>();
-    } else {
-        return 1.0f;
-    }
-}
-
-qreal TreeViewerState::getHorizontalZoom() const {
-    QVariant v = stateData.value(H_ZOOM);
-    if (v.isValid()) {
-        return v.value<qreal>();
-    } else {
-        return 1.0f;
-    }
-}
-
-void TreeViewerState::setVerticalZoom(qreal s) {
-    stateData[V_ZOOM] = s;
-}
-
-void TreeViewerState::setHorizontalZoom(qreal s) {
-    stateData[H_ZOOM] = s;
-}
-
-QTransform TreeViewerState::getTransform() const {
-    QVariant v = stateData.value(TRANSFORM);
-    if (v.type() == QVariant::Transform) {
-        return v.value<QTransform>();
-    }
-    QTransform t;
-    return t;
-}
-
-void TreeViewerState::setTransform(const QTransform &m) {
-    stateData[TRANSFORM] = m;
-}
-
-QVariantMap TreeViewerState::saveState(TreeViewer *v) {
+QVariantMap TreeViewerState::saveState(TreeViewer* v) {
     TreeViewerState ss;
 
     ss.stateData[VIEW_ID] = TreeViewerFactory::ID;
-
-    PhyTreeObject *phyObj = v->getPhyObject();
+    PhyTreeObject* phyObj = v->getPhyObject();
     if (phyObj) {
-        ss.setPhyObject(GObjectReference(phyObj));
+        ss.stateData[PHY_OBJ] = QVariant::fromValue<GObjectReference>(GObjectReference(phyObj));
     }
-
-    ss.setHorizontalZoom(v->getHorizontalZoom());
-    ss.setVerticalZoom(v->getVerticalZoom());
-    ss.setTransform(v->getTransform());
-
+    ss.stateData[ZOOM_LEVEL] = v->getZoomLevel();
     ss.stateData.unite(v->getSettingsState());
 
     return ss.stateData;
