@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TREE_VIEWER_TASKS_H_
-#define _U2_TREE_VIEWER_TASKS_H_
+#pragma once
 
 #include <QSplitter>
 
@@ -36,7 +35,6 @@ namespace U2 {
 class PhyTreeObject;
 class UnloadedObject;
 class TreeViewer;
-class CreateRectangularBranchesTask;
 class OpenTreeViewerTask;
 class MSAEditor;
 class MSAEditorTreeManager;
@@ -44,87 +42,76 @@ class MSAEditorTreeManager;
 class OpenTreeViewerTask : public ObjectViewTask {
     Q_OBJECT
 public:
-    OpenTreeViewerTask(PhyTreeObject *obj, QObject *_parent = nullptr);
-    OpenTreeViewerTask(UnloadedObject *obj, QObject *_parent = nullptr);
-    OpenTreeViewerTask(Document *doc, QObject *_parent = nullptr);
-    virtual ~OpenTreeViewerTask();
+    explicit OpenTreeViewerTask(PhyTreeObject* obj, QObject* _parent = nullptr);
+    explicit OpenTreeViewerTask(UnloadedObject* obj, QObject* _parent = nullptr);
+    explicit OpenTreeViewerTask(Document* doc, QObject* _parent = nullptr);
 
-    virtual void open();
+    void open() override;
 
     virtual void createTreeViewer();
 
-    static void updateTitle(TreeViewer *tv);
+    static void updateTitle(TreeViewer* tv);
 
 protected:
     QPointer<PhyTreeObject> phyObject;
     GObjectReference unloadedReference;
-    QObject *parent;
-    bool createMDIWindow;
+    QObject* parent = nullptr;
 };
 
 class MSAEditorOpenTreeViewerTask : public OpenTreeViewerTask {
     Q_OBJECT
 public:
-    MSAEditorOpenTreeViewerTask(PhyTreeObject *obj, MSAEditorTreeManager *_parent);
-    MSAEditorOpenTreeViewerTask(UnloadedObject *obj, MSAEditorTreeManager *_parent);
-    MSAEditorOpenTreeViewerTask(Document *doc, MSAEditorTreeManager *_parent);
-    virtual ~MSAEditorOpenTreeViewerTask() {
-    }
+    MSAEditorOpenTreeViewerTask(PhyTreeObject* obj, MSAEditorTreeManager* _parent);
 
-    virtual void createTreeViewer();
+    void createTreeViewer() override;
 
 private:
-    MSAEditorTreeManager *treeManager;
+    MSAEditorTreeManager* treeManager = nullptr;
 };
 
 class OpenSavedTreeViewerTask : public ObjectViewTask {
     Q_OBJECT
 public:
-    OpenSavedTreeViewerTask(const QString &viewName, const QVariantMap &stateData);
-    virtual void open();
+    OpenSavedTreeViewerTask(const QString& viewName, const QVariantMap& stateData);
+    void open() override;
 
-    static void updateRanges(const QVariantMap &stateData, TreeViewer *ctx);
+    static void applySavedState(TreeViewer* treeViewer, const QVariantMap& stateData);
 };
 
 class UpdateTreeViewerTask : public ObjectViewTask {
 public:
-    UpdateTreeViewerTask(GObjectView *v, const QString &stateName, const QVariantMap &stateData);
-    virtual void update();
+    UpdateTreeViewerTask(GObjectViewController* v, const QString& stateName, const QVariantMap& stateData);
+    void update() override;
 };
 
 class CreateMSAEditorTreeViewerTask : public Task {
     Q_OBJECT
 public:
-    CreateMSAEditorTreeViewerTask(const QString &name, const QPointer<PhyTreeObject> &obj, const QVariantMap &stateData);
-    virtual void prepare();
-    virtual ReportResult report();
-    TreeViewer *getTreeViewer();
-    const QVariantMap &getStateData();
+    CreateMSAEditorTreeViewerTask(MSAEditor* msaEditor, const QString& name, const QPointer<PhyTreeObject>& obj, const QVariantMap& stateData);
+    void prepare() override;
+    ReportResult report() override;
+    TreeViewer* getTreeViewer() const;
+    const QVariantMap& getStateData() const;
 
 private:
     QString viewName;
     QPointer<PhyTreeObject> phyObj;
-    CreateRectangularBranchesTask *subTask;
     QVariantMap stateData;
-    TreeViewer *view;
-    const PhyTree tempTree;
+    TreeViewer* view = nullptr;
+    QPointer<MSAEditor> msaEditor;
 };
 
 class CreateTreeViewerTask : public Task {
     Q_OBJECT
 public:
-    CreateTreeViewerTask(const QString &name, const QPointer<PhyTreeObject> &obj, const QVariantMap &stateData);
-    virtual void prepare();
-    virtual ReportResult report();
+    CreateTreeViewerTask(const QString& name, const QPointer<PhyTreeObject>& obj, const QVariantMap& stateData);
+    void prepare() override;
+    ReportResult report() override;
 
 private:
     QString viewName;
     QPointer<PhyTreeObject> phyObj;
-    CreateRectangularBranchesTask *subTask;
     QVariantMap stateData;
-    const PhyTree tempTree;
 };
 
 }  // namespace U2
-
-#endif
