@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,6 +21,7 @@
 
 #include "TreeViewerUtils.h"
 
+#include <QApplication>
 #include <QMessageBox>
 
 #include <U2Gui/LastUsedDirHelper.h>
@@ -30,26 +31,14 @@
 
 namespace U2 {
 
-QFont *TreeViewerUtils::font = nullptr;
-const char *TreeViewerUtils::IMAGE_FILTERS =
-    "BMP - Windows Bitmap (*.bmp);;"
-    "GIF - Graphic Interchange Format (*.gif);;"
-    "JPG/JPEG format (*.jpg);;"
-    "PBM - Portable Bitmap (*.pbm);;"
-    "PNG - Portable Network Graphics (*.png);;"
-    "PPM - Portable Pixmap (*.ppm);;"
-    "TIFF - Tagged Image File format (*.tif);;"
-    "XBM - X11 Bitmap (*.xbm);;"
-    "XPM - X11 Pixmap (*.xpm)";
-
-void TreeViewerUtils::saveImageDialog(const QString &filters, QString &fileName, QString &format) {
+void TreeViewerUtils::saveImageDialog(const QString& filters, QString& fileName, QString& format) {
     LastUsedDirHelper lod(IMAGE_DIR);
     int i = fileName.lastIndexOf('.');
     if (i != -1) {
         fileName = fileName.left(i);
     }
     QString initialPath = lod.dir + "/" + fileName;
-    fileName = U2FileDialog::getSaveFileName(nullptr, QObject::tr("Save As"), initialPath, filters, &format);
+    fileName = U2FileDialog::getSaveFileName(nullptr, QObject::tr("Save As"), initialPath, filters, format);
     lod.url = fileName;
     if (fileName.isEmpty())
         return;
@@ -58,20 +47,25 @@ void TreeViewerUtils::saveImageDialog(const QString &filters, QString &fileName,
     if (!fileName.endsWith("." + format)) {
         fileName.append("." + format);
         if (QFile::exists(fileName)) {
-            QMessageBox::StandardButtons b = QMessageBox::warning(0, QObject::tr("Replace file"), QObject::tr("%1 already exists.\nDo you want to replace it?").arg(fileName), QMessageBox::Yes | QMessageBox::No);
-            if (QMessageBox::Yes != b) {
+            QMessageBox::StandardButtons b = QMessageBox::warning(nullptr, QObject::tr("Replace file"), QObject::tr("%1 already exists.\nDo you want to replace it?").arg(fileName), QMessageBox::Yes | QMessageBox::No);
+            if (b != QMessageBox::Yes) {
                 return;
             }
         }
     }
 }
 
-const QFont &TreeViewerUtils::getFont() {
-    if (font == nullptr) {
-        font = new QFont();
-        font->setPointSize(8);
+QFont TreeViewerUtils::getFontFromSettings(const QMap<TreeViewOption, QVariant>& settings) {
+    QFont font = QApplication::font();
+    QString family = settings[LABEL_FONT_FAMILY].toString();
+    if (!family.isEmpty()) {
+        font.setFamily(family);
     }
-    return *font;
+    font.setPointSize(settings[LABEL_FONT_SIZE].toInt());
+    font.setBold(settings[LABEL_FONT_BOLD].toBool());
+    font.setItalic(settings[LABEL_FONT_ITALIC].toBool());
+    font.setUnderline(settings[LABEL_FONT_UNDERLINE].toBool());
+    return font;
 }
 
 }  // namespace U2
