@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,22 +19,20 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _TREE_VIEWER_UTILS_H_
-#define _TREE_VIEWER_UTILS_H_
+#pragma once
 
 #include <QFont>
 
+#include "TreeSettings.h"
+
 namespace U2 {
 
 class TreeViewerUtils {
-    static QFont *font;
-
 public:
-    static const char *IMAGE_FILTERS;
-    static void saveImageDialog(const QString &filters, QString &fileName, QString &format);
-    static const QFont &getFont();
+    static void saveImageDialog(const QString& filters, QString& fileName, QString& format);
+
+    /** Restores QFont from tree viewer settings. */
+    static QFont getFontFromSettings(const QMap<TreeViewOption, QVariant>& settings);
 };
 
 }  // namespace U2
-
-#endif  // _TREE_VIEWER_UTILS_H_
