@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADVANNOTATION_CREATION_H_
-#define _U2_ADVANNOTATION_CREATION_H_
+#pragma once
 
 #include <QPointer>
 
@@ -39,9 +38,9 @@ class U2SequenceObject;
 class U2VIEW_EXPORT ADVAnnotationCreation : public QObject {
     Q_OBJECT
 public:
-    ADVAnnotationCreation(AnnotatedDNAView *v);
+    ADVAnnotationCreation(AnnotatedDNAView* v);
 
-    QAction *getCreateAnnotationAction() const {
+    QAction* getCreateAnnotationAction() const {
         return createAction;
     }
 
@@ -49,29 +48,27 @@ private slots:
     void sl_createAnnotation();
 
 private:
-    AnnotatedDNAView *ctx;
-    QAction *createAction;
+    AnnotatedDNAView* ctx;
+    QAction* createAction;
 };
 
 class U2VIEW_EXPORT ADVCreateAnnotationsTask : public Task {
     Q_OBJECT
 public:
-    ADVCreateAnnotationsTask(AnnotatedDNAView *sequenceView,
-                             const GObjectReference &aobjRef,
-                             const QString &group,
-                             const QList<SharedAnnotationData> &data,
+    ADVCreateAnnotationsTask(AnnotatedDNAView* sequenceView,
+                             const GObjectReference& aobjRef,
+                             const QString& group,
+                             const QList<SharedAnnotationData>& data,
                              bool selectNewAnnotations = true);
 
     ReportResult report();
 
 private:
     QPointer<AnnotatedDNAView> sequenceView;
-    CreateAnnotationsTask *createAnnotationsTask;
+    CreateAnnotationsTask* createAnnotationsTask;
 
     /** If true the created annotations are added to the sequence view selection. */
     bool selectNewAnnotations;
 };
 
 }  // namespace U2
-
-#endif
