@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADV_SEQUENCE_OBJECT_CONTEXT_H_
-#define _U2_ADV_SEQUENCE_OBJECT_CONTEXT_H_
+#pragma once
 
 #include "SequenceObjectContext.h"
 
@@ -29,21 +28,19 @@ namespace U2 {
 class U2VIEW_EXPORT ADVSequenceObjectContext : public SequenceObjectContext {
     Q_OBJECT
 public:
-    ADVSequenceObjectContext(AnnotatedDNAView *v, U2SequenceObject *obj);
+    ADVSequenceObjectContext(AnnotatedDNAView* v, U2SequenceObject* obj);
 
-    AnnotatedDNAView *getAnnotatedDNAView() const {
+    AnnotatedDNAView* getAnnotatedDNAView() const {
         return view;
     }
 
-    AnnotationSelection *getAnnotationsSelection() const;
+    AnnotationSelection* getAnnotationsSelection() const;
 
 protected slots:
     void sl_onAnnotationRelationChange();
 
 private:
-    AnnotatedDNAView *view;
+    AnnotatedDNAView* view;
 };
 
 }  // namespace U2
-
-#endif
