@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADV_SINGLE_SEQ_WIDGET_H_
-#define _U2_ADV_SINGLE_SEQ_WIDGET_H_
+#pragma once
 
 #include <QLabel>
 #include <QMenu>
@@ -58,55 +57,55 @@ class U2SequenceObject;
 class U2VIEW_EXPORT ADVSingleSequenceWidget : public ADVSequenceWidget {
     Q_OBJECT
 public:
-    ADVSingleSequenceWidget(ADVSequenceObjectContext *seqCtx, AnnotatedDNAView *ctx);
+    ADVSingleSequenceWidget(ADVSequenceObjectContext* seqCtx, AnnotatedDNAView* ctx);
     ~ADVSingleSequenceWidget();
 
-    const QList<GSequenceLineView *> &getLineViews() const {
+    const QList<GSequenceLineView*>& getLineViews() const {
         return lineViews;
     }
 
-    GSequenceLineView *getPanGSLView() const;
+    GSequenceLineView* getPanGSLView() const;
 
-    GSequenceLineView *getDetGSLView() const;
+    GSequenceLineView* getDetGSLView() const;
 
-    PanView *getPanView() const {
+    PanView* getPanView() const {
         return panView;
     }
 
-    DetView *getDetView() const {
+    DetView* getDetView() const {
         return detView;
     }
 
-    virtual void centerPosition(int pos, QWidget *skipView = nullptr);
+    virtual void centerPosition(int pos, QWidget* skipView = nullptr);
 
-    ADVSequenceObjectContext *getActiveSequenceContext() const {
+    ADVSequenceObjectContext* getActiveSequenceContext() const {
         return (seqContexts.isEmpty()) ? nullptr : seqContexts.first();
     }
-    ADVSequenceObjectContext *getSequenceContext() const {
+    ADVSequenceObjectContext* getSequenceContext() const {
         return getActiveSequenceContext();
     }
 
-    DNATranslation *getComplementTT() const;
+    DNATranslation* getComplementTT() const;
 
-    DNATranslation *getAminoTT() const;
+    DNATranslation* getAminoTT() const;
 
-    DNASequenceSelection *getSequenceSelection() const;
+    DNASequenceSelection* getSequenceSelection() const;
 
     qint64 getSequenceLength() const;
 
-    virtual void addSequenceView(GSequenceLineView *v, QWidget *after = nullptr);
+    virtual void addSequenceView(GSequenceLineView* v, QWidget* after = nullptr);
 
-    virtual void removeSequenceView(GSequenceLineView *v, bool deleteView = true);
+    virtual void removeSequenceView(GSequenceLineView* v, bool deleteView = true);
 
-    U2SequenceObject *getSequenceObject() const;
+    U2SequenceObject* getSequenceObject() const;
 
-    virtual void buildPopupMenu(QMenu &m);
+    virtual void buildPopupMenu(QMenu& m);
 
-    virtual bool isWidgetOnlyObject(GObject *o) const;
+    virtual bool isWidgetOnlyObject(GObject* o) const;
 
-    virtual void addADVSequenceWidgetAction(ADVSequenceWidgetAction *action);
+    virtual void addADVSequenceWidgetAction(ADVSequenceWidgetAction* action);
 
-    void addADVSequenceWidgetActionToViewsToolbar(ADVSequenceWidgetAction *action);
+    void addADVSequenceWidgetActionToViewsToolbar(ADVSequenceWidgetAction* action);
 
     void setViewCollapsed(bool v);
     bool isViewCollapsed() const;
@@ -121,33 +120,33 @@ public:
     void setOverviewCollapsed(bool collapsed);
     bool isOverviewCollapsed() const;
 
-    virtual void updateState(const QVariantMap &m);
+    virtual void updateState(const QVariantMap& m);
     virtual void updateSelectionActions();
     QVector<U2Region> getSelectedAnnotationRegions(int max);
 
-    virtual void saveState(QVariantMap &m);
+    virtual void saveState(QVariantMap& m);
 
     void closeView();
 
     virtual U2Region getVisibleRange() const;
 
-    virtual void setVisibleRange(const U2Region &r);
+    virtual void setVisibleRange(const U2Region& r);
 
     virtual int getNumBasesVisible() const;
 
     virtual void setNumBasesVisible(qint64 n);
 
-    QAction *getSelectRangeAction() const {
+    QAction* getSelectRangeAction() const {
         return selectRangeAction1;
     }
 
-    virtual void onSequenceObjectRenamed(const QString &oldName);
+    virtual void onSequenceObjectRenamed(const QString& oldName);
 
 signals:
-    void si_titleClicked(ADVSequenceWidget *);
+    void si_titleClicked(ADVSequenceWidget*);
 
 protected slots:
-    void sl_onViewDestroyed(QObject *);
+    void sl_onViewDestroyed(QObject*);
 
     void sl_toggleAllSubViews();
     void sl_togglePanView(bool checked);
@@ -161,58 +160,58 @@ protected slots:
     void sl_createCustomRuler();
     void sl_removeCustomRuler();
 
-    void sl_onAnnotationSelectionChanged(AnnotationSelection *thiz, const QList<Annotation *> &added, const QList<Annotation *> &removed);
+    void sl_onAnnotationSelectionChanged(AnnotationSelection* thiz, const QList<Annotation*>& added, const QList<Annotation*>& removed);
 
     // QT 4.5.0 bug workaround
 public slots:
     void sl_closeView();
 
 signals:
-    void si_updateGraphView(const QStringList &, const QVariantMap &);
+    void si_updateGraphView(const QStringList&, const QVariantMap&);
 private slots:
     void sl_saveScreenshot();
 
 protected:
     void init();
-    bool eventFilter(QObject *o, QEvent *e);
+    bool eventFilter(QObject* o, QEvent* e);
 
 private:
     virtual void updateMinMaxHeight();
 
-    QToolButton *addButtonWithActionToToolbar(QAction *buttonAction, QToolBar *toolBar, int position = -1) const;
-    void addRulersMenu(QMenu &m);
-    void addSelectMenu(QMenu &m);
+    QToolButton* addButtonWithActionToToolbar(QAction* buttonAction, QToolBar* toolBar, int position = -1) const;
+    void addRulersMenu(QMenu& m);
+    void addSelectMenu(QMenu& m);
 
     /** Used by several other functions to set new selected region */
-    void setSelectedRegion(const U2Region &region);
+    void setSelectedRegion(const U2Region& region);
 
-    virtual GSequenceLineView *findSequenceViewByPos(const QPoint &globalPos) const;
+    virtual GSequenceLineView* findSequenceViewByPos(const QPoint& globalPos) const;
 
-    virtual void addZoomMenu(const QPoint &globalPos, QMenu *m);
+    virtual void addZoomMenu(const QPoint& globalPos, QMenu* m);
 
-    DetView *detView;
-    PanView *panView;
-    Overview *overview;
-    QList<GSequenceLineView *> lineViews;
-    QVBoxLayout *linesLayout;
-    QSplitter *linesSplitter;
-    ADVSingleSequenceHeaderWidget *headerWidget;
+    DetView* detView;
+    PanView* panView;
+    Overview* overview;
+    QList<GSequenceLineView*> lineViews;
+    QVBoxLayout* linesLayout;
+    QSplitter* linesSplitter;
+    ADVSingleSequenceHeaderWidget* headerWidget;
 
-    QAction *toggleViewAction;
-    QAction *togglePanViewAction;
-    QAction *toggleDetViewAction;
-    QAction *toggleOverviewAction;
-    QAction *selectRangeAction1;
-    QAction *selectRangeAction2;
-    QAction *selectInAnnotationRangeAction;
-    QAction *selectOutAnnotationRangeAction;
-    QAction *zoomToRangeAction;
-    QAction *createNewRulerAction;
-    QAction *shotScreenAction;
-    QAction *closeViewAction;
+    QAction* toggleViewAction;
+    QAction* togglePanViewAction;
+    QAction* toggleDetViewAction;
+    QAction* toggleOverviewAction;
+    QAction* selectRangeAction1;
+    QAction* selectRangeAction2;
+    QAction* selectInAnnotationRangeAction;
+    QAction* selectOutAnnotationRangeAction;
+    QAction* zoomToRangeAction;
+    QAction* createNewRulerAction;
+    QAction* shotScreenAction;
+    QAction* closeViewAction;
 
     GAutoDeleteList<QAction> rulerActions;
-    QList<QString> *buttonTabOrederedNames;
+    QList<QString>* buttonTabOrederedNames;
 
     PanView::ZoomUseObject zoomUseObject;
 
@@ -227,40 +226,38 @@ private:
 class U2VIEW_EXPORT ADVSingleSequenceHeaderWidget : public QWidget {
     Q_OBJECT
 public:
-    ADVSingleSequenceHeaderWidget(ADVSingleSequenceWidget *p);
+    ADVSingleSequenceHeaderWidget(ADVSingleSequenceWidget* p);
 
-    QToolBar *getStandardToolBar() const {
+    QToolBar* getStandardToolBar() const {
         return standardToolBar;
     }
-    QToolBar *getViewsToolBar() const {
+    QToolBar* getViewsToolBar() const {
         return viewsToolBar;
     }
 
-    void setTitle(const QString &title) {
+    void setTitle(const QString& title) {
         nameLabel->setText(title);
     }
     void updateTitle();
 
 protected:
-    virtual void mouseDoubleClickEvent(QMouseEvent *e);
-    virtual void paintEvent(QPaintEvent *e);
+    virtual void mouseDoubleClickEvent(QMouseEvent* e);
+    virtual void paintEvent(QPaintEvent* e);
 
 protected slots:
     /** Toggles header active/inactive visual state if the old or the new widget is related to the header. */
-    void sl_onActiveSequenceWidgetChanged(ADVSequenceWidget *oldActiveWidget, ADVSequenceWidget *newActiveWidget);
-    void sl_actionTriggered(QAction *a);
+    void sl_onActiveSequenceWidgetChanged(ADVSequenceWidget* oldActiveWidget, ADVSequenceWidget* newActiveWidget);
+    void sl_actionTriggered(QAction* a);
 
 private:
     void updateActiveState();
-    QString getShortAlphabetName(const DNAAlphabet *al);
+    QString getShortAlphabetName(const DNAAlphabet* al);
 
-    ADVSingleSequenceWidget *ctx;
-    QToolBar *standardToolBar;
-    QToolBar *viewsToolBar;
-    QLabel *pixLabel;
-    QLabel *nameLabel;
+    ADVSingleSequenceWidget* ctx;
+    QToolBar* standardToolBar;
+    QToolBar* viewsToolBar;
+    QLabel* pixLabel;
+    QLabel* nameLabel;
 };
 
 }  // namespace U2
-
-#endif
