@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADV_SPLIT_WIDGET_H_
-#define _U2_ADV_SPLIT_WIDGET_H_
+#pragma once
 
 #include <QSplitter>
 
@@ -34,24 +33,22 @@ class GObject;
 class U2VIEW_EXPORT ADVSplitWidget : public QWidget {
     Q_OBJECT
 public:
-    ADVSplitWidget(AnnotatedDNAView *view)
+    ADVSplitWidget(AnnotatedDNAView* view)
         : dnaView(view) {
     }
-    AnnotatedDNAView *getAnnotatedDNAView() const {
+    AnnotatedDNAView* getAnnotatedDNAView() const {
         return dnaView;
     }
-    virtual bool acceptsGObject(GObject *objects) = 0;
-    virtual void updateState(const QVariantMap &m) = 0;
-    virtual void saveState(QVariantMap &m) = 0;
+    virtual bool acceptsGObject(GObject* objects) = 0;
+    virtual void updateState(const QVariantMap& m) = 0;
+    virtual void saveState(QVariantMap& m) = 0;
 
     virtual bool onCloseEvent() {
         return true;
     }
 
 protected:
-    AnnotatedDNAView *dnaView;
+    AnnotatedDNAView* dnaView;
 };
 
 }  // namespace U2
-
-#endif  //_U2_ADV_SPLIT_WIDGET_H_
