@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADV_SYNC_VIEW_MANAGER_H_
-#define _U2_ADV_SYNC_VIEW_MANAGER_H_
+#pragma once
 
 #include <QAction>
 #include <QMenu>
@@ -40,17 +39,17 @@ class LRegionsSelection;
 class ADVSyncViewManager : public QObject {
     Q_OBJECT
 public:
-    ADVSyncViewManager(AnnotatedDNAView *v);
+    ADVSyncViewManager(AnnotatedDNAView* v);
     ~ADVSyncViewManager();
 
     void updateAutoAnnotationActions();
-    void updateToolbar1(QToolBar *tb);
-    void updateToolbar2(QToolBar *tb);
+    void updateToolbar1(QToolBar* tb);
+    void updateToolbar2(QToolBar* tb);
 private slots:
     void sl_rangeChanged();
-    void sl_onSelectionChanged(LRegionsSelection *thiz, const QVector<U2Region> &added, const QVector<U2Region> &removed);
-    void sl_sequenceWidgetAdded(ADVSequenceWidget *w);
-    void sl_sequenceWidgetRemoved(ADVSequenceWidget *w);
+    void sl_onSelectionChanged(LRegionsSelection* thiz, const QVector<U2Region>& added, const QVector<U2Region>& removed);
+    void sl_sequenceWidgetAdded(ADVSequenceWidget* w);
+    void sl_sequenceWidgetRemoved(ADVSequenceWidget* w);
 
     void sl_lock();
     void sl_sync();
@@ -69,55 +68,54 @@ private:
 
     void sync(bool lock, SyncMode mode);
 
-    int offsetBySeqSel(ADVSingleSequenceWidget *w) const;
-    int offsetByAnnSel(ADVSingleSequenceWidget *w) const;
+    int offsetBySeqSel(ADVSingleSequenceWidget* w) const;
+    int offsetByAnnSel(ADVSingleSequenceWidget* w) const;
 
     SyncMode detectSyncMode() const;
-    int findSelectedAnnotationPos(ADVSingleSequenceWidget *w) const;
+    int findSelectedAnnotationPos(ADVSingleSequenceWidget* w) const;
 
     void unlock();
     void updateEnabledState();
     void toggleCheckedAction(SyncMode mode);
 
-    QList<ADVSingleSequenceWidget *> getViewsFromADV() const;
+    QList<ADVSingleSequenceWidget*> getViewsFromADV() const;
 
-    AnnotatedDNAView *adv;
+    AnnotatedDNAView* adv;
 
-    QAction *lockByStartPosAction;
-    QAction *lockBySeqSelAction;
-    QAction *lockByAnnSelAction;
-    QAction *syncByStartPosAction;
-    QAction *syncBySeqSelAction;
-    QAction *syncByAnnSelAction;
-    QActionGroup *lockActionGroup;
+    QAction* lockByStartPosAction;
+    QAction* lockBySeqSelAction;
+    QAction* lockByAnnSelAction;
+    QAction* syncByStartPosAction;
+    QAction* syncBySeqSelAction;
+    QAction* syncByAnnSelAction;
+    QActionGroup* lockActionGroup;
 
-    QToolButton *syncButton;
-    QToolButton *lockButton;
-    QMenu *syncMenu;
-    QMenu *lockMenu;
+    QToolButton* syncButton;
+    QToolButton* lockButton;
+    QMenu* syncMenu;
+    QMenu* lockMenu;
 
-    QAction *syncButtonTBAction;
-    QAction *lockButtonTBAction;
+    QAction* syncButtonTBAction;
+    QAction* lockButtonTBAction;
 
     bool selectionRecursion;
     bool recursion;
-    QList<ADVSingleSequenceWidget *> views;
+    QList<ADVSingleSequenceWidget*> views;
 
     // auto annotation highlighting
-    QMap<QString, QAction *> aaActionMap;
-    QAction *toggleAutoAnnotationsAction;
-    QMenu *toggleAutoAnnotationsMenu;
-    QToolButton *toggleAutoAnnotationsButton;
+    QMap<QString, QAction*> aaActionMap;
+    QAction* toggleAutoAnnotationsAction;
+    QMenu* toggleAutoAnnotationsMenu;
+    QToolButton* toggleAutoAnnotationsButton;
 
     // visual mode vars
-    QAction *toggleViewButtonAction;
-    QToolButton *toggleViewButton;
-    QMenu *toggleViewButtonMenu;
-    QAction *toggleAllAction;
-    QAction *toggleOveAction;
-    QAction *togglePanAction;
-    QAction *toggleDetAction;
+    QAction* toggleViewButtonAction;
+    QToolButton* toggleViewButton;
+    QMenu* toggleViewButtonMenu;
+    QAction* toggleAllAction;
+    QAction* toggleOveAction;
+    QAction* togglePanAction;
+    QAction* toggleDetAction;
 };
 
 }  // namespace U2
-#endif
