@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,10 +27,10 @@
 
 namespace U2 {
 
-ADVGlobalAction::ADVGlobalAction(AnnotatedDNAView *v, const QIcon &icon, const QString &text, int ps, ADVGlobalActionFlags fl)
+ADVGlobalAction::ADVGlobalAction(AnnotatedDNAView* v, const QIcon& icon, const QString& text, int ps, const ADVGlobalActionFlags& fl)
     : GObjectViewAction(v, v, text), pos(ps), flags(fl) {
     setIcon(icon);
-    connect(v, SIGNAL(si_activeSequenceWidgetChanged(ADVSequenceWidget *, ADVSequenceWidget *)), SLOT(sl_activeSequenceChanged()));
+    connect(v, SIGNAL(si_activeSequenceWidgetChanged(ADVSequenceWidget*, ADVSequenceWidget*)), SLOT(sl_activeSequenceChanged()));
     updateState();
     v->addADVAction(this);
 }
@@ -40,10 +40,10 @@ void ADVGlobalAction::sl_activeSequenceChanged() {
 }
 
 void ADVGlobalAction::updateState() {
-    AnnotatedDNAView *av = qobject_cast<AnnotatedDNAView *>(getObjectView());
-    ADVSequenceWidget *w = av->getActiveSequenceWidget();
+    auto av = qobject_cast<AnnotatedDNAView*>(getObjectView());
+    ADVSequenceWidget* w = av->getActiveSequenceWidget();
     bool enabled = w != nullptr;
-    if (enabled && flags.testFlag(ADVGlobalActionFlag_SingleSequenceOnly) && qobject_cast<ADVSingleSequenceWidget *>(w) == nullptr) {
+    if (enabled && flags.testFlag(ADVGlobalActionFlag_SingleSequenceOnly) && qobject_cast<ADVSingleSequenceWidget*>(w) == nullptr) {
         enabled = false;
     }
     if (enabled && !alphabetFilter.isEmpty()) {
@@ -53,22 +53,4 @@ void ADVGlobalAction::updateState() {
     setEnabled(enabled);
 }
 
-QString ADVSelectionUtils::getSequenceIdsFromSelection(const QList<Annotation *> &selection, bool localBase) {
-    QStringList genbankID;
-    foreach (const Annotation *ann, selection) {
-        QString tmp = ann->findFirstQualifierValue("id");
-        if (!tmp.isEmpty()) {
-            if (!localBase) {
-                int off = tmp.indexOf("|");
-                int off1 = tmp.indexOf("|", off + 1);
-                tmp = tmp.mid(off + 1, off1 - off - 1);
-            }
-            if (!genbankID.contains(tmp)) {
-                genbankID.append(tmp);
-            }
-        }
-    }
-    return genbankID.join(",");
-}
-
 }  // namespace U2
