@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ADV_UTILS_H_
-#define _U2_ADV_UTILS_H_
+#pragma once
 
 #include <QSet>
 
@@ -46,7 +45,11 @@ typedef QFlags<ADVGlobalActionFlag> ADVGlobalActionFlags;
 class U2VIEW_EXPORT ADVGlobalAction : public GObjectViewAction {
     Q_OBJECT
 public:
-    ADVGlobalAction(AnnotatedDNAView *v, const QIcon &icon, const QString &text, int pos = 1000 * 1000, ADVGlobalActionFlags flags = ADVGlobalActionFlags(ADVGlobalActionFlag_AddToToolbar) | ADVGlobalActionFlag_AddToAnalyseMenu | ADVGlobalActionFlag_SingleSequenceOnly);
+    ADVGlobalAction(AnnotatedDNAView* v,
+                    const QIcon& icon,
+                    const QString& text,
+                    int pos = 1000 * 1000,
+                    const ADVGlobalActionFlags& flags = ADVGlobalActionFlags(ADVGlobalActionFlag_AddToToolbar) | ADVGlobalActionFlag_AddToAnalyseMenu | ADVGlobalActionFlag_SingleSequenceOnly);
 
     void addAlphabetFilter(DNAAlphabetType t) {
         alphabetFilter.insert(t);
@@ -73,10 +76,4 @@ private:
     ADVGlobalActionFlags flags;
 };
 
-class U2VIEW_EXPORT ADVSelectionUtils {
-public:
-    static QString getSequenceIdsFromSelection(const QList<Annotation *> &selection, bool localBase = false);
-};
-
 }  // namespace U2
-#endif
