@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATED_DNA_VIEW_FACTORY_H_
-#define _U2_ANNOTATED_DNA_VIEW_FACTORY_H_
+#pragma once
 
 #include <U2Gui/ObjectViewModel.h>
 
@@ -33,13 +32,13 @@ class U2VIEW_EXPORT AnnotatedDNAViewFactory : public GObjectViewFactory {
 public:
     AnnotatedDNAViewFactory();
 
-    virtual bool canCreateView(const MultiGSelection &multiSelection);
+    virtual bool canCreateView(const MultiGSelection& multiSelection);
 
-    virtual Task *createViewTask(const MultiGSelection &multiSelection, bool single = false);
+    virtual Task* createViewTask(const MultiGSelection& multiSelection, bool single = false);
 
-    virtual bool isStateInSelection(const MultiGSelection &multiSelection, const QVariantMap &stateData);
+    virtual bool isStateInSelection(const MultiGSelection& multiSelection, const QVariantMap& stateData);
 
-    virtual Task *createViewTask(const QString &viewName, const QVariantMap &stateData);
+    virtual Task* createViewTask(const QString& viewName, const QVariantMap& stateData);
 
     virtual bool supportsSavedStates() const {
         return true;
@@ -49,5 +48,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
