@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATED_DNA_VIEW_STATE_H_
-#define _U2_ANNOTATED_DNA_VIEW_STATE_H_
+#pragma once
 
 #include <QVariant>
 
@@ -34,15 +33,15 @@ class AnnotatedDNAView;
 class U2VIEW_EXPORT AnnotatedDNAViewState {
 public:
     AnnotatedDNAViewState();
-    AnnotatedDNAViewState(const QVariantMap &_stateData)
+    AnnotatedDNAViewState(const QVariantMap& _stateData)
         : stateData(_stateData) {
     }
 
-    static QVariantMap saveState(AnnotatedDNAView *v);
+    static QVariantMap saveState(AnnotatedDNAView* v);
 
     bool isValid() const;
 
-    void setSequenceObjects(const QList<GObjectReference> &objs, const QVector<U2Region> &selections);
+    void setSequenceObjects(const QList<GObjectReference>& objs, const QVector<U2Region>& selections);
 
     QList<GObjectReference> getSequenceObjects() const;
 
@@ -50,11 +49,9 @@ public:
 
     QList<GObjectReference> getAnnotationObjects() const;
 
-    void setAnnotationObjects(const QList<GObjectReference> &objs);
+    void setAnnotationObjects(const QList<GObjectReference>& objs);
 
     QVariantMap stateData;
 };
 
 }  // namespace U2
-
-#endif
