@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_AUTO_ANNOTATION_UTILS_H_
-#define _U2_AUTO_ANNOTATION_UTILS_H_
+#pragma once
 
 #include <U2Core/GObjectReference.h>
 
@@ -36,20 +35,20 @@ class MWMDIWindow;
 class AutoAnnotationsADVAction : public ADVSequenceWidgetAction {
     Q_OBJECT
 public:
-    AutoAnnotationsADVAction(ADVSequenceWidget *widget, AutoAnnotationObject *aaObj);
+    AutoAnnotationsADVAction(ADVSequenceWidget* widget, AutoAnnotationObject* aaObj);
     ~AutoAnnotationsADVAction();
-    QList<QAction *> getToggleActions();
-    QAction *getSelectAllAction() {
+    QList<QAction*> getToggleActions();
+    QAction* getSelectAllAction() {
         return selectAllAction;
     }
-    QAction *getDeselectAllAction() {
+    QAction* getDeselectAllAction() {
         return deselectAllAction;
     }
-    AutoAnnotationObject *getAAObj() {
+    AutoAnnotationObject* getAAObj() {
         return aaObj;
     }
-    QAction *findToggleAction(const QString &groupName);
-    void addUpdaterToMenu(AutoAnnotationsUpdater *updater);
+    QAction* findToggleAction(const QString& groupName);
+    void addUpdaterToMenu(AutoAnnotationsUpdater* updater);
     static const QString ACTION_NAME;
 
 private slots:
@@ -61,8 +60,8 @@ private slots:
 
 private:
     void updateMenu();
-    AutoAnnotationObject *aaObj;
-    QMenu *menu;
+    AutoAnnotationObject* aaObj;
+    QMenu* menu;
     QAction *selectAllAction, *deselectAllAction;
     int updatesCount;
 };
@@ -72,26 +71,24 @@ class ADVCreateAnnotationsTask;
 class ExportAutoAnnotationsGroupTask : public Task {
     Q_OBJECT
 public:
-    ExportAutoAnnotationsGroupTask(AnnotationGroup *ag, GObjectReference &aRef, ADVSequenceObjectContext *seqCtx, const QString &annDescription = "");
+    ExportAutoAnnotationsGroupTask(AnnotationGroup* ag, GObjectReference& aRef, ADVSequenceObjectContext* seqCtx, const QString& annDescription = "");
     void prepare();
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
 
 private:
-    AnnotationGroup *aGroup;
+    AnnotationGroup* aGroup;
     GObjectReference aRef;
-    ADVSequenceObjectContext *seqCtx;
-    ADVCreateAnnotationsTask *createTask;
+    ADVSequenceObjectContext* seqCtx;
+    ADVCreateAnnotationsTask* createTask;
     const QString annDescription;
 };
 
 class U2VIEW_EXPORT AutoAnnotationUtils {
 public:
-    static AutoAnnotationsADVAction *findAutoAnnotationADVAction(ADVSequenceObjectContext *ctx);
-    static QAction *findAutoAnnotationsToggleAction(ADVSequenceObjectContext *ctx, const QString &name);
-    static QList<QAction *> getAutoAnnotationToggleActions(ADVSequenceObjectContext *ctx);
-    static void triggerAutoAnnotationsUpdate(ADVSequenceObjectContext *ctx, const QString &aaGroupName);
+    static AutoAnnotationsADVAction* findAutoAnnotationADVAction(ADVSequenceObjectContext* ctx);
+    static QAction* findAutoAnnotationsToggleAction(ADVSequenceObjectContext* ctx, const QString& name);
+    static QList<QAction*> getAutoAnnotationToggleActions(ADVSequenceObjectContext* ctx);
+    static void triggerAutoAnnotationsUpdate(ADVSequenceObjectContext* ctx, const QString& aaGroupName);
 };
 
 }  // namespace U2
-
-#endif  // _U2_AUTO_ANNOTATION_UTILS_H_
