@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,17 +21,17 @@
 
 #include "CreateRulerDialogController.h"
 
-#include <QColorDialog>
 #include <QMessageBox>
 #include <QPushButton>
 
 #include <U2Core/TextUtils.h>
 
+#include <U2Gui/DialogUtils.h>
 #include <U2Gui/HelpButton.h>
 
 namespace U2 {
 
-CreateRulerDialogController::CreateRulerDialogController(const QSet<QString> &namesToFilter, int defaultOffset, QWidget *p)
+CreateRulerDialogController::CreateRulerDialogController(const QSet<QString>& namesToFilter, int defaultOffset, QWidget* p)
     : QDialog(p) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65929407");
@@ -66,7 +66,7 @@ void CreateRulerDialogController::updateColorSample() {
 }
 
 void CreateRulerDialogController::sl_colorButtonClicked() {
-    QColor c = QColorDialog::getColor(color, this);
+    QColor c = U2ColorDialog::getColor(color, this);
     if (!c.isValid()) {
         return;
     }
