@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,16 +19,15 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CREATE_RULER_DIALOG_CONTROLLER_H_
-#define _U2_CREATE_RULER_DIALOG_CONTROLLER_H_
-
-#include <ui_CreateRulerDialog.h>
+#pragma once
 
 #include <QDialog>
 #include <QSet>
 
 #include <U2Core/U2Region.h>
 
+#include <ui_CreateRulerDialog.h>
+
 namespace U2 {
 
 class U2VIEW_EXPORT CreateRulerDialogController : public QDialog, public Ui_CreateRulerDialog {
@@ -36,10 +35,10 @@ class U2VIEW_EXPORT CreateRulerDialogController : public QDialog, public Ui_Crea
 public:
     CreateRulerDialogController(
         /* The names in this set are already used and are not allowed */
-        const QSet<QString> &namesToFilter,
+        const QSet<QString>& namesToFilter,
         /** Ruler offset selected by default */
         int defaultOffset,
-        QWidget *p = nullptr);
+        QWidget* p = nullptr);
 
     virtual void accept();
 
@@ -57,5 +56,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
