@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GSEQUENCE_GRAPH_VIEW_WITH_FACTORY_H_
-#define _U2_GSEQUENCE_GRAPH_VIEW_WITH_FACTORY_H_
+#pragma once
 
 #include <U2Gui/ObjectViewModel.h>
 
@@ -35,17 +34,17 @@ namespace U2 {
  */
 class U2VIEW_EXPORT GSequenceGraphFactory : public QObject {
 public:
-    GSequenceGraphFactory(const QString &_name, QObject *p)
+    GSequenceGraphFactory(const QString& _name, QObject* p)
         : QObject(p), graphName(_name) {
     }
 
-    virtual QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView *v) = 0;
+    virtual QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView* v) = 0;
 
-    virtual GSequenceGraphDrawer *getDrawer(GSequenceGraphView *v);
+    virtual GSequenceGraphDrawer* getDrawer(GSequenceGraphView* v);
 
-    virtual bool isEnabled(const U2SequenceObject *o) const = 0;
+    virtual bool isEnabled(const U2SequenceObject* o) const = 0;
 
-    const QString &getGraphName() const {
+    const QString& getGraphName() const {
         return graphName;
     }
 
@@ -59,15 +58,13 @@ protected:
  */
 class U2VIEW_EXPORT GSequenceGraphViewWithFactory : public GSequenceGraphView {
 public:
-    GSequenceGraphViewWithFactory(ADVSingleSequenceWidget *, GSequenceGraphFactory *);
-    GSequenceGraphFactory *getFactory() const {
+    GSequenceGraphViewWithFactory(ADVSingleSequenceWidget*, GSequenceGraphFactory*);
+    GSequenceGraphFactory* getFactory() const {
         return factory;
     }
 
 private:
-    GSequenceGraphFactory *factory;
+    GSequenceGraphFactory* factory;
 };
 
 }  // namespace U2
-
-#endif
