@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -18,8 +18,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA 02110-1301, USA.
  */
-#ifndef _U2_GRAPH_SETTINGS_DIALOG_H_
-#define _U2_GRAPH_SETTINGS_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 #include <QMap>
@@ -35,14 +34,14 @@ class WindowStepSelectorWidget;
 class GraphSettingsDialog : public QDialog {
     Q_OBJECT
 public:
-    GraphSettingsDialog(GSequenceGraphDrawer *d, const U2Region &range, QWidget *parent);
-    WindowStepSelectorWidget *getWindowSelector() {
+    GraphSettingsDialog(GSequenceGraphDrawer* d, const U2Region& range, QWidget* parent);
+    WindowStepSelectorWidget* getWindowSelector() {
         return wss;
     }
-    MinMaxSelectorWidget *getMinMaxSelector() {
+    MinMaxSelectorWidget* getMinMaxSelector() {
         return mms;
     }
-    const QMap<QString, QColor> &getColors() {
+    const QMap<QString, QColor>& getColors() {
         return colorMap;
     }
 private slots:
@@ -51,11 +50,9 @@ private slots:
     void sl_onOkClicked();
 
 private:
-    WindowStepSelectorWidget *wss;
-    MinMaxSelectorWidget *mms;
+    WindowStepSelectorWidget* wss;
+    MinMaxSelectorWidget* mms;
     QMap<QString, QColor> colorMap;
 };
 
 }  // namespace U2
-
-#endif  //_U2_GRAPH_SETTINGS_DIALOG_H_
