@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PAN_VIEW_ROWS_H_
-#define _U2_PAN_VIEW_ROWS_H_
+#pragma once
 
 #include <U2Core/U2Region.h>
 
@@ -30,14 +29,16 @@ class Annotation;
 
 class PVRowData {
 public:
-    PVRowData(const QString &key);
+    PVRowData(const QString& key);
 
-    bool fitToRow(const QVector<U2Region> &locations);
+    static const QString RESTRICTION_SITE_NAME;
+
+    bool fitToRow(const QVector<U2Region>& locations);
 
     QString key;
     // invariant: keep the ranges in ascending order
     QVector<U2Region> ranges;
-    QList<Annotation *> annotations;
+    QList<Annotation*> annotations;
 };
 
 class PVRowsManager {
@@ -45,27 +46,24 @@ public:
     PVRowsManager();
     ~PVRowsManager();
 
-    void addAnnotation(Annotation *a);
-    void removeAnnotation(Annotation *f);
+    void addAnnotation(Annotation* a);
+    void removeAnnotation(Annotation* f);
 
-    bool contains(const QString &key) const;
-    int getNumRows() const;
-    PVRowData *getRow(int row) const;
+    bool hasRowWithName(const QString& name) const;
+    int getRowCount() const;
+    PVRowData* getRow(int row) const;
 
     /**
      * returns -1 if @a is not found
      */
-    int getAnnotationRowIdx(Annotation *a) const;
-    PVRowData *getAnnotationRow(Annotation *a) const;
+    int getAnnotationRowIdx(Annotation* a) const;
+    PVRowData* getAnnotationRow(Annotation* a) const;
 
     int getNumAnnotationsInRow(int rowNum) const;
 
 private:
-    QList<PVRowData *> rows;
-    QHash<QString, QList<PVRowData *>> rowByName;  // rows may have same names
-    QHash<Annotation *, PVRowData *> rowByAnnotation;
+    QList<PVRowData*> rows;
+    QHash<Annotation*, PVRowData*> rowByAnnotation;
 };
 
 }  // namespace U2
-
-#endif
