@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -37,10 +37,10 @@
 
 namespace U2 {
 
-SaveGraphCutoffsDialogController::SaveGraphCutoffsDialogController(QSharedPointer<GSequenceGraphData> &_graph,
-                                                                   const GSequenceGraphMinMaxCutOffState &cutOffState,
-                                                                   QWidget *parent,
-                                                                   SequenceObjectContext *ctx)
+SaveGraphCutoffsDialogController::SaveGraphCutoffsDialogController(QSharedPointer<GSequenceGraphData>& _graph,
+                                                                   const GSequenceGraphMinMaxCutOffState& cutOffState,
+                                                                   QWidget* parent,
+                                                                   SequenceObjectContext* ctx)
     : QDialog(parent), ctx(ctx), graph(_graph) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65929579");
@@ -50,14 +50,14 @@ SaveGraphCutoffsDialogController::SaveGraphCutoffsDialogController(QSharedPointe
     CreateAnnotationModel m;
     m.hideLocation = true;
     m.data->name = QString("graph_cutoffs");
-    m.sequenceObjectRef = ctx->getSequenceObject();
+    m.sequenceObjectRef = ctx->getSequenceObject()->getReference();
     m.useUnloadedObjects = false;
     m.useAminoAnnotationTypes = ctx->getAlphabet()->isAmino();
     m.sequenceLen = ctx->getSequenceObject()->getSequenceLength();
     createAnnotationController = new CreateAnnotationWidgetController(m, this);
 
-    QWidget *caw = createAnnotationController->getWidget();
-    QVBoxLayout *l = new QVBoxLayout();
+    QWidget* caw = createAnnotationController->getWidget();
+    QVBoxLayout* l = new QVBoxLayout();
     l->setSizeConstraint(QLayout::SetMinAndMaxSize);
     l->setMargin(0);
     l->addWidget(caw);
@@ -130,9 +130,9 @@ void SaveGraphCutoffsDialogController::accept() {
         return;
     }
 
-    const CreateAnnotationModel &annotationModel = createAnnotationController->getModel();
+    const CreateAnnotationModel& annotationModel = createAnnotationController->getModel();
     QList<SharedAnnotationData> data;
-    for (const U2Region &r : qAsConst(resultRegions)) {
+    for (const U2Region& r : qAsConst(resultRegions)) {
         SharedAnnotationData annotationData(new AnnotationData());
         annotationData->location->regions.append(r);
         annotationData->type = annotationModel.data->type;
@@ -143,7 +143,7 @@ void SaveGraphCutoffsDialogController::accept() {
     auto annotationObject = annotationModel.getAnnotationObject();
     tryAddObject(annotationObject);
 
-    auto task = new CreateAnnotationsTask(annotationObject, data, annotationModel.groupName);
+    auto task = new CreateAnnotationsTask(annotationObject, {{annotationModel.groupName, data}});
     AppContext::getTaskScheduler()->registerTopLevelTask(task);
     QDialog::accept();
 }
@@ -161,8 +161,8 @@ bool SaveGraphCutoffsDialogController::validate() {
     return true;
 }
 
-void SaveGraphCutoffsDialogController::tryAddObject(AnnotationTableObject *annotationTableObject) {
-    ADVSequenceObjectContext *advContext = qobject_cast<ADVSequenceObjectContext *>(ctx);
+void SaveGraphCutoffsDialogController::tryAddObject(AnnotationTableObject* annotationTableObject) {
+    auto advContext = qobject_cast<ADVSequenceObjectContext*>(ctx);
     CHECK(advContext != nullptr, );
     advContext->getAnnotatedDNAView()->tryAddObject(annotationTableObject);
 }
