@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEARCH_QUALIFIER_DIALOG_H_
-#define _U2_SEARCH_QUALIFIER_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 #include <QQueue>
@@ -40,20 +39,20 @@ class U2VIEW_EXPORT SearchQualifierDialog : public QDialog {
 private:
     // Qualifier search settings.
     struct SearchQualifierSettings {
-        SearchQualifierSettings(AVItem *groupToSearchIn, const QString &name, const QString &value, bool isExactMatch, bool searchAll, AVItem *prevAnnotation, int prevIndex);
+        SearchQualifierSettings(AVItem* groupToSearchIn, const QString& name, const QString& value, bool isExactMatch, bool searchAll, AVItem* prevAnnotation, int prevIndex);
 
-        AVItem *groupToSearchIn;
+        AVItem* groupToSearchIn;
         QString name;
         QString value;
         bool isExactMatch;
         bool searchAll;
-        AVItem *prevAnnotation;  // Annotation containing the previously found qualifier.
+        AVItem* prevAnnotation;  // Annotation containing the previously found qualifier.
         int prevIndex;  // Index in `prevAnnotation` of the previously found qualifier.
     };
 
     // Qualifier search algorithm. The class also expands found `AVItem`(s) in the Annotation Tree View.
     class SearchQualifier {
-        AnnotationsTreeView *const treeView;  // This is needed to show the found qualifier(s).
+        AnnotationsTreeView* const treeView;  // This is needed to show the found qualifier(s).
         const QString name;
         const QString value;
         const bool isExactMatch;
@@ -64,31 +63,31 @@ private:
 
         // Annotation containing the found qualifier. Equals to `nullptr` if no qualifier was found.
         // Outdated if `foundResult == false`.
-        AVItem *resultAnnotation;
+        AVItem* resultAnnotation;
 
         // Index in `resultAnnotation` of the found qualifier. Equals to `-1` if no qualifier was found.
         // Outdated if `foundResult == false`.
         int resultInd;
 
-        QQueue<AVItem *> toExpand;  // This queue is needed to expand items in main thread.
-        QList<QPair<AVAnnotationItem *, int>> foundQuals;  // This is needed to set found items as selected.
+        QQueue<AVItem*> toExpand;  // This queue is needed to expand items in main thread.
+        QList<QPair<AVAnnotationItem*, int>> foundQuals;  // This is needed to set found items as selected.
 
         // Expands found `AVItem`(s) in the Annotation Tree View.
         void showQualifier() const;
 
-        void searchInGroup(AVItem *group, bool &found);
+        void searchInGroup(AVItem* group, bool& found);
 
-        void searchInAnnotation(AVItem *annotation, bool &found);
+        void searchInAnnotation(AVItem* annotation, bool& found);
 
         // The group index from which to start searching for the qualifier. Depends on the `resultAnnotation`.
-        int getStartGroupIndex(AVItem *group);
+        int getStartGroupIndex(AVItem* group);
 
         // The annotation index in group from which to start searching for the qualifier.
         // Depends on the `resultAnnotation`.
-        int getStartAnnotationIndex(AVItem *annotation);
+        int getStartAnnotationIndex(AVItem* annotation);
 
     public:
-        SearchQualifier(AnnotationsTreeView *treeView, const SearchQualifierSettings &settings);
+        SearchQualifier(AnnotationsTreeView* treeView, const SearchQualifierSettings& settings);
 
         // Whether an qualifier was found. If true, then `getResultAnnotation()`, `getIndexOfResult()` will return
         // corrected values. See `foundResult` filed.
@@ -96,7 +95,7 @@ private:
 
         // Returns an annotation containing the found qualifier. Call `isFound()` before using.
         // See `resultAnnotation` filed.
-        AVItem *getResultAnnotation() const;
+        AVItem* getResultAnnotation() const;
 
         // Index of the found qualifier within the annotation. Call `isFound()` before using.
         // See `resultInd` filed.
@@ -104,11 +103,11 @@ private:
     };
 
 public:
-    SearchQualifierDialog(QWidget *p, AnnotationsTreeView *treeView);
+    SearchQualifierDialog(QWidget* p, AnnotationsTreeView* treeView);
     ~SearchQualifierDialog();
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *e);
+    bool eventFilter(QObject* obj, QEvent* e);
     void clearPrevResults();
 
 protected slots:
@@ -120,15 +119,13 @@ private slots:
 
 private:
     void search(bool searchAll = false);
-    void updateResultAndShowWarnings(const SearchQualifier &foundQualifier);
+    void updateResultAndShowWarnings(const SearchQualifier& foundQualifier);
 
-    AnnotationsTreeView *treeView;
-    Ui_SearchQualifierDialog *ui;
-    AVItem *groupToSearchIn;
-    AVItem *parentAnnotationofPrevResult;
+    AnnotationsTreeView* treeView;
+    Ui_SearchQualifierDialog* ui;
+    AVItem* groupToSearchIn;
+    AVItem* parentAnnotationofPrevResult;
     int indexOfPrevResult;
 };
 
 }  // namespace U2
-
-#endif  //_U2_SEARCH_QUALIFIER_DIALOG_H_
