@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@
 
 namespace U2 {
 
-AnnotHighlightSettingsWidget::AnnotHighlightSettingsWidget(QWidget *parent) {
+AnnotHighlightSettingsWidget::AnnotHighlightSettingsWidget(QWidget* parent) {
     Q_UNUSED(parent);
     setupUi(this);
 
@@ -41,10 +41,10 @@ AnnotHighlightSettingsWidget::AnnotHighlightSettingsWidget(QWidget *parent) {
     connect(checkShowHideAnnots, SIGNAL(stateChanged(int)), SLOT(sl_onShowHideChanged(int)));
     connect(checkShowOnTranslation, SIGNAL(stateChanged(int)), SLOT(sl_onShowOnTranslationChanged(int)));
     connect(checkVisualQualifier, SIGNAL(stateChanged(int)), SLOT(sl_onShowQualifierChanged(int)));
-    connect(editQualifiers, SIGNAL(textChanged(const QString &)), SLOT(sl_onEditQualifiersChanged(const QString &)));
+    connect(editQualifiers, SIGNAL(textChanged(const QString&)), SLOT(sl_onEditQualifiersChanged(const QString&)));
 }
 
-void AnnotHighlightSettingsWidget::setSettings(AnnotationSettings *annotSettings, bool disableShowTranslations) {
+void AnnotHighlightSettingsWidget::setSettings(AnnotationSettings* annotSettings, bool disableShowTranslations) {
     SAFE_POINT(0 != annotSettings, "Annotation settings equals to NULL!", );
 
     currentSettings = annotSettings;
@@ -62,25 +62,35 @@ void AnnotHighlightSettingsWidget::setSettings(AnnotationSettings *annotSettings
 
 void AnnotHighlightSettingsWidget::sl_onShowHideChanged(int checkedState) {
     SAFE_POINT(0 != currentSettings, "An annotation should always be selected!", );
+    bool prevValue = currentSettings->visible;
     currentSettings->visible = (checkedState == Qt::Checked) ? true : false;
-    emit si_annotSettingsChanged(currentSettings);
+    if (prevValue != currentSettings->visible) {
+        emit si_annotSettingsChanged(currentSettings);
+    }
 }
 
 void AnnotHighlightSettingsWidget::sl_onShowOnTranslationChanged(int checkedState) {
     SAFE_POINT(0 != currentSettings, "An annotation should always be selected!", );
+    bool prevValue = currentSettings->amino;
     currentSettings->amino = (checkedState == Qt::Checked) ? true : false;
-    emit si_annotSettingsChanged(currentSettings);
+    if (prevValue != currentSettings->amino) {
+        emit si_annotSettingsChanged(currentSettings);
+    }
 }
 
 void AnnotHighlightSettingsWidget::sl_onShowQualifierChanged(int checkedState) {
     SAFE_POINT(0 != currentSettings, "An annotation should always be selected!", );
+    bool prevValue = currentSettings->showNameQuals;
     currentSettings->showNameQuals = (checkedState == Qt::Checked) ? true : false;
-    emit si_annotSettingsChanged(currentSettings);
+    if (prevValue != currentSettings->showNameQuals) {
+        emit si_annotSettingsChanged(currentSettings);
+    }
 }
 
-void AnnotHighlightSettingsWidget::sl_onEditQualifiersChanged(const QString &inputNameQuals) {
+void AnnotHighlightSettingsWidget::sl_onEditQualifiersChanged(const QString& inputNameQuals) {
     SAFE_POINT(0 != currentSettings, "An annotation should always be selected!", );
     QStringList qualifierNames = inputNameQuals.split(',', QString::SkipEmptyParts);
+    QStringList prevValue = currentSettings->nameQuals;
 
     // Validate the input
     foreach (QString qualifierName, qualifierNames) {
@@ -93,7 +103,9 @@ void AnnotHighlightSettingsWidget::sl_onEditQualifiersChanged(const QString &inp
     // If the qualifier names are correct
     currentSettings->nameQuals = qualifierNames;
     setCorrectState();
-    emit si_annotSettingsChanged(currentSettings);
+    if (prevValue != currentSettings->nameQuals) {
+        emit si_annotSettingsChanged(currentSettings);
+    }
 }
 
 void AnnotHighlightSettingsWidget::setIncorrectState() {
