@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOT_HIGHLIGHT_TREE_H_
-#define _U2_ANNOT_HIGHLIGHT_TREE_H_
+#pragma once
 
 #include <QTreeWidget>
 
@@ -68,21 +67,21 @@ signals:
     void si_colorChanged(QString annotName, QColor annotColor);
 
 private slots:
-    void sl_onCurrentItemChanged(QTreeWidgetItem *current, QTreeWidgetItem *previous);
-    void sl_onItemClicked(QTreeWidgetItem *item, int column);
+    void sl_onCurrentItemChanged(QTreeWidgetItem* current, QTreeWidgetItem* previous);
+    void sl_onItemClicked(QTreeWidgetItem* item, int column);
 
 private:
     /** Do not use these methods to add an item to the tree, use addItem(...) instead */
-    virtual void addTopLevelItem(QTreeWidgetItem *item) {
+    virtual void addTopLevelItem(QTreeWidgetItem* item) {
         QTreeWidget::addTopLevelItem(item);
     }
-    virtual void addTopLevelItems(const QList<QTreeWidgetItem *> &items) {
+    virtual void addTopLevelItems(const QList<QTreeWidgetItem*>& items) {
         QTreeWidget::addTopLevelItems(items);
     }
-    virtual void insertTopLevelItem(int index, QTreeWidgetItem *item) {
+    virtual void insertTopLevelItem(int index, QTreeWidgetItem* item) {
         QTreeWidget::insertTopLevelItem(index, item);
     }
-    virtual void insertTopLevelItems(int index, const QList<QTreeWidgetItem *> &items) {
+    virtual void insertTopLevelItems(int index, const QList<QTreeWidgetItem*>& items) {
         QTreeWidget::insertTopLevelItems(index, items);
     }
 
@@ -96,5 +95,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
