@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOT_HIGHLIGHT_TREE_ITEM_H_
-#define _U2_ANNOT_HIGHLIGHT_TREE_ITEM_H_
+#pragma once
 
 #include <QTreeWidgetItem>
 
@@ -30,7 +29,7 @@ namespace U2 {
 
 class U2VIEW_EXPORT AnnotHighlightTreeItem : public QTreeWidgetItem {
 public:
-    AnnotHighlightTreeItem(const QString &annotName, const QColor &annotColor);
+    AnnotHighlightTreeItem(const QString& annotName, const QColor& annotColor);
 
     inline QString getName() {
         return annotName;
@@ -39,7 +38,7 @@ public:
     inline QColor getColor() {
         return annotColor;
     }
-    void setColor(const QColor &_annotColor);
+    void setColor(const QColor& _annotColor);
 
     static const int ROW_HEIGHT;
     static const int COLOR_ICON_SIZE;
@@ -52,5 +51,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
