@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CODON_TABLE_H_
-#define _U2_CODON_TABLE_H_
+#pragma once
 
 #include <QLabel>
 #include <QTableWidget>
@@ -37,14 +36,14 @@ namespace U2 {
 class U2VIEW_EXPORT CodonTableView : public ADVSplitWidget {
     Q_OBJECT
 public:
-    CodonTableView(AnnotatedDNAView *view);
+    CodonTableView(AnnotatedDNAView* view);
 
-    virtual bool acceptsGObject(GObject *) {
+    virtual bool acceptsGObject(GObject*) {
         return false;
     }
-    virtual void updateState(const QVariantMap &) {
+    virtual void updateState(const QVariantMap&) {
     }
-    virtual void saveState(QVariantMap &) {
+    virtual void saveState(QVariantMap&) {
     }
 
     static const QColor NONPOLAR_COLOR;
@@ -58,21 +57,19 @@ public slots:
     void sl_setAminoTranslation();
 
     /** Updates amino translation to match the new active sequence translation. */
-    void sl_onActiveSequenceChanged(ADVSequenceWidget *from, ADVSequenceWidget *to);
+    void sl_onActiveSequenceChanged(ADVSequenceWidget* from, ADVSequenceWidget* to);
 
 private:
-    QTableWidget *table;
+    QTableWidget* table;
 
-    void addItemToTable(int row, int column, const QString &text, const QColor &backgroundColor = QColor(0, 0, 0, 0), int rowSpan = 1, int columnSpan = 1);
-    void addItemToTable(int row, int column, const QString &text, int rowSpan = 1, int columnSpan = 1);
-    void addItemToTable(int row, int column, const QString &text, const QColor &backgroundColor, const QString &link, int rowSpan = 1, int columnSpan = 1);
-    void addItemToTable(int row, int column, DNACodon *codon);
+    void addItemToTable(int row, int column, const QString& text, const QColor& backgroundColor = QColor(0, 0, 0, 0), int rowSpan = 1, int columnSpan = 1);
+    void addItemToTable(int row, int column, const QString& text, int rowSpan = 1, int columnSpan = 1);
+    void addItemToTable(int row, int column, const QString& text, const QColor& backgroundColor, const QString& link, int rowSpan = 1, int columnSpan = 1);
+    void addItemToTable(int row, int column, DNACodon* codon);
 
-    void setAminoTranslation(const QString &trId);
+    void setAminoTranslation(const QString& trId);
     void spanEqualCells();
     QColor getColor(DNACodonGroup gr);
 };
 
 }  // namespace U2
-
-#endif  // _U2_CODON_TABLE_H_
