@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,25 +19,24 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_PATTERN_WIDGET_FACTORY_H_
-#define _U2_FIND_PATTERN_WIDGET_FACTORY_H_
+#pragma once
 
 #include <U2Gui/OPWidgetFactory.h>
 
 namespace U2 {
 
-class GObjectView;
+class GObjectViewController;
 
 class U2VIEW_EXPORT FindPatternWidgetFactory : public OPWidgetFactory {
     Q_OBJECT
 public:
     FindPatternWidgetFactory();
 
-    QWidget *createWidget(GObjectView *objView, const QVariantMap &options) override;
+    QWidget* createWidget(GObjectViewController* objView, const QVariantMap& options) override;
 
     OPGroupParameters getOPGroupParameters() override;
 
-    static const QString &getGroupId();
+    static const QString& getGroupId();
 
 private:
     static const QString GROUP_ID;
@@ -46,5 +45,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
