@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_PATTERN_SAVABLE_TAB_H_
-#define _U2_FIND_PATTERN_SAVABLE_TAB_H_
+#pragma once
 
 #include <QStringList>
 
@@ -32,16 +31,14 @@ class U2SequenceObject;
 
 class FindPatternWidgetSavableTab : public U2SavableWidget {
 public:
-    FindPatternWidgetSavableTab(QWidget *wrappedWidget, MWMDIWindow *contextWindow);
+    FindPatternWidgetSavableTab(QWidget* wrappedWidget, MWMDIWindow* contextWindow);
     ~FindPatternWidgetSavableTab();
 
-    void setChildValue(const QString &childId, const QVariant &value);
-    void setRegionWidgetIds(const QStringList &s);
+    void setChildValue(const QString& childId, const QVariant& value);
+    void setRegionWidgetIds(const QStringList& s);
 
 private:
     QStringList regionWidgetIds;
 };
 
 }  // namespace U2
-
-#endif
