@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_IMAGE_PAINTER_H_
-#define _U2_EXPORT_IMAGE_PAINTER_H_
+#pragma once
 
 #include <QPainter>
 
@@ -44,11 +43,9 @@ public:
     virtual ~ExportImagePainter() {
     }
 
-    virtual void paint(QPainter &p, CustomExportSettings *settings) const = 0;
-    virtual QSize getImageSize(CustomExportSettings *settings) const = 0;
-    virtual bool canPaintSvg(CustomExportSettings *settings, U2OpStatus &os) const = 0;
+    virtual void paint(QPainter& p, CustomExportSettings* settings) const = 0;
+    virtual QSize getImageSize(CustomExportSettings* settings) const = 0;
+    virtual bool canPaintSvg(CustomExportSettings* settings, U2OpStatus& os) const = 0;
 };
 
 }  // namespace U2
-
-#endif  // _U2_EXPORT_IMAGE_PAINTER_H_
