@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SINGLE_SEQUENCE_IMAGE_EXPORT_CONTROLLER_H_
-#define _U2_SINGLE_SEQUENCE_IMAGE_EXPORT_CONTROLLER_H_
+#pragma once
 
 #include <QSharedPointer>
 
@@ -41,23 +40,23 @@ class SequenceExportSettingsWidget;
 class SingleSequenceImageExportController : public ImageExportController {
     Q_OBJECT
 public:
-    SingleSequenceImageExportController(ADVSingleSequenceWidget *sequenceWidget);
+    SingleSequenceImageExportController(ADVSingleSequenceWidget* sequenceWidget);
 
 protected:
     void initSettingsWidget();
 
-    Task *getExportToSvgTask(const ImageExportTaskSettings &imageSettings) const;
-    Task *getExportToPdfTask(const ImageExportTaskSettings &imageSettings) const;
-    Task *getExportToBitmapTask(const ImageExportTaskSettings &imageSettings) const;
+    Task* getExportToSvgTask(const ImageExportTaskSettings& imageSettings) const;
+    Task* getExportToPdfTask(const ImageExportTaskSettings& imageSettings) const;
+    Task* getExportToBitmapTask(const ImageExportTaskSettings& imageSettings) const;
 
 public slots:
-    void sl_onFormatChanged(const QString &format);
+    void sl_onFormatChanged(const QString& format);
     void sl_customSettingsChanged();
 
 private:
     void checkExportSettings();
-    ADVSingleSequenceWidget *sequenceWidget;
-    SequenceExportSettingsWidget *seqSettingsWidget;
+    ADVSingleSequenceWidget* sequenceWidget;
+    SequenceExportSettingsWidget* seqSettingsWidget;
     QString format;
 
     QSharedPointer<ExportImagePainter> currentPainter;
@@ -65,5 +64,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_SINGLE_SEQUENCE_IMAGE_EXPORT_CONTROLLER_H_
