@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CHAR_OCCUR_TASK_H_
-#define _U2_CHAR_OCCUR_TASK_H_
+#pragma once
 
 #include <U2Core/BackgroundTaskRunner.h>
 #include <U2Core/U2Region.h>
@@ -56,7 +55,7 @@ typedef QList<CharOccurResult> CharactersOccurrence;
 
 class U2VIEW_EXPORT CharOccurTask : public BackgroundTask<QList<CharOccurResult>> {
 public:
-    CharOccurTask(const DNAAlphabet *alphabet, U2EntityRef seqRef, const QVector<U2Region> &regions);
+    CharOccurTask(const DNAAlphabet* alphabet, U2EntityRef seqRef, const QVector<U2Region>& regions);
 
     /**
      * Calculates the characters occurrence (in a different thread).
@@ -65,7 +64,7 @@ public:
     virtual void run();
 
 private:
-    const DNAAlphabet *alphabet;
+    const DNAAlphabet* alphabet;
     U2EntityRef seqRef;
     QVector<U2Region> regions;
 
@@ -74,5 +73,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
