@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,15 +21,20 @@
 
 #include "SequenceInfo.h"
 
+#include <QDialog>
 #include <QLabel>
+#include <QScopedPointer>
 #include <QVBoxLayout>
 
+#include <U2Algorithm/TmCalculatorRegistry.h>
+
 #include <U2Core/AnnotationSelection.h>
 #include <U2Core/AppContext.h>
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/DNASequenceSelection.h>
 #include <U2Core/DNATranslation.h>
+#include <U2Core/QObjectScopedPointer.h>
 #include <U2Core/U2Region.h>
 #include <U2Core/U2SafePoints.h>
 
@@ -39,41 +44,41 @@
 #include <U2View/ADVSequenceObjectContext.h>
 #include <U2View/ADVSequenceWidget.h>
 #include <U2View/AnnotatedDNAView.h>
+#include <U2View/TmCalculatorSelectorDialog.h>
 
 #include "CodonOccurTask.h"
 
 namespace U2 {
 
-const int SequenceInfo::COMMON_STATISTICS_TABLE_CELLSPACING = 5;
-const QString SequenceInfo::CAPTION_SEQ_REGION_LENGTH = "Length: ";
+static constexpr int COMMON_STATISTICS_TABLE_CELLSPACING = 5;
 
-const QString SequenceInfo::CAPTION_SUFFIX_DS_DNA = "dsDNA:";
-const QString SequenceInfo::CAPTION_SUFFIX_SS_DNA = "ssDNA:";
-const QString SequenceInfo::CAPTION_SUFFIX_DS_RNA = "dsRNA:";
-const QString SequenceInfo::CAPTION_SUFFIX_SS_RNA = "ssRNA:";
+static const QString CAPTION_SUFFIX_DS_DNA = "dsDNA:";
+static const QString CAPTION_SUFFIX_SS_DNA = "ssDNA:";
+static const QString CAPTION_SUFFIX_DS_RNA = "dsRNA:";
+static const QString CAPTION_SUFFIX_SS_RNA = "ssRNA:";
 
-// nucl
-const QString SequenceInfo::CAPTION_SEQ_GC_CONTENT = "GC content: ";
-const QString SequenceInfo::CAPTION_SEQ_NUCL_MOLECULAR_WEIGHT = "Molecular weight: ";
-const QString SequenceInfo::CAPTION_SEQ_EXTINCTION_COEFFICIENT = "Extinction coefficient: ";
-const QString SequenceInfo::CAPTION_SEQ_MELTING_TEMPERATURE = "Melting temperature: ";
+static const QString CAPTION_SEQ_NMOLE_OD = "nmole/OD<sub>260</sub>";
+static const QString CAPTION_SEQ_MG_OD = QChar(0x3BC) + QString("g/OD<sub>260</sub>");  // 0x3BC - greek 'mu'
 
-const QString SequenceInfo::CAPTION_SEQ_NMOLE_OD = "nmole/OD<sub>260</sub>: ";
-const QString SequenceInfo::CAPTION_SEQ_MG_OD = QChar(0x3BC) + QString("g/OD<sub>260</sub>: ");  // 0x3BC - greek 'mu'
+static const QString CHAR_OCCUR_GROUP_ID = "char_occur_group";
+static const QString DINUCL_OCCUR_GROUP_ID = "dinucl_occur_group";
+static const QString CODON_OCCUR_GROUP_ID = "codon_occur_group";
+static const QString AMINO_ACID_OCCUR_GROUP_ID = "amino_acid_occur_group";
+static const QString STAT_GROUP_ID = "stat_group";
 
-// amino
-const QString SequenceInfo::CAPTION_SEQ_AMINO_MOLECULAR_WEIGHT = "Molecular weight: ";
-const QString SequenceInfo::CAPTION_SEQ_ISOELECTIC_POINT = "Isoelectic point: ";
+SequenceInfo::SequenceInfo(AnnotatedDNAView* _annotatedDnaView)
+    : annotatedDnaView(_annotatedDnaView),
+      annotatedDnaViewName(annotatedDnaView->getName()),
+      savableWidget(this, GObjectViewUtils::findViewByName(annotatedDnaViewName)),
+      temperatureCalculator(AppContext::getTmCalculatorRegistry()->createTmCalculator(annotatedDnaViewName)),
+      captionSeqRegionLength(tr("Length")),
+      captionSeqGcContent(tr("GC content")),
+      captionSeqMolecularWeight(tr("Molecular weight")),
+      captionSeqExtinctionCoefficient(tr("Extinction coefficient")),
+      captionSeqMeltingTemperature(tr("Melting temperature")),
+      captionSeqIsoelecticPoint(tr("Isoelectic point")) {
+    SAFE_POINT(annotatedDnaView != nullptr, "AnnotatedDNAView is NULL!", );
 
-const QString SequenceInfo::CHAR_OCCUR_GROUP_ID = "char_occur_group";
-const QString SequenceInfo::DINUCL_OCCUR_GROUP_ID = "dinucl_occur_group";
-const QString SequenceInfo::CODON_OCCUR_GROUP_ID = "codon_occur_group";
-const QString SequenceInfo::AMINO_ACID_OCCUR_GROUP_ID = "amino_acid_occur_group";
-const QString SequenceInfo::STAT_GROUP_ID = "stat_group";
-
-SequenceInfo::SequenceInfo(AnnotatedDNAView *_annotatedDnaView)
-    : annotatedDnaView(_annotatedDnaView), savableWidget(this, GObjectViewUtils::findViewByName(_annotatedDnaView->getName())) {
-    SAFE_POINT(0 != annotatedDnaView, "AnnotatedDNAView is NULL!", );
 
     updateCurrentRegions();
     initLayout();
@@ -83,15 +88,19 @@ SequenceInfo::SequenceInfo(AnnotatedDNAView *_annotatedDnaView)
     U2WidgetStateStorage::restoreWidgetState(savableWidget);
 }
 
+SequenceInfo::~SequenceInfo() {
+    AppContext::getTmCalculatorRegistry()->saveSettings(annotatedDnaViewName, temperatureCalculator->getSettings());
+}
+
 void SequenceInfo::initLayout() {
-    QVBoxLayout *mainLayout = new QVBoxLayout();
+    auto mainLayout = new QVBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(0);
 
     setLayout(mainLayout);
 
     // Common statistics
-    QWidget *statisticLabelContainer = new QWidget(this);
+    auto statisticLabelContainer = new QWidget(this);
     statisticLabelContainer->setLayout(new QHBoxLayout);
     statisticLabelContainer->layout()->setContentsMargins(0, 0, 0, 0);
 
@@ -99,7 +108,9 @@ void SequenceInfo::initLayout() {
     statisticLabel->installEventFilter(this);
     statisticLabel->setMinimumWidth(1);
     statisticLabel->setObjectName("Common Statistics");
+    statisticLabel->setOpenExternalLinks(false);
     statisticLabelContainer->layout()->addWidget(statisticLabel);
+    connect(statisticLabel, &QLabel::linkActivated, this, &SequenceInfo::statisticLabelLinkActivated);
 
     statsWidget = new ShowHideSubgroupWidget(STAT_GROUP_ID, tr("Common Statistics"), statisticLabelContainer, true);
 
@@ -137,7 +148,7 @@ void SequenceInfo::initLayout() {
     dinuclLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
     codonLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
     aminoAcidLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
-    statisticLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
+    statisticLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
 
     updateLayout();
 }
@@ -176,10 +187,10 @@ QString getFormattedLongNumber(qint64 num) {
 }  // namespace
 
 void SequenceInfo::updateCharOccurLayout() {
-    ADVSequenceObjectContext *activeSequenceContext = annotatedDnaView->getActiveSequenceContext();
-    if (0 != activeSequenceContext) {
-        const DNAAlphabet *activeSequenceAlphabet = activeSequenceContext->getAlphabet();
-        SAFE_POINT(0 != activeSequenceAlphabet, "An active sequence alphabet is NULL!", );
+    ADVSequenceObjectContext* activeSequenceContext = annotatedDnaView->getActiveSequenceContext();
+    if (activeSequenceContext != nullptr) {
+        const DNAAlphabet* activeSequenceAlphabet = activeSequenceContext->getAlphabet();
+        SAFE_POINT(activeSequenceAlphabet != nullptr, "An active sequence alphabet is NULL!", );
         if ((activeSequenceAlphabet->isNucleic()) || (activeSequenceAlphabet->isAmino())) {
             charOccurWidget->show();
         } else {
@@ -190,11 +201,11 @@ void SequenceInfo::updateCharOccurLayout() {
 }
 
 void SequenceInfo::updateDinuclLayout() {
-    ADVSequenceObjectContext *activeSequenceContext = annotatedDnaView->getActiveSequenceContext();
-    SAFE_POINT(0 != activeSequenceContext, "A sequence context is NULL!", );
+    ADVSequenceObjectContext* activeSequenceContext = annotatedDnaView->getActiveSequenceContext();
+    SAFE_POINT(activeSequenceContext != nullptr, "A sequence context is NULL!", );
 
-    const DNAAlphabet *activeSequenceAlphabet = activeSequenceContext->getAlphabet();
-    SAFE_POINT(0 != activeSequenceAlphabet, "An active sequence alphabet is NULL!", );
+    const DNAAlphabet* activeSequenceAlphabet = activeSequenceContext->getAlphabet();
+    SAFE_POINT(activeSequenceAlphabet != nullptr, "An active sequence alphabet is NULL!", );
 
     const QString alphabetId = activeSequenceAlphabet->getId();
     if ((alphabetId == BaseDNAAlphabetIds::NUCL_DNA_DEFAULT()) || (alphabetId == BaseDNAAlphabetIds::NUCL_RNA_DEFAULT())) {
@@ -205,7 +216,7 @@ void SequenceInfo::updateDinuclLayout() {
 }
 
 void SequenceInfo::updateCodonOccurLayout() {
-    ADVSequenceObjectContext *activeSequenceContext = annotatedDnaView->getActiveSequenceContext();
+    ADVSequenceObjectContext* activeSequenceContext = annotatedDnaView->getActiveSequenceContext();
     SAFE_POINT(activeSequenceContext != nullptr, "A sequence context is NULL!", );
     codonWidget->setVisible(activeSequenceContext->getAlphabet()->isNucleic());
     aminoAcidWidget->setVisible(activeSequenceContext->getComplementTT() != nullptr && activeSequenceContext->getAminoTT() != nullptr);
@@ -218,8 +229,8 @@ void SequenceInfo::updateData() {
     updateCodonsOccurrenceData();
 }
 
-void SequenceInfo::updateCommonStatisticsData() {
-    if (!getCommonStatisticsCache()->isValid(currentRegions)) {
+void SequenceInfo::updateCommonStatisticsData(bool forceUpdate) {
+    if (!getCommonStatisticsCache()->isValid(currentRegions) || forceUpdate) {
         launchCalculations(STAT_GROUP_ID);
     } else {
         updateCommonStatisticsData(getCommonStatisticsCache()->getStatistics());
@@ -228,19 +239,19 @@ void SequenceInfo::updateCommonStatisticsData() {
 
 namespace {
 
-QString getValue(const QString &value, bool isValid) {
+QString getValue(const QString& value, bool isValid) {
     return isValid ? value : "N/A";
 }
 
 }  // namespace
 
-void SequenceInfo::updateCommonStatisticsData(const DNAStatistics &commonStatistics) {
-    ADVSequenceWidget *wgt = annotatedDnaView->getActiveSequenceWidget();
+void SequenceInfo::updateCommonStatisticsData(const DNAStatistics& commonStatistics) {
+    ADVSequenceWidget* wgt = annotatedDnaView->getActiveSequenceWidget();
     CHECK(wgt != nullptr, );
-    ADVSequenceObjectContext *ctx = wgt->getActiveSequenceContext();
+    ADVSequenceObjectContext* ctx = wgt->getActiveSequenceContext();
     SAFE_POINT(ctx != nullptr, tr("Sequence context is NULL"), );
 
-    const DNAAlphabet *alphabet = ctx->getAlphabet();
+    const DNAAlphabet* alphabet = ctx->getAlphabet();
     SAFE_POINT(alphabet != nullptr, tr("Sequence alphabet is NULL"), );
 
     int availableSpace = getAvailableSpace(alphabet->getType());
@@ -251,30 +262,32 @@ void SequenceInfo::updateCommonStatisticsData(const DNAStatistics &commonStatist
 
     const QString lengthSuffix = alphabet->isNucleic() ? tr("nt") : alphabet->isAmino() ? tr("aa")
                                                                                         : QString();
-    statsInfo += formTableRow(CAPTION_SEQ_REGION_LENGTH, getValue(getFormattedLongNumber(commonStatistics.length) + lengthSuffix, isValid), availableSpace);
+    statsInfo += formTableRow(captionSeqRegionLength, getValue(getFormattedLongNumber(commonStatistics.length) + lengthSuffix, isValid), availableSpace);
 
     if (alphabet->isNucleic()) {
-        statsInfo += formTableRow(CAPTION_SEQ_GC_CONTENT, getValue(QString::number(commonStatistics.gcContent, 'f', 2) + "%", isValid), availableSpace);
-        statsInfo += formTableRow(CAPTION_SEQ_MELTING_TEMPERATURE, getValue(QString::number(commonStatistics.meltingTemp, 'f', 2) + " &#176;C", isValid), availableSpace);
+        statsInfo += formTableRow(captionSeqGcContent, getValue(QString::number(commonStatistics.gcContent, 'f', 2) + "%", isValid), availableSpace);
+        bool isValidMeltingTm = isValid && commonStatistics.meltingTemp != TmCalculator::INVALID_TM;
+        QString meltingTmFormattedValue = getValue(QString::number(commonStatistics.meltingTemp, 'f', 2) + " °C", isValidMeltingTm);
+        statsInfo += formTableRow(captionSeqMeltingTemperature, meltingTmFormattedValue, availableSpace, true);
 
         const QString ssCaption = alphabet->isRNA() ? CAPTION_SUFFIX_SS_RNA : CAPTION_SUFFIX_SS_DNA;
         statsInfo += QString("<tr><td colspan=2><b>") + tr("%1").arg(ssCaption) + "</b></td></tr>";
 
-        statsInfo += formTableRow(QString("&nbsp;").repeated(4) + CAPTION_SEQ_NUCL_MOLECULAR_WEIGHT, getValue(QString::number(commonStatistics.ssMolecularWeight, 'f', 2) + tr(" Da"), isValid), availableSpace);
-        statsInfo += formTableRow(QString("&nbsp;").repeated(4) + CAPTION_SEQ_EXTINCTION_COEFFICIENT, getValue(QString::number(commonStatistics.ssExtinctionCoefficient) + tr(" l/(mol * cm)"), isValid), availableSpace);
+        statsInfo += formTableRow(QString("&nbsp;").repeated(4) + captionSeqMolecularWeight, getValue(QString::number(commonStatistics.ssMolecularWeight, 'f', 2) + tr(" Da"), isValid), availableSpace);
+        statsInfo += formTableRow(QString("&nbsp;").repeated(4) + captionSeqExtinctionCoefficient, getValue(QString::number(commonStatistics.ssExtinctionCoefficient) + tr(" l/(mol * cm)"), isValid), availableSpace);
         statsInfo += formTableRow(QString("&nbsp;").repeated(4) + CAPTION_SEQ_NMOLE_OD, getValue(QString::number(commonStatistics.ssOd260AmountOfSubstance, 'f', 2), isValid), availableSpace);
         statsInfo += formTableRow(QString("&nbsp;").repeated(4) + CAPTION_SEQ_MG_OD, getValue(QString::number(commonStatistics.ssOd260Mass, 'f', 2), isValid), availableSpace);
 
         const QString dsCaption = alphabet->isRNA() ? CAPTION_SUFFIX_DS_RNA : CAPTION_SUFFIX_DS_DNA;
         statsInfo += QString("<tr><td colspan=2><b>") + tr("%1").arg(dsCaption) + "</b></td></tr>";
 
-        statsInfo += formTableRow(QString("&nbsp;").repeated(4) + CAPTION_SEQ_NUCL_MOLECULAR_WEIGHT, getValue(QString::number(commonStatistics.dsMolecularWeight, 'f', 2) + tr(" Da"), isValid), availableSpace);
-        statsInfo += formTableRow(QString("&nbsp;").repeated(4) + CAPTION_SEQ_EXTINCTION_COEFFICIENT, getValue(QString::number(commonStatistics.dsExtinctionCoefficient) + tr(" l/(mol * cm)"), isValid), availableSpace);
+        statsInfo += formTableRow(QString("&nbsp;").repeated(4) + captionSeqMolecularWeight, getValue(QString::number(commonStatistics.dsMolecularWeight, 'f', 2) + tr(" Da"), isValid), availableSpace);
+        statsInfo += formTableRow(QString("&nbsp;").repeated(4) + captionSeqExtinctionCoefficient, getValue(QString::number(commonStatistics.dsExtinctionCoefficient) + tr(" l/(mol * cm)"), isValid), availableSpace);
         statsInfo += formTableRow(QString("&nbsp;").repeated(4) + CAPTION_SEQ_NMOLE_OD, getValue(QString::number(commonStatistics.dsOd260AmountOfSubstance, 'f', 2), isValid), availableSpace);
         statsInfo += formTableRow(QString("&nbsp;").repeated(4) + CAPTION_SEQ_MG_OD, getValue(QString::number(commonStatistics.dsOd260Mass, 'f', 2), isValid), availableSpace);
     } else if (alphabet->isAmino()) {
-        statsInfo += formTableRow(CAPTION_SEQ_AMINO_MOLECULAR_WEIGHT, getValue(QString::number(commonStatistics.ssMolecularWeight, 'f', 2), isValid), availableSpace);
-        statsInfo += formTableRow(CAPTION_SEQ_ISOELECTIC_POINT, getValue(QString::number(commonStatistics.isoelectricPoint, 'f', 2), isValid), availableSpace);
+        statsInfo += formTableRow(captionSeqMolecularWeight, getValue(QString::number(commonStatistics.ssMolecularWeight, 'f', 2) + tr(" gram/mol"), isValid), availableSpace);
+        statsInfo += formTableRow(captionSeqIsoelecticPoint, getValue(QString::number(commonStatistics.isoelectricPoint, 'f', 2), isValid), availableSpace);
     }
 
     statsInfo += "</table>";
@@ -292,11 +305,11 @@ void SequenceInfo::updateCharactersOccurrenceData() {
     }
 }
 
-void SequenceInfo::updateCharactersOccurrenceData(const CharactersOccurrence &charactersOccurrence) {
+void SequenceInfo::updateCharactersOccurrenceData(const CharactersOccurrence& charactersOccurrence) {
     const bool isValid = charOccurTaskRunner.isIdle();
 
     QString charOccurInfo = "<table cellspacing=5>";
-    foreach (const CharOccurResult &result, charactersOccurrence) {
+    foreach (const CharOccurResult& result, charactersOccurrence) {
         charOccurInfo += "<tr>";
         charOccurInfo += QString("<td><b>") + result.getChar() + QString(":&nbsp;&nbsp;</td>");
         charOccurInfo += "<td>" + getValue(getFormattedLongNumber(result.getNumberOfOccur()), isValid) + "&nbsp;&nbsp;</td>";
@@ -318,7 +331,7 @@ void SequenceInfo::updateDinucleotidesOccurrenceData() {
     }
 }
 
-void SequenceInfo::updateDinucleotidesOccurrenceData(const DinucleotidesOccurrence &dinucleotidesOccurrence) {
+void SequenceInfo::updateDinucleotidesOccurrenceData(const DinucleotidesOccurrence& dinucleotidesOccurrence) {
     const bool isValid = dinuclTaskRunner.isIdle();
 
     DinucleotidesOccurrence::const_iterator i = dinucleotidesOccurrence.constBegin();
@@ -346,13 +359,13 @@ void SequenceInfo::updateCodonsOccurrenceData() {
     }
 }
 
-void SequenceInfo::updateCodonsOccurrenceData(const QMap<QByteArray, qint64> &codonStatMap) {
-    ADVSequenceObjectContext *activeContext = annotatedDnaView->getActiveSequenceContext();
+void SequenceInfo::updateCodonsOccurrenceData(const QMap<QByteArray, qint64>& codonStatMap) {
+    ADVSequenceObjectContext* activeContext = annotatedDnaView->getActiveSequenceContext();
     SAFE_POINT(activeContext != nullptr, "A sequence context is NULL!", );
 
-    DNATranslation *aminoTranslation = activeContext->getAminoTT();
-    AnnotationSelection *annotationSelection = activeContext->getAnnotationsSelection();
-    DNASequenceSelection *sequenceSelection = activeContext->getSequenceSelection();
+    DNATranslation* aminoTranslation = activeContext->getAminoTT();
+    AnnotationSelection* annotationSelection = activeContext->getAnnotationsSelection();
+    DNASequenceSelection* sequenceSelection = activeContext->getSequenceSelection();
     bool isAnnotationSelection = !annotationSelection->isEmpty();
     bool isSequenceSelection = !isAnnotationSelection && !sequenceSelection->isEmpty();
     QString whereInfo = isAnnotationSelection ? (annotationSelection->getAnnotations().size() > 1 ? tr("selected annotations") : tr("selected annotation"))
@@ -380,8 +393,8 @@ void SequenceInfo::updateCodonsOccurrenceData(const QMap<QByteArray, qint64> &co
         // Prepare codons report & convert raw codons into amino acids.
         QList<QByteArray> codons = codonStatMap.keys();
         QHash<char, qint64> countPerAminoAcid;
-        bool tableColumnIndex = 0;  // Report is written using 2 columns.
-        for (const QByteArray &codon : qAsConst(codons)) {
+        int tableColumnIndex = 0;  // Report is written using 2 columns.
+        for (const QByteArray& codon : qAsConst(codons)) {
             codonsHtml += tableColumnIndex == 0 ? "<tr>" : "";
             codonsHtml += QString("<td><b>") + QString::fromLatin1(codon) + QString(":&nbsp;&nbsp;</b></td>");
             qint64 count = codonStatMap.value(codon);
@@ -404,11 +417,11 @@ void SequenceInfo::updateCodonsOccurrenceData(const QMap<QByteArray, qint64> &co
             qint64 count = it.value();
             aminoAcidList << CharOccurResult(aminoAcid, count, 0);
         }
-        std::sort(aminoAcidList.begin(), aminoAcidList.end(), [](const CharOccurResult &c1, CharOccurResult &c2) {
+        std::sort(aminoAcidList.begin(), aminoAcidList.end(), [](const CharOccurResult& c1, CharOccurResult& c2) {
             // Reversed order: most frequent is first, if both counts are equal sort by character.
             return c1.getNumberOfOccur() != c2.getNumberOfOccur() ? c1.getNumberOfOccur() > c2.getNumberOfOccur() : c1.getChar() < c2.getChar();
         });
-        for (const CharOccurResult &aminoAcid : qAsConst(aminoAcidList)) {
+        for (const CharOccurResult& aminoAcid : qAsConst(aminoAcidList)) {
             aminoAcidsHtml += "<tr>";
             aminoAcidsHtml += QString("<td><b>") + aminoAcid.getChar() + QString(":&nbsp;&nbsp;</b></td>");
             aminoAcidsHtml += "<td>" + getValue(getFormattedLongNumber(aminoAcid.getNumberOfOccur()), isFinal) + "&nbsp;&nbsp;</td>";
@@ -427,38 +440,38 @@ void SequenceInfo::updateCodonsOccurrenceData(const QMap<QByteArray, qint64> &co
     }
 }
 
-void SequenceInfo::connectSlotsForSeqContext(ADVSequenceObjectContext *seqContext) {
+void SequenceInfo::connectSlotsForSeqContext(ADVSequenceObjectContext* seqContext) {
     SAFE_POINT(seqContext, "A sequence context is NULL!", );
 
     connect(seqContext->getSequenceSelection(),
-            SIGNAL(si_selectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)),
-            SLOT(sl_onSelectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)));
+            SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)),
+            SLOT(sl_onSelectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)));
 
     connect(seqContext->getAnnotationsSelection(),
-            SIGNAL(si_selectionChanged(AnnotationSelection *, const QList<Annotation *> &, const QList<Annotation *> &)),
-            SLOT(sl_onAnnotationSelectionChanged(AnnotationSelection *, const QList<Annotation *> &, const QList<Annotation *> &)));
+            SIGNAL(si_selectionChanged(AnnotationSelection*, const QList<Annotation*>&, const QList<Annotation*>&)),
+            SLOT(sl_onAnnotationSelectionChanged(AnnotationSelection*, const QList<Annotation*>&, const QList<Annotation*>&)));
 
     connect(seqContext, SIGNAL(si_aminoTranslationChanged()), SLOT(sl_onAminoTranslationChanged()));
     connect(seqContext->getSequenceObject(), SIGNAL(si_sequenceChanged()), SLOT(sl_onSequenceModified()));
 }
 
 void SequenceInfo::connectSlots() {
-    QList<ADVSequenceObjectContext *> seqContexts = annotatedDnaView->getSequenceContexts();
+    QList<ADVSequenceObjectContext*> seqContexts = annotatedDnaView->getSequenceContexts();
     SAFE_POINT(!seqContexts.empty(), "AnnotatedDNAView has no sequences contexts!", );
 
     // A sequence has been selected in the Sequence View
-    connect(annotatedDnaView, SIGNAL(si_activeSequenceWidgetChanged(ADVSequenceWidget *, ADVSequenceWidget *)), this, SLOT(sl_onActiveSequenceChanged(ADVSequenceWidget *, ADVSequenceWidget *)));
+    connect(annotatedDnaView, SIGNAL(si_activeSequenceWidgetChanged(ADVSequenceWidget*, ADVSequenceWidget*)), this, SLOT(sl_onActiveSequenceChanged(ADVSequenceWidget*, ADVSequenceWidget*)));
 
     // A sequence has been modified (a subsequence added, removed, etc.)
-    connect(annotatedDnaView, SIGNAL(si_sequenceModified(ADVSequenceObjectContext *)), this, SLOT(sl_onSequenceModified()));
+    connect(annotatedDnaView, SIGNAL(si_sequenceModified(ADVSequenceObjectContext*)), this, SLOT(sl_onSequenceModified()));
 
     // A user has selected a sequence region
-    foreach (ADVSequenceObjectContext *seqContext, seqContexts) {
+    foreach (ADVSequenceObjectContext* seqContext, seqContexts) {
         connectSlotsForSeqContext(seqContext);
     }
 
     // A sequence object has been added
-    connect(annotatedDnaView, SIGNAL(si_sequenceAdded(ADVSequenceObjectContext *)), SLOT(sl_onSequenceAdded(ADVSequenceObjectContext *)));
+    connect(annotatedDnaView, SIGNAL(si_sequenceAdded(ADVSequenceObjectContext*)), SLOT(sl_onSequenceAdded(ADVSequenceObjectContext*)));
 
     // Calculations have been finished
     connect(&charOccurTaskRunner, SIGNAL(si_finished()), SLOT(sl_updateCharOccurData()));
@@ -473,16 +486,16 @@ void SequenceInfo::connectSlots() {
     connect(aminoAcidWidget, SIGNAL(si_subgroupStateChanged(QString)), SLOT(sl_subgroupStateChanged(QString)));
 }
 
-void SequenceInfo::sl_onSelectionChanged(LRegionsSelection *,
-                                         const QVector<U2Region> & /*added*/,
-                                         const QVector<U2Region> & /*removed*/) {
+void SequenceInfo::sl_onSelectionChanged(LRegionsSelection*,
+                                         const QVector<U2Region>& /*added*/,
+                                         const QVector<U2Region>& /*removed*/) {
     getCodonsOccurrenceCache()->sl_invalidate();
     updateCurrentRegions();
     updateData();
 }
 
-void SequenceInfo::sl_onAnnotationSelectionChanged(AnnotationSelection *, const QList<Annotation *> &, const QList<Annotation *> &) {
-    ADVSequenceObjectContext *sequenceContext = annotatedDnaView->getActiveSequenceContext();
+void SequenceInfo::sl_onAnnotationSelectionChanged(AnnotationSelection*, const QList<Annotation*>&, const QList<Annotation*>&) {
+    ADVSequenceObjectContext* sequenceContext = annotatedDnaView->getActiveSequenceContext();
     if (sequenceContext == nullptr) {
         return;  // Sequence context may be null when ADV is being destroyed.
     }
@@ -502,7 +515,7 @@ void SequenceInfo::sl_onSequenceModified() {
     updateData();
 }
 
-void SequenceInfo::sl_onActiveSequenceChanged(ADVSequenceWidget * /*oldSequenceWidget*/, ADVSequenceWidget *newSequenceWidget) {
+void SequenceInfo::sl_onActiveSequenceChanged(ADVSequenceWidget* /*oldSequenceWidget*/, ADVSequenceWidget* newSequenceWidget) {
     if (newSequenceWidget != nullptr) {  // i.e. the sequence has been deleted
         updateLayout();
         updateCurrentRegions();
@@ -510,11 +523,11 @@ void SequenceInfo::sl_onActiveSequenceChanged(ADVSequenceWidget * /*oldSequenceW
     }
 }
 
-void SequenceInfo::sl_onSequenceAdded(ADVSequenceObjectContext *seqContext) {
+void SequenceInfo::sl_onSequenceAdded(ADVSequenceObjectContext* seqContext) {
     connectSlotsForSeqContext(seqContext);
 }
 
-void SequenceInfo::sl_subgroupStateChanged(const QString &subgroupId) {
+void SequenceInfo::sl_subgroupStateChanged(const QString& subgroupId) {
     if (subgroupId == STAT_GROUP_ID) {
         updateCommonStatisticsData();
     } else if (subgroupId == CHAR_OCCUR_GROUP_ID) {
@@ -526,18 +539,29 @@ void SequenceInfo::sl_subgroupStateChanged(const QString &subgroupId) {
     }
 }
 
-bool SequenceInfo::eventFilter(QObject *object, QEvent *event) {
+bool SequenceInfo::eventFilter(QObject* object, QEvent* event) {
     if (event->type() == QEvent::Resize && object == statisticLabel) {
         updateCommonStatisticsData();
     }
     return false;
 }
 
-void SequenceInfo::updateCurrentRegions() {
-    ADVSequenceObjectContext *seqContext = annotatedDnaView->getActiveSequenceContext();
-    SAFE_POINT(0 != seqContext, "A sequence context is NULL!", );
+void SequenceInfo::statisticLabelLinkActivated(const QString& link) {
+    if (link == captionSeqMeltingTemperature) {
+        QObjectScopedPointer<TmCalculatorSelectorDialog> dialog(new TmCalculatorSelectorDialog(annotatedDnaView->getActiveSequenceWidget(), temperatureCalculator->getSettings()));
+        int res = dialog->exec();
+        CHECK(!dialog.isNull() && res == QDialog::Accepted, );
 
-    DNASequenceSelection *selection = seqContext->getSequenceSelection();
+        temperatureCalculator = dialog->createTemperatureCalculator();
+        updateCommonStatisticsData(true);
+    }
+}
+
+void SequenceInfo::updateCurrentRegions() {
+    ADVSequenceObjectContext* seqContext = annotatedDnaView->getActiveSequenceContext();
+    SAFE_POINT(seqContext != nullptr, "A sequence context is NULL!", );
+
+    DNASequenceSelection* selection = seqContext->getSequenceSelection();
 
     QVector<U2Region> selectedRegions = selection->getSelectedRegions();
     if (!selectedRegions.empty()) {
@@ -548,15 +572,15 @@ void SequenceInfo::updateCurrentRegions() {
     }
 }
 
-void SequenceInfo::launchCalculations(const QString &subgroupId) {
+void SequenceInfo::launchCalculations(const QString& subgroupId) {
     // Launch the statistics, characters and dinucleotides calculation tasks,
     // if corresponding groups are present and opened
-    ADVSequenceObjectContext *activeContext = annotatedDnaView->getActiveSequenceContext();
+    ADVSequenceObjectContext* activeContext = annotatedDnaView->getActiveSequenceContext();
     SAFE_POINT(activeContext != nullptr, "A sequence context is NULL!", );
 
-    U2SequenceObject *seqObj = activeContext->getSequenceObject();
+    U2SequenceObject* seqObj = activeContext->getSequenceObject();
     U2EntityRef seqRef = seqObj->getSequenceRef();
-    const DNAAlphabet *alphabet = activeContext->getAlphabet();
+    const DNAAlphabet* alphabet = activeContext->getAlphabet();
 
     if (subgroupId.isEmpty() || subgroupId == CHAR_OCCUR_GROUP_ID) {
         if (!charOccurWidget->isHidden() && charOccurWidget->isSubgroupOpened()) {
@@ -577,7 +601,7 @@ void SequenceInfo::launchCalculations(const QString &subgroupId) {
     }
 
     if (subgroupId.isEmpty() || subgroupId == CODON_OCCUR_GROUP_ID || subgroupId == AMINO_ACID_OCCUR_GROUP_ID) {
-        bool isCodonReportOpened = codonWidget->isVisible() && codonWidget->isSubgroupOpened();
+        bool isCodonReportOpened = activeContext->getAlphabet()->isNucleic() && codonWidget->isSubgroupOpened();
         bool isAminoAcidReportOpened = aminoAcidWidget->isVisible() && aminoAcidWidget->isSubgroupOpened();
         if (isCodonReportOpened || isAminoAcidReportOpened) {
             if (isCodonReportOpened) {
@@ -586,9 +610,9 @@ void SequenceInfo::launchCalculations(const QString &subgroupId) {
             if (isAminoAcidReportOpened) {
                 aminoAcidWidget->showProgress();
             }
-            DNATranslation *complementTranslation = activeContext->getComplementTT();
-            AnnotationSelection *annotationSelection = activeContext->getAnnotationsSelection();
-            DNASequenceSelection *sequenceSelection = activeContext->getSequenceSelection();
+            DNATranslation* complementTranslation = activeContext->getComplementTT();
+            AnnotationSelection* annotationSelection = activeContext->getAnnotationsSelection();
+            DNASequenceSelection* sequenceSelection = activeContext->getSequenceSelection();
             auto task = !annotationSelection->isEmpty()
                             ? new CodonOccurTask(complementTranslation, seqRef, annotationSelection->getAnnotations())
                             : (!sequenceSelection->isEmpty()
@@ -603,7 +627,7 @@ void SequenceInfo::launchCalculations(const QString &subgroupId) {
     if (subgroupId.isEmpty() || subgroupId == STAT_GROUP_ID) {
         if ((!statsWidget->isHidden()) && (statsWidget->isSubgroupOpened())) {
             statsWidget->showProgress();
-            dnaStatisticsTaskRunner.run(new DNAStatisticsTask(alphabet, seqRef, currentRegions));
+            dnaStatisticsTaskRunner.run(new DNAStatisticsTask(alphabet, seqRef, currentRegions, temperatureCalculator));
             getCommonStatisticsCache()->sl_invalidate();
             updateCommonStatisticsData(getCommonStatisticsCache()->getStatistics());
         }
@@ -614,29 +638,29 @@ int SequenceInfo::getAvailableSpace(DNAAlphabetType alphabetType) const {
     QStringList captions;
     switch (alphabetType) {
         case DNAAlphabet_NUCL:
-            captions << CAPTION_SEQ_REGION_LENGTH
-                     << CAPTION_SEQ_GC_CONTENT
-                     << CAPTION_SEQ_MELTING_TEMPERATURE
-                     << QString("    ") + CAPTION_SEQ_NUCL_MOLECULAR_WEIGHT
-                     << QString("    ") + CAPTION_SEQ_EXTINCTION_COEFFICIENT;
+            captions << captionSeqRegionLength
+                     << captionSeqGcContent
+                     << captionSeqMeltingTemperature
+                     << QString("    ") + captionSeqMolecularWeight
+                     << QString("    ") + captionSeqExtinctionCoefficient;
             // Two captions are ignored because of HTML tags within them
             //                 << CAPTION_SEQ_NMOLE_OD
             //                 << CAPTION_SEQ_MG_OD;
             break;
         case DNAAlphabet_AMINO:
-            captions << CAPTION_SEQ_REGION_LENGTH
-                     << CAPTION_SEQ_AMINO_MOLECULAR_WEIGHT
-                     << CAPTION_SEQ_ISOELECTIC_POINT;
+            captions << captionSeqRegionLength
+                     << captionSeqMolecularWeight
+                     << captionSeqIsoelecticPoint;
             break;
         default:
-            captions << CAPTION_SEQ_REGION_LENGTH;
+            captions << captionSeqRegionLength;
             break;
     }
 
     QFontMetrics fontMetrics(statisticLabel->font());
 
     int availableSize = INT_MAX;
-    foreach (const QString &caption, captions) {
+    foreach (const QString& caption, captions) {
         availableSize = qMin(availableSize, statisticLabel->width() - fontMetrics.boundingRect(caption).width() - 3 * COMMON_STATISTICS_TABLE_CELLSPACING);
     }
 
@@ -668,34 +692,40 @@ void SequenceInfo::sl_updateCodonOccurData() {
     updateCodonsOccurrenceData(getCodonsOccurrenceCache()->getStatistics());
 }
 
-QString SequenceInfo::formTableRow(const QString &caption, const QString &value, int availableSpace) const {
+QString SequenceInfo::formTableRow(const QString& caption, const QString& value, int availableSpace, bool addSettingsButton) const {
     QString result;
 
     QFontMetrics metrics = statisticLabel->fontMetrics();
-    result = "<tr><td>" + tr("%1").arg(caption) + "</td><td>" + metrics.elidedText(value, Qt::ElideRight, availableSpace) + "</td></tr>";
+    QString settingsLink;
+    if (addSettingsButton) {
+        settingsLink = QString(R"(&nbsp;&nbsp;<a href="%1"><img src=":core/images/gear.svg" width=16 height=16;"></a>)")
+                           .arg(caption);
+    }
+    result = "<tr><td>" + tr("%1").arg(caption) + ": </td><td" + (addSettingsButton ? " style=\"vertical-align:top;\">" : ">") +
+             metrics.elidedText(value, Qt::ElideRight, availableSpace) + settingsLink + "</td></tr>";
     return result;
 }
 
-StatisticsCache<DNAStatistics> *SequenceInfo::getCommonStatisticsCache() const {
-    ADVSequenceObjectContext *sequenceContext = annotatedDnaView->getActiveSequenceContext();
+StatisticsCache<DNAStatistics>* SequenceInfo::getCommonStatisticsCache() const {
+    ADVSequenceObjectContext* sequenceContext = annotatedDnaView->getActiveSequenceContext();
     SAFE_POINT(sequenceContext != nullptr, "A sequence context is NULL!", nullptr);
     return sequenceContext->getCommonStatisticsCache();
 }
 
-StatisticsCache<CharactersOccurrence> *SequenceInfo::getCharactersOccurrenceCache() const {
-    ADVSequenceObjectContext *sequenceContext = annotatedDnaView->getActiveSequenceContext();
+StatisticsCache<CharactersOccurrence>* SequenceInfo::getCharactersOccurrenceCache() const {
+    ADVSequenceObjectContext* sequenceContext = annotatedDnaView->getActiveSequenceContext();
     SAFE_POINT(sequenceContext != nullptr, "A sequence context is NULL!", nullptr);
     return sequenceContext->getCharactersOccurrenceCache();
 }
 
-StatisticsCache<DinucleotidesOccurrence> *SequenceInfo::getDinucleotidesOccurrenceCache() const {
-    ADVSequenceObjectContext *sequenceContext = annotatedDnaView->getActiveSequenceContext();
+StatisticsCache<DinucleotidesOccurrence>* SequenceInfo::getDinucleotidesOccurrenceCache() const {
+    ADVSequenceObjectContext* sequenceContext = annotatedDnaView->getActiveSequenceContext();
     SAFE_POINT(sequenceContext != nullptr, "A sequence context is NULL!", nullptr);
     return sequenceContext->getDinucleotidesOccurrenceCache();
 }
 
-StatisticsCache<QMap<QByteArray, qint64>> *SequenceInfo::getCodonsOccurrenceCache() const {
-    ADVSequenceObjectContext *sequenceContext = annotatedDnaView->getActiveSequenceContext();
+StatisticsCache<QMap<QByteArray, qint64>>* SequenceInfo::getCodonsOccurrenceCache() const {
+    ADVSequenceObjectContext* sequenceContext = annotatedDnaView->getActiveSequenceContext();
     SAFE_POINT(sequenceContext != nullptr, "A sequence context is NULL!", nullptr);
     return sequenceContext->getCodonsOccurrenceCache();
 }
