@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,9 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_INFO_H_
-#define _U2_SEQUENCE_INFO_H_
+#pragma once
 
+#include <QSharedPointer>
 #include <QWidget>
 
 #include <U2Core/BackgroundTaskRunner.h>
@@ -41,6 +41,7 @@ namespace U2 {
 class ADVSequenceObjectContext;
 class ADVSequenceWidget;
 class AnnotatedDNAView;
+class TmCalculator;
 class LRegionsSelection;
 class ShowHideSubgroupWidget;
 class AnnotationSelection;
@@ -49,21 +50,22 @@ class Annotation;
 class U2VIEW_EXPORT SequenceInfo : public QWidget {
     Q_OBJECT
 public:
-    SequenceInfo(AnnotatedDNAView *);
+    SequenceInfo(AnnotatedDNAView*);
+    ~SequenceInfo();
 
 private slots:
-    void sl_onSelectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &);
-    void sl_onAnnotationSelectionChanged(AnnotationSelection *, const QList<Annotation *> &, const QList<Annotation *> &);
+    void sl_onSelectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&);
+    void sl_onAnnotationSelectionChanged(AnnotationSelection*, const QList<Annotation*>&, const QList<Annotation*>&);
     void sl_onAminoTranslationChanged();
 
     /** Updates sequence info to match active sequence. */
-    void sl_onActiveSequenceChanged(ADVSequenceWidget *oldSequenceWidget, ADVSequenceWidget *newSequenceWidget);
+    void sl_onActiveSequenceChanged(ADVSequenceWidget* oldSequenceWidget, ADVSequenceWidget* newSequenceWidget);
 
     /** A sequence part was added, removed or replaced */
     void sl_onSequenceModified();
 
     /** A sequence object has been added */
-    void sl_onSequenceAdded(ADVSequenceObjectContext *);
+    void sl_onSequenceAdded(ADVSequenceObjectContext*);
 
     /** Update calculated info */
     void sl_updateCharOccurData();
@@ -72,9 +74,11 @@ private slots:
     void sl_updateStatData();
 
     /** A subgroup (e.g. characters occurrence subgroup) has been opened/closed */
-    void sl_subgroupStateChanged(const QString &subgroupId);
+    void sl_subgroupStateChanged(const QString& subgroupId);
 
-    bool eventFilter(QObject *object, QEvent *event);
+    bool eventFilter(QObject* object, QEvent* event);
+
+    void statisticLabelLinkActivated(const QString& link);
 
 private:
     /** Initializes the whole layout of the widget */
@@ -87,21 +91,21 @@ private:
     void updateCodonOccurLayout();
 
     void updateData();
-    void updateCommonStatisticsData();
-    void updateCommonStatisticsData(const DNAStatistics &commonStatistics);
+    void updateCommonStatisticsData(bool forceUpdate = false);
+    void updateCommonStatisticsData(const DNAStatistics& commonStatistics);
     void updateCharactersOccurrenceData();
-    void updateCharactersOccurrenceData(const CharactersOccurrence &charactersOccurrence);
+    void updateCharactersOccurrenceData(const CharactersOccurrence& charactersOccurrence);
     void updateDinucleotidesOccurrenceData();
-    void updateDinucleotidesOccurrenceData(const DinucleotidesOccurrence &dinucleotidesOccurrence);
+    void updateDinucleotidesOccurrenceData(const DinucleotidesOccurrence& dinucleotidesOccurrence);
 
     /** Updates codon occurrence data from cache if available or re-launch the update task if the cached data does not match current selection state. */
     void updateCodonsOccurrenceData();
 
     /** Updates codon occurrence label from the 'codonStatList'. */
-    void updateCodonsOccurrenceData(const QMap<QByteArray, qint64> &codonStatsMap);
+    void updateCodonsOccurrenceData(const QMap<QByteArray, qint64>& codonStatsMap);
 
     /**  Listen when something has been changed in the AnnotatedDNAView or in the Options Panel */
-    void connectSlotsForSeqContext(ADVSequenceObjectContext *);
+    void connectSlotsForSeqContext(ADVSequenceObjectContext*);
     void connectSlots();
 
     /**
@@ -117,71 +121,56 @@ private:
      * The subgroupId parameter is used to skip unnecessary calculation when a subgroup signal has come.
      * Empty subgroupId means that the signal has come from other place and all required calculation should be re-done.
      */
-    void launchCalculations(const QString &subgroupId = "");
+    void launchCalculations(const QString& subgroupId = "");
 
     int getAvailableSpace(DNAAlphabetType alphabetType) const;
 
-    QString formTableRow(const QString &caption, const QString &value, int availableSpace) const;
+    QString formTableRow(const QString& caption, const QString& value, int availableSpace, bool addSettingsButton = false) const;
 
-    StatisticsCache<DNAStatistics> *getCommonStatisticsCache() const;
-    StatisticsCache<CharactersOccurrence> *getCharactersOccurrenceCache() const;
-    StatisticsCache<DinucleotidesOccurrence> *getDinucleotidesOccurrenceCache() const;
-    StatisticsCache<QMap<QByteArray, qint64>> *getCodonsOccurrenceCache() const;
+    StatisticsCache<DNAStatistics>* getCommonStatisticsCache() const;
+    StatisticsCache<CharactersOccurrence>* getCharactersOccurrenceCache() const;
+    StatisticsCache<DinucleotidesOccurrence>* getDinucleotidesOccurrenceCache() const;
+    StatisticsCache<QMap<QByteArray, qint64>>* getCodonsOccurrenceCache() const;
 
-    AnnotatedDNAView *annotatedDnaView;
+    QPointer<AnnotatedDNAView> annotatedDnaView;
+    // This field is required because we need to save some settings in the destructor,
+    // but @annotatedDnaView is dead up to this time
+    QString annotatedDnaViewName;
 
-    ShowHideSubgroupWidget *statsWidget = nullptr;
-    QLabel *statisticLabel = nullptr;
+    ShowHideSubgroupWidget* statsWidget = nullptr;
+    QLabel* statisticLabel = nullptr;
     BackgroundTaskRunner<DNAStatistics> dnaStatisticsTaskRunner;
     DNAStatistics currentCommonStatistics;
 
-    ShowHideSubgroupWidget *charOccurWidget = nullptr;
-    QLabel *charOccurLabel = nullptr;
+    ShowHideSubgroupWidget* charOccurWidget = nullptr;
+    QLabel* charOccurLabel = nullptr;
     BackgroundTaskRunner<CharactersOccurrence> charOccurTaskRunner;
 
-    ShowHideSubgroupWidget *dinuclWidget = nullptr;
-    QLabel *dinuclLabel = nullptr;
+    ShowHideSubgroupWidget* dinuclWidget = nullptr;
+    QLabel* dinuclLabel = nullptr;
     BackgroundTaskRunner<DinucleotidesOccurrence> dinuclTaskRunner;
 
-    ShowHideSubgroupWidget *codonWidget = nullptr;
-    QLabel *codonLabel = nullptr;
+    ShowHideSubgroupWidget* codonWidget = nullptr;
+    QLabel* codonLabel = nullptr;
     BackgroundTaskRunner<QMap<QByteArray, qint64>> codonTaskRunner;
 
-    ShowHideSubgroupWidget *aminoAcidWidget = nullptr;
-    QLabel *aminoAcidLabel = nullptr;
+    ShowHideSubgroupWidget* aminoAcidWidget = nullptr;
+    QLabel* aminoAcidLabel = nullptr;
 
     QVector<U2Region> currentRegions;
 
     U2SavableWidget savableWidget;
 
-    static const int COMMON_STATISTICS_TABLE_CELLSPACING;
-    static const QString CAPTION_SEQ_REGION_LENGTH;
+    QSharedPointer<TmCalculator> temperatureCalculator;
 
-    static const QString CAPTION_SUFFIX_DS_DNA;
-    static const QString CAPTION_SUFFIX_SS_DNA;
-    static const QString CAPTION_SUFFIX_DS_RNA;
-    static const QString CAPTION_SUFFIX_SS_RNA;
+    const QString captionSeqRegionLength;
+    const QString captionSeqGcContent;
+    const QString captionSeqMolecularWeight;
+    const QString captionSeqExtinctionCoefficient;
+    const QString captionSeqMeltingTemperature;
+    const QString captionSeqIsoelecticPoint;
 
-    // nucl
-    static const QString CAPTION_SEQ_GC_CONTENT;
-    static const QString CAPTION_SEQ_NUCL_MOLECULAR_WEIGHT;
-    static const QString CAPTION_SEQ_EXTINCTION_COEFFICIENT;
-    static const QString CAPTION_SEQ_MELTING_TEMPERATURE;
 
-    static const QString CAPTION_SEQ_NMOLE_OD;
-    static const QString CAPTION_SEQ_MG_OD;
-
-    // amino
-    static const QString CAPTION_SEQ_AMINO_MOLECULAR_WEIGHT;
-    static const QString CAPTION_SEQ_ISOELECTIC_POINT;
-
-    static const QString CHAR_OCCUR_GROUP_ID;
-    static const QString DINUCL_OCCUR_GROUP_ID;
-    static const QString CODON_OCCUR_GROUP_ID;
-    static const QString AMINO_ACID_OCCUR_GROUP_ID;
-    static const QString STAT_GROUP_ID;
 };
 
 }  // namespace U2
-
-#endif
