@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_STATISTICS_CACHE_H_
-#define _U2_STATISTICS_CACHE_H_
+#pragma once
 
 #include <U2Core/U2Region.h>
 
@@ -37,10 +36,10 @@ class StatisticsCache : public StatisticsCacheBase {
 public:
     StatisticsCache();
 
-    const T &getStatistics() const;
-    void setStatistics(const T &statistics, const QVector<U2Region> &regions);
+    const T& getStatistics() const;
+    void setStatistics(const T& statistics, const QVector<U2Region>& regions);
 
-    bool isValid(const QVector<U2Region> &regionsToMatch) const;
+    bool isValid(const QVector<U2Region>& regionsToMatch) const;
 
     void sl_invalidate();
 
@@ -56,19 +55,19 @@ StatisticsCache<T>::StatisticsCache()
 }
 
 template<class T>
-const T &StatisticsCache<T>::getStatistics() const {
+const T& StatisticsCache<T>::getStatistics() const {
     return statistics;
 }
 
 template<class T>
-void StatisticsCache<T>::setStatistics(const T &newStatistics, const QVector<U2Region> &newRegions) {
+void StatisticsCache<T>::setStatistics(const T& newStatistics, const QVector<U2Region>& newRegions) {
     statistics = newStatistics;
     regions = newRegions;
     valid = true;
 }
 
 template<class T>
-bool StatisticsCache<T>::isValid(const QVector<U2Region> &regionsToMatch) const {
+bool StatisticsCache<T>::isValid(const QVector<U2Region>& regionsToMatch) const {
     return regions == regionsToMatch && valid;
 }
 
@@ -78,5 +77,3 @@ void StatisticsCache<T>::sl_invalidate() {
 }
 
 }  // namespace U2
-
-#endif  // _U2_STATISTICS_CACHE_H_
