@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -80,7 +80,7 @@ const int SequenceViewAnnotatedRenderer::CUT_SITE_HALF_HEIGHT = 2;
 
 const int SequenceViewAnnotatedRenderer::MAX_VIRTUAL_RANGE = 10000;
 
-SequenceViewAnnotatedRenderer::SequenceViewAnnotatedRenderer(SequenceObjectContext *ctx)
+SequenceViewAnnotatedRenderer::SequenceViewAnnotatedRenderer(SequenceObjectContext* ctx)
     : SequenceViewRenderer(ctx) {
 }
 
@@ -89,7 +89,7 @@ SequenceViewAnnotatedRenderer::SequenceViewAnnotatedRenderer(SequenceObjectConte
 
 #define MAX_CUTSITE_DISTANCE 100
 
-void SequenceViewAnnotatedRenderer::drawAnnotations(QPainter &p, const QSize &canvasSize, const U2Region &visibleRange, const AnnotationDisplaySettings &displaySettings) {
+void SequenceViewAnnotatedRenderer::drawAnnotations(QPainter& p, const QSize& canvasSize, const U2Region& visibleRange, const AnnotationDisplaySettings& displaySettings) {
     GTIMER(c1, t1, "SequenceViewAnnotatedRenderer::drawAnnotations");
     U2Region annotationsRange = visibleRange;
     QList<U2Region> extraAnnotationRegions;
@@ -105,9 +105,10 @@ void SequenceViewAnnotatedRenderer::drawAnnotations(QPainter &p, const QSize &ca
             extraAnnotationRegions << U2Region(0, headLength);
         }
     }
-    const QSet<AnnotationTableObject *> annotationObjectSet = ctx->getAnnotationObjects(true);
-    for (const AnnotationTableObject *annotationObject : qAsConst(annotationObjectSet)) {
-        for (Annotation *annotation : annotationObject->getAnnotations()) {
+    QSet<AnnotationTableObject*> annotationObjectSet = ctx->getAnnotationObjects(true);
+    for (const AnnotationTableObject* annotationObject : qAsConst(annotationObjectSet)) {
+        const QList<Annotation*>& annotations = annotationObject->getAnnotations();
+        for (Annotation* annotation : qAsConst(annotations)) {
             bool isVisible = annotationsRange.intersects(annotation->getRegions());
             for (int i = 0; i < extraAnnotationRegions.size() && !isVisible; i++) {
                 isVisible = extraAnnotationRegions[i].intersects(annotation->getRegions());
@@ -119,20 +120,20 @@ void SequenceViewAnnotatedRenderer::drawAnnotations(QPainter &p, const QSize &ca
     }
 }
 
-void SequenceViewAnnotatedRenderer::drawAnnotationSelection(QPainter &p, const QSize &canvasSize, const U2Region &visibleRange, const AnnotationDisplaySettings &displaySettings) {
-    const AnnotationSelection *selection = ctx->getAnnotationsSelection();
-    for (Annotation *annotation : qAsConst(selection->getAnnotations())) {
-        AnnotationTableObject *o = annotation->getGObject();
+void SequenceViewAnnotatedRenderer::drawAnnotationSelection(QPainter& p, const QSize& canvasSize, const U2Region& visibleRange, const AnnotationDisplaySettings& displaySettings) {
+    const AnnotationSelection* selection = ctx->getAnnotationsSelection();
+    for (Annotation* annotation : qAsConst(selection->getAnnotations())) {
+        AnnotationTableObject* o = annotation->getGObject();
         if (ctx->getAnnotationObjects(true).contains(o)) {
             drawAnnotation(p, canvasSize, visibleRange, annotation, displaySettings, true);
         }
     }
 }
 
-void SequenceViewAnnotatedRenderer::drawAnnotation(QPainter &p, const QSize &canvasSize, const U2Region &visibleRange, Annotation *a, const AnnotationDisplaySettings &displaySettings, bool selected, const AnnotationSettings *as) {
-    const SharedAnnotationData &aData = a->getData();
+void SequenceViewAnnotatedRenderer::drawAnnotation(QPainter& p, const QSize& canvasSize, const U2Region& visibleRange, Annotation* a, const AnnotationDisplaySettings& displaySettings, bool selected, const AnnotationSettings* as) {
+    const SharedAnnotationData& aData = a->getData();
     if (as == nullptr) {
-        AnnotationSettingsRegistry *asr = AppContext::getAnnotationsSettingsRegistry();
+        AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
         as = asr->getAnnotationSettings(aData);
     }
     CHECK(as->visible, );
@@ -142,37 +143,25 @@ void SequenceViewAnnotatedRenderer::drawAnnotation(QPainter &p, const QSize &can
 
     const bool isRestrictionSite = a->getType() == U2FeatureTypes::RestrictionSite;
     QVector<U2Region> location = aData->getRegions();
-    bool simple = location.size() == 1;
-    int availableHeight = canvasSize.height();
     for (int ri = 0, ln = location.size(); ri < ln; ri++) {
-        const U2Region &r = location.at(ri);
+        const U2Region& r = location.at(ri);
         if (r.intersects(visibleRange)) {
-            const U2Region visibleLocation = r.intersect(visibleRange);
-            const U2Region y = getAnnotationYRange(a, ri, as, availableHeight);
-            if (y.startPos < 0) {
-                continue;
-            }
+            const QRect annotationRect = getAnnotationRect(r, canvasSize, visibleRange, selected, a, as);
+            CHECK_CONTINUE(!annotationRect.isEmpty());
 
-            const int x1 = posToXCoord(visibleLocation.startPos, canvasSize, visibleRange);
-            const int x2 = posToXCoord(visibleLocation.endPos(), canvasSize, visibleRange);
-
-            const int rw = qMax(selected ? MIN_SELECTED_ANNOTATION_WIDTH : MIN_ANNOTATION_WIDTH, x2 - x1);
-            SAFE_POINT(rw > 0, "Negative length of annotationYRange", );
-
-            // annotation rect setting
-            const QRect annotationRect(x1, y.startPos, rw, y.length);
             QPainterPath rectPath;
-            rectPath.addRect(x1, y.startPos, rw, y.length);
+            rectPath.addRect(annotationRect.x(), annotationRect.y(), annotationRect.width(), annotationRect.height());
             // find out if the arrow is needed
+            const U2Region visibleLocation = r.intersect(visibleRange);
             const bool leftTrim = visibleLocation.startPos != r.startPos;
             const bool rightTrim = visibleLocation.endPos() != r.endPos();
-            const bool drawArrow = aData->getStrand().isCompementary() ? !leftTrim : !rightTrim;
+            const bool drawArrow = aData->getStrand().isComplementary() ? !leftTrim : !rightTrim;
             if (displaySettings.displayAnnotationArrows && drawArrow) {
                 bool isLeft = false;
                 if (1 == ri && aData->findFirstQualifierValue("rpt_type") == "inverted") {  // temporary solution for drawing inverted repeats correct
                     isLeft = true;
                 } else {
-                    isLeft = aData->getStrand().isCompementary();
+                    isLeft = aData->getStrand().isComplementary();
                 }
                 addArrowPath(rectPath, annotationRect, isLeft);
             }
@@ -182,27 +171,76 @@ void SequenceViewAnnotatedRenderer::drawAnnotation(QPainter &p, const QSize &can
             p.fillPath(rectPath, annMetrics.gradientMaskBrush);
 
             p.setPen(borderPen);
-            if (rw > MIN_ANNOTATION_WIDTH) {
+            if (annotationRect.width() > MIN_ANNOTATION_WIDTH) {
                 p.drawPath(rectPath);
                 if (displaySettings.displayAnnotationNames && annotationRect.width() >= MIN_ANNOTATION_TEXT_WIDTH) {
                     const QString aText = prepareAnnotationText(aData, as);
                     drawBoundedText(p, annotationRect, aText);
                 }
-                if (simple &&
-                    annotationRect.width() > MIN_WIDTH_TO_DRAW_EXTRA_FEATURES &&
-                    displaySettings.displayCutSites) {
-                    drawCutSite(p, aData, r, annotationRect, as->color, canvasSize, visibleRange);
-                }
             }
             drawAnnotationConnections(p, a, as, displaySettings, canvasSize, visibleRange);
-        } else if (isRestrictionSite && simple && displaySettings.displayCutSites) {
-            p.setPen(borderPen);
-            drawCutSite(p, aData, r, QRect(), as->color, canvasSize, visibleRange);
+        }
+    }
+    // draw restriction sites
+    if (isRestrictionSite && displaySettings.displayCutSites) {
+        p.setPen(borderPen);
+        const bool isCircular = ctx->getSequenceObject()->isCircular();
+        qint64 seqLength = ctx->getSequenceLength();
+        bool isDirectStrand = aData->getStrand().isDirect();
+        const auto& qual = aData->findFirstQualifierValue(GBFeatureUtils::QUALIFIER_CUT);
+        if (isCircular && U1AnnotationUtils::isAnnotationContainsJunctionPoint(a, seqLength)) {
+            auto merged = U1AnnotationUtils::mergeAnnotatedRegionsAroundJunctionPoint(location, seqLength);
+            auto regionPair = merged.front();
+            // draw cuts separately,
+            // because they are located one on the 3' end of the direct sequence,
+            // and the other one on the 3' end of reverse-complementary sequence
+            // draw direct cut
+            auto cutPosDirect = getCutPosition(regionPair.first, qual, isDirectStrand, true);
+            if (cutPosDirect != INCORRECT_CUT_POSITION) {
+                auto annRect = getAnnotationRect(regionPair.first, canvasSize, visibleRange, selected, a, as);
+                drawCutSite(p, aData, cutPosDirect, annRect, as->color, canvasSize, visibleRange, true);
+            }
+            // draw complement cut
+            auto cutPosComplement = getCutPosition(regionPair.second, qual, isDirectStrand, false);
+            if (cutPosComplement != INCORRECT_CUT_POSITION) {
+                auto annRect = getAnnotationRect(regionPair.second, canvasSize, visibleRange, selected, a, as);
+                drawCutSite(p, aData, cutPosComplement, annRect, as->color, canvasSize, visibleRange, false);
+            }
+        } else if (location.size() == 1) {
+            const auto& reg = location.first();
+            QRect annRect;
+            // draw direct cut
+            auto cutPosDirect = getCutPosition(reg, qual, isDirectStrand, true);
+            if (cutPosDirect != INCORRECT_CUT_POSITION) {
+                annRect = getAnnotationRect(reg, canvasSize, visibleRange, selected, a, as);
+                drawCutSite(p, aData, cutPosDirect, annRect, as->color, canvasSize, visibleRange, true);
+            }
+            // draw complement cut
+            auto cutPosComplement = getCutPosition(reg, qual, isDirectStrand, false);
+            if (cutPosComplement != INCORRECT_CUT_POSITION) {
+                if (annRect.isEmpty()) {
+                    annRect = getAnnotationRect(reg, canvasSize, visibleRange, selected, a, as);
+                }
+                drawCutSite(p, aData, cutPosComplement, annRect, as->color, canvasSize, visibleRange, false);
+            }
         }
     }
 }
 
-void SequenceViewAnnotatedRenderer::drawBoundedText(QPainter &p, const QRect &r, const QString &text) {
+U2Region SequenceViewAnnotatedRenderer::getAnnotationXRange(const U2Region& annotationRegion, const U2Region& visibleRange, const QSize& canvasSize, bool selected) const {
+    const U2Region visibleLocation = annotationRegion.intersect(visibleRange);
+    CHECK(!visibleLocation.isEmpty(), U2Region());
+
+    const int visibleLocationStartCoord = posToXCoord(visibleLocation.startPos, canvasSize, visibleRange);
+    const int visibleLocationEndCoord = posToXCoord(visibleLocation.endPos(), canvasSize, visibleRange);
+    
+    const int visibleRegionWidth = qMax(selected ? MIN_SELECTED_ANNOTATION_WIDTH : MIN_ANNOTATION_WIDTH, visibleLocationEndCoord - visibleLocationStartCoord);
+    SAFE_POINT(visibleRegionWidth > 0, "Negative length of annotationXRange", U2Region());
+
+    return U2Region(visibleLocationStartCoord, visibleRegionWidth);
+}
+
+void SequenceViewAnnotatedRenderer::drawBoundedText(QPainter& p, const QRect& r, const QString& text) {
     if (annMetrics.afSmallCharWidth > r.width()) {
         return;
     }
@@ -231,8 +269,51 @@ void SequenceViewAnnotatedRenderer::drawBoundedText(QPainter &p, const QRect &r,
     p.drawText(r, Qt::TextSingleLine | Qt::AlignCenter, text.left(prefixLen));
 }
 
-void SequenceViewAnnotatedRenderer::drawAnnotationConnections(QPainter &p, Annotation *a, const AnnotationSettings *as, const AnnotationDisplaySettings &displaySettings, const QSize &canvasSize, const U2Region &visibleRange) {
-    const SharedAnnotationData &aData = a->getData();
+int SequenceViewAnnotatedRenderer::getCutPosition(const U2Region& r, const QString& cutQual, bool isAnnotationDirect, bool isCutDirect) const {
+    bool hasDirect = false;
+    bool hasComplement = false;
+    int cutDirectShift = 0;
+    int cutComplementShift = 0;
+    if (!cutQual.isEmpty()) {
+        int complSplit = cutQual.indexOf('/');
+        if (complSplit  != -1) {
+            cutDirectShift = cutQual.left(complSplit).toInt(&hasDirect);
+            cutComplementShift = cutQual.mid(complSplit + 1).toInt(&hasComplement);
+        } else {
+            cutDirectShift = cutQual.toInt(&hasDirect);
+            cutComplementShift = cutQual.toInt(&hasComplement);
+        }
+    }
+
+    int cutPosition = INCORRECT_CUT_POSITION;
+    if (isCutDirect && hasDirect) {
+        cutPosition = correctCutPos(isAnnotationDirect ? r.startPos + cutDirectShift : r.startPos + cutComplementShift);
+    } else if (!isCutDirect && hasComplement) {
+        cutPosition = correctCutPos(isAnnotationDirect ? r.endPos() - cutComplementShift : r.endPos() - cutDirectShift);
+    }
+
+    return cutPosition;
+}
+
+QRect SequenceViewAnnotatedRenderer::getAnnotationRect(const U2Region& reg, const QSize& canvasSize, const U2Region& visibleRange, bool selected, Annotation* a, const AnnotationSettings* as) const {
+    QRect res;
+    const U2Region y = getAnnotationYRange(a, 0, as, canvasSize.height());
+    CHECK(y.startPos >= 0, res);
+
+    if (reg.intersects(visibleRange)) {
+        const U2Region x = getAnnotationXRange(reg, visibleRange, canvasSize, selected);
+        CHECK(!x.isEmpty(), res);
+
+        res = QRect(x.startPos, y.startPos, x.length, y.length);
+    } else {
+        res = QRect(0, y.startPos, 0, y.length);
+    }
+
+    return res;
+}
+
+void SequenceViewAnnotatedRenderer::drawAnnotationConnections(QPainter& p, Annotation* a, const AnnotationSettings* as, const AnnotationDisplaySettings& displaySettings, const QSize& canvasSize, const U2Region& visibleRange) {
+    const SharedAnnotationData& aData = a->getData();
     CHECK(!aData->location->isSingleRegion(), );
 
     const qint64 seqLength = ctx->getSequenceLength();
@@ -244,7 +325,7 @@ void SequenceViewAnnotatedRenderer::drawAnnotationConnections(QPainter &p, Annot
     int dx1 = 0;
     int dx2 = 0;
     if (displaySettings.displayAnnotationArrows) {
-        if (aData->getStrand().isCompementary()) {
+        if (aData->getStrand().isComplementary()) {
             dx2 = -FEATURE_ARROW_HLEN;
         } else {
             dx1 = FEATURE_ARROW_HLEN;
@@ -253,7 +334,7 @@ void SequenceViewAnnotatedRenderer::drawAnnotationConnections(QPainter &p, Annot
     int availableHeight = canvasSize.height();
     QVector<U2Region> location = aData->getRegions();
     for (int ri = 0, ln = location.size(); ri < ln; ri++) {
-        const U2Region &r = location.at(ri);
+        const U2Region& r = location.at(ri);
         if (ri > 0) {
             U2Region prev = location.at(ri - 1);
             const int prevPos = prev.endPos();
@@ -288,25 +369,7 @@ void SequenceViewAnnotatedRenderer::drawAnnotationConnections(QPainter &p, Annot
     }
 }
 
-void SequenceViewAnnotatedRenderer::drawCutSite(QPainter &p, const SharedAnnotationData &aData, const U2Region &r, const QRect &annotationRect, const QColor &color, const QSize &canvasSize, const U2Region &visibleRange) {
-    const QString cutStr = aData->findFirstQualifierValue(GBFeatureUtils::QUALIFIER_CUT);
-    bool hasD = false;
-    bool hasC = false;
-    int cutD = 0;
-    int cutC = 0;
-    if (!cutStr.isEmpty()) {
-        int complSplit = cutStr.indexOf('/');
-        if (-1 != complSplit) {
-            cutD = cutStr.left(complSplit).toInt(&hasD);
-            cutC = cutStr.mid(qMin(cutStr.length(), complSplit + 1))
-                       .toInt(&hasC);
-        } else {
-            cutD = cutStr.toInt(&hasD);
-            cutC = cutD;
-            hasC = hasD;
-        }
-    }
-
+void SequenceViewAnnotatedRenderer::drawCutSite(QPainter& p, const SharedAnnotationData& aData, int cutPos, const QRect& annotationRect, const QColor& color, const QSize& canvasSize, const U2Region& visibleRange, bool isDirectCut) {
     bool isDirectStrand = aData->getStrand().isDirect();
     int availableHeight = canvasSize.height();
     U2Region cutSiteY = getCutSiteYRange(U2Strand(isDirectStrand ? U2Strand::Complementary : U2Strand::Direct), availableHeight);
@@ -316,21 +379,19 @@ void SequenceViewAnnotatedRenderer::drawCutSite(QPainter &p, const SharedAnnotat
 
     CutSiteDrawData toInsert;
     toInsert.color = color;
-    if (hasD) {
+    toInsert.pos = cutPos;
+    if (isDirectCut) {
         toInsert.direct = true;
-        toInsert.pos = correctCutPos(isDirectStrand ? r.startPos + cutD : r.startPos + cutC);
         toInsert.r = isDirectStrand ? annotationRect : mirroredAnnotationRect;
         drawCutSite(p, toInsert, canvasSize, visibleRange);
-    }
-    if (hasC) {
+    } else {
         toInsert.direct = false;
-        toInsert.pos = correctCutPos(isDirectStrand ? r.endPos() - cutC : r.endPos() - cutD);
         toInsert.r = !isDirectStrand ? annotationRect : mirroredAnnotationRect;
         drawCutSite(p, toInsert, canvasSize, visibleRange);
     }
 }
 
-void SequenceViewAnnotatedRenderer::drawCutSite(QPainter &p, const CutSiteDrawData &cData, const QSize &canvasSize, const U2Region &visibleRange) {
+void SequenceViewAnnotatedRenderer::drawCutSite(QPainter& p, const CutSiteDrawData& cData, const QSize& canvasSize, const U2Region& visibleRange) {
     int xCenter = posToXCoord(cData.pos, canvasSize, visibleRange);
     CHECK(xCenter != -1, );
 
@@ -349,12 +410,12 @@ void SequenceViewAnnotatedRenderer::drawCutSite(QPainter &p, const CutSiteDrawDa
     p.drawPath(path);
 }
 
-QString SequenceViewAnnotatedRenderer::prepareAnnotationText(const SharedAnnotationData &a, const AnnotationSettings *as) const {
+QString SequenceViewAnnotatedRenderer::prepareAnnotationText(const SharedAnnotationData& a, const AnnotationSettings* as) const {
     if (!as->showNameQuals || as->nameQuals.isEmpty()) {
         return a->name;
     }
     QVector<U2Qualifier> qs;
-    foreach (const QString &qn, as->nameQuals) {
+    foreach (const QString& qn, as->nameQuals) {
         qs.clear();
         a->findQualifiers(qn, qs);
         if (!qs.isEmpty()) {
@@ -365,7 +426,7 @@ QString SequenceViewAnnotatedRenderer::prepareAnnotationText(const SharedAnnotat
     return a->name;
 }
 
-void SequenceViewAnnotatedRenderer::addArrowPath(QPainterPath &path, const QRect &rect, bool leftArrow) const {
+void SequenceViewAnnotatedRenderer::addArrowPath(QPainterPath& path, const QRect& rect, bool leftArrow) const {
     if (rect.width() <= FEATURE_ARROW_HLEN || rect.height() <= 0) {
         return;
     }
@@ -397,8 +458,9 @@ qint64 SequenceViewAnnotatedRenderer::correctCutPos(qint64 pos) const {
         } else if (result > sequenceLength) {
             result = result - sequenceLength;
         }
-    } else {
-        result = qBound((qint64)0, result, sequenceLength);
+    } else if (result < 0 || result > sequenceLength) {
+        // out of sequence, do not draw
+        result = INCORRECT_CUT_POSITION;
     }
 
     return result;
