@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_VIEW_RENDERER_H_
-#define _U2_SEQUENCE_VIEW_RENDERER_H_
+#pragma once
 
 #include <QFont>
 
@@ -51,11 +50,11 @@ struct CommonSequenceViewMetrics {
 /************************************************************************/
 class U2VIEW_EXPORT SequenceViewRenderer : public QObject {
 public:
-    SequenceViewRenderer(SequenceObjectContext *ctx);
+    SequenceViewRenderer(SequenceObjectContext* ctx);
 
-    virtual qint64 coordToPos(const QPoint &p, const QSize &canvasSize, const U2Region &visibleRange) const = 0;
+    virtual qint64 coordToPos(const QPoint& p, const QSize& canvasSize, const U2Region& visibleRange) const = 0;
 
-    virtual int posToXCoord(qint64 pos, const QSize &canvasSize, const U2Region &visibleRange) const;
+    virtual int posToXCoord(qint64 pos, const QSize& canvasSize, const U2Region& visibleRange) const;
 
     virtual int getRowLineHeight() const;
 
@@ -63,16 +62,14 @@ public:
 
     virtual int getMinimumHeight() const = 0;
 
-    virtual void drawAll(QPainter &p, const QSize &canvasSize, const U2Region &visibleRange) = 0;
-    virtual void drawSelection(QPainter &p, const QSize &canvasSize, const U2Region &visibleRange) = 0;
+    virtual void drawAll(QPainter& p, const QSize& canvasSize, const U2Region& visibleRange) = 0;
+    virtual void drawSelection(QPainter& p, const QSize& canvasSize, const U2Region& visibleRange) = 0;
 
-    virtual QSize getBaseCanvasSize(const U2Region &visibleRange) const = 0;
+    virtual QSize getBaseCanvasSize(const U2Region& visibleRange) const = 0;
 
 protected:
-    SequenceObjectContext *ctx;
+    SequenceObjectContext* ctx;
     CommonSequenceViewMetrics commonMetrics;
 };
 
 }  // namespace U2
-
-#endif  // _U2_SEQUENCE_VIEW_RENDERER_H_
