@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -36,22 +36,22 @@ namespace U2 {
 //////////////////////////////////////////////////////////////////////////
 // open view task
 
-OpenSimpleTextObjectViewTask::OpenSimpleTextObjectViewTask(const QList<GObject *> &_objects)
+OpenSimpleTextObjectViewTask::OpenSimpleTextObjectViewTask(const QList<GObject*>& _objects)
     : ObjectViewTask(SimpleTextObjectViewFactory::ID), objects(_objects) {
-    foreach (GObject *obj, objects) {
-        CHECK_EXT(nullptr != obj, stateInfo.setError(tr("Invalid object detected!")), );
+    foreach (GObject* obj, objects) {
+        CHECK_EXT(obj != nullptr, stateInfo.setError(tr("Invalid object detected!")), );
         CHECK_EXT(GObjectTypes::TEXT == obj->getGObjectType(),
                   stateInfo.setError(tr("Invalid object type detected!")), );
 
-        Document *doc = obj->getDocument();
-        CHECK_EXT(nullptr != doc, stateInfo.setError(tr("Invalid document detected!")), );
+        Document* doc = obj->getDocument();
+        CHECK_EXT(doc != nullptr, stateInfo.setError(tr("Invalid document detected!")), );
         if (!documentsToLoad.contains(doc) && !doc->isLoaded()) {
             documentsToLoad.append(doc);
         }
     }
 }
 
-OpenSavedTextObjectViewTask::OpenSavedTextObjectViewTask(const QString &vname, const QVariantMap &stateData)
+OpenSavedTextObjectViewTask::OpenSavedTextObjectViewTask(const QString& vname, const QVariantMap& stateData)
     : ObjectViewTask(SimpleTextObjectViewFactory::ID, vname, stateData), doc(nullptr) {
     QString documentUrl = SimpleTextObjectView::getDocumentUrl(stateData);
     doc = AppContext::getProject()->findDocumentByURL(documentUrl);
@@ -74,16 +74,16 @@ void OpenSavedTextObjectViewTask::open() {
     }
     assert(doc->isLoaded());
     QString objName = SimpleTextObjectView::getObjectName(stateData);
-    GObject *obj = doc->findGObjectByName(objName);
-    TextObject *to = qobject_cast<TextObject *>(obj);
+    GObject* obj = doc->findGObjectByName(objName);
+    auto to = qobject_cast<TextObject*>(obj);
     if (!to) {
         stateInfo.setError(tr("Text object '%1' is not found").arg(objName));
         stateIsIllegal = true;
         return;
     }
-    SimpleTextObjectView *v = new SimpleTextObjectView(viewName, to, stateData);
-    GObjectViewWindow *w = new GObjectViewWindow(v, viewName, !stateData.isEmpty());
-    MWMDIManager *mdiManager = AppContext::getMainWindow()->getMDIManager();
+    SimpleTextObjectView* v = new SimpleTextObjectView(viewName, to, stateData);
+    GObjectViewWindow* w = new GObjectViewWindow(v, viewName, !stateData.isEmpty());
+    MWMDIManager* mdiManager = AppContext::getMainWindow()->getMDIManager();
     mdiManager->addMDIWindow(w);
 }
 
@@ -91,23 +91,23 @@ void OpenSimpleTextObjectViewTask::open() {
     if (stateInfo.hasError()) {
         return;
     }
-    foreach (GObject *obj, objects) {
-        Document *doc = obj->getDocument();
+    foreach (GObject* obj, objects) {
+        Document* doc = obj->getDocument();
         CHECK_EXT(doc->isLoaded(), stateInfo.setError(tr("Document is not loaded!")), );
 
-        TextObject *to = qobject_cast<TextObject *>(obj);
-        CHECK_EXT(nullptr != obj, stateInfo.setError(tr("Invalid object detected!")), );
+        auto to = qobject_cast<TextObject*>(obj);
+        CHECK_EXT(obj != nullptr, stateInfo.setError(tr("Invalid object detected!")), );
 
         const QString viewName = GObjectViewUtils::genUniqueViewName(doc, to);
-        SimpleTextObjectView *v = new SimpleTextObjectView(viewName, to, stateData);
-        GObjectViewWindow *w = new GObjectViewWindow(v, viewName, !stateData.isEmpty());
-        if (nullptr == v->parent()) {
+        SimpleTextObjectView* v = new SimpleTextObjectView(viewName, to, stateData);
+        GObjectViewWindow* w = new GObjectViewWindow(v, viewName, !stateData.isEmpty());
+        if (v->parent() == nullptr) {
             stateInfo.setError("Could not open view");
             delete v;
             delete w;
             continue;
         }
-        MWMDIManager *mdiManager = AppContext::getMainWindow()->getMDIManager();
+        MWMDIManager* mdiManager = AppContext::getMainWindow()->getMDIManager();
         mdiManager->addMDIWindow(w);
     }
 }
@@ -115,7 +115,7 @@ void OpenSimpleTextObjectViewTask::open() {
 //////////////////////////////////////////////////////////////////////////
 // update view task
 
-UpdateSimpleTextObjectViewTask::UpdateSimpleTextObjectViewTask(GObjectView *v, const QString &stateName, const QVariantMap &stateData)
+UpdateSimpleTextObjectViewTask::UpdateSimpleTextObjectViewTask(GObjectViewController* v, const QString& stateName, const QVariantMap& stateData)
     : ObjectViewTask(v, stateName, stateData) {
 }
 
@@ -123,7 +123,7 @@ void UpdateSimpleTextObjectViewTask::update() {
     if (view.isNull()) {
         return;
     }
-    SimpleTextObjectView *tv = qobject_cast<SimpleTextObjectView *>(view);
+    auto tv = qobject_cast<SimpleTextObjectView*>(view);
     if (tv == nullptr) {
         return;
     }
