@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SIMPLE_TEXT_OBJECT_VIEW_TASKS_H_
-#define _U2_SIMPLE_TEXT_OBJECT_VIEW_TASKS_H_
+#pragma once
 
 #include <U2Gui/ObjectViewTasks.h>
 
@@ -29,17 +28,17 @@ namespace U2 {
 class OpenSimpleTextObjectViewTask : public ObjectViewTask {
     Q_OBJECT
 public:
-    OpenSimpleTextObjectViewTask(const QList<GObject *> &objects);
+    OpenSimpleTextObjectViewTask(const QList<GObject*>& objects);
     virtual void open();
 
 private:
-    QList<GObject *> objects;
+    QList<GObject*> objects;
 };
 
 class OpenSavedTextObjectViewTask : public ObjectViewTask {
     Q_OBJECT
 public:
-    OpenSavedTextObjectViewTask(const QString &viewName, const QVariantMap &stateData);
+    OpenSavedTextObjectViewTask(const QString& viewName, const QVariantMap& stateData);
     virtual void open();
 
 private:
@@ -48,11 +47,9 @@ private:
 
 class UpdateSimpleTextObjectViewTask : public ObjectViewTask {
 public:
-    UpdateSimpleTextObjectViewTask(GObjectView *v, const QString &stateName, const QVariantMap &stateData);
+    UpdateSimpleTextObjectViewTask(GObjectViewController* v, const QString& stateName, const QVariantMap& stateData);
 
     virtual void update();
 };
 
 }  // namespace U2
-
-#endif
