@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PHYLTREE_BASE_SETTINGS_DIALOG_H_
-#define _U2_PHYLTREE_BASE_SETTINGS_DIALOG_H_
+#pragma once
 
 #include "ov_phyltree/TreeSettings.h"
 
@@ -29,14 +28,12 @@ namespace U2 {
 class BaseSettingsDialog : public QDialog {
     Q_OBJECT
 public:
-    BaseSettingsDialog(QWidget *parent);
+    BaseSettingsDialog(QWidget* parent);
 
-    const OptionsMap &getSettings() const;
+    const QMap<TreeViewOption, QVariant>& getSettings() const;
 
 protected:
-    OptionsMap updatedSettings;
+    QMap<TreeViewOption, QVariant> updatedSettings;
 };
 
 }  // namespace U2
-
-#endif
