@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CREATE_PHY_TREE_WIDGET_H_
-#define _U2_CREATE_PHY_TREE_WIDGET_H_
+#pragma once
 
 #include <QWidget>
 
@@ -35,18 +34,21 @@ class PhyTreeDisplayOptionsWidget;
 
 class U2VIEW_EXPORT CreatePhyTreeWidget : public QWidget {
 public:
-    CreatePhyTreeWidget(QWidget *parent);
+    CreatePhyTreeWidget(QWidget* parent);
 
-    virtual void fillSettings(CreatePhyTreeSettings &settings) = 0;
+    /** Saves the current UI widget state into the settings data model. */
+    virtual void fillSettings(CreatePhyTreeSettings& settings) = 0;
+
+    /** Stores current UI widget state into U2::Settings. */
     virtual void storeSettings() = 0;
+
+    /** Resets current widget & U2::Settings state to the algorithm defaults. */
     virtual void restoreDefault() = 0;
 
-    virtual bool checkSettings(QString &message, const CreatePhyTreeSettings &settings);
-    virtual bool checkMemoryEstimation(QString &message, const MultipleSequenceAlignment &ma, const CreatePhyTreeSettings &settings);
+    virtual bool checkSettings(QString& message, const CreatePhyTreeSettings& settings);
+    virtual bool checkMemoryEstimation(QString& message, const MultipleSequenceAlignment& ma, const CreatePhyTreeSettings& settings);
 
     static QString getAppSettingsRoot();
 };
 
 }  // namespace U2
-
-#endif  // _U2_CREATE_PHY_TREE_WIDGET_H_
