@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PHY_TREE_DISPLAY_OPTIONS_WIDGET_H_
-#define _U2_PHY_TREE_DISPLAY_OPTIONS_WIDGET_H_
+#pragma once
 
 #include "CreatePhyTreeWidget.h"
 
@@ -30,20 +29,18 @@ namespace U2 {
 
 class U2VIEW_EXPORT PhyTreeDisplayOptionsWidget : public CreatePhyTreeWidget {
 public:
-    PhyTreeDisplayOptionsWidget(QWidget *parent = nullptr);
+    PhyTreeDisplayOptionsWidget(QWidget* parent = nullptr);
     ~PhyTreeDisplayOptionsWidget();
 
-    void fillSettings(CreatePhyTreeSettings &settings);
+    void fillSettings(CreatePhyTreeSettings& settings);
     void storeSettings();
     void restoreDefault();
 
 private:
-    Ui_PhyTreeDisplayOptionsWidget *ui;
+    Ui_PhyTreeDisplayOptionsWidget* ui;
 
     static const QString displayWithMsaEditor;
     static const QString synchronizeWithMsa;
 };
 
 }  // namespace U2
-
-#endif  // _U2_PHY_TREE_DISPLAY_OPTIONS_WIDGET_H_
