@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,25 +30,21 @@
 
 namespace U2 {
 
-TreeSettingsDialog::TreeSettingsDialog(QWidget *parent, const OptionsMap &settings, bool isRectLayout)
+TreeSettingsDialog::TreeSettingsDialog(QWidget* parent, const QMap<TreeViewOption, QVariant>& settings)
     : BaseSettingsDialog(parent) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65929724");
     buttonBox->button(QDialogButtonBox::Ok)->setText(tr("OK"));
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
 
-    heightSlider->setValue(settings[HEIGHT_COEF].toUInt());
-    widthlSlider->setValue(settings[WIDTH_COEF].toUInt());
-
-    heightSlider->setEnabled(isRectLayout);
-
     scaleSpinBox->setValue(settings[SCALEBAR_RANGE].toDouble());
 
     treeViewCombo->addItem(getDefaultTreeModeText());
     treeViewCombo->addItem(getPhylogramTreeModeText());
     treeViewCombo->addItem(getCladogramTreeModeText());
 
-    switch (settings[BRANCHES_TRANSFORMATION_TYPE].toUInt()) {
+    int transformationType = settings[BRANCH_DEPTH_SCALE_MODE].toInt();
+    switch (transformationType) {
         case DEFAULT:
             treeViewCombo->setCurrentIndex(treeViewCombo->findText(getDefaultTreeModeText()));
             break;
@@ -63,6 +59,7 @@ TreeSettingsDialog::TreeSettingsDialog(QWidget *parent, const OptionsMap &settin
     }
 
     connect(treeViewCombo, SIGNAL(currentIndexChanged(int)), SLOT(sl_treeTypeChanged(int)));
+    sl_treeTypeChanged(transformationType);
 }
 
 void TreeSettingsDialog::sl_treeTypeChanged(int value) {
@@ -71,15 +68,12 @@ void TreeSettingsDialog::sl_treeTypeChanged(int value) {
 }
 
 void TreeSettingsDialog::accept() {
-    updatedSettings[HEIGHT_COEF] = heightSlider->value();
-    updatedSettings[WIDTH_COEF] = widthlSlider->value();
-
     if (treeViewCombo->currentText() == getDefaultTreeModeText()) {
-        updatedSettings[BRANCHES_TRANSFORMATION_TYPE] = DEFAULT;
+        updatedSettings[BRANCH_DEPTH_SCALE_MODE] = DEFAULT;
     } else if (treeViewCombo->currentText() == getPhylogramTreeModeText()) {
-        updatedSettings[BRANCHES_TRANSFORMATION_TYPE] = PHYLOGRAM;
+        updatedSettings[BRANCH_DEPTH_SCALE_MODE] = PHYLOGRAM;
     } else if (treeViewCombo->currentText() == getCladogramTreeModeText()) {
-        updatedSettings[BRANCHES_TRANSFORMATION_TYPE] = CLADOGRAM;
+        updatedSettings[BRANCH_DEPTH_SCALE_MODE] = CLADOGRAM;
     } else {
         FAIL("Unexpected tree type value", );
     }
