@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,20 +19,19 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _TREE_SETTINGS_DIALOG_
-#define _TREE_SETTINGS_DIALOG_
-
-#include <ui_TreeSettingsDialog.h>
+#pragma once
 
 #include "BaseSettingsDialog.h"
 #include "ov_phyltree/TreeSettings.h"
 
+#include <ui_TreeSettingsDialog.h>
+
 namespace U2 {
 
 class TreeSettingsDialog : public BaseSettingsDialog, public Ui_TreeSettingsDialog {
     Q_OBJECT
 public:
-    TreeSettingsDialog(QWidget *parent, const OptionsMap &settings, bool isRectLayout);
+    TreeSettingsDialog(QWidget* parent, const QMap<TreeViewOption, QVariant>& settings);
 
     void accept() override;
 
@@ -45,4 +44,3 @@ private slots:
 };
 
 }  // namespace U2
-#endif
