@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_ASSEMBLEY_DIALOG_H_
-#define _U2_DNA_ASSEMBLEY_DIALOG_H_
-
-#include <ui_AssemblyToRefDialog.h>
+#pragma once
 
 #include <QStringList>
 #include <QVariant>
@@ -31,6 +28,8 @@
 
 #include <U2Core/GUrl.h>
 
+#include <ui_AssemblyToRefDialog.h>
+
 namespace U2 {
 
 class DnaAssemblyAlgRegistry;
@@ -38,26 +37,26 @@ class DnaAssemblyAlgorithmMainWidget;
 class SaveDocumentController;
 
 class ShortReadsTableItem : public QTreeWidgetItem {
-    QComboBox *mateTypeBox;
+    QComboBox* mateTypeBox;
 
 private:
     void updateState();
 
 public:
-    ShortReadsTableItem(QTreeWidget *widget, const QString &url);
+    ShortReadsTableItem(QTreeWidget* widget, const QString& url);
     GUrl getUrl() const;
     ShortReadSet::LibraryType getType() const;
     ShortReadSet::MateOrder getOrder() const;
-    void setLibraryType(const QString &libraryType);
+    void setLibraryType(const QString& libraryType);
 
-    static void addItemToTable(ShortReadsTableItem *item, QTreeWidget *treeWidget);
+    static void addItemToTable(ShortReadsTableItem* item, QTreeWidget* treeWidget);
 };
 
 class DnaAssemblyDialog : public QDialog, private Ui_AssemblyToRefDialog {
     Q_OBJECT
 
 public:
-    DnaAssemblyDialog(QWidget *p = nullptr, const QStringList &shortReadsUrls = QStringList(), const QString &refSeqUrl = QString());
+    DnaAssemblyDialog(QWidget* p = nullptr, const QStringList& shortReadsUrls = QStringList(), const QString& refSeqUrl = QString());
     const GUrl getRefSeqUrl();
     const QList<ShortReadSet> getShortReadSets();
     const QString getAlgorithmName();
@@ -68,27 +67,27 @@ public:
     QMap<QString, QVariant> getCustomSettings();
 
 protected:
-    bool eventFilter(QObject *, QEvent *);
+    bool eventFilter(QObject*, QEvent*);
 
 private slots:
     void sl_onAddRefButtonClicked();
     void sl_onAddShortReadsButtonClicked();
     void sl_onRemoveShortReadsButtonClicked();
-    void sl_onAlgorithmChanged(const QString &text);
+    void sl_onAlgorithmChanged(const QString& text);
     void sl_onSamBoxClicked();
     void sl_onLibraryTypeChanged();
-    void sl_formatChanged(const QString &newFormat);
+    void sl_formatChanged(const QString& newFormat);
 
 private:
     void updateState();
     void addGuiExtension();
     void accept();
     void initSaveController();
-    void buildResultUrl(const QString &refUrl);
+    void buildResultUrl(const QString& refUrl);
 
-    const DnaAssemblyAlgRegistry *assemblyRegistry;
-    DnaAssemblyAlgorithmMainWidget *customGUI;
-    SaveDocumentController *saveController;
+    const DnaAssemblyAlgRegistry* assemblyRegistry;
+    DnaAssemblyAlgorithmMainWidget* customGUI;
+    SaveDocumentController* saveController;
 
     static QString lastRefSeqUrl;
     static QStringList lastShortReadsUrls;
@@ -98,5 +97,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  //  _U2_DNA_ASSEMBLEY_DIALOG_H_
