@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_ASSEMBLEY_GUI_EXTENSION_H_
-#define _U2_DNA_ASSEMBLEY_GUI_EXTENSION_H_
+#pragma once
 
 #include <QWidget>
 
@@ -34,8 +33,8 @@ namespace U2 {
 
 class U2VIEW_EXPORT DnaAssemblyAlgorithmBaseWidget : public QWidget {
 public:
-    DnaAssemblyAlgorithmBaseWidget(QWidget *parent);
-    virtual void validateReferenceSequence(const GUrl &url) const;
+    DnaAssemblyAlgorithmBaseWidget(QWidget* parent);
+    virtual void validateReferenceSequence(const GUrl& url) const;
 };
 
 // These classes are intended for extending standard Dna Assembly dialog GUI
@@ -44,15 +43,15 @@ public:
 class U2VIEW_EXPORT DnaAssemblyAlgorithmMainWidget : public DnaAssemblyAlgorithmBaseWidget {
     Q_OBJECT
 public:
-    DnaAssemblyAlgorithmMainWidget(QWidget *parent);
+    DnaAssemblyAlgorithmMainWidget(QWidget* parent);
 
     virtual QMap<QString, QVariant> getDnaAssemblyCustomSettings() const = 0;
 
-    virtual bool isParametersOk(QString &error) const;
-    virtual bool buildIndexUrl(const GUrl &url, bool prebuiltIndex, QString &error) const;
-    virtual bool isIndexOk(const GUrl &url, QString &error) const;
-    virtual bool isIndex(const QString &url) const;
-    virtual bool isValidIndex(const QString &oneIndexFileUrl) const;
+    virtual bool isParametersOk(QString& error) const;
+    virtual bool buildIndexUrl(const GUrl& url, bool prebuiltIndex, QString& error) const;
+    virtual bool isIndexOk(const GUrl& url, QString& error) const;
+    virtual bool isIndex(const QString& url) const;
+    virtual bool isValidIndex(const QString& oneIndexFileUrl) const;
 
 protected:
     bool requiredToolsAreOk() const;
@@ -63,18 +62,18 @@ protected:
 
 class U2VIEW_EXPORT DnaAssemblyAlgorithmBuildIndexWidget : public DnaAssemblyAlgorithmBaseWidget {
 public:
-    DnaAssemblyAlgorithmBuildIndexWidget(QWidget *parent);
+    DnaAssemblyAlgorithmBuildIndexWidget(QWidget* parent);
 
     virtual QMap<QString, QVariant> getBuildIndexCustomSettings() = 0;
     virtual QString getIndexFileExtension() = 0;
-    virtual GUrl buildIndexUrl(const GUrl &url) = 0;
+    virtual GUrl buildIndexUrl(const GUrl& url) = 0;
 };
 
 class U2VIEW_EXPORT DnaAssemblyGUIExtensionsFactory {
 public:
     virtual ~DnaAssemblyGUIExtensionsFactory();
-    virtual DnaAssemblyAlgorithmMainWidget *createMainWidget(QWidget *parent) = 0;
-    virtual DnaAssemblyAlgorithmBuildIndexWidget *createBuildIndexWidget(QWidget *parent) = 0;
+    virtual DnaAssemblyAlgorithmMainWidget* createMainWidget(QWidget* parent) = 0;
+    virtual DnaAssemblyAlgorithmBuildIndexWidget* createBuildIndexWidget(QWidget* parent) = 0;
     virtual bool hasMainWidget() = 0;
     virtual bool hasBuildIndexWidget() = 0;
 };
@@ -82,8 +81,8 @@ public:
 class DnaAssemblyDialog;
 class U2VIEW_EXPORT DnaAssemblyGUIUtils : public QObject {
 public:
-    static void runAssembly2ReferenceDialog(const QStringList &shortReadUrls = QStringList(), const QString &refSeqUrl = QString());
-    static DnaAssemblyToRefTaskSettings getSettings(DnaAssemblyDialog *dialog);
+    static void runAssembly2ReferenceDialog(const QStringList& shortReadUrls = QStringList(), const QString& refSeqUrl = QString());
+    static DnaAssemblyToRefTaskSettings getSettings(DnaAssemblyDialog* dialog);
 };
 
 // These classes are intended for extending standard Genome Assembly dialog GUI
@@ -91,11 +90,9 @@ public:
 
 class U2VIEW_EXPORT GenomeAssemblyAlgorithmMainWidget : public QWidget {
 public:
-    GenomeAssemblyAlgorithmMainWidget(QWidget *parent);
+    GenomeAssemblyAlgorithmMainWidget(QWidget* parent);
     virtual QMap<QString, QVariant> getGenomeAssemblyCustomSettings() = 0;
-    virtual bool isParametersOk(QString &error) = 0;
+    virtual bool isParametersOk(QString& error) = 0;
 };
 
 }  // namespace U2
-
-#endif  // _U2_DNA_ASSEMBLEY_GUI_EXTENSION_H_
