@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_ASSEMBLEY_UTILS_H_
-#define _U2_DNA_ASSEMBLEY_UTILS_H_
+#pragma once
 
 #include <U2Algorithm/DnaAssemblyMultiTask.h>
 
@@ -35,9 +34,9 @@ class U2VIEW_EXPORT DnaAssemblySupport : public QObject {
 public:
     DnaAssemblySupport();
 
-    static QMap<QString, QString> toConvert(const DnaAssemblyToRefTaskSettings &settings, QList<GUrl> &unknownFormatFiles);
-    static QString toConvertText(const QMap<QString, QString> &files);
-    static QString unknownText(const QList<GUrl> &unknownFormatFiles);
+    static QMap<QString, QString> toConvert(const DnaAssemblyToRefTaskSettings& settings, QList<GUrl>& unknownFormatFiles);
+    static QString toConvertText(const QMap<QString, QString>& files);
+    static QString unknownText(const QList<GUrl>& unknownFormatFiles);
 
 private slots:
     void sl_showDnaAssemblyDialog();
@@ -49,15 +48,15 @@ private slots:
 class FilterUnpairedReadsTask : public Task {
     Q_OBJECT
 public:
-    FilterUnpairedReadsTask(const DnaAssemblyToRefTaskSettings &settings);
+    FilterUnpairedReadsTask(const DnaAssemblyToRefTaskSettings& settings);
     void run();
-    const QList<ShortReadSet> &getFilteredReadList() const {
+    const QList<ShortReadSet>& getFilteredReadList() const {
         return filteredReads;
     }
 
 private:
-    QString getTmpFilePath(const GUrl &initialFile);
-    void compareFiles(const GUrl &upstream, const GUrl &downstream, const GUrl &upstreamFiltered, const GUrl &downstreamFiltered);
+    QString getTmpFilePath(const GUrl& initialFile);
+    void compareFiles(const GUrl& upstream, const GUrl& downstream, const GUrl& upstreamFiltered, const GUrl& downstreamFiltered);
 
     DnaAssemblyToRefTaskSettings settings;
     QList<ShortReadSet> filteredReads;
@@ -67,11 +66,11 @@ private:
 class U2VIEW_EXPORT DnaAssemblyTaskWithConversions : public ExternalToolSupportTask {
     Q_OBJECT
 public:
-    DnaAssemblyTaskWithConversions(const DnaAssemblyToRefTaskSettings &settings, bool viewResult = false, bool justBuildIndex = false);
+    DnaAssemblyTaskWithConversions(const DnaAssemblyToRefTaskSettings& settings, bool viewResult = false, bool justBuildIndex = false);
 
     void prepare();
-    QList<Task *> onSubTaskFinished(Task *subTask);
-    const DnaAssemblyToRefTaskSettings &getSettings() const;
+    QList<Task*> onSubTaskFinished(Task* subTask);
+    const DnaAssemblyToRefTaskSettings& getSettings() const;
     ReportResult report();
 
 private:
@@ -79,9 +78,7 @@ private:
     bool viewResult;
     bool justBuildIndex;
     int conversionTasksCount;
-    DnaAssemblyMultiTask *assemblyTask;
+    DnaAssemblyMultiTask* assemblyTask;
 };
 
 }  // namespace U2
-
-#endif  // _U2_DNA_ASSEMBLEY_TASK_H_
