@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 
 namespace U2 {
 
-AlignmentAlgorithmMainWidget::AlignmentAlgorithmMainWidget(QWidget *parent, QVariantMap *s)
+AlignmentAlgorithmMainWidget::AlignmentAlgorithmMainWidget(QWidget* parent, QVariantMap* s)
     : QWidget(parent), externSettings(s), externSettingsExists(s != nullptr) {
 }
 
@@ -31,12 +31,12 @@ AlignmentAlgorithmMainWidget::~AlignmentAlgorithmMainWidget() {
     getAlignmentAlgorithmCustomSettings(true);
 }
 
-void AlignmentAlgorithmMainWidget::sl_externSettingsInvalide() {
+void AlignmentAlgorithmMainWidget::sl_externSettingsInvalidate() {
     externSettingsExists = false;
 }
 
 QMap<QString, QVariant> AlignmentAlgorithmMainWidget::getAlignmentAlgorithmCustomSettings(bool append = false) {
-    if (append == true && externSettingsExists == true) {
+    if (append && externSettingsExists) {
         foreach (QString key, innerSettings.keys()) {
             externSettings->insert(key, innerSettings.value(key));
         }
@@ -47,12 +47,12 @@ QMap<QString, QVariant> AlignmentAlgorithmMainWidget::getAlignmentAlgorithmCusto
 void AlignmentAlgorithmMainWidget::fillInnerSettings() {
 }
 
-bool AlignmentAlgorithmGUIExtensionFactory::hasMainWidget(const QWidget *parent) {
+bool AlignmentAlgorithmGUIExtensionFactory::hasMainWidget(const QWidget* parent) {
     return mainWidgets.contains(parent);
 }
 
-void AlignmentAlgorithmGUIExtensionFactory::sl_widgetDestroyed(QObject *obj) {
-    foreach (AlignmentAlgorithmMainWidget *mainWidget, mainWidgets.values()) {
+void AlignmentAlgorithmGUIExtensionFactory::sl_widgetDestroyed(QObject* obj) {
+    foreach (AlignmentAlgorithmMainWidget* mainWidget, mainWidgets.values()) {
         if (obj == mainWidget) {
             mainWidgets.remove(mainWidgets.key(mainWidget));
         }
