@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ALIGNMENT_ALGORITHM_GUI_EXTENSION_H_
-#define _U2_ALIGNMENT_ALGORITHM_GUI_EXTENSION_H_
+#pragma once
 
 #include <QMap>
 #include <QObject>
@@ -43,8 +42,8 @@ class U2VIEW_EXPORT AlignmentAlgorithmMainWidget : public QWidget {
     Q_OBJECT
 
 public:
-    AlignmentAlgorithmMainWidget(QWidget *parent, QVariantMap *s);
-    virtual ~AlignmentAlgorithmMainWidget();
+    AlignmentAlgorithmMainWidget(QWidget* parent, QVariantMap* s);
+    ~AlignmentAlgorithmMainWidget() override;
 
     virtual QVariantMap getAlignmentAlgorithmCustomSettings(bool append);
 
@@ -52,14 +51,14 @@ public:
     }
 
 public slots:
-    void sl_externSettingsInvalide();
+    void sl_externSettingsInvalidate();
 
 protected:
     virtual void fillInnerSettings();
 
 protected:
     QVariantMap innerSettings;  // inner settings
-    QVariantMap *externSettings;  // extern settings (from msa)
+    QVariantMap* externSettings;  // extern settings (from msa)
     bool externSettingsExists;  // msa editor is alive, pointer externSettings is valid
 };
 
@@ -67,16 +66,14 @@ class U2VIEW_EXPORT AlignmentAlgorithmGUIExtensionFactory : public QObject {
     Q_OBJECT
 
 public:
-    virtual AlignmentAlgorithmMainWidget *createMainWidget(QWidget *parent, QVariantMap *s) = 0;
-    virtual bool hasMainWidget(const QWidget *parent);
+    virtual AlignmentAlgorithmMainWidget* createMainWidget(QWidget* parent, QVariantMap* s) = 0;
+    virtual bool hasMainWidget(const QWidget* parent);
 
 protected slots:
-    virtual void sl_widgetDestroyed(QObject *obj);
+    virtual void sl_widgetDestroyed(QObject* obj);
 
 protected:
-    QMap<const QWidget *, AlignmentAlgorithmMainWidget *> mainWidgets;
+    QMap<const QWidget*, AlignmentAlgorithmMainWidget*> mainWidgets;
 };
 
 }  // namespace U2
-
-#endif  //_U2_ALIGNMENT_ALGORITHM_GUI_EXTENSION_H_
