@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,10 +21,8 @@
 
 #include "SecStructDialog.h"
 
-#include <QHeaderView>
 #include <QMessageBox>
 #include <QMutableListIterator>
-#include <QPushButton>
 
 #include <U2Algorithm/SecStructPredictAlgRegistry.h>
 #include <U2Algorithm/SecStructPredictTask.h>
@@ -32,7 +30,6 @@
 #include <U2Core/AppContext.h>
 #include <U2Core/CreateAnnotationTask.h>
 #include <U2Core/DNASequenceObject.h>
-#include <U2Core/DNASequenceSelection.h>
 #include <U2Core/L10n.h>
 #include <U2Core/PluginModel.h>
 #include <U2Core/QObjectScopedPointer.h>
@@ -52,8 +49,8 @@
 
 namespace U2 {
 
-SecStructDialog::SecStructDialog(ADVSequenceObjectContext *_ctx, QWidget *p)
-    : QDialog(p), ctx(_ctx), task(nullptr) {
+SecStructDialog::SecStructDialog(ADVSequenceObjectContext* _ctx, QWidget* p)
+    : QDialog(p), Ui_SecStructDialog(), ctx(_ctx), task(nullptr) {
     setupUi(this);
     new HelpButton(this, buttonBox, "65930792");
 
@@ -80,7 +77,7 @@ SecStructDialog::SecStructDialog(ADVSequenceObjectContext *_ctx, QWidget *p)
     resultsTable->setHorizontalHeaderLabels(headerNames);
     resultsTable->horizontalHeader()->setStretchLastSection(true);
 
-    connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task *)), SLOT(sl_onTaskFinished(Task *)));
+    connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task*)), SLOT(sl_onTaskFinished(Task*)));
     connectGUI();
 }
 
@@ -104,13 +101,21 @@ void SecStructDialog::updateState() {
 void SecStructDialog::sl_onStartPredictionClicked() {
     SAFE_POINT(task == nullptr, "Found pending prediction task!", );
 
-    SecStructPredictTaskFactory *factory = sspr->getAlgorithm(algorithmComboBox->currentText());
-    SAFE_POINT(nullptr != factory, "Unregistered factory name", );
+    SecStructPredictTaskFactory* factory = sspr->getAlgorithm(algorithmComboBox->currentText());
+    SAFE_POINT(factory != nullptr, "Unregistered factory name", );
+
+    bool okFlag = false;
+    region = regionSelector->getRegion(&okFlag);
+    if (!okFlag) {
+        regionSelector->showErrorMessage();
+        return;
+    }
+    SAFE_POINT(region.length > 0 && region.startPos >= 0 && region.endPos() <= ctx->getSequenceLength(), "Illegal region!", );
 
     // Check license
     QString algorithm = algorithmComboBox->currentText();
-    QList<Plugin *> plugins = AppContext::getPluginSupport()->getPlugins();
-    foreach (Plugin *plugin, plugins) {
+    QList<Plugin*> plugins = AppContext::getPluginSupport()->getPlugins();
+    foreach (Plugin* plugin, plugins) {
         if (plugin->getName() == algorithm) {
             if (!plugin->isFree() && !plugin->isLicenseAccepted()) {
                 QObjectScopedPointer<LicenseDialog> licenseDialog = new LicenseDialog(plugin);
@@ -126,7 +131,7 @@ void SecStructDialog::sl_onStartPredictionClicked() {
 
     // prepare target sequence
     region = regionSelector->getRegion();
-    SAFE_POINT(region.length > 0 && region.startPos >= 0 && region.endPos() <= ctx->getSequenceLength(), "Illegal region!", );
+
 
     U2OpStatusImpl os;
     QByteArray seqPart = ctx->getSequenceData(region, os);
@@ -139,7 +144,7 @@ void SecStructDialog::sl_onStartPredictionClicked() {
     updateState();
 }
 
-void SecStructDialog::sl_onTaskFinished(Task *t) {
+void SecStructDialog::sl_onTaskFinished(Task* t) {
     if (t != task || t->getState() != Task::State_Finished) {
         return;
     }
@@ -147,7 +152,7 @@ void SecStructDialog::sl_onTaskFinished(Task *t) {
 
     // shifting results according to startPos
     for (QMutableListIterator<SharedAnnotationData> it_ad(results); it_ad.hasNext();) {
-        SharedAnnotationData &ad = it_ad.next();
+        SharedAnnotationData& ad = it_ad.next();
         U2Region::shift(region.startPos, ad->location->regions);
     }
     task = nullptr;
@@ -157,12 +162,12 @@ void SecStructDialog::sl_onTaskFinished(Task *t) {
 void SecStructDialog::showResults() {
     int rowIndex = 0;
     resultsTable->setRowCount(results.size());
-    foreach (const SharedAnnotationData &data, results) {
+    foreach (const SharedAnnotationData& data, results) {
         U2Region annRegion = data->getRegions().first();
-        QTableWidgetItem *locItem = new QTableWidgetItem(QString("[%1..%2]").arg(annRegion.startPos).arg(annRegion.endPos()));
+        auto locItem = new QTableWidgetItem(QString("[%1..%2]").arg(annRegion.startPos).arg(annRegion.endPos()));
         resultsTable->setItem(rowIndex, 0, locItem);
         SAFE_POINT(data->qualifiers.size() == 1, "Only one qualifier expected!", );
-        QTableWidgetItem *nameItem = new QTableWidgetItem(QString(data->qualifiers.first().value));
+        auto nameItem = new QTableWidgetItem(QString(data->qualifiers.first().value));
         resultsTable->setItem(rowIndex, 1, nameItem);
         ++rowIndex;
     }
@@ -172,7 +177,7 @@ void SecStructDialog::showResults() {
 
 void SecStructDialog::sl_onSaveAnnotations() {
     CreateAnnotationModel m;
-    m.sequenceObjectRef = ctx->getSequenceObject();
+    m.sequenceObjectRef = ctx->getSequenceObject()->getReference();
     m.hideLocation = true;
     m.hideAnnotationType = true;
     m.hideAnnotationName = true;
@@ -186,11 +191,12 @@ void SecStructDialog::sl_onSaveAnnotations() {
     if (rc != QDialog::Accepted) {
         return;
     }
-    ctx->getAnnotatedDNAView()->tryAddObject(m.getAnnotationObject());
+    AnnotationTableObject* annotationObject = m.getAnnotationObject();
+    ctx->getAnnotatedDNAView()->tryAddObject(annotationObject);
 
     U1AnnotationUtils::addDescriptionQualifier(results, m.description);
 
-    CreateAnnotationsTask *t = new CreateAnnotationsTask(m.getAnnotationObject(), results, m.groupName);
+    auto t = new CreateAnnotationsTask(annotationObject, {{m.groupName, results}});
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 
     QDialog::accept();
