@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,13 +19,12 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_SEC_STRUCT_DIALOG_H_
-#define _U2_EXPORT_SEC_STRUCT_DIALOG_H_
-
-#include <ui_SecStructDialog.h>
+#pragma once
 
 #include <U2Core/AnnotationData.h>
 
+#include <ui_SecStructDialog.h>
+
 namespace U2 {
 
 class ADVSequenceObjectContext;
@@ -37,22 +36,22 @@ class RegionSelector;
 class U2VIEW_EXPORT SecStructDialog : public QDialog, private Ui_SecStructDialog {
     Q_OBJECT
 public:
-    SecStructDialog(ADVSequenceObjectContext *ctx, QWidget *p = nullptr);
+    SecStructDialog(ADVSequenceObjectContext* ctx, QWidget* p = nullptr);
 
 private slots:
     void sl_onStartPredictionClicked();
-    void sl_onTaskFinished(Task *);
+    void sl_onTaskFinished(Task*);
     void sl_onSaveAnnotations();
 
 private:
     QList<SharedAnnotationData> results;
-    ADVSequenceObjectContext *ctx;
-    SecStructPredictTask *task;
-    SecStructPredictAlgRegistry *sspr;
-    QPushButton *saveAnnotationButton;
-    QPushButton *startButton;
-    QPushButton *cancelButton;
-    RegionSelector *regionSelector;
+    ADVSequenceObjectContext* ctx;
+    SecStructPredictTask* task;
+    SecStructPredictAlgRegistry* sspr;
+    QPushButton* saveAnnotationButton;
+    QPushButton* startButton;
+    QPushButton* cancelButton;
+    RegionSelector* regionSelector;
 
     U2Region region;
 
@@ -62,5 +61,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  //  _U2_EXPORT_SEC_STRUCT_DIALOG_H_
