@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -42,7 +42,7 @@
 
 namespace U2 {
 
-SecStructPredictViewAction::SecStructPredictViewAction(AnnotatedDNAView *v)
+SecStructPredictViewAction::SecStructPredictViewAction(AnnotatedDNAView* v)
     : ADVGlobalAction(v, QIcon(":core//images//ssp_logo.png"), tr("Predict secondary structure...")) {
     connect(this, SIGNAL(triggered()), SLOT(sl_execute()));
     setObjectName("Predict secondary structure");
@@ -50,15 +50,15 @@ SecStructPredictViewAction::SecStructPredictViewAction(AnnotatedDNAView *v)
 }
 
 void SecStructPredictViewAction::sl_execute() {
-    QAction *a = dynamic_cast<QAction *>(sender());
-    GObjectViewAction *viewAction = dynamic_cast<GObjectViewAction *>(a);
-    SAFE_POINT(nullptr != viewAction, "NULL action", );
+    auto a = dynamic_cast<QAction*>(sender());
+    auto viewAction = dynamic_cast<GObjectViewAction*>(a);
+    SAFE_POINT(viewAction != nullptr, "NULL action", );
 
-    AnnotatedDNAView *av = qobject_cast<AnnotatedDNAView *>(viewAction->getObjectView());
-    SAFE_POINT(nullptr != av, "NULL dna view", );
+    auto av = qobject_cast<AnnotatedDNAView*>(viewAction->getObjectView());
+    SAFE_POINT(av != nullptr, "NULL dna view", );
 
-    SecStructPredictAlgRegistry *sspar = AppContext::getSecStructPredictAlgRegistry();
-    SAFE_POINT(nullptr != sspar, "NULL SecStructPredictAlgRegistry", );
+    SecStructPredictAlgRegistry* sspar = AppContext::getSecStructPredictAlgRegistry();
+    SAFE_POINT(sspar != nullptr, "NULL SecStructPredictAlgRegistry", );
 
     if (sspar->getAlgNameList().isEmpty()) {
         QMessageBox::information(av->getWidget(),
@@ -67,17 +67,17 @@ void SecStructPredictViewAction::sl_execute() {
         return;
     }
 
-    ADVSequenceObjectContext *seqCtx = av->getActiveSequenceContext();
-    SAFE_POINT(nullptr != seqCtx, "NULL sequence context", );
-    SAFE_POINT(nullptr != seqCtx->getAlphabet(), "NULL alphabet", );
+    ADVSequenceObjectContext* seqCtx = av->getActiveSequenceContext();
+    SAFE_POINT(seqCtx != nullptr, "NULL sequence context", );
+    SAFE_POINT(seqCtx->getAlphabet() != nullptr, "NULL alphabet", );
     SAFE_POINT(seqCtx->getAlphabet()->isAmino(), "Wrong alphabet", );
 
     QObjectScopedPointer<SecStructDialog> secStructDialog = new SecStructDialog(seqCtx, av->getWidget());
     secStructDialog->exec();
 }
 
-ADVGlobalAction *SecStructPredictViewAction::createAction(AnnotatedDNAView *av) {
-    ADVGlobalAction *action = new SecStructPredictViewAction(av);
+ADVGlobalAction* SecStructPredictViewAction::createAction(AnnotatedDNAView* av) {
+    ADVGlobalAction* action = new SecStructPredictViewAction(av);
 
     return action;
 }
@@ -116,7 +116,7 @@ QString SecStructPredictUtils::getStructNameForCharTag(char tag) {
     return BioStruct3D::getSecStructTypeName(type);
 }
 
-QList<SharedAnnotationData> SecStructPredictUtils::saveAlgorithmResultsAsAnnotations(const QByteArray &predicted, const QString &annotationName) {
+QList<SharedAnnotationData> SecStructPredictUtils::saveAlgorithmResultsAsAnnotations(const QByteArray& predicted, const QString& annotationName) {
     char emptyCoil = 'C';
 
     int numAcronyms = predicted.length();
@@ -128,7 +128,7 @@ QList<SharedAnnotationData> SecStructPredictUtils::saveAlgorithmResultsAsAnnotat
         if ((curChar != prevChar) || (i == numAcronyms - 1)) {
             if (prevChar != emptyCoil) {
                 SharedAnnotationData sd(new AnnotationData);
-                sd->type = U2FeatureTypes::SeconadaryStructure;
+                sd->type = U2FeatureTypes::SecondaryStructure;
                 sd->name = annotationName;
                 sd->location->regions.append(U2Region(lastRecordedPos, i - lastRecordedPos));
                 sd->qualifiers.append(U2Qualifier(BioStruct3D::SecStructTypeQualifierName, getStructNameForCharTag(prevChar)));
