@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SMITH_WATERMAN_DIALOG_H_
-#define _U2_SMITH_WATERMAN_DIALOG_H_
+#pragma once
 
 #include <U2Algorithm/SmithWatermanSettings.h>
 
@@ -101,9 +100,7 @@ struct SWDialogConfig {
 
 class U2VIEW_EXPORT SmithWatermanDialogController {
 public:
-    static void run(QWidget *p, ADVSequenceObjectContext *ctx, SWDialogConfig *dialogConfig);
+    static void run(QWidget* p, ADVSequenceObjectContext* ctx, SWDialogConfig* dialogConfig);
 };
 
 }  // namespace U2
-
-#endif
