@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SUBST_MATRIX_DIALOG_H_
-#define _U2_SUBST_MATRIX_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -34,7 +33,7 @@ namespace U2 {
 class U2VIEW_EXPORT SubstMatrixDialog : public QDialog, public Ui_SubstMatrixDialogBase {
     Q_OBJECT
 public:
-    SubstMatrixDialog(const SMatrix &m, QWidget *parent);
+    SubstMatrixDialog(const SMatrix& m, QWidget* parent);
 
 private slots:
     void sl_closeWindow();
@@ -53,9 +52,7 @@ private:
 
     SMatrix m;
 
-    QPushButton *bttnClose;
+    QPushButton* bttnClose;
 };
 
 }  // namespace U2
-
-#endif
