@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,10 +23,10 @@
 
 namespace HI {
 
-DefaultDialogFiller::DefaultDialogFiller(GUITestOpStatus &os, const QString &name, QDialogButtonBox::StandardButton _b, CustomScenario *scenario)
-    : Filler(os, name, scenario), b(_b) {
+DefaultDialogFiller::DefaultDialogFiller(const QString& name, QDialogButtonBox::StandardButton _b, CustomScenario* scenario)
+    : Filler(name, scenario), b(_b) {
 }
 void DefaultDialogFiller::commonScenario() {
-    GTUtilsDialog::clickButtonBox(os, b);
+    GTUtilsDialog::clickButtonBox(b);
 }
 }  // namespace HI
