@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,14 +29,11 @@
 namespace HI {
 
 #define GT_CLASS_NAME "GTUtilsDialog::FontDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void FontDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != NULL, "dialog is NULL");
+    GTWidget::getActiveModalWidget();
     GTGlobals::sleep();
 
     GTKeyboardDriver::keyClick(Qt::Key_Enter);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 }  // namespace HI
