@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,144 +32,135 @@ namespace HI {
 
 #define GT_CLASS_NAME "GTUtilsDialog::MessageBoxDialogFiller"
 
-MessageBoxDialogFiller::MessageBoxDialogFiller(GUITestOpStatus &os, QMessageBox::StandardButton b, const QString &message, const QString &objectName)
-    : Filler(os, objectName),
+MessageBoxDialogFiller::MessageBoxDialogFiller(QMessageBox::StandardButton b, const QString& _message, const QString& objectName)
+    : Filler(objectName),
       b(b),
-      message(message) {
+      message(_message) {
+    settings.logName = "MessageBoxDialogFiller, message: '" + message + "', button code: " + QString::number(b);
 }
 
-MessageBoxDialogFiller::MessageBoxDialogFiller(GUITestOpStatus &os, const QString &buttonText, const QString &message)
-    : Filler(os, ""),
+MessageBoxDialogFiller::MessageBoxDialogFiller(const QString& _buttonText, const QString& _message)
+    : Filler(""),
       b(QMessageBox::NoButton),
-      buttonText(buttonText),
-      message(message) {
+      buttonText(_buttonText),
+      message(_message) {
+    settings.logName = "MessageBoxDialogFiller, message: '" + message + "', buttonText: '" + buttonText + "'";
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void MessageBoxDialogFiller::commonScenario() {
-    QWidget *activeModal = QApplication::activeModalWidget();
-    QMessageBox *messageBox = qobject_cast<QMessageBox *>(activeModal);
-    GT_CHECK(messageBox != NULL, "messageBox is NULL");
+    auto modalWidget = GTWidget::getActiveModalWidget();
+    auto messageBox = qobject_cast<QMessageBox*>(modalWidget);
+    GT_CHECK(messageBox != nullptr, "messageBox is NULL");
 
-    if (message != "") {
+    if (!message.isEmpty()) {
         QString actualText = messageBox->text();
         GT_CHECK(messageBox->text().contains(message, Qt::CaseInsensitive),
                  QString("Expected: %1, found: %2").arg(message).arg(actualText));
     }
 
-    if (buttonText != "") {
-        for (QAbstractButton *button : messageBox->buttons()) {
+    if (!buttonText.isEmpty()) {
+        for (QAbstractButton* button : messageBox->buttons()) {
             if (button->text().contains(buttonText, Qt::CaseInsensitive)) {
-                GTWidget::click(os, button);
+                GTWidget::click(button);
                 return;
             }
         }
     }
 
-    QAbstractButton *button = messageBox->button(b);
+    QAbstractButton* button = messageBox->button(b);
     GT_CHECK(button != nullptr, QString("There is no such button in messagebox: 0x%1").arg(QString::number(b, 16)));
-    GTWidget::click(os, button);
+    GTWidget::click(button);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
 #define GT_CLASS_NAME "GTUtilsDialog::AppCloseMessageBoxDialogFiller"
 
-AppCloseMessageBoxDialogFiller::AppCloseMessageBoxDialogFiller(GUITestOpStatus &os)
-    : Filler(os, "") {
+AppCloseMessageBoxDialogFiller::AppCloseMessageBoxDialogFiller()
+    : Filler("") {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void AppCloseMessageBoxDialogFiller::commonScenario() {
-    QWidget *activeModal = QApplication::activeModalWidget();
-    QMessageBox *messageBox = qobject_cast<QMessageBox *>(activeModal);
+    QWidget* activeModal = GTWidget::getActiveModalWidget();
+    auto messageBox = qobject_cast<QMessageBox*>(activeModal);
     GT_CHECK(messageBox != NULL, "messageBox is NULL");
 
-    QAbstractButton *noButton = messageBox->button(QMessageBox::No);
-    QAbstractButton *noToAllButton = messageBox->button(QMessageBox::NoToAll);
+    QAbstractButton* noButton = messageBox->button(QMessageBox::No);
+    QAbstractButton* noToAllButton = messageBox->button(QMessageBox::NoToAll);
 
     if (NULL != noToAllButton) {
-        GTWidget::click(os, noToAllButton);
+        GTWidget::click(noToAllButton);
     } else if (NULL != noButton) {
-        GTWidget::click(os, noButton);
+        GTWidget::click(noButton);
     } else {
-        GT_CHECK(false, "There are neither \"No\" or \"No to all\" buttons in the message box");
+        GT_FAIL("There are neither \"No\" or \"No to all\" buttons in the message box", );
     }
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
 #define GT_CLASS_NAME "GTUtilsDialog::MessageBoxNoToAllOrNo"
 
-MessageBoxNoToAllOrNo::MessageBoxNoToAllOrNo(GUITestOpStatus &os)
-    : Filler(os, "") {
+MessageBoxNoToAllOrNo::MessageBoxNoToAllOrNo()
+    : Filler("") {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void MessageBoxNoToAllOrNo::commonScenario() {
-    QWidget *activeModal = QApplication::activeModalWidget();
-    QMessageBox *messageBox = qobject_cast<QMessageBox *>(activeModal);
+    QWidget* activeModal = GTWidget::getActiveModalWidget();
+    auto messageBox = qobject_cast<QMessageBox*>(activeModal);
     GT_CHECK(messageBox != NULL, "messageBox is NULL");
 
-    QAbstractButton *button = messageBox->button(QMessageBox::NoToAll);
+    QAbstractButton* button = messageBox->button(QMessageBox::NoToAll);
     if (!button) {
         button = messageBox->button(QMessageBox::No);
     }
     GT_CHECK(button != NULL, "There are no No buttons in messagebox");
 
-    GTWidget::click(os, button);
+    GTWidget::click(button);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
 #define GT_CLASS_NAME "MessageBoxOpenAnotherProject"
 
-MessageBoxOpenAnotherProject::MessageBoxOpenAnotherProject(GUITestOpStatus &os)
-    : Filler(os, "") {
+MessageBoxOpenAnotherProject::MessageBoxOpenAnotherProject()
+    : Filler("") {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void MessageBoxOpenAnotherProject::commonScenario() {
-    QWidget *activeModal = QApplication::activeModalWidget();
-    QMessageBox *messageBox = qobject_cast<QMessageBox *>(activeModal);
+    QWidget* activeModal = GTWidget::getActiveModalWidget();
+    auto messageBox = qobject_cast<QMessageBox*>(activeModal);
     GT_CHECK(messageBox != NULL, "messageBox is NULL");
 
-    QAbstractButton *button = messageBox->findChild<QAbstractButton *>("New Window");
+    QAbstractButton* button = messageBox->findChild<QAbstractButton*>("New Window");
     GT_CHECK(button != NULL, "There are no New Window buttons in messagebox");
 
-    button = messageBox->findChild<QAbstractButton *>("This Window");
+    button = messageBox->findChild<QAbstractButton*>("This Window");
     GT_CHECK(button != NULL, "There are no This Window buttons in messagebox");
 
     button = messageBox->button(QMessageBox::Abort);
     GT_CHECK(button != NULL, "There are no Abort buttons in messagebox");
 
-    GTWidget::click(os, button);
+    GTWidget::click(button);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
 #define GT_CLASS_NAME "MessageBoxOpenAnotherProject"
 
-InputIntFiller::InputIntFiller(GUITestOpStatus &os, int value)
-    : Filler(os, ""),
+InputIntFiller::InputIntFiller(int value)
+    : Filler(""),
       value(value) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void InputIntFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    QSpinBox *spinBox = dialog->findChild<QSpinBox *>();
-    GT_CHECK(NULL != spinBox, "NULL spinBox");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
+    auto spinBox = GTWidget::findSpinBox("", dialog);
 
-    GTSpinBox::setValue(os, spinBox, value);
+    GTSpinBox::setValue(spinBox, value);
 
-    GTWidget::click(os, GTWidget::findButtonByText(os, "OK", dialog));
+    GTWidget::click(GTWidget::findButtonByText("OK", dialog));
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
