@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _HI_CUSTOM_SCENARIO_H_
-#define _HI_CUSTOM_SCENARIO_H_
+#pragma once
 
 #include <core/GUITestOpStatus.h>
 #include <core/global.h>
@@ -30,9 +29,7 @@ namespace HI {
 class HI_EXPORT CustomScenario {
 public:
     virtual ~CustomScenario();
-    virtual void run(HI::GUITestOpStatus &os) = 0;
+    virtual void run() = 0;
 };
 
 }  // namespace HI
-
-#endif  // _HI_CUSTOM_SCENARIO_H_
