@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _HI_GUI_TEST_OP_STATUS_H_
-#define _HI_GUI_TEST_OP_STATUS_H_
+#pragma once
 
 #include <QString>
 
@@ -28,25 +27,26 @@
 
 namespace HI {
 
-class HI_EXPORT GUITestOpStatus {
+class HI_EXPORT GUITestOpStatus final {
 public:
-    GUITestOpStatus() {
-    }
-
-    virtual void setError(const QString &err) {
-        error = err;
+    void setError(const QString& err) {
+        if (!error.isEmpty()) {
+            qWarning("Can't override error! Current error: %s, new error: %s", error.toLocal8Bit().constData(), err.toLocal8Bit().constData());
+        } else {
+            error = err;
+        }
         throw this;
     }
 
-    virtual QString getError() const {
+    QString getError() const {
         return error;
     }
 
-    virtual bool hasError() const {
+    bool hasError() const {
         return !error.isEmpty();
     }
 
-    virtual bool isCoR() const {
+    bool isCoR() const {
         return hasError();
     }
 
@@ -54,4 +54,3 @@ private:
     QString error;
 };
 }  // namespace HI
-#endif  // GUITESTOPSTATUS_H
