@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,13 +26,11 @@
 
 namespace HI {
 
-MainThreadRunnable::MainThreadRunnable(GUITestOpStatus &os, CustomScenario *scenario)
-    : QObject(NULL),
-      os(os),
-      scenario(scenario) {
-    if (Q_UNLIKELY(NULL == scenario)) {
-        os.setError("Scenario is NULL");
-        return;
+MainThreadRunnable::MainThreadRunnable(CustomScenario* _scenario)
+    : QObject(nullptr),
+      scenario(_scenario) {
+    if (scenario == nullptr) {
+        GT_FAIL("Scenario is null!", );
     }
 }
 
@@ -51,9 +49,9 @@ void MainThreadRunnable::doRequest() {
     obj.moveToThread(QApplication::instance()->thread());
 
     QMetaObject::Connection connection = connect(this,
-                                                 SIGNAL(si_request(MainThreadRunnable *)),
+                                                 SIGNAL(si_request(MainThreadRunnable*)),
                                                  &obj,
-                                                 SLOT(sl_requestAsked(MainThreadRunnable *)),
+                                                 SLOT(sl_requestAsked(MainThreadRunnable*)),
                                                  Qt::BlockingQueuedConnection);
 
     emit si_request(this);
@@ -61,27 +59,22 @@ void MainThreadRunnable::doRequest() {
 }
 
 void MainThreadRunnable::run() {
-    if (Q_UNLIKELY(NULL == scenario)) {
-        os.setError("Scenario is NULL");
-        return;
+    if (scenario == nullptr) {
+        GT_FAIL("Scenario is null!", );
     }
-    scenario->run(os);
+    scenario->run();
 }
 
-void MainThreadRunnable::runInMainThread(GUITestOpStatus &os, CustomScenario *scenario) {
-    if (Q_UNLIKELY(NULL == scenario)) {
-        os.setError("Custom scenario is NULL");
-        return;
+void MainThreadRunnable::runInMainThread(CustomScenario* scenario) {
+    CHECK_NO_OS_ERROR();
+    if (scenario == nullptr) {
+        GT_FAIL("Scenario is null!", );
     }
-    MainThreadRunnable mainThreadRunnable(os, scenario);
+    MainThreadRunnable mainThreadRunnable(scenario);
     mainThreadRunnable.doRequest();
 }
 
-MainThreadRunnableObject::MainThreadRunnableObject()
-    : QObject(NULL) {
-}
-
-void MainThreadRunnableObject::sl_requestAsked(MainThreadRunnable *runnable) {
+void MainThreadRunnableObject::sl_requestAsked(MainThreadRunnable* runnable) {
     runnable->run();
 }
 
