@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _HI_MAIN_THREAD_RUNNABLE_H_
-#define _HI_MAIN_THREAD_RUNNABLE_H_
+#pragma once
 
 #include <core/CustomScenario.h>
 
@@ -34,31 +33,28 @@ namespace HI {
 class HI_EXPORT MainThreadRunnable : public QObject {
     Q_OBJECT
 public:
-    MainThreadRunnable(GUITestOpStatus &os, CustomScenario *scenario);
-    ~MainThreadRunnable();
+    MainThreadRunnable(CustomScenario* scenario);
+    ~MainThreadRunnable() override;
 
     void doRequest();
     void run();
 
-    static void runInMainThread(GUITestOpStatus &os, CustomScenario *scenario);
+    static void runInMainThread(CustomScenario* scenario);
 
 signals:
-    void si_request(MainThreadRunnable *mainThreadRunnable);
+    void si_request(MainThreadRunnable* mainThreadRunnable);
 
 private:
-    GUITestOpStatus &os;
-    CustomScenario *scenario;
+    ;
+    CustomScenario* scenario;
 };
 
 class MainThreadRunnableObject : public QObject {
     Q_OBJECT
 public:
-    MainThreadRunnableObject();
 
 public slots:
-    void sl_requestAsked(MainThreadRunnable *mainThreadRunnable);
+    void sl_requestAsked(MainThreadRunnable* mainThreadRunnable);
 };
 
 }  // namespace HI
-
-#endif
