@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,7 +28,6 @@ namespace HI {
 
 #define GT_CLASS_NAME "GTKeyboardDriver"
 
-#define GT_METHOD_NAME "keyClick"
 
 QList<Qt::Key> GTKeyboardDriver::modifiersToKeys(Qt::KeyboardModifiers mod) {
     QList<Qt::Key> result;
@@ -66,9 +65,8 @@ bool GTKeyboardDriver::keyClick(Qt::Key key, Qt::KeyboardModifiers modifiers, bo
     }
     return true;
 }
-#undef GT_METHOD_NAME
 
-bool GTKeyboardDriver::keySequence(const QString &str, Qt::KeyboardModifiers modifiers) {
+bool GTKeyboardDriver::keySequence(const QString& str, Qt::KeyboardModifiers modifiers) {
     QList<Qt::Key> modifierKeys = modifiersToKeys(modifiers);
     foreach (Qt::Key mod, modifierKeys) {
         DRIVER_CHECK(keyPress(mod), "modifier could not be pressed");
@@ -92,7 +90,7 @@ bool GTKeyboardDriver::keySequence(const QString &str, Qt::KeyboardModifiers mod
 }
 
 /******************************************************************************/
-int GTKeyboardDriver::keys::operator[](const Qt::Key &key) const {
+int GTKeyboardDriver::keys::operator[](const Qt::Key& key) const {
     return value(key);
 }
 
