@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,13 +30,19 @@ namespace HI {
 
 #if defined __linux__
 
+void GTKeyboardDriver::releasePressedKeys() {
+    GTKeyboardDriver::keyRelease(Qt::Key_Control);
+    GTKeyboardDriver::keyRelease(Qt::Key_Shift);
+    GTKeyboardDriver::keyRelease(Qt::Key_Alt);
+}
+
 bool GTKeyboardDriver::keyPress(char key, Qt::KeyboardModifiers modifiers) {
     DRIVER_CHECK(key != 0, "key = 0");
 
     QByteArray display_name = qgetenv("DISPLAY");
     DRIVER_CHECK(!display_name.isEmpty(), "Environment variable \"DISPLAY\" not found");
 
-    Display *display = XOpenDisplay(display_name.constData());
+    Display* display = XOpenDisplay(display_name.constData());
     DRIVER_CHECK(display != 0, "display is NULL");
 
     QList<Qt::Key> modifierKeys = modifiersToKeys(modifiers);
@@ -144,7 +150,7 @@ bool GTKeyboardDriver::keyRelease(char key, Qt::KeyboardModifiers modifiers) {
     QByteArray display_name = qgetenv("DISPLAY");
     DRIVER_CHECK(!display_name.isEmpty(), "Environment variable \"DISPLAY\" not found");
 
-    Display *display = XOpenDisplay(display_name.constData());
+    Display* display = XOpenDisplay(display_name.constData());
     DRIVER_CHECK(display != 0, "display is NULL");
 
     switch (key) {
@@ -282,11 +288,11 @@ bool GTKeyboardDriver::keyPress(Qt::Key key, Qt::KeyboardModifiers modifiers) {
     QByteArray displayName = qgetenv("DISPLAY");
     DRIVER_CHECK(!displayName.isEmpty(), "Environment variable 'DISPLAY' not found");
 
-    Display *display = XOpenDisplay(displayName.constData());
+    Display* display = XOpenDisplay(displayName.constData());
     DRIVER_CHECK(display != nullptr, "display is NULL");
 
     QList<Qt::Key> modifierKeys = modifiersToKeys(modifiers);
-    for (const Qt::Key &mod : qAsConst(modifierKeys)) {
+    for (const Qt::Key& mod : qAsConst(modifierKeys)) {
         KeyCode modCode = XKeysymToKeycode(display, GTKeyboardDriver::key[mod]);
         DRIVER_CHECK(XTestFakeKeyEvent(display, modCode, 1, 0) != 0, "keyPress modifier failed");
     }
@@ -304,7 +310,7 @@ bool GTKeyboardDriver::keyRelease(Qt::Key key, Qt::KeyboardModifiers modifiers)
     QByteArray display_name = qgetenv("DISPLAY");
     DRIVER_CHECK(!display_name.isEmpty(), "Environment variable \"DISPLAY\" not found");
 
-    Display *display = XOpenDisplay(display_name.constData());
+    Display* display = XOpenDisplay(display_name.constData());
     DRIVER_CHECK(display != 0, "display is NULL");
 
     XTestFakeKeyEvent(display, XKeysymToKeycode(display, GTKeyboardDriver::key[key]), 0, 0);
