@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,7 +29,6 @@
 #    include <windows.h>
 #    define VIRTUAL_TO_SCAN_CODE 0
 #endif
-#define GT_METHOD_NAME "keyPress"
 
 namespace HI {
 
@@ -37,11 +36,7 @@ namespace HI {
 
 #    define GT_CLASS_NAME "GTKeyboardDriver Windows"
 
-namespace {
-
-namespace {
-
-QList<int> initExtendedKeys() {
+static QList<int> initExtendedKeys() {
     // The list is taken from here: https://msdn.microsoft.com/en-us/library/windows/desktop/ms646267(v=vs.85).aspx#_win32_Keystroke_Message_Flags
     // There also sohuld be the numpad enter key in the list, but I don't know its code
     return QList<int>() << VK_RCONTROL
@@ -62,18 +57,16 @@ QList<int> initExtendedKeys() {
                         << VK_DIVIDE;
 }
 
-bool isExtended(int key) {
+static bool isExtended(int key) {
     static const QList<int> extendedKeys = initExtendedKeys();
     return extendedKeys.contains(key);
 }
 
-bool isExtended(Qt::Key key) {
+static bool isExtended(Qt::Key key) {
     return isExtended(GTKeyboardDriver::key[key]);
 }
 
-}  // namespace
-
-INPUT getKeyEvent(int key, bool keyUp = false, bool extended = false) {
+static INPUT getKeyEvent(int key, bool keyUp = false, bool extended = false) {
     INPUT event;
     event.type = INPUT_KEYBOARD;
     event.ki.wVk = key;
@@ -88,7 +81,7 @@ INPUT getKeyEvent(int key, bool keyUp = false, bool extended = false) {
     return event;
 }
 
-bool keyPressWindows(int key, int modifiers = 0, bool extended = false) {
+static bool keyPressWindows(int key, int modifiers = 0, bool extended = false) {
     DRIVER_CHECK(key != 0, " Error: key = 0 in GTKeyboardDriver::keyPress()");
 
     if (modifiers) {
@@ -104,7 +97,7 @@ bool keyPressWindows(int key, int modifiers = 0, bool extended = false) {
 #    undef GT_METHOD_NAME
 
 #    define GT_METHOD_NAME "keyRelease"
-bool keyReleaseWindows(int key, int modifiers = 0, bool extended = false) {
+static bool keyReleaseWindows(int key, int modifiers = 0, bool extended = false) {
     DRIVER_CHECK(key != 0, " Error: key = 0 in GTKeyboardDriver::keyRelease()");
 
     if (modifiers) {
@@ -118,7 +111,6 @@ bool keyReleaseWindows(int key, int modifiers = 0, bool extended = false) {
     return true;
 }
 #    undef GT_METHOD_NAME
-}  // namespace
 
 bool GTKeyboardDriver::keyPress(char key, Qt::KeyboardModifiers modifiers) {
     if (isalpha(key)) {
@@ -403,6 +395,9 @@ GTKeyboardDriver::keys::keys() {
     // macro VK_* defined in WinUser.h
 }
 
+void GTKeyboardDriver::releasePressedKeys() {
+}
+
 #    undef GT_CLASS_NAME
 
 #endif
