@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@
 #include <utils/GTThread.h>
 
 #include <QApplication>
+#include <QScreen>
 
 #include "GTMouseDriver.h"
 
@@ -31,72 +32,63 @@ bool GTMouseDriver::click(Qt::MouseButton button) {
     DRIVER_CHECK(press(button), "Button could not be pressed");
     DRIVER_CHECK(release(button), "Button could not be released");
     GTThread::waitForMainThread();
-    GTGlobals::sleep(100);  // Adding extra sleep to avoid occasional doubleclicks
     return true;
 }
 
-#ifndef Q_OS_DARWIN
-bool GTMouseDriver::click(const QPoint &p, Qt::MouseButton button) {
+bool GTMouseDriver::click(const QPoint& p, Qt::MouseButton button) {
     DRIVER_CHECK(moveTo(p), "Mouse move was failed");
-    DRIVER_CHECK(press(button), "Button could not be pressed");
-    DRIVER_CHECK(release(button), "Button could not be released");
-    GTThread::waitForMainThread();
-    GTGlobals::sleep(100);  // Adding extra sleep to avoid occasional doubleclicks
-    return true;
+    return click(button);
 }
-#endif
 
-namespace {
-
-#ifdef Q_OS_WIN
-bool isFarEnoughToStartDnd(const QPoint &start, const QPoint &end) {
-    return (end - start).manhattanLength() > 2 * QApplication::startDragDistance();
-}
-#endif
-
-}  // namespace
-
-bool GTMouseDriver::dragAndDrop(const QPoint &start, const QPoint &end) {
+bool GTMouseDriver::dragAndDrop(const QPoint& start, const QPoint& end) {
+    GTGlobals::sleep(QApplication::doubleClickInterval() + 1);  // Protect from double-clicks.
     DRIVER_CHECK(moveTo(start), QString("Mouse was not moved to the start point (%1, %2)").arg(start.x()).arg(start.y()));
-
-    // Wait to avoid next press to be merged with a possible click in user code into a double click.
-    GTGlobals::sleep(500);
-
     DRIVER_CHECK(press(), "Mouse button was not be pressed");
-
-// After Linux version was improved the Windows has a lot of regressions. Keeping Windows version with no changes below during investigation.
-#ifdef Q_OS_WIN
-    QPoint farPoint = (isFarEnoughToStartDnd(start, (end + start) / 2) ? (end + start) / 2 : QPoint(0, 0));
-    DRIVER_CHECK(moveTo(farPoint), QString("Mouse could not be moved to point (%1, %2)").arg(farPoint.x()).arg(farPoint.y()));
-    DRIVER_CHECK(moveTo(end), QString("Mouse could not be moved to point (%1, %2)").arg(end.x()).arg(end.y()));
-#else
     GTThread::waitForMainThread();
+
+    QPoint middlePoint = (end + start) / 2;
+    int startDragDistance = QApplication::startDragDistance();
+    bool isMiddlePointValid = (middlePoint - start).manhattanLength() > 2 * startDragDistance;
+    if (!isMiddlePointValid) {
+        middlePoint = start + QPoint(3 * startDragDistance, 3 * startDragDistance);
+        QRect screenRect = QGuiApplication::primaryScreen()->geometry();
+        if (middlePoint.x() > screenRect.right()) {
+            middlePoint.setX(start.x() - 3 * startDragDistance);
+        }
+        if (middlePoint.y() > screenRect.bottom()) {
+            middlePoint.setY(start.y() - 3 * startDragDistance);
+        }
+    }
+    DRIVER_CHECK(moveTo(middlePoint), QString("Mouse could not be moved to point (%1, %2)").arg(middlePoint.x()).arg(middlePoint.y()));
+
     DRIVER_CHECK(moveTo(end), QString("Mouse was not moved to the end point (%1, %2)").arg(end.x()).arg(end.y()));
     GTThread::waitForMainThread();
-    GTGlobals::sleep(500);  // Do extra wait before the release. Otherwise the method is not stable on Linux.
+
+#ifndef Q_OS_WIN
+    GTGlobals::sleep(500);  // Do extra wait before the release. Otherwise, the method is not stable on Linux.
 #endif
+
     DRIVER_CHECK(release(), "Mouse button was not released");
     GTThread::waitForMainThread();
     return true;
 }
 
-bool GTMouseDriver::selectArea(const QPoint &start, const QPoint &end) {
+bool GTMouseDriver::selectArea(const QPoint& start, const QPoint& end) {
     DRIVER_CHECK(dragAndDrop(start, end), "Drag and drop failed");
     return true;
 }
 
-#ifndef Q_OS_DARWIN
 bool GTMouseDriver::doubleClick() {
     DRIVER_CHECK(press(Qt::LeftButton), "Left button could not be pressed on first click");
     DRIVER_CHECK(release(Qt::LeftButton), "Left button could not be released on first click");
-    GTGlobals::sleep(100);
+    // Use an interval below "doubleClickInterval" between clicks because we want it to be a "double-click".
+    GTGlobals::sleep(QApplication::doubleClickInterval() / 2);
 
     DRIVER_CHECK(press(Qt::LeftButton), "Left button could not be pressed on second click");
     DRIVER_CHECK(release(Qt::LeftButton), "Left button could not be released on second click");
-    GTGlobals::sleep(250);
+    GTThread::waitForMainThread();
     return true;
 }
-#endif
 
 QPoint GTMouseDriver::getMousePosition() {
     return QCursor::pos();
