@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _HI_GUI_GTMOUSEDRIVER_H_
-#define _HI_GUI_GTMOUSEDRIVER_H_
-
+#pragma once
 #include <QtCore/QPoint>
 
 #include "GTGlobals.h"
@@ -34,12 +32,12 @@ class HI_EXPORT GTMouseDriver {
 public:
     // fails if given coordinates are not in the screen's rect
     // Linux: fails if there is an opening X display error
-    static bool moveTo(const QPoint &p);
+    static bool moveTo(const QPoint& p);
 
     // fails if press or release fails
     // Linux: fails if there is an opening X display error
     static bool click(Qt::MouseButton = Qt::LeftButton);  // all click methods work with the current position of the cursor
-    static bool click(const QPoint &p, Qt::MouseButton = Qt::LeftButton);  // move and click
+    static bool click(const QPoint& p, Qt::MouseButton = Qt::LeftButton);  // move and click
     static bool doubleClick();
 
     // fails if the given button is not Qt::LeftButton, Qt::RightButton or Qt::MiddleButton
@@ -47,19 +45,19 @@ public:
     static bool press(Qt::MouseButton = Qt::LeftButton);
     static bool release(Qt::MouseButton = Qt::LeftButton);  // release method should check if this key has been already pressed. Do nothing otherwise
 
-    static bool dragAndDrop(const QPoint &start, const QPoint &end);
-    static bool selectArea(const QPoint &start, const QPoint &end);
+    static bool dragAndDrop(const QPoint& start, const QPoint& end);
+    static bool selectArea(const QPoint& start, const QPoint& end);
 
     // Linux: fails if there is an opening X display error
     static bool scroll(int value);  // positive values for scrolling up, negative for scrolling down
 
+    /** Releases all currently pressed buttons. Run before every test to reset mouse state. */
+    static void releasePressedButtons();
+
     static QPoint getMousePosition();
 
 private:
-    static QPoint mousePos;
     static Qt::MouseButtons bp;
 };
 
 }  // namespace HI
-
-#endif
