@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,11 @@
  * MA 02110-1301, USA.
  */
 
+#include <utils/GTThread.h>
+
 #include <QByteArray>
 
 #include "GTMouseDriver.h"
-
 #ifdef __linux__
 #    include <X11/extensions/XTest.h>
 #endif
@@ -31,9 +32,6 @@ namespace HI {
 
 #ifdef __linux__
 
-#    define GT_CLASS_NAME "GTMouseDriver Linux"
-QPoint GTMouseDriver::mousePos = QPoint(-1, -1);
-
 #    define DELAY_ON_EVERY_N_PX 16
 /**
  * Returns delay = 1 millisecond for every DELAY_ON_EVERY_N_PX pixel or 0 otherwise.
@@ -43,13 +41,12 @@ static int getMouseMoveDelayMillis(int pos) {
     return pos % DELAY_ON_EVERY_N_PX == 0 ? 1 : 0;
 }
 
-#    define GT_METHOD_NAME "moveTo"
-bool GTMouseDriver::moveTo(const QPoint &p) {
+bool GTMouseDriver::moveTo(const QPoint& p) {
     QByteArray display_name = qgetenv("DISPLAY");
     DRIVER_CHECK(!display_name.isEmpty(), "Environment variable \"DISPLAY\" not found");
 
-    Display *display = XOpenDisplay(display_name.constData());
-    DRIVER_CHECK(display != 0, "display is NULL");
+    Display* display = XOpenDisplay(display_name.constData());
+    DRIVER_CHECK(display != nullptr, "display is NULL");
 
     int horres = XDisplayWidth(display, 0);
     int vertres = XDisplayHeight(display, 0);
@@ -95,19 +92,17 @@ bool GTMouseDriver::moveTo(const QPoint &p) {
     GTGlobals::sleep(100);
     return true;
 }
-#    undef GT_METHOD_NAME
 
-#    define GT_METHOD_NAME "press"
 bool GTMouseDriver::press(Qt::MouseButton button) {
     QByteArray display_name = qgetenv("DISPLAY");
     DRIVER_CHECK(!display_name.isEmpty(), "Environment variable \"DISPLAY\" not found");
 
-    Display *display = XOpenDisplay(display_name.constData());
-    DRIVER_CHECK(display != 0, "display is NULL");
+    Display* display = XOpenDisplay(display_name.constData());
+    DRIVER_CHECK(display != nullptr, "display is NULL");
 
     // 1 = Left, 2 = Middle, 3 = Right
     unsigned int btn = button == Qt::LeftButton ? 1 : button == Qt::RightButton ? 3
-                                                  : button == Qt::MidButton     ? 2
+                                                  : button == Qt::MiddleButton  ? 2
                                                                                 : 0;
     DRIVER_CHECK(btn != 0, "button is 0");
 
@@ -118,19 +113,17 @@ bool GTMouseDriver::press(Qt::MouseButton button) {
 
     return true;
 }
-#    undef GT_METHOD_NAME
 
-#    define GT_METHOD_NAME "release"
 bool GTMouseDriver::release(Qt::MouseButton button) {
     // TODO: check if this key has been already pressed
     QByteArray display_name = qgetenv("DISPLAY");
     DRIVER_CHECK(!display_name.isEmpty(), "Environment variable \"DISPLAY\" not found");
 
-    Display *display = XOpenDisplay(display_name.constData());
-    DRIVER_CHECK(display != 0, "display is NULL");
+    Display* display = XOpenDisplay(display_name.constData());
+    DRIVER_CHECK(display != nullptr, "display is NULL");
 
     unsigned int btn = button == Qt::LeftButton ? 1 : button == Qt::RightButton ? 3
-                                                  : button == Qt::MidButton     ? 2
+                                                  : button == Qt::MiddleButton  ? 2
                                                                                 : 0;
     DRIVER_CHECK(btn != 0, "button is 0");
 
@@ -141,15 +134,13 @@ bool GTMouseDriver::release(Qt::MouseButton button) {
 
     return true;
 }
-#    undef GT_METHOD_NAME
 
-#    define GT_METHOD_NAME "scroll"
 bool GTMouseDriver::scroll(int value) {
     QByteArray display_name = qgetenv("DISPLAY");
     DRIVER_CHECK(!display_name.isEmpty(), "Environment variable \"DISPLAY\" not found");
 
-    Display *display = XOpenDisplay(display_name.constData());
-    DRIVER_CHECK(display != 0, "display is NULL");
+    Display* display = XOpenDisplay(display_name.constData());
+    DRIVER_CHECK(display != nullptr, "display is NULL");
 
     unsigned button = value > 0 ? Button4 : Button5;  // Button4 - scroll up, Button5 - scroll down
     value = value > 0 ? value : -value;
@@ -162,11 +153,14 @@ bool GTMouseDriver::scroll(int value) {
     XFlush(display);
     XCloseDisplay(display);
 
+    GTThread::waitForMainThread();
     return true;
 }
-#    undef GT_METHOD_NAME
 
-#    undef GT_CLASS_NAME
+void GTMouseDriver::releasePressedButtons() {
+    GTMouseDriver::release(Qt::RightButton);
+    GTMouseDriver::release(Qt::LeftButton);
+}
 
 #endif
 }  // namespace HI
