@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,6 +19,8 @@
  * MA 02110-1301, USA.
  */
 
+#include <utils/GTThread.h>
+
 #include "GTMouseDriver.h"
 
 #ifdef _WIN32
@@ -29,11 +31,8 @@ namespace HI {
 
 #ifdef _WIN32
 
-#    define GT_CLASS_NAME "GTMouseDriver Windows"
-QPoint GTMouseDriver::mousePos = QPoint(-1, -1);
-
 #    define GT_METHOD_NAME "moveToP"
-bool GTMouseDriver::moveTo(const QPoint &p) {
+bool GTMouseDriver::moveTo(const QPoint& p) {
     int x = p.x();
     int y = p.y();
     // get screen resolution
@@ -123,7 +122,7 @@ bool GTMouseDriver::moveTo(const QPoint &p) {
 #    define GT_METHOD_NAME "press"
 bool GTMouseDriver::press(Qt::MouseButton button) {
     unsigned int btn = button == Qt::LeftButton ? MOUSEEVENTF_LEFTDOWN : button == Qt::RightButton ? MOUSEEVENTF_RIGHTDOWN
-                                                                     : button == Qt::MidButton     ? MOUSEEVENTF_MIDDLEDOWN
+                                                                     : button == Qt::MiddleButton  ? MOUSEEVENTF_MIDDLEDOWN
                                                                                                    : 0;
     DRIVER_CHECK(btn != 0, "button is 0");
 
@@ -147,7 +146,7 @@ bool GTMouseDriver::release(Qt::MouseButton button) {
     // TODO: check if this key has been already pressed
     // unsigned int buttons[3] = {MOUSEEVENTF_LEFTUP, MOUSEEVENTF_RIGHTUP, MOUSEEVENTF_MIDDLEUP};
     unsigned int btn = button == Qt::LeftButton ? MOUSEEVENTF_LEFTUP : button == Qt::RightButton ? MOUSEEVENTF_RIGHTUP
-                                                                   : button == Qt::MidButton     ? MOUSEEVENTF_MIDDLEUP
+                                                                   : button == Qt::MiddleButton  ? MOUSEEVENTF_MIDDLEUP
                                                                                                  : 0;
     DRIVER_CHECK(btn != 0, "button is 0");
 
@@ -178,10 +177,14 @@ bool GTMouseDriver::scroll(int value) {
 
     SendInput(1, &event, sizeof(event));
 
+    GTThread::waitForMainThread();
     return true;
 }
 
 #    undef GT_CLASS_NAME
 
+void GTMouseDriver::releasePressedButtons() {
+}
+
 #endif
 }  // namespace HI
