@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _HI_GT_CHECKBOX_H_
-#define _HI_GT_CHECKBOX_H_
+#pragma once
 
 #include <QCheckBox>
 
@@ -32,16 +31,15 @@ namespace HI {
  */
 class HI_EXPORT GTCheckBox {
 public:
-    static void setChecked(GUITestOpStatus &os, QCheckBox *checkBox, bool checked = true);
-    static void setChecked(GUITestOpStatus &os, const QString &checkBoxName, bool checked = true, QWidget const *const parent = NULL);
-    static void setChecked(GUITestOpStatus &os, const QString &checkBoxName, QWidget const *const parent = NULL);
+    static void setChecked(QCheckBox* checkBox, bool checked = true);
+    static void setChecked(const QString& checkBoxName, bool checked = true, QWidget* parent = nullptr);
+    static void setChecked(const QString& checkBoxName, QWidget* parent = nullptr);
 
-    static bool getState(GUITestOpStatus &os, QCheckBox const *const checkBox);
-    static bool getState(GUITestOpStatus &os, const QString &checkBoxName, QWidget *const parent = NULL);
+    static bool getState(QCheckBox* checkBox);
+    static bool getState(const QString& checkBoxName, QWidget* parent = nullptr);
 
-    static void checkState(GUITestOpStatus &os, QCheckBox const *const checkBox, const bool expectedState);
-    static void checkState(GUITestOpStatus &os, const QString &checkBoxName, bool expectedState, QWidget const *const parent = NULL);
+    static void checkState(QCheckBox* checkBox, bool expectedState);
+    static void checkState(const QString& checkBoxName, bool expectedState, QWidget* parent = nullptr);
 };
 
 }  // namespace HI
-#endif
