@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,23 +30,18 @@ namespace HI {
 
 #define GT_CLASS_NAME "GTGroupBox"
 
-#define GT_METHOD_NAME "getChecked"
-bool GTGroupBox::getChecked(GUITestOpStatus &os, QGroupBox *groupBox) {
+bool GTGroupBox::getChecked(QGroupBox* groupBox) {
     GT_CHECK_RESULT(groupBox != NULL, "QGroupBox is NULL", false);
     GT_CHECK_RESULT(groupBox->isEnabled(), "QGroupBox is disabled", false);
 
     return groupBox->isChecked();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "getChecked"
-bool GTGroupBox::getChecked(GUITestOpStatus &os, const QString &groupBoxName, QWidget *parent) {
-    return GTGroupBox::getChecked(os, GTWidget::findExactWidget<QGroupBox *>(os, groupBoxName, parent));
+bool GTGroupBox::getChecked(const QString& groupBoxName, QWidget* parent) {
+    return GTGroupBox::getChecked(GTWidget::findGroupBox(groupBoxName, parent));
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "setChecked"
-void GTGroupBox::setChecked(GUITestOpStatus &os, QGroupBox *groupBox, bool checked) {
+void GTGroupBox::setChecked(QGroupBox* groupBox, bool checked) {
     GT_CHECK(groupBox != NULL, "QGroupBox is NULL");
 
     if (groupBox->isChecked() == checked) {
@@ -72,26 +67,21 @@ void GTGroupBox::setChecked(GUITestOpStatus &os, QGroupBox *groupBox, bool check
 
     const QRect checkboxRect = groupBox->style()->subControlRect(QStyle::CC_GroupBox, &options, QStyle::SC_GroupBoxCheckBox);
 
-    GTWidget::click(os, groupBox, Qt::LeftButton, checkboxRect.center());
+    GTWidget::click(groupBox, Qt::LeftButton, checkboxRect.center());
     GTGlobals::sleep(200);
 
     GT_CHECK(checked == groupBox->isChecked(), "Can't set a new state");
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "setChecked"
-void GTGroupBox::setChecked(GUITestOpStatus &os, const QString &groupBoxName, bool checked, QWidget *parent) {
-    GTGroupBox::setChecked(os, GTWidget::findExactWidget<QGroupBox *>(os, groupBoxName, parent), checked);
+void GTGroupBox::setChecked(const QString& groupBoxName, bool checked, QWidget* parent) {
+    GTGroupBox::setChecked(GTWidget::findGroupBox(groupBoxName, parent), checked);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "setChecked"
-void GTGroupBox::setChecked(GUITestOpStatus &os, const QString &groupBoxName, QWidget *parent) {
-    GTGroupBox::setChecked(os, GTWidget::findExactWidget<QGroupBox *>(os, groupBoxName, parent));
+void GTGroupBox::setChecked(const QString& groupBoxName, QWidget* parent) {
+    GTGroupBox::setChecked(GTWidget::findGroupBox(groupBoxName, parent));
 }
-#undef GT_METHOD_NAME
 
-QRect GTGroupBox::getCheckBoxRect(QGroupBox *groupBox) {
+QRect GTGroupBox::getCheckBoxRect(QGroupBox* groupBox) {
     QStyleOptionGroupBox options;
     return groupBox->style()->subControlRect(QStyle::CC_GroupBox, &options, QStyle::SC_GroupBoxCheckBox);
 }
