@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,10 +26,9 @@
 namespace HI {
 #define GT_CLASS_NAME "GTMenuBar"
 
-#define GT_METHOD_NAME "clickCornerMenu"
-void GTMenuBar::clickCornerMenu(GUITestOpStatus &os, QMenuBar *mBar, GTGlobals::WindowAction action) {
+void GTMenuBar::clickCornerMenu(QMenuBar* mBar, GTGlobals::WindowAction action) {
     GT_CHECK(mBar != NULL, "QMenuBar is NULL");
-    QWidget *cWidget = mBar->cornerWidget();
+    QWidget* cWidget = mBar->cornerWidget();
     GT_CHECK(cWidget != NULL, "Corner widget is NULL");
     QRect r = cWidget->rect();
 
@@ -47,7 +46,6 @@ void GTMenuBar::clickCornerMenu(GUITestOpStatus &os, QMenuBar *mBar, GTGlobals::
     GTMouseDriver::click();
     GTGlobals::sleep(500);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
