@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _HI_GT_PLAINTEXTEDIT_H_
-#define _HI_GT_PLAINTEXTEDIT_H_
-
+#pragma once
 #include <QPlainTextEdit>
 
 #include "GTGlobals.h"
@@ -30,24 +28,11 @@ namespace HI {
 
 class HI_EXPORT GTPlainTextEdit {
 public:
-    enum PasteMethod { Shortcut,
-                       Mouse };
+    /** Sets new text to the 'textEdit'. */
+    static void setText(QPlainTextEdit* textEdit, const QString& text);
 
-    // fails if lineEdit is NULL, GTLineEdit::clear fails
-    // or a set text differs from a given string
-    static void setPlainText(GUITestOpStatus &os, QPlainTextEdit *plainTextEdit, const QString &text);
-
-    // fails if lineEdit is NULL, or lineEdit's text wasn't cleared
-    static void clear(GUITestOpStatus &os, QPlainTextEdit *plainTextEdit);
-
-    // fails if GTLineEdit::clear fails
-    // static void pasteClipboard(GUITestOpStatus& os, QPlainTextEdit* plainTextEdit, PasteMethod pasteMethod = Shortcut);
-
-    // fails if lineEdit is NULL or lineEdit text is not in lineEdit's rect
-    // considering lineEdit's fontMetrics and textMargins
-    // static void checkTextSize(GUITestOpStatus& os, QPlainTextEdit* plainTextEdit);
+    /** Clears 'textEdit'. */
+    static void clear(QPlainTextEdit* textEdit);
 };
 
 }  // namespace HI
-
-#endif  // _HI_GT_PLAINTEXTEDIT_H_
