@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,32 +25,27 @@
 #include "drivers/GTKeyboardDriver.h"
 #include "drivers/GTMouseDriver.h"
 #include "primitives/GTWidget.h"
+#include "utils//GTKeyboardUtils.h"
 
 namespace HI {
 
 #define GT_CLASS_NAME "GTSpinBox"
 
-#define GT_METHOD_NAME "getValue"
-int GTSpinBox::getValue(GUITestOpStatus &os, QSpinBox *spinBox) {
-    Q_UNUSED(os);
-    GT_CHECK_RESULT(spinBox != NULL, "spinBox is NULL", -1);
+int GTSpinBox::getValue(QSpinBox* spinBox) {
+    GT_CHECK_RESULT(spinBox != nullptr, "spinBox is NULL", -1);
     return spinBox->value();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "getValue"
-int GTSpinBox::getValue(GUITestOpStatus &os, const QString &spinBoxName, QWidget *parent) {
-    return GTSpinBox::getValue(os, GTWidget::findExactWidget<QSpinBox *>(os, spinBoxName, parent));
+int GTSpinBox::getValue(const QString& spinBoxName, QWidget* parent) {
+    return GTSpinBox::getValue(GTWidget::findSpinBox(spinBoxName, parent));
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "setValue"
-void GTSpinBox::setValue(GUITestOpStatus &os, QSpinBox *spinBox, int v, GTGlobals::UseMethod useMethod) {
-    GT_CHECK(spinBox != NULL, "spinBox is NULL");
-    if (spinBox->value() == v) {
+void GTSpinBox::setValue(QSpinBox* spinBox, int v, GTGlobals::UseMethod useMethod) {
+    GT_CHECK(spinBox != nullptr, "spinBox is NULL");
+    qDebug("GTSpinBox::setValue %d", v);
+    if (getValue(spinBox) == v) {
         return;
     }
-
     GT_CHECK(v <= spinBox->maximum(), QString("value for this spinbox cannot be more then %1").arg(spinBox->maximum()));
     GT_CHECK(v >= spinBox->minimum(), QString("value for this spinbox cannot be less then %1").arg(spinBox->minimum()));
 
@@ -84,7 +79,7 @@ void GTSpinBox::setValue(GUITestOpStatus &os, QSpinBox *spinBox, int v, GTGlobal
                     key = Qt::Key_Down;
                 }
 
-                GTWidget::setFocus(os, spinBox);
+                GTWidget::setFocus(spinBox);
                 while (spinBox->value() != v) {
                     GTKeyboardDriver::keyClick(key);
                     GTGlobals::sleep(100);
@@ -93,11 +88,11 @@ void GTSpinBox::setValue(GUITestOpStatus &os, QSpinBox *spinBox, int v, GTGlobal
             }
             case GTGlobals::UseKeyBoard:
                 QString s = QString::number(v);
-                GTWidget::setFocus(os, spinBox);
+                GTWidget::setFocus(spinBox);
                 GTGlobals::sleep(100);
-                GTKeyboardDriver::keyClick('a', Qt::ControlModifier);
+                GTKeyboardUtils::selectAll();
                 GTGlobals::sleep(100);
-                GTKeyboardDriver::keyClick(Qt::Key_Delete);
+                GTKeyboardDriver::keyClick(Qt::Key_Backspace);
                 GTGlobals::sleep(100);
                 GTKeyboardDriver::keySequence(s);
                 GTGlobals::sleep(100);
@@ -108,35 +103,26 @@ void GTSpinBox::setValue(GUITestOpStatus &os, QSpinBox *spinBox, int v, GTGlobal
     GT_CHECK(currIndex == v, QString("Can't set index. Expected: %1 actual: %2").arg(v).arg(currIndex));
     GTGlobals::sleep(100);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "setValue"
-void GTSpinBox::setValue(GUITestOpStatus &os, const QString &spinBoxName, int v, GTGlobals::UseMethod useMethod, QWidget *parent) {
-    GTSpinBox::setValue(os, GTWidget::findExactWidget<QSpinBox *>(os, spinBoxName, parent), v, useMethod);
+void GTSpinBox::setValue(const QString& spinBoxName, int v, GTGlobals::UseMethod useMethod, QWidget* parent) {
+    GTSpinBox::setValue(GTWidget::findSpinBox(spinBoxName, parent), v, useMethod);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "setValue"
-void GTSpinBox::setValue(GUITestOpStatus &os, const QString &spinBoxName, int v, QWidget *parent) {
-    GTSpinBox::setValue(os, GTWidget::findExactWidget<QSpinBox *>(os, spinBoxName, parent), v);
+void GTSpinBox::setValue(const QString& spinBoxName, int v, QWidget* parent) {
+    GTSpinBox::setValue(GTWidget::findSpinBox(spinBoxName, parent), v);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "checkLimits"
-void GTSpinBox::checkLimits(GUITestOpStatus &os, QSpinBox *spinBox, int min, int max) {
+void GTSpinBox::checkLimits(QSpinBox* spinBox, int min, int max) {
     GT_CHECK(spinBox != NULL, "spinbox is NULL");
     int actualMin = spinBox->minimum();
     int actualMax = spinBox->maximum();
     GT_CHECK(actualMin == min, QString("wrong minimum. Expected: %1, actual: %2").arg(min).arg(actualMin));
     GT_CHECK(actualMax == max, QString("wrong maximum. Expected: %1, actual: %2").arg(max).arg(actualMax));
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "checkLimits"
-void GTSpinBox::checkLimits(GUITestOpStatus &os, const QString &spinBoxName, int min, int max, QWidget *parent) {
-    GTSpinBox::checkLimits(os, GTWidget::findExactWidget<QSpinBox *>(os, spinBoxName, parent), min, max);
+void GTSpinBox::checkLimits(const QString& spinBoxName, int min, int max, QWidget* parent) {
+    GTSpinBox::checkLimits(GTWidget::findSpinBox(spinBoxName, parent), min, max);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
