@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,17 +32,16 @@
 namespace HI {
 #define GT_CLASS_NAME "GTTabBar"
 
-#define GT_METHOD_NAME "setCurrentIndex"
-void GTTabBar::setCurrentIndex(GUITestOpStatus &os, QTabBar *tabBar, int index) {
+void GTTabBar::setCurrentIndex(QTabBar* tabBar, int index) {
     GT_CHECK(tabBar != nullptr, "QTabBar is null");
 
     // TODO: set index by mouse/keyboard
     class MainThreadAction : public CustomScenario {
     public:
-        MainThreadAction(QTabBar *tabBar, int index)
-            : CustomScenario(), tabBar(tabBar), index(index) {
+        MainThreadAction(QTabBar* tabBar, int index)
+            : tabBar(tabBar), index(index) {
         }
-        void run(HI::GUITestOpStatus &os) {
+        void run() {
             if (tabBar->currentIndex() == index) {
                 return;
             }
@@ -50,17 +49,16 @@ void GTTabBar::setCurrentIndex(GUITestOpStatus &os, QTabBar *tabBar, int index)
             GT_CHECK(index >= 0 && index < tabsCount, "invalid index");
             tabBar->setCurrentIndex(index);
         }
-        QTabBar *tabBar;
+        QTabBar* tabBar;
         int index;
     };
 
-    GTThread::runInMainThread(os, new MainThreadAction(tabBar, index));
+    GTThread::runInMainThread(new MainThreadAction(tabBar, index));
     GTThread::waitForMainThread();
 
     int currIndex = tabBar->currentIndex();
     GT_CHECK(currIndex == index, "Can't set index");
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
