@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,61 +20,56 @@
  */
 
 #include <drivers/GTKeyboardDriver.h>
+#include <primitives/GTTextEdit.h>
 #include <primitives/GTWidget.h>
-
-#include "primitives/GTTextEdit.h"
-#include "utils/GTKeyboardUtils.h"
+#include <system/GTClipboard.h>
+#include <utils/GTKeyboardUtils.h>
 
 namespace HI {
 
 #define GT_CLASS_NAME "GTTextEdit"
 
-#define GT_METHOD_NAME ""
-void GTTextEdit::setText(GUITestOpStatus &os, QTextEdit *textEdit, const QString &text) {
-    GT_CHECK(textEdit != NULL, "plainTextEdit is NULL");
+void GTTextEdit::setText(QTextEdit* textEdit, const QString& text, bool useCopyPaste) {
+    GT_CHECK(textEdit != nullptr, "textEdit is NULL");
 
     if (textEdit->toPlainText() == text) {
         return;
     }
+    clear(textEdit);
+    GTWidget::setFocus(textEdit);
 
-    clear(os, textEdit);
-    GTWidget::setFocus(os, textEdit);
-
-    GTKeyboardDriver::keySequence(text);
-    GTGlobals::sleep(500);
+    if (useCopyPaste) {
+        GTClipboard::setText(text);
+        GTKeyboardUtils::paste();
+    } else {
+        GTKeyboardDriver::keySequence(text);
+        GTGlobals::sleep(500);
+    }
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "getText"
-QString GTTextEdit::getText(GUITestOpStatus &os, QTextEdit *textEdit) {
-    Q_UNUSED(os);
-    GT_CHECK_RESULT(NULL != textEdit, "Text edit is NULL", "");
+QString GTTextEdit::getText(QTextEdit* textEdit) {
+    GT_CHECK_RESULT(textEdit != nullptr, "textEdit is NULL", "");
     return textEdit->toPlainText();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "containsString"
-bool GTTextEdit::containsString(GUITestOpStatus &os, QTextEdit *textEdit, const QString &string) {
-    const QString text = getText(os, textEdit);
+bool GTTextEdit::containsString(QTextEdit* textEdit, const QString& string) {
+    const QString text = getText(textEdit);
     return text.contains(string);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "clear"
-void GTTextEdit::clear(GUITestOpStatus &os, QTextEdit *textEdit) {
+void GTTextEdit::clear(QTextEdit* textEdit) {
     GT_CHECK(textEdit != NULL, "textEdit is NULL");
 
-    GTWidget::setFocus(os, textEdit);
+    GTWidget::setFocus(textEdit);
 
     GTKeyboardUtils::selectAll();
     GTGlobals::sleep(100);
-    GTKeyboardDriver::keyClick(Qt::Key_Delete);
+    GTKeyboardDriver::keyClick(Qt::Key_Backspace);
     GTGlobals::sleep(1000);
 
     QString s = textEdit->toPlainText();
-    GT_CHECK(s.isEmpty() == true, "Can't clear text, textEdit is not empty");
+    GT_CHECK(s.isEmpty(), "Can't clear text, textEdit is not empty");
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
