@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,9 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _HI_GUI_GTTOOLBAR_H_
-#define _HI_GUI_GTTOOLBAR_H_
-
+#pragma once
 #include <QToolBar>
+#include <QToolButton>
 
 #include "GTGlobals.h"
 
@@ -30,18 +29,21 @@ namespace HI {
 
 class HI_EXPORT GTToolbar {
 public:
-    static QToolBar *getToolbar(GUITestOpStatus &os, const QString &toolbarSysName);
+    static QToolBar* getToolbar(const QString& toolbarSysName);
 
-    static QWidget *getWidgetForAction(GUITestOpStatus &os, const QToolBar *toolbar, QAction *action);
-    static QWidget *getWidgetForActionObjectName(GUITestOpStatus &os, const QToolBar *toolbar, const QString &actionName);
-    static QWidget *getWidgetForActionTooltip(GUITestOpStatus &os, const QToolBar *toolbar, const QString &tooltip);
+    static QWidget* getWidgetForAction(const QToolBar* toolbar, QAction* action);
+    static QWidget* getWidgetForActionObjectName(const QToolBar* toolbar, const QString& actionName);
+    static QWidget* getWidgetForActionTooltip(const QToolBar* toolbar, const QString& tooltip);
 
-    static void clickButtonByTooltipOnToolbar(GUITestOpStatus &os, const QString &toolbarSysName, const QString &tooltip);
+    static QToolButton* getToolButtonByAction(const QToolBar* toolbar, const QString& actionName);
+
+    static void clickButtonByTooltipOnToolbar(const QString& toolbarSysName, const QString& tooltip);
+
+    /** Clicks on a widget with the given action name on the toolbar. Fails if the widget is not found or disabled. */
+    static void clickWidgetByActionName(const QString& toolbarSysName, const QString& actionObjectName);
 
 private:
-    static QAction *getActionByObjectName(GUITestOpStatus &os, const QString &actionName, const QToolBar *toolbar);
+    static QAction* getActionByObjectName(const QString& actionName, const QToolBar* toolbar);
 };
 
 }  // namespace HI
-
-#endif
