@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +26,13 @@
 
 #include "system/GTFile.h"
 
+#ifdef Q_OS_LINUX
+// We using c++14, while <filesystem> is in c++17, so using experimental version.
+// TODO: check on Windows & Mac.
+#    include <experimental/filesystem>
+namespace fs = std::experimental::filesystem;
+#endif
+
 #ifdef Q_OS_WIN
 
 // Microsoft's example of how to change file system permissions is used below.
@@ -115,7 +122,7 @@ static const QFile::Permissions GenericReadPermissions = QFile::ReadOwner | QFil
 static const QFile::Permissions GenericWritePermissions = QFile::WriteOwner |
                                                           QFile::WriteUser | QFile::WriteGroup | QFile::WriteOther;
 
-static bool setFilePermissions(const QString &path, bool allowWrite, bool recursive) {
+static bool setFilePermissions(const QString& path, bool allowWrite, bool recursive) {
     QFileInfo fileInfo(path);
     if (!(fileInfo.exists())) {
         return false;
@@ -127,7 +134,7 @@ static bool setFilePermissions(const QString &path, bool allowWrite, bool recurs
     bool res = true;
     if (recursive && fileInfo.isDir()) {
         QDir dir(path);
-        foreach (const QString &entryPath, dir.entryList(QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks)) {
+        foreach (const QString& entryPath, dir.entryList(QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks)) {
             res &= setFilePermissions(path + "/" + entryPath, allowWrite, recursive);
         }
     }
@@ -169,24 +176,24 @@ static bool setFilePermissions(const QString &path, bool allowWrite, bool recurs
 
 #define GT_CLASS_NAME "GTFile"
 
-#define GT_METHOD_NAME "setReadWrite"
-void GTFile::setReadWrite(GUITestOpStatus &os, const QString &path, bool recursive) {
+void GTFile::setReadWrite(const QString& path, bool recursive) {
+    waitForFile(path);
     bool set = setFilePermissions(path, true, recursive);
     GT_CHECK(set, "read-write permission could not be set")
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "setReadOnly"
-void GTFile::setReadOnly(GUITestOpStatus &os, const QString &path, bool recursive) {
+void GTFile::setReadOnly(const QString& path, bool recursive) {
+    waitForFile(path);
     bool set = setFilePermissions(path, false, recursive);
     GT_CHECK(set, "read-only permission could not be set")
 }
-#undef GT_METHOD_NAME
 
 const QString GTFile::backupPostfix = "_GT_backup";
 
-#define GT_METHOD_NAME "equals"
-bool GTFile::equals(GUITestOpStatus &os, const QString &path1, const QString &path2) {
+bool GTFile::equals(const QString& path1, const QString& path2, bool simplified) {
+    waitForFile(path1);
+    waitForFile(path2);
+
     QFile f1(path1);
     QFile f2(path2);
 
@@ -195,39 +202,36 @@ bool GTFile::equals(GUITestOpStatus &os, const QString &path1, const QString &pa
 
     QByteArray byteArray1 = f1.readAll();
     QByteArray byteArray2 = f2.readAll();
+    if (simplified) {
+        byteArray1 = byteArray1.simplified();
+        byteArray2 = byteArray2.simplified();
+    }
 
-    GT_CHECK_RESULT((f1.error() == QFile::NoError) && (f2.error() == QFile::NoError), f1.errorString() + " " + f2.errorString(), false);
-
+    GT_CHECK_RESULT((f1.error() == QFile::NoError && f2.error() == QFile::NoError), f1.errorString() + " " + f2.errorString(), false);
     return byteArray1 == byteArray2;
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "equals"
-bool GTFile::equals(GUITestOpStatus &os, const QString &path1) {
+bool GTFile::equals(const QString& path1) {
     QFile f1(path1);
 
     bool ok = f1.open(QIODevice::ReadOnly);
     GT_CHECK_RESULT(ok, f1.errorString(), false);
 
     QByteArray byteArray1 = f1.readAll();
-    QByteArray byteArray2 = GTClipboard::text(os).toLocal8Bit();
+    QByteArray byteArray2 = GTClipboard::text().toLocal8Bit();
 
     GT_CHECK_RESULT(f1.error() == QFile::NoError, f1.errorString(), false);
 
     return byteArray1 == byteArray2;
 }
-#undef GT_METHOD_NAME
-#define GT_METHOD_NAME "getSize"
-qint64 GTFile::getSize(GUITestOpStatus &os, const QString &path) {
+qint64 GTFile::getSize(const QString& path) {
     QFile file(path);
     bool ok = file.open(QIODevice::ReadOnly);
     GT_CHECK_RESULT(ok, "file '" + path + "' is not found", -1);
     return file.size();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "copy"
-void GTFile::copy(GUITestOpStatus &os, const QString &from, const QString &to) {
+void GTFile::copy(const QString& from, const QString& to) {
     QFile f2(to);
     bool ok = f2.open(QIODevice::ReadOnly);
     if (ok) {
@@ -237,10 +241,18 @@ void GTFile::copy(GUITestOpStatus &os, const QString &from, const QString &to) {
     bool copied = QFile::copy(from, to);
     GT_CHECK(copied == true, "can't copy <" + from + "> to <" + to + ">");
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "copyDir"
-void GTFile::copyDir(GUITestOpStatus &os, const QString &dirToCopy, const QString &dirToPaste) {
+void GTFile::copyDir(const QString& dirToCopy, const QString& dirToPaste) {
+#ifdef Q_OS_LINUX
+    QByteArray from = dirToCopy.toLocal8Bit();
+    QByteArray to = dirToPaste.toLocal8Bit();
+    GT_CHECK(!fs::exists(to.constData()), "Target dir is already exists: " + dirToPaste);
+
+    std::error_code errorCode;
+    fs::copy_options options = fs::copy_options::recursive;
+    fs::copy(from.constData(), to.constData(), options, errorCode);
+    GT_CHECK(errorCode.value() == 0, "Failed to copy " + dirToCopy + " to " + dirToPaste);
+#else
     QDir from;
     from.setFilter(QDir::Hidden | QDir::AllDirs | QDir::Files);
     from.setPath(dirToCopy);
@@ -255,16 +267,15 @@ void GTFile::copyDir(GUITestOpStatus &os, const QString &dirToCopy, const QStrin
             continue;
         }
         if (info.isFile()) {
-            copy(os, info.filePath(), pastePath + '/' + info.fileName());
+            copy(info.filePath(), pastePath + '/' + info.fileName());
         } else if (info.isDir()) {
-            copyDir(os, info.filePath(), pastePath + '/' + info.fileName());
+            copyDir(info.filePath(), pastePath + '/' + info.fileName());
         }
     }
+#endif
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "removeDir"
-void GTFile::removeDir(const QString &dirPath) {
+void GTFile::removeDir(const QString& dirPath) {
     QDir dir(dirPath);
     qDebug("GT_DEBUG_MESSAGE removing dir: %s", dirPath.toLocal8Bit().constData());
 
@@ -307,27 +318,21 @@ void GTFile::removeDir(const QString &dirPath) {
     dir.rmdir(dir.absoluteFilePath(dirPath));
     qDebug("GT_DEBUG_MESSAGE directory removed: %s", dirPath.toLocal8Bit().constData());
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "backup"
-void GTFile::backup(GUITestOpStatus &os, const QString &path) {
+void GTFile::backup(const QString& path) {
     qDebug("Backup file %s", path.toLocal8Bit().constData());
     if (QFile(path).exists()) {
-        copy(os, path, path + backupPostfix);
+        copy(path, path + backupPostfix);
     } else {
         qDebug("Failed to backup. Files does not exist: %s", path.toLocal8Bit().constData());
     }
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "backupDir"
-void GTFile::backupDir(GUITestOpStatus &os, const QString &path) {
-    copyDir(os, path, path + backupPostfix);
+void GTFile::backupDir(const QString& path) {
+    copyDir(path, path + backupPostfix);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "restore"
-void GTFile::restore(GUITestOpStatus &os, const QString &path) {
+void GTFile::restore(const QString& path) {
     qDebug("Restoring file %s", path.toLocal8Bit().constData());
     QFile backupFile(path + backupPostfix);
 
@@ -343,10 +348,8 @@ void GTFile::restore(GUITestOpStatus &os, const QString &path) {
     bool renamed = backupFile.rename(path);
     GT_CHECK(renamed == true, "restore of <" + path + "> can't be done");
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "restoreDir"
-void GTFile::restoreDir(GUITestOpStatus &os, const QString &path) {
+void GTFile::restoreDir(const QString& path) {
     QDir backupDir(path + backupPostfix);
     bool exists = backupDir.exists();
     if (!exists) {
@@ -362,33 +365,45 @@ void GTFile::restoreDir(GUITestOpStatus &os, const QString &path) {
     bool renamed = backupDir.rename(path + backupPostfix, path);
     GT_CHECK(renamed == true, "restore of <" + path + "> can't be done");
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "check"
-bool GTFile::check(GUITestOpStatus & /*os*/, const QString &path) {
+bool GTFile::check(const QString& path) {
     QFile file(path);
     return file.exists();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "create"
-void GTFile::create(GUITestOpStatus &os, const QString &filePath) {
-    Q_UNUSED(os);
+void GTFile::waitForFile(const QString& path, int timeout) {
+    for (int time = 0; time < timeout && !check(path); time += 500) {
+    }
+}
+
+void GTFile::create(const QString& filePath) {
     bool success = QFile(filePath).open(QIODevice::WriteOnly);
     GT_CHECK(success, "Can't open file to write");
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "readAll"
-QByteArray GTFile::readAll(GUITestOpStatus &os, const QString &filePath) {
-    Q_UNUSED(os);
+QByteArray GTFile::readAll(const QString& filePath) {
     QFile file(filePath);
     bool opened = file.open(QFile::ReadOnly);
-    GT_CHECK_RESULT(opened, "Can't open file for read", "");
+    GT_CHECK_RESULT(opened, "Can't open file for read: '" + filePath + "'", "");
 
     return file.readAll();
 }
-#undef GT_METHOD_NAME
+
+void GTFile::writeFile(const QString& filePath, const QByteArray& data) {
+    QFile file(filePath);
+    bool opened = file.open(QFile::WriteOnly);
+    GT_CHECK_RESULT(opened, "Can't open file for write: '" + filePath + "'", );
+    qint64 sizeWriten = file.write(data);
+    GT_CHECK_RESULT(sizeWriten == data.size(),
+                    "Failed to write data to file, input size" + QString::number(data.length()) + ", written: " + QString::number(sizeWriten), );
+}
+
+void GTFile::replaceInFile(const QString& filePath, const QString& fromText, const QString& toText) {
+    QString content = QString::fromLocal8Bit(readAll(filePath));
+    content.replace(fromText, toText);
+    writeFile(filePath, content.toLocal8Bit());
+}
+
 #undef GT_CLASS_NAME
 
 }  // namespace HI
