@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,23 +30,19 @@ namespace HI {
 
 #define GT_CLASS_NAME "GTMouse"
 
-#define GT_METHOD_NAME "moveCursorToWidget"
-void GTMouseUtils::moveCursorToWidget(GUITestOpStatus &os, QWidget *widget) {
+void GTMouseUtils::moveCursorToWidget(QWidget* widget) {
     GT_CHECK(widget != NULL, "Provided widget is null");
     QPoint widgetCenter = widget->rect().center();
     GTMouseDriver::moveTo(widgetCenter);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "moveCursorOutOfWidget"
-void GTMouseUtils::moveCursorOutOfWidget(GUITestOpStatus &os, QWidget *widget) {
+void GTMouseUtils::moveCursorOutOfWidget(QWidget* widget) {
     GT_CHECK(widget != NULL, "Provided widget is null");
     QPoint currentPosition = QCursor::pos();
     GT_CHECK(widget->rect().contains(currentPosition, false), "Cursor not over widget");
     QPoint finalPosition = widget->rect().topLeft() + QPoint(1, 1);  // top left + offset
     GTMouseDriver::moveTo(finalPosition);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
