@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,23 +19,18 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef HI_GUI_GTMOUSE_H_
-#define HI_GUI_GTMOUSE_H_
+#pragma once
+
+#include <QtWidgets/QWidget>
 
 #include "GTGlobals.h"
-#if (QT_VERSION < 0x050000)  // Qt 5
-#    include <QtGui/QWidget>
-#else
-#    include <QtWidgets/QWidget>
-#endif
 
 namespace HI {
 
 class HI_EXPORT GTMouseUtils {
 public:
-    static void moveCursorToWidget(GUITestOpStatus &os, QWidget *widget);
-    static void moveCursorOutOfWidget(GUITestOpStatus &os, QWidget *widget);
+    static void moveCursorToWidget(QWidget* widget);
+    static void moveCursorOutOfWidget(QWidget* widget);
 };
 
 }  // namespace HI
-#endif
