@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,12 +25,10 @@ namespace HI {
 
 #define GT_CLASS_NAME "GTUtilsToolTip"
 
-#define GT_METHOD_NAME "checkExistingToolTip"
-void GTUtilsToolTip::checkExistingToolTip(GUITestOpStatus &os, const QString &tooltip) {
+void GTUtilsToolTip::checkExistingToolTip(const QString& tooltip) {
     QString t = getToolTip();
     GT_CHECK(t.contains(tooltip), "Tooltip is <" + t + ">, doesn't contain <" + tooltip + ">");
 }
-#undef GT_METHOD_NAME
 
 QString GTUtilsToolTip::getToolTip() {
     GTGlobals::sleep(3000);
