@@ -4,9 +4,7 @@
 #include <stdint.h>
 #include <bam.h>
 #include "errmod.h"
-#include "bcftools/bcf.h"
-
-#define B2B_INDEL_NULL 10000
+#include "bcf.h"
 
 typedef struct __bcf_callaux_t {
 	int capQ, min_baseQ;
@@ -46,8 +44,6 @@ extern "C" {
 	void bcf_call_destroy(bcf_callaux_t *bca);
 	int bcf_call_glfgen(int _n, const bam_pileup1_t *pl, int ref_base, bcf_callaux_t *bca, bcf_callret1_t *r);
 	int bcf_call_combine(int n, const bcf_callret1_t *calls, int ref_base /*4-bit*/, bcf_call_t *call);
-	int bcf_call2bcf(int tid, int pos, bcf_call_t *bc, bcf1_t *b, bcf_callret1_t *bcr, int is_SP,
-					 const bcf_callaux_t *bca, const char *ref);
 	int bcf_call_gap_prep(int n, int *n_plp, bam_pileup1_t **plp, int pos, bcf_callaux_t *bca, const char *ref,
 						  const void *rghash);
 
