@@ -3,8 +3,6 @@
 #include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
-#include <unistd.h>
-#include <assert.h>
 #ifdef _WIN32
 #include <fcntl.h>
 #endif
@@ -116,7 +114,8 @@ static bam_header_t *hash2header(const kh_ref_t *hash)
 	bam_init_header_hash(header);
 	return header;
 }
-bam_header_t *sam_header_read2(const char *fn)
+
+bam_header_t *sam_header_read2_fd(int fd)
 {
 	bam_header_t *header;
 	int c, dret, ret, error = 0;
@@ -125,8 +124,8 @@ bam_header_t *sam_header_read2(const char *fn)
 	kstring_t *str;
 	kh_ref_t *hash;
 	khiter_t k;
-	if (fn == 0) return 0;
-	fp = (strcmp(fn, "-") == 0)? gzdopen(fileno(stdin), "r") : gzopen(fn, "r");
+	if (fd == 0) return 0;
+	fp = gzdopen(fd, "r");
 	if (fp == 0) return 0;
 	hash = kh_init(ref);
 	ks = ks_init(fp);
@@ -155,6 +154,7 @@ bam_header_t *sam_header_read2(const char *fn)
 	kh_destroy(ref, hash);
 	return header;
 }
+
 static inline uint8_t *alloc_data(bam1_t *b, int size)
 {
 	if (b->m_data < size) {
@@ -176,11 +176,11 @@ static inline bool append_text(bam_header_t *header, kstring_t *str)
 {
 	size_t x = header->l_text, y = header->l_text + str->l + 2; // 2 = 1 byte dret + 1 byte null
 	kroundup32(x); kroundup32(y);
-	if (x < y) 
+	if (x < y)
     {
         header->n_text = y;
         header->text = (char*)realloc(header->text, y);
-        if ( !header->text ) 
+        if ( !header->text )
         {
             fprintf(stderr,"realloc failed to alloc %ld bytes\n", y);
             SAMTOOLS_ERROR_MESSAGE = "realloc failed to alloc bytes\n";
@@ -481,6 +481,18 @@ int sam_read1(tamFile fp, bam_header_t *header, bam1_t *b)
 	return z;
 }
 
+/** Same as sam_open(const char*) but uses the provided file handle instead of the file name. */
+tamFile sam_dopen(int fd) {
+    tamFile fp;
+    gzFile gzfp = gzdopen(fd, "rb");
+    if (gzfp == 0) return 0;
+    fp = (tamFile)calloc(1, sizeof(struct __tamFile_t));
+    fp->str = (kstring_t*)calloc(1, sizeof(kstring_t));
+    fp->fp = gzfp;
+    fp->ks = ks_init(fp->fp);
+    return fp;
+}
+
 tamFile sam_open(const char *fn)
 {
 	tamFile fp;
