@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATION_TABLE_OBJECT_TESTS_H_
-#define _U2_ANNOTATION_TABLE_OBJECT_TESTS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -37,10 +36,10 @@ class Document;
 class GTestAnnotationDataItem : public QObject {
     Q_OBJECT
 public:
-    GTestAnnotationDataItem(const SharedAnnotationData &ad, QObject *p)
+    GTestAnnotationDataItem(const SharedAnnotationData& ad, QObject* p)
         : QObject(p), aData(ad) {
     }
-    const SharedAnnotationData &getAnnotation() const {
+    const SharedAnnotationData& getAnnotation() const {
         return aData;
     }
 
@@ -65,7 +64,7 @@ class GTest_FindAnnotationByNum : public XmlTest {
 
     ReportResult report();
 
-    Annotation *getAnnotation() const {
+    Annotation* getAnnotation() const {
         return result;
     }
 
@@ -75,27 +74,27 @@ private:
     QString objContextName;
     QString annotationContextName;
     int number;
-    Annotation *result;
+    Annotation* result;
 };
 
 class GTest_FindAnnotationByName : public XmlTest {
     Q_OBJECT
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_FindAnnotationByName, "find-annotation-by-name")
 
-    ReportResult report();
+    ReportResult report() override;
 
-    Annotation *getAnnotation() const {
+    Annotation* getAnnotation() const {
         return result;
     }
 
-    void cleanup();
+    void cleanup() override;
 
 private:
     QString objContextName;
     QString annotationContextName;
     QString aName;
     int number;
-    Annotation *result;
+    Annotation* result;
 };
 
 class GTest_FindAnnotationByLocation : public XmlTest {
@@ -104,7 +103,7 @@ class GTest_FindAnnotationByLocation : public XmlTest {
 
     ReportResult report();
 
-    Annotation *getAnnotation() const {
+    Annotation* getAnnotation() const {
         return result;
     }
 
@@ -116,7 +115,7 @@ private:
     QString annotationName;
     U2Region location;
     U2Strand strand;
-    Annotation *result;
+    Annotation* result;
 };
 
 class GTest_CheckAnnotationLocation : public XmlTest {
@@ -225,6 +224,17 @@ class GTest_CheckAnnotationsNamesInTwoObjects : public XmlTest {
     QString secondDocContextName;
 };
 
+// Compares all annotation tables in two documents. Groups and order of tables are taken into account, the order of
+// annotations is not taken into account.
+class GTest_CheckAnnotationsInTwoDocuments : public XmlTest {
+    Q_OBJECT
+    SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_CheckAnnotationsInTwoDocuments, "compare-annotations-in-two-objects")
+
+    ReportResult report() override;
+    QString doc1ContextName;
+    QString doc2ContextName;
+};
+
 class GTest_CreateTmpAnnotationObject : public XmlTest {
     Q_OBJECT
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_CreateTmpAnnotationObject, "create-tmp-annotation-object")
@@ -232,13 +242,12 @@ class GTest_CreateTmpAnnotationObject : public XmlTest {
     ReportResult report();
     void cleanup();
     QString objContextName;
-    AnnotationTableObject *aobj;
+    AnnotationTableObject* aobj;
 };
 
 class AnnotationTableObjectTest {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-#endif
