@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -37,7 +37,15 @@ namespace U2 {
 #define TYPE_ATTR "type"
 #define CHILDREN_COUNT_ATTR "children-count"
 
-void GTest_LoadAsnTree::init(XMLTestFormat *, const QDomElement &el) {
+AsnNodeContextObject::AsnNodeContextObject(AsnNode* _node)
+    : node(_node) {
+}
+
+AsnNodeContextObject::~AsnNodeContextObject() {
+    delete node;
+}
+
+void GTest_LoadAsnTree::init(XMLTestFormat*, const QDomElement& el) {
     rootElem = nullptr;
     contextAdded = false;
 
@@ -56,7 +64,7 @@ void GTest_LoadAsnTree::init(XMLTestFormat *, const QDomElement &el) {
     url = env->getVar("COMMON_DATA_DIR") + "/" + url;
 
     IOAdapterId ioid = el.attribute("io");
-    IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(ioid);
+    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(ioid);
 
     if (iof == nullptr) {
         stateInfo.setError(QString("io_adapter_not_found_%1").arg(ioid));
@@ -86,7 +94,7 @@ void GTest_LoadAsnTree::cleanup() {
 
 Task::ReportResult GTest_LoadAsnTree::report() {
     if (rootElem != nullptr) {
-        addContext(asnTreeContextName, rootElem);
+        addContext(asnTreeContextName, new AsnNodeContextObject(rootElem));
         contextAdded = true;
     }
 
@@ -95,7 +103,7 @@ Task::ReportResult GTest_LoadAsnTree::report() {
 
 //--------------------------------------------------------------------------------
 
-void GTest_FindFirstNodeByName::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_FindFirstNodeByName::init(XMLTestFormat*, const QDomElement& el) {
     contextAdded = false;
 
     nodeContextName = el.attribute(INDEX_ATTR);
@@ -126,19 +134,20 @@ void GTest_FindFirstNodeByName::cleanup() {
 }
 
 Task::ReportResult GTest_FindFirstNodeByName::report() {
-    AsnNode *rootElem = getContext<AsnNode>(this, rootContextName);
+    auto rootElemContext = getContext<AsnNodeContextObject>(this, rootContextName);
+    AsnNode* rootElem = rootElemContext == nullptr ? nullptr : rootElemContext->node;
     if (rootElem == nullptr) {
         stateInfo.setError(QString("node is not in the context, wrong value %1").arg(rootContextName));
         return ReportResult_Finished;
     }
 
-    AsnNode *node = ASNFormat::findFirstNodeByName(rootElem, nodeName);
+    AsnNode* node = ASNFormat::findFirstNodeByName(rootElem, nodeName);
     if (node == nullptr) {
         stateInfo.setError(QString("node not found %1").arg(nodeName));
         return ReportResult_Finished;
     }
 
-    addContext(nodeContextName, node);
+    addContext(nodeContextName, new AsnNodeContextObject(node));
     contextAdded = true;
 
     return ReportResult_Finished;
@@ -146,7 +155,7 @@ Task::ReportResult GTest_FindFirstNodeByName::report() {
 
 //--------------------------------------------------------------------------------
 
-void GTest_CheckNodeType::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_CheckNodeType::init(XMLTestFormat*, const QDomElement& el) {
     nodeContextName = el.attribute(NODE_ATTR);
     if (nodeContextName.isEmpty()) {
         failMissingValue(NODE_ATTR);
@@ -161,7 +170,8 @@ void GTest_CheckNodeType::init(XMLTestFormat *, const QDomElement &el) {
 }
 
 Task::ReportResult GTest_CheckNodeType::report() {
-    AsnNode *node = getContext<AsnNode>(this, nodeContextName);
+    auto nodeContext = getContext<AsnNodeContextObject>(this, nodeContextName);
+    AsnNode* node = nodeContext == nullptr ? nullptr : nodeContext->node;
     if (node == nullptr) {
         stateInfo.setError(QString("node is in the context, wrong value %1").arg(nodeContextName));
         return ReportResult_Finished;
@@ -178,7 +188,7 @@ Task::ReportResult GTest_CheckNodeType::report() {
 
 //--------------------------------------------------------------------------------
 
-void GTest_CheckNodeValue::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_CheckNodeValue::init(XMLTestFormat*, const QDomElement& el) {
     nodeContextName = el.attribute(NODE_ATTR);
     if (nodeContextName.isEmpty()) {
         failMissingValue(NODE_ATTR);
@@ -193,7 +203,8 @@ void GTest_CheckNodeValue::init(XMLTestFormat *, const QDomElement &el) {
 }
 
 Task::ReportResult GTest_CheckNodeValue::report() {
-    AsnNode *node = getContext<AsnNode>(this, nodeContextName);
+    auto nodeContext = getContext<AsnNodeContextObject>(this, nodeContextName);
+    AsnNode* node = nodeContext == nullptr ? nullptr : nodeContext->node;
     if (node == nullptr) {
         stateInfo.setError(QString("node is not in the context, wrong value %1").arg(nodeContextName));
         return ReportResult_Finished;
@@ -210,7 +221,7 @@ Task::ReportResult GTest_CheckNodeValue::report() {
 
 //--------------------------------------------------------------------------------
 
-void GTest_CheckNodeChildrenCount::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_CheckNodeChildrenCount::init(XMLTestFormat*, const QDomElement& el) {
     nodeContextName = el.attribute(NODE_ATTR);
     if (nodeContextName.isEmpty()) {
         failMissingValue(NODE_ATTR);
@@ -231,13 +242,14 @@ void GTest_CheckNodeChildrenCount::init(XMLTestFormat *, const QDomElement &el)
 }
 
 Task::ReportResult GTest_CheckNodeChildrenCount::report() {
-    AsnNode *node = getContext<AsnNode>(this, nodeContextName);
+    auto nodeContext = getContext<AsnNodeContextObject>(this, nodeContextName);
+    AsnNode* node = nodeContext == nullptr ? nullptr : nodeContext->node;
     if (node == nullptr) {
         stateInfo.setError(QString("node is not in the context, wrong value %1").arg(nodeContextName));
         return ReportResult_Finished;
     }
 
-    int tmpNum = node->children.count();
+    int tmpNum = node->getChildren().count();
     if (numChildren != tmpNum) {
         stateInfo.setError(QString("children count for node (%1) doesn't match: (%2)").arg(nodeContextName).arg(tmpNum) +
                            QString(", expected (%1) ").arg(numChildren));
@@ -248,8 +260,8 @@ Task::ReportResult GTest_CheckNodeChildrenCount::report() {
 
 //--------------------------------------------------------------------------------
 
-QList<XMLTestFactory *> AsnParserTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> AsnParserTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_LoadAsnTree::createFactory());
     res.append(GTest_FindFirstNodeByName::createFactory());
     res.append(GTest_CheckNodeType::createFactory());
