@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASN_PARSER_TESTS_H_
-#define _U2_ASN_PARSER_TESTS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -32,19 +31,27 @@ namespace U2 {
 
 class AsnNode;
 
+class AsnNodeContextObject : public QObject {
+    Q_OBJECT
+public:
+    AsnNodeContextObject(AsnNode* node);
+    ~AsnNodeContextObject();
+    AsnNode* const node;
+};
+
 class GTest_LoadAsnTree : public XmlTest {
     Q_OBJECT
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_LoadAsnTree, "load-asn-tree");
 
-    ReportResult report();
+    ReportResult report() override;
 
-    virtual void cleanup();
+    void cleanup() override;
 
 private:
     QString asnTreeContextName;
     bool contextAdded;
-    AsnNode *rootElem;
+    AsnNode* rootElem;
 };
 
 class GTest_FindFirstNodeByName : public XmlTest {
@@ -52,14 +59,14 @@ class GTest_FindFirstNodeByName : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_FindFirstNodeByName, "find-first-node-by-name");
 
-    ReportResult report();
-    void cleanup();
+    ReportResult report() override;
+    void cleanup() override;
 
 private:
     QString rootContextName;
     QString nodeContextName;
     QString nodeName;
-    bool contextAdded;
+    bool contextAdded = false;
 };
 
 class GTest_CheckNodeType : public XmlTest {
@@ -67,7 +74,7 @@ class GTest_CheckNodeType : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_CheckNodeType, "check-node-type");
 
-    ReportResult report();
+    ReportResult report() override;
 
 private:
     QString nodeContextName;
@@ -79,7 +86,7 @@ class GTest_CheckNodeValue : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_CheckNodeValue, "check-node-value");
 
-    ReportResult report();
+    ReportResult report() override;
 
 private:
     QString nodeContextName;
@@ -90,18 +97,16 @@ class GTest_CheckNodeChildrenCount : public XmlTest {
     Q_OBJECT
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_CheckNodeChildrenCount, "check-node-children-count");
-    ReportResult report();
+    ReportResult report() override;
 
 private:
     QString nodeContextName;
-    int numChildren;
+    int numChildren =0;
 };
 
 class AsnParserTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-
-#endif  // _U2_ASN_PARSER_TESTS_H_
