@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -49,7 +49,7 @@ namespace U2 {
 /************************
  * GTest_RunCMDLine
  ************************/
-void GTest_RunCMDLine::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_RunCMDLine::init(XMLTestFormat*, const QDomElement& el) {
     setUgeneclPath();
     setArgs(el);
     proc = new QProcess(this);
@@ -73,7 +73,7 @@ void GTest_RunCMDLine::init(XMLTestFormat *, const QDomElement &el) {
     QDir protoDir(protoPath);
     protoDir.setNameFilters({"*.usa"});
     QFileInfoList protoScriptFiles = protoDir.entryInfoList();
-    for (const QFileInfo &protoScriptFile : qAsConst(protoScriptFiles)) {
+    for (const QFileInfo& protoScriptFile : qAsConst(protoScriptFiles)) {
         QFileInfo targetScriptFile(userScriptsDir.path() + "/" + protoScriptFile.fileName());
         if (!targetScriptFile.exists() || protoScriptFile.size() != targetScriptFile.size()) {
             QFile::copy(protoScriptFile.absoluteFilePath(), targetScriptFile.absoluteFilePath());
@@ -81,7 +81,7 @@ void GTest_RunCMDLine::init(XMLTestFormat *, const QDomElement &el) {
     }
 }
 
-void GTest_RunCMDLine::setArgs(const QDomElement &el) {
+void GTest_RunCMDLine::setArgs(const QDomElement& el) {
     args.append("--log-level-details");
     args.append("--lang=en");
     args.append("--log-no-task-progress");
@@ -115,15 +115,15 @@ void GTest_RunCMDLine::setArgs(const QDomElement &el) {
     cmdLog.info(args.join(" "));
 }
 
-QString GTest_RunCMDLine::splitVal(const QString &val, const QString &prefValue, const QString &prefix, bool isTmp) {
+QString GTest_RunCMDLine::splitVal(const QString& val, const QString& prefValue, const QString& prefix, bool isTmp) {
     int midSize = prefValue.size();
     const QString splitter = WorkflowUtils::getDatasetSplitter(val);
     QStringList dsVals = val.split(splitter + splitter);
     QStringList result;
-    foreach (const QString &dsVal, dsVals) {
+    foreach (const QString& dsVal, dsVals) {
         QStringList realVals = dsVal.split(splitter);
         QStringList dsResult;
-        foreach (QString s, realVals) {
+        for (QString s : qAsConst(realVals)) {
             if (s.startsWith(prefValue)) {
                 s = s.mid(midSize);
             }
@@ -138,7 +138,7 @@ QString GTest_RunCMDLine::splitVal(const QString &val, const QString &prefValue,
     return result.join(";;");
 }
 
-QString GTest_RunCMDLine::getVal(const QString &val) {
+QString GTest_RunCMDLine::getVal(const QString& val) {
     if (val.isEmpty()) {
         return val;
     }
@@ -189,7 +189,7 @@ void GTest_RunCMDLine::prepare() {
 }
 
 static const QString ERROR_LABEL_TRY1 = "finished with error";
-static QString getErrorMsg(const QString &str) {
+static QString getErrorMsg(const QString& str) {
     int ind = str.indexOf(ERROR_LABEL_TRY1);
     if (ind != -1) {
         return str.mid(ind + ERROR_LABEL_TRY1.size());
@@ -214,12 +214,13 @@ Task::ReportResult GTest_RunCMDLine::report() {
         if (!output.contains(expectedMessage, Qt::CaseSensitive)) {
             stateInfo.setError(QString("Expected message not found in output"));
         }
-        return ReportResult_Finished;
     }
     if (!unexpectedMessage.isEmpty()) {
         if (output.contains(unexpectedMessage, Qt::CaseSensitive)) {
             stateInfo.setError(QString("Unexpected message is found in output"));
         }
+    }
+    if (!expectedMessage.isEmpty() || !unexpectedMessage.isEmpty()) {
         return ReportResult_Finished;
     }
 
@@ -241,7 +242,7 @@ Task::ReportResult GTest_RunCMDLine::report() {
 
 void GTest_RunCMDLine::cleanup() {
     if (!XMLTestUtils::parentTasksHaveError(this)) {
-        foreach (const QString &file, tmpFiles) {
+        foreach (const QString& file, tmpFiles) {
             taskLog.trace(QString("Temporary file removed: %1").arg(file));
             QFile::remove(file);
         }
@@ -258,8 +259,8 @@ void GTest_RunCMDLine::cleanup() {
 /************************
  * GTest_RunCMDLine
  ************************/
-QList<XMLTestFactory *> CMDLineTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> CMDLineTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_RunCMDLine::createFactory());
     return res;
 }
