@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CMDLINE_TESTS_H_
-#define _U2_CMDLINE_TESTS_H_
+#pragma once
 
 #include <QProcess>
 
@@ -44,15 +43,15 @@ public:
 
 private:
     void setUgeneclPath();
-    void setArgs(const QDomElement &owner);
-    QString getVal(const QString &val);
-    QString splitVal(const QString &val, const QString &prefValue, const QString &prefix, bool isTmp);
+    void setArgs(const QDomElement& owner);
+    QString getVal(const QString& val);
+    QString splitVal(const QString& val, const QString& prefValue, const QString& prefix, bool isTmp);
 
 private:
     QString expectedMessage;
     QString unexpectedMessage;
     QStringList args;
-    QProcess *proc = nullptr;
+    QProcess* proc = nullptr;
     QString ugeneclPath;
     QStringList tmpFiles;
     QString workingDir;
@@ -61,9 +60,7 @@ private:
 
 class CMDLineTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };  // CMDLineTests
 
 }  // namespace U2
-
-#endif  // _U2_CMDLINE_TESTS_H_
