@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +31,6 @@
 #include "AnnotationTableObjectTest.h"
 #include "AnnotationUtilsTests.h"
 #include "AsnParserTests.h"
-#include "BinaryFindOpenCLTests.h"
 #include "BioStruct3DObjectTests.h"
 #include "CMDLineTests.h"
 #include "DNASequenceObjectTests.h"
@@ -60,7 +59,7 @@
 
 namespace U2 {
 
-extern "C" Q_DECL_EXPORT U2::Plugin *U2_PLUGIN_INIT_FUNC() {
+extern "C" Q_DECL_EXPORT U2::Plugin* U2_PLUGIN_INIT_FUNC() {
     return new CoreTests();
 }
 
@@ -72,12 +71,12 @@ CoreTests::~CoreTests() {
 }
 
 template<class Factory>
-bool CoreTests::registerFactory(XMLTestFormat *xmlTestFormat) {
-    GAutoDeleteList<XMLTestFactory> *l = new GAutoDeleteList<XMLTestFactory>(this);
+bool CoreTests::registerFactory(XMLTestFormat* xmlTestFormat) {
+    GAutoDeleteList<XMLTestFactory>* l = new GAutoDeleteList<XMLTestFactory>(this);
     l->qlist = Factory::createTestFactories();
 
     bool res = true;
-    foreach (XMLTestFactory *f, l->qlist) {
+    foreach (XMLTestFactory* f, l->qlist) {
         bool ok = xmlTestFormat->registerTestFactory(f);
         res = res && ok;
     }
@@ -87,8 +86,8 @@ bool CoreTests::registerFactory(XMLTestFormat *xmlTestFormat) {
 }
 
 void CoreTests::registerFactories() {
-    GTestFormatRegistry *tfr = AppContext::getTestFramework()->getTestFormatRegistry();
-    XMLTestFormat *xmlTestFormat = qobject_cast<XMLTestFormat *>(tfr->findFormat("XML"));
+    GTestFormatRegistry* tfr = AppContext::getTestFramework()->getTestFormatRegistry();
+    auto xmlTestFormat = qobject_cast<XMLTestFormat*>(tfr->findFormat("XML"));
     assert(xmlTestFormat != nullptr);
 
     registerFactory<SMatrixTests>(xmlTestFormat);
@@ -148,12 +147,7 @@ void CoreTests::registerFactories() {
     // GUrl tests
     registerFactory<GUrlTests>(xmlTestFormat);
 
-    // BinaryFindOpencl tests
-#ifdef OPENCL_SUPPORT
-    registerFactory<BinaryFindOpenCLTests>(xmlTestFormat);
-#endif
-
-    // FindAlforithm tests
+    // FindAlgorithm tests
     registerFactory<FindAlgorithmTests>(xmlTestFormat);
 
     // Automatic format detection tests
