@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -38,7 +38,7 @@ namespace U2 {
 #define END_ATTR "seqend"
 #define OBJ_ATTR "obj"
 //---------------------------------------------------------------------
-void GTest_DNATranslation3to1Test::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_DNATranslation3to1Test::init(XMLTestFormat*, const QDomElement& el) {
     objContextName = el.attribute(OBJ_ATTR);
     if (objContextName.isEmpty()) {
         failMissingValue(OBJ_ATTR);
@@ -75,13 +75,13 @@ void GTest_DNATranslation3to1Test::init(XMLTestFormat *, const QDomElement &el)
 }
 
 Task::ReportResult GTest_DNATranslation3to1Test::report() {
-    GObject *obj = getContext<GObject>(this, objContextName);
+    GObject* obj = getContext<GObject>(this, objContextName);
     if (obj == nullptr) {
         stateInfo.setError(QString("wrong value: %1").arg(OBJ_ATTR));
         return ReportResult_Finished;
     }
 
-    U2SequenceObject *mySequence = qobject_cast<U2SequenceObject *>(obj);
+    auto mySequence = qobject_cast<U2SequenceObject*>(obj);
     if (mySequence == nullptr) {
         stateInfo.setError(QString("error can't cast to sequence from: %1").arg(obj->getGObjectName()));
         return ReportResult_Finished;
@@ -91,11 +91,11 @@ Task::ReportResult GTest_DNATranslation3to1Test::report() {
         return ReportResult_Finished;
     }
 
-    DNATranslation *aminoTransl = 0;
+    DNATranslation* aminoTransl = 0;
 
-    DNATranslationRegistry *tr = AppContext::getDNATranslationRegistry();
+    DNATranslationRegistry* tr = AppContext::getDNATranslationRegistry();
 
-    QList<DNATranslation *> aminoTs = tr->lookupTranslation(mySequence->getAlphabet(), DNATranslationType_NUCL_2_AMINO);
+    QList<DNATranslation*> aminoTs = tr->lookupTranslation(mySequence->getAlphabet(), DNATranslationType_NUCL_2_AMINO);
     if (!aminoTs.empty()) {
         aminoTransl = tr->getStandardGeneticCodeTranslation(mySequence->getAlphabet());
     }
@@ -119,8 +119,8 @@ Task::ReportResult GTest_DNATranslation3to1Test::report() {
 }
 
 //---------------------------------------------------------------------
-QList<XMLTestFactory *> DNATranslationImplTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> DNATranslationImplTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_DNATranslation3to1Test::createFactory());
 
     return res;
