@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_ASSEMBLY_TESTS_H_
-#define _U2_DNA_ASSEMBLY_TESTS_H_
+#pragma once
 
 #include <QList>
 
@@ -43,8 +42,8 @@ public:
     void cleanup();
 
 private:
-    DnaAssemblyMultiTask *assemblyMultiTask;
-    LoadDocumentTask *loadResultTask;
+    DnaAssemblyMultiTask* assemblyMultiTask;
+    LoadDocumentTask* loadResultTask;
     QList<GUrl> shortReadUrls;
     QMap<QString, QString> customOptions;
     QString objName;
@@ -62,13 +61,11 @@ class GTest_AssemblycompareTwoSAMbyLength : public XmlTest {
     ReportResult report();
     QString file1Url;
     QString file2Url;
-    bool isBam;
 };
 
 class DnaAssemblyTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-#endif
