@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EDIT_ALIGNMENT_TESTS_H_
-#define _U2_EDIT_ALIGNMENT_TESTS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -44,11 +43,11 @@ public:
     Task::ReportResult report();
 
 private:
-    MultipleSequenceAlignmentObject *maobj;
-    MultipleSequenceAlignmentObject *expectedMaobj;
+    MultipleSequenceAlignmentObject* maobj;
+    MultipleSequenceAlignmentObject* expectedMaobj;
     QString docName;
     bool negativeTest;
-    Task *t;
+    Task* t;
     QString expectedDocName;
     QStringList seqNames;
     U2Region window;
@@ -62,8 +61,8 @@ public:
     Task::ReportResult report();
 
 private:
-    MultipleSequenceAlignmentObject *maobj;
-    MultipleSequenceAlignmentObject *expectedMaobj;
+    MultipleSequenceAlignmentObject* maobj;
+    MultipleSequenceAlignmentObject* expectedMaobj;
     QString docName;
     QString expectedDocName;
     int startBase, startSeq, width, height;
@@ -77,8 +76,8 @@ public:
     Task::ReportResult report();
 
 private:
-    MultipleSequenceAlignmentObject *maobj;
-    MultipleSequenceAlignmentObject *expectedMaobj;
+    MultipleSequenceAlignmentObject* maobj;
+    MultipleSequenceAlignmentObject* expectedMaobj;
     QString docName;
     QString expectedDocName;
     QString seqFileName;
@@ -96,9 +95,7 @@ private:
 
 class CreateSubalignimentTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-
-#endif  //_U2_EDIT_ALIGNMENT_TESTS_H_
