@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@ namespace U2 {
 #define EXPECTED_ANNOTATION_STRATEGY_ATTR "annotation_processing"
 #define LENGTH_ATTR "length"
 
-void GTest_AddPartToSequenceTask::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_AddPartToSequenceTask::init(XMLTestFormat*, const QDomElement& el) {
     QString buf;
     buf = el.attribute(DOC_NAME_ATTR);
     if (!buf.isEmpty()) {
@@ -86,19 +86,19 @@ void GTest_AddPartToSequenceTask::init(XMLTestFormat *, const QDomElement &el) {
 }
 
 void GTest_AddPartToSequenceTask::prepare() {
-    Document *loadedDocument = getContext<Document>(this, docName);
+    Document* loadedDocument = getContext<Document>(this, docName);
     if (loadedDocument == nullptr) {
         stateInfo.setError(GTest::tr("context not found %1").arg(docName));
         return;
     }
-    dnaso = (U2SequenceObject *)loadedDocument->findGObjectByName(seqName);
+    dnaso = (U2SequenceObject*)loadedDocument->findGObjectByName(seqName);
     if (dnaso == nullptr) {
         stateInfo.setError(GTest::tr("Sequence %1 not found").arg(seqName));
     } else {
-        QList<Document *> docList;
+        QList<Document*> docList;
         docList.append(loadedDocument);
         DNASequence seqToIns("test", insertedSequence.toLatin1(), U2AlphabetUtils::findBestAlphabet(insertedSequence.toLatin1()));
-        Task *t = new ModifySequenceContentTask(loadedDocument->getDocumentFormatId(), dnaso, U2Region(startPos, 0), seqToIns, false, strat);
+        Task* t = new ModifySequenceContentTask(loadedDocument->getDocumentFormatId(), dnaso, U2Region(startPos, 0), seqToIns, false, strat);
         addSubTask(t);
     }
 }
@@ -121,20 +121,21 @@ Task::ReportResult GTest_AddPartToSequenceTask::report() {
     CHECK_OP(stateInfo, ReportResult_Finished);
     if (annotationName.length() != 0) {
         if (strat != U1AnnotationUtils::AnnotationStrategyForResize_Split_To_Separate) {
-            Document *loadedDocument = getContext<Document>(this, docName);
-            QList<GObject *> annotationTablesList = loadedDocument->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
-            foreach (GObject *table, annotationTablesList) {
-                AnnotationTableObject *ato = dynamic_cast<AnnotationTableObject *>(table);
-                foreach (Annotation *curentAnnotation, ato->getAnnotations()) {
+            Document* loadedDocument = getContext<Document>(this, docName);
+            QList<GObject*> annotationTablesList = loadedDocument->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
+            for (GObject* table : qAsConst(annotationTablesList)) {
+                auto ato = dynamic_cast<AnnotationTableObject*>(table);
+                foreach (Annotation* curentAnnotation, ato->getAnnotations()) {
                     if (curentAnnotation->getName() == annotationName) {
                         int i = 0;
-                        if (curentAnnotation->getRegions().size() != expectedRegions.size()) {
+                        QVector<U2Region> regions = curentAnnotation->getRegions();
+                        if (regions.size() != expectedRegions.size()) {
                             stateInfo.setError(GTest::tr("Regions is incorrect. Expected size:%1 Actual size:%2")
                                                    .arg(expectedRegions.size())
-                                                   .arg(curentAnnotation->getRegions().size()));
+                                                   .arg(regions.size()));
                             break;
                         }
-                        foreach (const U2Region &curRegion, curentAnnotation->getRegions()) {
+                        for (const U2Region& curRegion : qAsConst(regions)) {
                             if (curRegion != expectedRegions.at(i)) {
                                 stateInfo.setError(GTest::tr("Regions is incorrect. Expected:%3,%4, but Actual:%1,%2")
                                                        .arg(curRegion.startPos)
@@ -149,13 +150,14 @@ Task::ReportResult GTest_AddPartToSequenceTask::report() {
                 }
             }
         } else {
-            Document *loadedDocument = getContext<Document>(this, docName);
-            QList<GObject *> annotationTablesList = loadedDocument->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
-            foreach (GObject *table, annotationTablesList) {
-                AnnotationTableObject *ato = dynamic_cast<AnnotationTableObject *>(table);
-                foreach (Annotation *curentAnnotation, ato->getAnnotations()) {
+            Document* loadedDocument = getContext<Document>(this, docName);
+            QList<GObject*> annotationTablesList = loadedDocument->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
+            for (GObject* table : qAsConst(annotationTablesList)) {
+                auto ato = dynamic_cast<AnnotationTableObject*>(table);
+                foreach (Annotation* curentAnnotation, ato->getAnnotations()) {
                     if (curentAnnotation->getName() == annotationName) {
-                        foreach (const U2Region &curRegion, curentAnnotation->getRegions()) {
+                        QVector<U2Region> regions = curentAnnotation->getRegions();
+                        for (const U2Region& curRegion : qAsConst(regions)) {
                             if (!expectedRegions.contains(curRegion)) {
                                 stateInfo.setError(GTest::tr("Regions is incorrect. actual region didn't found in expected region list"));
                             }
@@ -175,7 +177,7 @@ GTest_AddPartToSequenceTask::~GTest_AddPartToSequenceTask() {
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 
-void GTest_RemovePartFromSequenceTask::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_RemovePartFromSequenceTask::init(XMLTestFormat*, const QDomElement& el) {
     QString buf;
     buf = el.attribute(DOC_NAME_ATTR);
     if (!buf.isEmpty()) {
@@ -220,16 +222,16 @@ void GTest_RemovePartFromSequenceTask::init(XMLTestFormat *, const QDomElement &
 }
 
 void GTest_RemovePartFromSequenceTask::prepare() {
-    Document *loadedDocument = getContext<Document>(this, docName);
+    Document* loadedDocument = getContext<Document>(this, docName);
     if (loadedDocument == nullptr) {
         stateInfo.setError(GTest::tr("context not found %1").arg(docName));
         return;
     }
-    dnaso = (U2SequenceObject *)loadedDocument->findGObjectByName(seqName);
+    dnaso = (U2SequenceObject*)loadedDocument->findGObjectByName(seqName);
     if (dnaso == nullptr) {
         stateInfo.setError(GTest::tr("Sequence %1 not found").arg(seqName));
     } else {
-        QList<Document *> docList;
+        QList<Document*> docList;
         docList.append(loadedDocument);
         addSubTask(new ModifySequenceContentTask(loadedDocument->getDocumentFormatId(), dnaso, U2Region(startPos, length), DNASequence(), false, strat));
     }
@@ -252,20 +254,21 @@ Task::ReportResult GTest_RemovePartFromSequenceTask::report() {
     }
     CHECK_OP(stateInfo, ReportResult_Finished);
     if (annotationName.length() != 0) {
-        Document *loadedDocument = getContext<Document>(this, docName);
-        QList<GObject *> annotationTablesList = loadedDocument->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
-        foreach (GObject *table, annotationTablesList) {
-            AnnotationTableObject *ato = dynamic_cast<AnnotationTableObject *>(table);
-            foreach (Annotation *curentAnnotation, ato->getAnnotations()) {
+        Document* loadedDocument = getContext<Document>(this, docName);
+        QList<GObject*> annotationTablesList = loadedDocument->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
+        for (GObject* table : qAsConst(annotationTablesList)) {
+            auto ato = dynamic_cast<AnnotationTableObject*>(table);
+            foreach (Annotation* curentAnnotation, ato->getAnnotations()) {
                 if (curentAnnotation->getName() == annotationName) {
                     int i = 0;
-                    if (curentAnnotation->getRegions().size() != expectedRegions.size()) {
+                    QVector<U2Region> currentAnnotationRegions = curentAnnotation->getRegions();
+                    if (currentAnnotationRegions.size() != expectedRegions.size()) {
                         stateInfo.setError(GTest::tr("Regions is incorrect. Expected size:%1 Actual size:%2")
                                                .arg(expectedRegions.size())
-                                               .arg(curentAnnotation->getRegions().size()));
+                                               .arg(currentAnnotationRegions.size()));
                         break;
                     }
-                    foreach (const U2Region &curRegion, curentAnnotation->getRegions()) {
+                    for (const U2Region& curRegion : qAsConst(currentAnnotationRegions)) {
                         if (curRegion != expectedRegions.at(i)) {
                             stateInfo.setError(GTest::tr("Regions is incorrect. Expected:%3,%4, but Actual:%1,%2")
                                                    .arg(curRegion.startPos)
@@ -294,7 +297,7 @@ GTest_RemovePartFromSequenceTask::~GTest_RemovePartFromSequenceTask() {
 
 //////////////////////////////////////////////////////////////////////////
 
-void GTest_ReplacePartOfSequenceTask::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_ReplacePartOfSequenceTask::init(XMLTestFormat*, const QDomElement& el) {
     QString buf;
     buf = el.attribute(DOC_NAME_ATTR);
     if (!buf.isEmpty()) {
@@ -347,16 +350,16 @@ void GTest_ReplacePartOfSequenceTask::init(XMLTestFormat *, const QDomElement &e
 }
 
 void GTest_ReplacePartOfSequenceTask::prepare() {
-    Document *loadedDocument = getContext<Document>(this, docName);
+    Document* loadedDocument = getContext<Document>(this, docName);
     if (loadedDocument == nullptr) {
         stateInfo.setError(GTest::tr("Context not found %1").arg(docName));
         return;
     }
-    dnaso = (U2SequenceObject *)loadedDocument->findGObjectByName(seqName);
+    dnaso = (U2SequenceObject*)loadedDocument->findGObjectByName(seqName);
     if (dnaso == nullptr) {
         stateInfo.setError(GTest::tr("Sequence %1 not found").arg(seqName));
     } else {
-        QList<Document *> docList;
+        QList<Document*> docList;
         docList.append(loadedDocument);
         DNASequence dna("Inserted DNA", insertedSequence.toLatin1());
         addSubTask(new ModifySequenceContentTask(loadedDocument->getDocumentFormatId(), dnaso, U2Region(startPos, length), dna, false, strat));
@@ -380,20 +383,21 @@ Task::ReportResult GTest_ReplacePartOfSequenceTask::report() {
     }
     CHECK_OP(stateInfo, ReportResult_Finished);
     if (!annotationName.isEmpty()) {
-        Document *loadedDocument = getContext<Document>(this, docName);
-        QList<GObject *> annotationTablesList = loadedDocument->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
-        foreach (GObject *table, annotationTablesList) {
-            AnnotationTableObject *ato = dynamic_cast<AnnotationTableObject *>(table);
-            foreach (Annotation *curentAnnotation, ato->getAnnotations()) {
+        Document* loadedDocument = getContext<Document>(this, docName);
+        QList<GObject*> annotationTablesList = loadedDocument->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
+        for (GObject* table : qAsConst(annotationTablesList)) {
+            auto ato = dynamic_cast<AnnotationTableObject*>(table);
+            foreach (Annotation* curentAnnotation, ato->getAnnotations()) {
                 if (curentAnnotation->getName() == annotationName) {
                     int i = 0;
-                    if (curentAnnotation->getRegions().size() != expectedRegions.size()) {
+                    QVector<U2Region> currentAnnotationRegions = curentAnnotation->getRegions();
+                    if (currentAnnotationRegions.size() != expectedRegions.size()) {
                         stateInfo.setError(GTest::tr("Regions is incorrect. Expected size:%1 Actual size:%2")
                                                .arg(expectedRegions.size())
-                                               .arg(curentAnnotation->getRegions().size()));
+                                               .arg(currentAnnotationRegions.size()));
                         break;
                     }
-                    foreach (const U2Region &curRegion, curentAnnotation->getRegions()) {
+                    for (const U2Region& curRegion : currentAnnotationRegions) {
                         if (curRegion != expectedRegions.at(i)) {
                             stateInfo.setError(GTest::tr("Regions is incorrect. Expected:%3,%4, but Actual:%1,%2")
                                                    .arg(curRegion.startPos)
@@ -414,8 +418,8 @@ Task::ReportResult GTest_ReplacePartOfSequenceTask::report() {
 
 //////////////////////////////////////////////////////////////////////////
 
-QList<XMLTestFactory *> EditSequenceTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> EditSequenceTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_AddPartToSequenceTask::createFactory());
     res.append(GTest_RemovePartFromSequenceTask::createFactory());
     res.append(GTest_ReplacePartOfSequenceTask::createFactory());
