@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -45,7 +45,10 @@ namespace U2 {
 
 #define CIRCULAR_LABEL "circular"
 
-U2Region stringToRegion(const QString &regionStr) {
+#define TASK_NOT_CANCELLED "checkTaskNotCancelled"
+#define SKIP_RESULTS_CHECK "skipResultsCheck"
+
+U2Region stringToRegion(const QString& regionStr) {
     int region[2];
     QStringList regStrList = regionStr.split("..", QString::SkipEmptyParts);
     if (regStrList.size() != 2) {
@@ -61,7 +64,7 @@ U2Region stringToRegion(const QString &regionStr) {
     return U2Region(region[0], region[1] - region[0]);
 }
 
-void GTest_FindAlgorithmTest::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_FindAlgorithmTest::init(XMLTestFormat*, const QDomElement& el) {
     QString buf = el.attribute(STRAND_ATTR);
     if (buf.isEmpty()) {
         stateInfo.setError(GTest::tr("value not set %1").arg(STRAND_ATTR));
@@ -174,7 +177,7 @@ void GTest_FindAlgorithmTest::init(XMLTestFormat *, const QDomElement &el) {
 
             QStringList regList = regStr.split(",", QString::SkipEmptyParts);
             r = U2Region();
-            foreach (QString reg, regList) {
+            for (const QString& reg : qAsConst(regList)) {
                 U2Region regionPart = stringToRegion(reg);
                 if (regionPart.startPos > r.startPos) {
                     r.startPos = regionPart.startPos;
@@ -189,23 +192,37 @@ void GTest_FindAlgorithmTest::init(XMLTestFormat *, const QDomElement &el) {
         }
         expectedResults.append(r);
     }
+
+    buf = el.attribute(TASK_NOT_CANCELLED);
+    if (!buf.isEmpty()) {
+        if (buf.toLower() == "true") {
+            checkTaskNotCancelled = true;
+        }
+    }
+
+    buf = el.attribute(SKIP_RESULTS_CHECK);
+    if (!buf.isEmpty()) {
+        if (buf.toLower() == "true") {
+            skipResultsCheck = true;
+        }
+    }
 }
 
 void GTest_FindAlgorithmTest::prepare() {
-    Document *doc = getContext<Document>(this, docName);
+    Document* doc = getContext<Document>(this, docName);
     if (doc == nullptr) {
         stateInfo.setError(GTest::tr("context not found %1").arg(docName));
         return;
     }
-    QList<GObject *> list = doc->findGObjectByType(GObjectTypes::SEQUENCE);
+    QList<GObject*> list = doc->findGObjectByType(GObjectTypes::SEQUENCE);
     if (list.size() == 0) {
         stateInfo.setError(GTest::tr("container of object with type \"%1\" is empty").arg(GObjectTypes::SEQUENCE));
         return;
     }
 
-    foreach (GObject *go, list) {
+    foreach (GObject* go, list) {
         if (go->getGObjectName() == sequenceName) {
-            se = qobject_cast<U2SequenceObject *>(go);
+            se = qobject_cast<U2SequenceObject*>(go);
             break;
         }
     }
@@ -224,6 +241,13 @@ void GTest_FindAlgorithmTest::prepare() {
 
 Task::ReportResult GTest_FindAlgorithmTest::report() {
     QList<FindAlgorithmResult> actualResults = t->popResults();
+    if (checkTaskNotCancelled && t->isCanceled()) {
+        stateInfo.setError("'FindAlgorithmTask' was cancelled, but shouldn't.");
+        return ReportResult_Finished;
+    }
+    if (skipResultsCheck) {
+        return ReportResult_Finished;
+    }
     if (actualResults.size() != expectedResults.size()) {
         stateInfo.setError(GTest::tr("Expected and actual result sizes are different: %1 , %2")
                                .arg(expectedResults.size())
@@ -245,8 +269,8 @@ Task::ReportResult GTest_FindAlgorithmTest::report() {
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
-QList<XMLTestFactory *> FindAlgorithmTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> FindAlgorithmTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_FindAlgorithmTest::createFactory());
 
     return res;
