@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FINDALGORITHM_TESTS_H_
-#define _U2_FINDALGORITHM_TESTS_H_
+#pragma once
 
 #include <U2Algorithm/FindAlgorithmTask.h>
 
@@ -42,16 +41,16 @@ private:
     bool translatetoAmino;
     QString sequenceName;
     QString docName;
-    U2SequenceObject *se;
+    U2SequenceObject* se;
     QList<U2Region> expectedResults;
-    FindAlgorithmTask *t;
+    FindAlgorithmTask* t;
+    bool checkTaskNotCancelled = false;
+    bool skipResultsCheck = false;
 };
 
 class FindAlgorithmTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-
-#endif
