@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_PATTERN_MSA_TASK_TEST_
-#define _U2_FIND_PATTERN_MSA_TASK_TEST_
+#pragma once
 
 #include <QDomElement>
 #include <QFileInfo>
@@ -45,19 +44,18 @@ public:
 
 private:
     QString inputObjectName;
-    MultipleSequenceAlignmentObject *msaObj;
-    Document *doc;
+    MultipleSequenceAlignmentObject* msaObj;
+    Document* doc;
     FindPatternMsaSettings settings;
-    FindPatternMsaTask *findPatternTask;
+    FindPatternMsaTask* findPatternTask;
     int expectedResultsSize;
     QList<U2Region> regionsToCheck;
+    bool checkTaskNotCancelled = false;
 };
 
 class FindPatternMsaTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-
-#endif
