@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GURL_TESTS_H_
-#define _U2_GURL_TESTS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -40,6 +39,13 @@ private:
     bool isFileUrl, runThisTest;
 };
 
+// For testing GUrlUtils::getNativeAbsolutePath.
+class GTest_ConvertPathToNative : public XmlTest {
+    Q_OBJECT
+public:
+    SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_ConvertPathToNative, "convert-path-to-native");
+};
+
 class GTest_CreateTmpDir : public XmlTest {
     Q_OBJECT
 public:
@@ -62,7 +68,7 @@ private:
     QString url;
 
 private:
-    void removeDir(const QString &url);
+    void removeDir(const QString& url);
 };
 
 class GTest_RemoveTmpFile : public XmlTest {
@@ -108,7 +114,7 @@ public:
     ReportResult report();
 
 private:
-    bool findRecursive(const QString &currentDirUrl);
+    bool findRecursive(const QString& currentDirUrl);
 
     QString storageUrl;
     QString fileName;
@@ -142,8 +148,7 @@ private:
 
 class GUrlTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-#endif
