@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_LOAD_REMOTE_DOCUMENT_TEST_H_
-#define _U2_LOAD_REMOTE_DOCUMENT_TEST_H_
+#pragma once
 
 #include <U2Test/GTest.h>
 #include <U2Test/XMLTestUtils.h>
@@ -38,7 +37,7 @@ public:
     ReportResult report();
 
 private:
-    LoadRemoteDocumentTask *t;
+    LoadRemoteDocumentTask* t;
     QString dbName;
     QString docId;
     QString expectedDoc;
@@ -46,9 +45,7 @@ private:
 
 class LoadRemoteDocumentTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-
-#endif  // _U2_LOAD_REMOTE_DOCUMENT_TEST_H_
