@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _MCA_OBJECT_TESTS_H_
-#define _MCA_OBJECT_TESTS_H_
+#pragma once
 
 #include <U2Test/XMLTestUtils.h>
 
@@ -43,9 +42,7 @@ private:
 
 class McaObjectTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-
-#endif  // _MCA_OBJECT_TESTS_H_
