@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,7 +34,7 @@ namespace U2 {
 const QString GTest_CompareTwoMsa::DOC1_ATTR = "doc1";
 const QString GTest_CompareTwoMsa::DOC2_ATTR = "doc2";
 
-void GTest_CompareTwoMsa::init(XMLTestFormat *, const QDomElement &element) {
+void GTest_CompareTwoMsa::init(XMLTestFormat*, const QDomElement& element) {
     docContextName = element.attribute(DOC1_ATTR);
     if (docContextName.isEmpty()) {
         failMissingValue(DOC1_ATTR);
@@ -49,26 +49,26 @@ void GTest_CompareTwoMsa::init(XMLTestFormat *, const QDomElement &element) {
 }
 
 Task::ReportResult GTest_CompareTwoMsa::report() {
-    Document *doc1 = getContext<Document>(this, docContextName);
-    CHECK_EXT(nullptr != doc1, setError(QString("document not found: %1").arg(docContextName)), ReportResult_Finished);
+    Document* doc1 = getContext<Document>(this, docContextName);
+    CHECK_EXT(doc1 != nullptr, setError(QString("document not found: %1").arg(docContextName)), ReportResult_Finished);
 
-    const QList<GObject *> objs1 = doc1->getObjects();
+    const QList<GObject*> objs1 = doc1->getObjects();
     CHECK_EXT(1 == objs1.size(), setError(QString("document '%1' contains several objects: the comparison not implemented").arg(docContextName)), ReportResult_Finished);
 
-    MultipleSequenceAlignmentObject *msa1 = qobject_cast<MultipleSequenceAlignmentObject *>(objs1.first());
-    CHECK_EXT(nullptr != msa1, setError(QString("document '%1' contains an incorrect object: expected '%2', got '%3'").arg(docContextName).arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT).arg(objs1.first()->getGObjectType())), ReportResult_Finished);
+    auto msa1 = qobject_cast<MultipleSequenceAlignmentObject*>(objs1.first());
+    CHECK_EXT(msa1 != nullptr, setError(QString("document '%1' contains an incorrect object: expected '%2', got '%3'").arg(docContextName).arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT).arg(objs1.first()->getGObjectType())), ReportResult_Finished);
 
-    Document *doc2 = getContext<Document>(this, secondDocContextName);
-    CHECK_EXT(nullptr != doc2, setError(QString("document not found: %1").arg(secondDocContextName)), ReportResult_Finished);
+    Document* doc2 = getContext<Document>(this, secondDocContextName);
+    CHECK_EXT(doc2 != nullptr, setError(QString("document not found: %1").arg(secondDocContextName)), ReportResult_Finished);
 
-    const QList<GObject *> objs2 = doc2->getObjects();
+    const QList<GObject*> objs2 = doc2->getObjects();
     CHECK_EXT(1 == objs2.size(), setError(QString("document '%1' contains several objects: the comparison not implemented").arg(secondDocContextName)), ReportResult_Finished);
 
-    MultipleSequenceAlignmentObject *msa2 = qobject_cast<MultipleSequenceAlignmentObject *>(objs2.first());
-    CHECK_EXT(nullptr != msa2, setError(QString("document '%1' contains an incorrect object: expected '%2', got '%3'").arg(secondDocContextName).arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT).arg(objs2.first()->getGObjectType())), ReportResult_Finished);
+    auto msa2 = qobject_cast<MultipleSequenceAlignmentObject*>(objs2.first());
+    CHECK_EXT(msa2 != nullptr, setError(QString("document '%1' contains an incorrect object: expected '%2', got '%3'").arg(secondDocContextName).arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT).arg(objs2.first()->getGObjectType())), ReportResult_Finished);
 
-    const qint64 rowsNumber1 = msa1->getNumRows();
-    const qint64 rowsNumber2 = msa2->getNumRows();
+    const qint64 rowsNumber1 = msa1->getRowCount();
+    const qint64 rowsNumber2 = msa2->getRowCount();
     CHECK_EXT(rowsNumber1 == rowsNumber2,
               setError(QString("The rows numbers differ: the object '%1' from the document '%2' contains %3 rows, the object '%4' from the document '%5' contains %6 rows")
                            .arg(msa1->getGObjectName())
@@ -82,15 +82,15 @@ Task::ReportResult GTest_CompareTwoMsa::report() {
     for (int i = 0; i < rowsNumber1; i++) {
         const MultipleSequenceAlignmentRow row1 = msa1->getMsaRow(i);
         const MultipleSequenceAlignmentRow row2 = msa2->getMsaRow(i);
-        const bool areEqual = row1->isRowContentEqual(row2);
+        const bool areEqual = row1->isEqualCore(*row2);
         CHECK_EXT(areEqual, setError(QString("The rows with number %1 differ from each other").arg(i)), ReportResult_Finished);
     }
 
     return ReportResult_Finished;
 }
 
-QList<XMLTestFactory *> MsaObjectTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> MsaObjectTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_CompareTwoMsa::createFactory());
     return res;
 }
