@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -47,7 +47,7 @@ namespace U2 {
 #define EXPECTED "expected-values"
 
 //---------------------------------------------------------------------
-void GTest_PFMtoPWMConvertTest::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_PFMtoPWMConvertTest::init(XMLTestFormat*, const QDomElement& el) {
     objContextName = el.attribute(OBJ_ATTR);
     if (objContextName.isEmpty()) {
         failMissingValue(OBJ_ATTR);
@@ -59,7 +59,7 @@ Task::ReportResult GTest_PFMtoPWMConvertTest::report() {
     return ReportResult_Finished;
 }
 
-void GTest_PFMCreateTest::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_PFMCreateTest::init(XMLTestFormat*, const QDomElement& el) {
     objContextName = el.attribute(OBJ_ATTR);
     if (objContextName.isEmpty()) {
         failMissingValue(OBJ_ATTR);
@@ -142,18 +142,18 @@ void GTest_PFMCreateTest::init(XMLTestFormat *, const QDomElement &el) {
 
 Task::ReportResult GTest_PFMCreateTest::report() {
     if (objType == "alignment") {
-        Document *doc = getContext<Document>(this, objContextName);
+        Document* doc = getContext<Document>(this, objContextName);
         if (doc == nullptr) {
             stateInfo.setError(GTest::tr("context not found %1").arg(objContextName));
             return ReportResult_Finished;
         }
 
-        QList<GObject *> list = doc->findGObjectByType(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT);
+        QList<GObject*> list = doc->findGObjectByType(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT);
         if (list.size() == 0) {
             stateInfo.setError(GTest::tr("container of object with type \"%1\" is empty").arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT));
             return ReportResult_Finished;
         }
-        MultipleSequenceAlignmentObject *myAlign = qobject_cast<MultipleSequenceAlignmentObject *>(list.first());
+        auto myAlign = qobject_cast<MultipleSequenceAlignmentObject*>(list.first());
         const MultipleSequenceAlignment al = myAlign->getMultipleAlignment();
         PFMatrix pfm(al, type);
         for (int i = 0, n = (type == PFM_MONONUCLEOTIDE) ? 4 : 16; i < n; i++) {
@@ -165,20 +165,20 @@ Task::ReportResult GTest_PFMCreateTest::report() {
             }
         }
     } else if (objType == "sequences") {
-        Document *doc = getContext<Document>(this, objContextName);
+        Document* doc = getContext<Document>(this, objContextName);
         if (doc == nullptr) {
             stateInfo.setError(GTest::tr("context not found %1").arg(objContextName));
             return ReportResult_Finished;
         }
 
-        QList<GObject *> list = doc->findGObjectByType(GObjectTypes::SEQUENCE);
+        QList<GObject*> list = doc->findGObjectByType(GObjectTypes::SEQUENCE);
         if (list.size() == 0 || list.size() < size) {
             stateInfo.setError(GTest::tr("container of object with type \"%1\" is empty or less than %2").arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT).arg(size));
             return ReportResult_Finished;
         }
-        QList<DNASequence *> data;
+        QList<DNASequence*> data;
         for (int i = 0; i < size; i++) {
-            U2SequenceObject *seq = (U2SequenceObject *)list[i];
+            U2SequenceObject* seq = (U2SequenceObject*)list[i];
             if (seq->getSequenceLength() != length) {
                 stateInfo.setError(QString("wrong length of %1 sequence: %2").arg(i + 1).arg(seq->getSequenceLength()));
                 return ReportResult_Finished;
@@ -187,7 +187,7 @@ Task::ReportResult GTest_PFMCreateTest::report() {
                 stateInfo.setError(QString("Wrong sequence alphabet"));
                 return ReportResult_Finished;
             }
-            DNASequence *s = new DNASequence(QString("%1 sequence").arg(i + 1), seq->getWholeSequenceData(stateInfo), seq->getAlphabet());
+            DNASequence* s = new DNASequence(QString("%1 sequence").arg(i + 1), seq->getWholeSequenceData(stateInfo), seq->getAlphabet());
             CHECK_OP(stateInfo, ReportResult_Finished);
             data.push_back(s);
         }
@@ -208,7 +208,7 @@ Task::ReportResult GTest_PFMCreateTest::report() {
     return ReportResult_Finished;
 }
 
-void GTest_PWMCreateTest::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_PWMCreateTest::init(XMLTestFormat*, const QDomElement& el) {
     objContextName = el.attribute(OBJ_ATTR);
     if (objContextName.isEmpty()) {
         failMissingValue(OBJ_ATTR);
@@ -297,12 +297,12 @@ void GTest_PWMCreateTest::init(XMLTestFormat *, const QDomElement &el) {
 }
 
 Task::ReportResult GTest_PWMCreateTest::report() {
-    PWMConversionAlgorithmFactory *fact = AppContext::getPWMConversionAlgorithmRegistry()->getAlgorithmFactory(algo);
+    PWMConversionAlgorithmFactory* fact = AppContext::getPWMConversionAlgorithmRegistry()->getAlgorithmFactory(algo);
     if (fact == nullptr) {
         stateInfo.setError(GTest::tr("algorithm not found %1").arg(algo));
         return ReportResult_Finished;
     }
-    PWMConversionAlgorithm *algorithm = fact->createAlgorithm();
+    PWMConversionAlgorithm* algorithm = fact->createAlgorithm();
     if (algorithm == nullptr) {
         stateInfo.setError(GTest::tr("unable to create algorithm %1").arg(algo));
         return ReportResult_Finished;
@@ -310,38 +310,38 @@ Task::ReportResult GTest_PWMCreateTest::report() {
     PWMatrix pwm;
     PFMatrixType pftype = (type == PWM_MONONUCLEOTIDE) ? PFM_MONONUCLEOTIDE : PFM_DINUCLEOTIDE;
     if (objType == "alignment") {
-        Document *doc = getContext<Document>(this, objContextName);
+        Document* doc = getContext<Document>(this, objContextName);
         if (doc == nullptr) {
             stateInfo.setError(GTest::tr("context not found %1").arg(objContextName));
             return ReportResult_Finished;
         }
 
-        QList<GObject *> list = doc->findGObjectByType(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT);
+        QList<GObject*> list = doc->findGObjectByType(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT);
         if (list.size() == 0) {
             stateInfo.setError(GTest::tr("container of object with type \"%1\" is empty").arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT));
             return ReportResult_Finished;
         }
-        MultipleSequenceAlignmentObject *myAlign = (MultipleSequenceAlignmentObject *)list.first();
+        MultipleSequenceAlignmentObject* myAlign = (MultipleSequenceAlignmentObject*)list.first();
         const MultipleSequenceAlignment al = myAlign->getMultipleAlignment();
 
         PFMatrix pfm(al, pftype);
         pwm = algorithm->convert(pfm);
 
     } else if (objType == "sequences") {
-        Document *doc = getContext<Document>(this, objContextName);
+        Document* doc = getContext<Document>(this, objContextName);
         if (doc == nullptr) {
             stateInfo.setError(GTest::tr("context not found %1").arg(objContextName));
             return ReportResult_Finished;
         }
 
-        QList<GObject *> list = doc->findGObjectByType(GObjectTypes::SEQUENCE);
+        QList<GObject*> list = doc->findGObjectByType(GObjectTypes::SEQUENCE);
         if (list.size() == 0 || list.size() < size) {
             stateInfo.setError(GTest::tr("container of object with type \"%1\" is empty or less than %2").arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT).arg(size));
             return ReportResult_Finished;
         }
-        QList<DNASequence *> data;
+        QList<DNASequence*> data;
         for (int i = 0; i < size; i++) {
-            U2SequenceObject *seq = (U2SequenceObject *)list[i];
+            U2SequenceObject* seq = (U2SequenceObject*)list[i];
             if (seq->getSequenceLength() != length) {
                 stateInfo.setError(GTest::tr("wrong length of %1 sequence: %2").arg(i).arg(seq->getSequenceLength()));
                 return ReportResult_Finished;
@@ -350,7 +350,7 @@ Task::ReportResult GTest_PWMCreateTest::report() {
                 stateInfo.setError(GTest::tr("Wrong %1 sequence alphabet").arg(i));
                 return ReportResult_Finished;
             }
-            DNASequence *s = new DNASequence(QString("%1 sequence").arg(i), seq->getWholeSequenceData(stateInfo), seq->getAlphabet());
+            DNASequence* s = new DNASequence(QString("%1 sequence").arg(i), seq->getWholeSequenceData(stateInfo), seq->getAlphabet());
             CHECK_OP(stateInfo, ReportResult_Finished);
             data.push_back(s);
         }
@@ -375,8 +375,8 @@ Task::ReportResult GTest_PWMCreateTest::report() {
 }
 
 //---------------------------------------------------------------------
-QList<XMLTestFactory *> PWMatrixTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> PWMatrixTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_PFMtoPWMConvertTest::createFactory());
     res.append(GTest_PFMCreateTest::createFactory());
     res.append(GTest_PWMCreateTest::createFactory());
