@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,8 +21,9 @@
 
 #include "RealignSequencesInAlignmentTaskTest.h"
 
+#include <U2Algorithm/BaseAlignmentAlgorithmsIds.h>
+
 #include <U2Core/DocumentModel.h>
-#include <U2Core/GObjectTypes.h>
 #include <U2Core/MultipleSequenceAlignmentObject.h>
 
 #include <U2View/RealignSequencesInAlignmentTask.h>
@@ -31,11 +32,8 @@ namespace U2 {
 
 #define IN_OBJECT_NAME_ATTR "in"
 #define ROWS_LIST_ATTR "rows"
-#define FORCE_USE_UGENE_ALIGNER_ATTR "useUgeneAligner"
-
-void GTest_Realign::init(XMLTestFormat *, const QDomElement &el) {
-    forceUseUgeneAligner = false;
 
+void GTest_Realign::init(XMLTestFormat*, const QDomElement& el) {
     inputObjectName = el.attribute(IN_OBJECT_NAME_ATTR);
     if (inputObjectName.isEmpty()) {
         failMissingValue(IN_OBJECT_NAME_ATTR);
@@ -50,19 +48,14 @@ void GTest_Realign::init(XMLTestFormat *, const QDomElement &el) {
 
     QStringList rowsIndexesToAlignStringList = rows.split(",");
     bool conversionIsOk = false;
-    foreach (const QString &str, rowsIndexesToAlignStringList) {
-        qint64 rowIndex = str.toUInt(&conversionIsOk);
+    for (const QString& str : qAsConst(rowsIndexesToAlignStringList)) {
+        int rowIndex = str.toInt(&conversionIsOk);
         if (!conversionIsOk) {
             wrongValue(ROWS_LIST_ATTR);
             return;
         }
         rowsIndexesToAlign.append(rowIndex);
     }
-
-    QString forceUseUgeneAlignerStr = el.attribute(FORCE_USE_UGENE_ALIGNER_ATTR);
-    if (!forceUseUgeneAlignerStr.isEmpty() && forceUseUgeneAlignerStr == "true") {
-        forceUseUgeneAligner = true;
-    }
 }
 
 void GTest_Realign::prepare() {
@@ -72,28 +65,28 @@ void GTest_Realign::prepare() {
         return;
     }
 
-    QList<GObject *> list = doc->findGObjectByType(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT);
-    if (list.size() == 0) {
+    QList<GObject*> list = doc->findGObjectByType(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT);
+    if (list.isEmpty()) {
         stateInfo.setError(QString("container of object with type \"%1\" is empty").arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT));
         return;
     }
 
-    GObject *obj = list.first();
+    GObject* obj = list.first();
     if (obj == nullptr) {
         stateInfo.setError(QString("object with type \"%1\" not found").arg(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT));
         return;
     }
-    assert(obj != nullptr);
-    msaObj = qobject_cast<MultipleSequenceAlignmentObject *>(obj);
+    msaObj = qobject_cast<MultipleSequenceAlignmentObject*>(obj);
     if (msaObj == nullptr) {
         stateInfo.setError(QString("error can't cast to multiple alignment from GObject"));
         return;
     }
+    QList<qint64> rowIds = msaObj->getMultipleAlignment()->getRowsIds();
     QSet<qint64> rowIdsToRealign;
-    foreach (const qint64 index, rowsIndexesToAlign) {
-        rowIdsToRealign.insert(msaObj->getMultipleAlignment()->getRowsIds().at(index));
+    for (int index : qAsConst(rowsIndexesToAlign)) {
+        rowIdsToRealign.insert(rowIds.at(index));
     }
-    realignTask = new RealignSequencesInAlignmentTask(msaObj, rowIdsToRealign);
+    realignTask = new RealignSequencesInAlignmentTask(msaObj, rowIdsToRealign, BaseAlignmentAlgorithmsIds::ALIGN_SEQUENCES_TO_ALIGNMENT_BY_MAFFT);
     addSubTask(realignTask);
 }
 
@@ -111,8 +104,8 @@ void GTest_Realign::cleanup() {
     XmlTest::cleanup();
 }
 
-QList<XMLTestFactory *> RealignTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> RealignTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_Realign::createFactory());
     return res;
 }
