@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCEWALKER_TESTS_H_
-#define _U2_SEQUENCEWALKER_TESTS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -38,7 +37,7 @@ public:
 
     ReportResult report();
 
-    void onRegion(SequenceWalkerSubtask *, TaskStateInfo &) {
+    void onRegion(SequenceWalkerSubtask*, TaskStateInfo&) {
     }
 
 private:
@@ -54,7 +53,6 @@ protected:
 
 class SequenceWalkerTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 }  // namespace U2
-#endif
