@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,6 +24,8 @@
 #include <QThread>
 
 #include <U2Core/AppContext.h>
+#include <U2Core/AppResources.h>
+#include <U2Core/AppSettings.h>
 #include <U2Core/Task.h>
 
 namespace U2 {
@@ -57,7 +59,7 @@ public:
     }
 };
 
-static TaskFlags flagsFromString(QString str, bool *ok = nullptr) {
+static TaskFlags flagsFromString(QString str, bool* ok = nullptr) {
     TaskFlags taskFlags = TaskFlags(TaskFlag_None);
     if (ok != nullptr)
         *ok = false;
@@ -86,7 +88,7 @@ static TaskFlags flagsFromString(QString str, bool *ok = nullptr) {
     return taskFlags;
 }
 
-static Task::State stateFromString(QString str, bool *ok = nullptr) {
+static Task::State stateFromString(QString str, bool* ok = nullptr) {
     Task::State taskState = Task::State_New;
     if (ok != nullptr)
         *ok = false;
@@ -129,7 +131,7 @@ DestructorCleanupTask::~DestructorCleanupTask() {
     cleanup();
 }
 
-StateOrderTestTask::StateOrderTestTask(StateOrderTestTaskCallback *ptr, TaskFlags _f)
+StateOrderTestTask::StateOrderTestTask(StateOrderTestTaskCallback* ptr, TaskFlags _f)
     : Task("calback_test_task", _f) {
     callback = ptr;
     step = 0;
@@ -149,7 +151,7 @@ StateOrderTestTask::~StateOrderTestTask() {
     callback->func(this, StateOrder_Done);
 }
 
-void GTest_TaskCreateTest::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_TaskCreateTest::init(XMLTestFormat*, const QDomElement& el) {
     deleteTask = false;
 
     resultContextName = el.attribute(INDEX_ATTR);
@@ -216,7 +218,7 @@ void GTest_TaskCreateTest::cleanup() {
     XmlTest::cleanup();
 }
 
-void GTest_TaskAddSubtaskTest::init(U2::XMLTestFormat *, const QDomElement &el) {
+void GTest_TaskAddSubtaskTest::init(U2::XMLTestFormat*, const QDomElement& el) {
     taskContextName = el.attribute(OBJ_ATTR);
     if (taskContextName.isEmpty()) {
         failMissingValue(OBJ_ATTR);
@@ -230,13 +232,13 @@ void GTest_TaskAddSubtaskTest::init(U2::XMLTestFormat *, const QDomElement &el)
 }
 
 Task::ReportResult GTest_TaskAddSubtaskTest::report() {
-    Task *task = getContext<Task>(this, taskContextName);
+    Task* task = getContext<Task>(this, taskContextName);
     if (task == nullptr) {
         stateInfo.setError(QString("invalid context: %1").arg(taskContextName));
         return ReportResult_Finished;
     }
 
-    Task *subtask = getContext<Task>(this, subtaskContextName);
+    Task* subtask = getContext<Task>(this, subtaskContextName);
     if (subtask == nullptr) {
         stateInfo.setError(QString("invalid context: %1").arg(subtaskContextName));
         return ReportResult_Finished;
@@ -255,7 +257,7 @@ Task::ReportResult GTest_TaskAddSubtaskTest::report() {
     return ReportResult_Finished;
 }
 
-void GTest_TaskCancelTest::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_TaskCancelTest::init(XMLTestFormat*, const QDomElement& el) {
     objContextName = el.attribute(OBJ_ATTR);
     if (objContextName.isEmpty()) {
         failMissingValue(OBJ_ATTR);
@@ -264,13 +266,13 @@ void GTest_TaskCancelTest::init(XMLTestFormat *, const QDomElement &el) {
 }
 
 Task::ReportResult GTest_TaskCancelTest::report() {
-    QObject *obj = getContext(objContextName);
+    QObject* obj = getContext(objContextName);
     if (obj == nullptr) {
         stateInfo.setError(QString("invalid object context"));
         return ReportResult_Finished;
     }
     assert(obj != nullptr);
-    Task *task = qobject_cast<Task *>(obj);
+    auto task = qobject_cast<Task*>(obj);
     task->cancel();
     if (!task->getStateInfo().cancelFlag) {
         stateInfo.setError(QString("task state flag not matched: %1, expected %2 ").arg(task->getStateInfo().cancelFlag).arg(true));
@@ -279,7 +281,7 @@ Task::ReportResult GTest_TaskCancelTest::report() {
     return ReportResult_Finished;
 }
 
-void GTest_TaskCheckFlag::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_TaskCheckFlag::init(XMLTestFormat*, const QDomElement& el) {
     taskContextName = el.attribute(OBJ_ATTR);
     if (taskContextName.isEmpty()) {
         failMissingValue(OBJ_ATTR);
@@ -299,13 +301,13 @@ void GTest_TaskCheckFlag::init(XMLTestFormat *, const QDomElement &el) {
 }
 
 Task::ReportResult GTest_TaskCheckFlag::report() {
-    QObject *obj = getContext(taskContextName);
+    QObject* obj = getContext(taskContextName);
     if (obj == nullptr) {
         stateInfo.setError(QString("invalid object context"));
         return ReportResult_Finished;
     }
     assert(obj != nullptr);
-    Task *task = qobject_cast<Task *>(obj);
+    auto task = qobject_cast<Task*>(obj);
     if (task->getFlags().operator&(flag) == 0) {
         stateInfo.setError(QString("task flags not matched %1, expected %2").arg(task->getFlags()).arg(flag));
         return ReportResult_Finished;
@@ -313,12 +315,10 @@ Task::ReportResult GTest_TaskCheckFlag::report() {
     return ReportResult_Finished;
 }
 
-void GTest_TaskCheckState::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_TaskCheckState::init(XMLTestFormat*, const QDomElement& el) {
     checkState = false;
     checkProgress = false;
     checkCancelFlag = false;
-    checkError = false;
-    checkStateDesc = false;
 
     taskContextName = el.attribute(OBJ_ATTR);
     if (taskContextName.isEmpty()) {
@@ -360,7 +360,7 @@ void GTest_TaskCheckState::init(XMLTestFormat *, const QDomElement &el) {
 }
 
 Task::ReportResult GTest_TaskCheckState::report() {
-    Task *task = getContext<Task>(this, taskContextName);
+    Task* task = getContext<Task>(this, taskContextName);
     if (task == nullptr) {
         stateInfo.setError(QString("invalid context %1").arg(taskContextName));
         return ReportResult_Finished;
@@ -386,7 +386,7 @@ Task::ReportResult GTest_TaskCheckState::report() {
     return ReportResult_Finished;
 }
 
-void GTest_TaskExec::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_TaskExec::init(XMLTestFormat*, const QDomElement& el) {
     taskContextName = el.attribute(OBJ_ATTR);
     if (taskContextName.isEmpty()) {
         failMissingValue(OBJ_ATTR);
@@ -395,7 +395,7 @@ void GTest_TaskExec::init(XMLTestFormat *, const QDomElement &el) {
 }
 
 void GTest_TaskExec::prepare() {
-    Task *task = getContext<Task>(this, taskContextName);
+    Task* task = getContext<Task>(this, taskContextName);
     if (task == nullptr) {
         stateInfo.setError(QString("invalid context %1").arg(taskContextName));
         return;
@@ -407,7 +407,7 @@ Task::ReportResult GTest_TaskExec::report() {
     return ReportResult_Finished;
 }
 
-void GTest_TaskStateOrder::init(XMLTestFormat *, const QDomElement &el) {
+void GTest_TaskStateOrder::init(XMLTestFormat*, const QDomElement& el) {
     serial_flag = true;
     subtask_num = 0;
     cancel_flag = false;
@@ -456,7 +456,7 @@ void GTest_TaskStateOrder::init(XMLTestFormat *, const QDomElement &el) {
     task = new StateOrderTestTask(this, (run_after_all_subs_flag ? TaskFlag_None : TaskFlag_RunBeforeSubtasksFinished));
 
     for (int i = 0; i < subtask_num; i++) {
-        StateOrderTestTask *sub = new StateOrderTestTask(this, TaskFlag_None);
+        auto* sub = new StateOrderTestTask(this, TaskFlag_None);
         subs.append(sub);
         task->addSubTask(sub);
     }
@@ -469,7 +469,7 @@ void GTest_TaskStateOrder::run() {
     }
 }
 
-void GTest_TaskStateOrder::func(StateOrderTestTask *_task, StateOrderType st) {
+void GTest_TaskStateOrder::func(StateOrderTestTask* _task, StateOrderType st) {
     int ind = -1;
     if (task == _task) {
         if (st == StateOrder_Done) {
@@ -487,7 +487,7 @@ void GTest_TaskStateOrder::func(StateOrderTestTask *_task, StateOrderType st) {
             return;
         }
     }
-    int &step = _task->step;
+    int& step = _task->step;
     State newState = _task->getState();
 
     if (step == 0) {
@@ -513,8 +513,10 @@ void GTest_TaskStateOrder::func(StateOrderTestTask *_task, StateOrderType st) {
         if (task == _task) {
             if (run_after_all_subs_flag) {
                 for (int i = 0; i < subs.count(); i++) {
-                    if (!subs[i]->isFinished()) {
-                        stateInfo.setError(QString("task promoting error: run after all subtasks finished"));
+                    StateOrderTestTask* sub = subs[i];
+                    bool isSubProcessingFinished = sub->isFinished() || (sub->isNew() && sub->isCanceled());
+                    if (!isSubProcessingFinished) {
+                        stateInfo.setError(QString("task promoting error: run after all subtasks processed"));
                         return;
                     }
                 }
@@ -542,7 +544,7 @@ Task::ReportResult GTest_TaskStateOrder::report() {
     return ReportResult_Finished;
 }
 
-void GTest_Wait::init(U2::XMLTestFormat *, const QDomElement &el) {
+void GTest_Wait::init(U2::XMLTestFormat*, const QDomElement& el) {
     waitOk = false;
     condition = WaitCond_None;
     QString ms_str = el.attribute(DELAY_ATTR);
@@ -584,7 +586,7 @@ void GTest_Wait::init(U2::XMLTestFormat *, const QDomElement &el) {
 
 void GTest_Wait::prepare() {
     if (!objContextName.isEmpty()) {
-        Task *task = getContext<Task>(this, objContextName);
+        Task* task = getContext<Task>(this, objContextName);
         if (task == nullptr) {
             stateInfo.setError(QString("invalid context %1").arg(objContextName));
             return;
@@ -594,7 +596,7 @@ void GTest_Wait::prepare() {
 }
 
 void GTest_Wait::sl_WaitCond_StateChanged() {
-    Task *task = getContext<Task>(this, objContextName);
+    Task* task = getContext<Task>(this, objContextName);
     if (task == nullptr) {
         stateInfo.setError(QString("invalid context %1").arg(objContextName));
         return;
@@ -607,7 +609,7 @@ void GTest_Wait::sl_WaitCond_StateChanged() {
 
 void GTest_Wait::run() {
     if (!objContextName.isEmpty()) {
-        Task *task = getContext<Task>(this, objContextName);
+        Task* task = getContext<Task>(this, objContextName);
         if (task == nullptr) {
             stateInfo.setError(QString("invalid context %1").arg(objContextName));
             return;
@@ -636,8 +638,82 @@ Task::ReportResult GTest_Wait::report() {
     return ReportResult_Finished;
 }
 
-QList<XMLTestFactory *> TaskTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+/// Check dynamic resources
+struct ResourceCheckerTaskSettings {
+    QString resourceId;
+    TaskResourceStage stage = TaskResourceStage::Prepare;
+};
+
+class ResourceCheckerTask : public Task {
+public:
+    ResourceCheckerTask(const ResourceCheckerTaskSettings& _settings)
+        : Task("ResourceCheckerTask", TaskFlag_RunInMainThread), settings(_settings) {
+        resourcePool = AppContext::getAppSettings()->getAppResourcePool();
+    }
+
+    void prepare() override {
+        auto resource = resourcePool->getResource(settings.resourceId);
+        if (settings.stage == TaskResourceStage::Prepare) {
+            if (resource == nullptr) {
+                setError("prepare: resource is not registered");
+            } else if (resource->available() > 0) {
+                setError("prepare: resource has free capacity");
+            }
+        } else if (resource != nullptr) {
+            setError("prepare: resource must not be registered");
+        }
+    }
+
+    void run() override {
+        CHECK(!hasError(), );
+        auto resource = resourcePool->getResource(settings.resourceId);
+        if (resource == nullptr) {
+            setError("run: resource is not registered");
+        } else if (resource->available() > 0) {
+            setError("run: resource has free capacity");
+        }
+    }
+
+    ReportResult report() override {
+        CHECK(!hasError(), ReportResult_Finished);
+        auto resource = resourcePool->getResource(settings.resourceId);
+        if (settings.stage == TaskResourceStage::Prepare) {
+            if (resource == nullptr) {
+                setError("report: resource is not registered");
+            } else if (resource->available() > 0) {
+                setError("report: resource has free capacity");
+            }
+        } else if (resource != nullptr) {
+            setError("report: resource must not be registered");
+        }
+        return ReportResult_Finished;
+    }
+
+    AppResourcePool* resourcePool = nullptr;
+    ResourceCheckerTaskSettings settings;
+};
+
+void GTest_TaskCheckDynamicResources::init(U2::XMLTestFormat*, const QDomElement& el) {
+    QString lockStageAttr = "lock_stage";
+    QString stage = el.attribute(lockStageAttr);
+    if (stage.isEmpty()) {
+        failMissingValue(lockStageAttr);
+        return;
+    }
+    if (stage != "prepare" && stage != "run") {
+        wrongValue(lockStageAttr);
+        return;
+    }
+    ResourceCheckerTaskSettings settings;
+    settings.resourceId = AppResource::buildDynamicResourceId("GTest_TaskCheckDynamicResources");
+    settings.stage = stage == "prepare" ? TaskResourceStage::Prepare : TaskResourceStage::Run;
+    auto task = new ResourceCheckerTask(settings);
+    task->addTaskResource(TaskResourceUsage(settings.resourceId, 1, settings.stage));
+    addSubTask(task);
+}
+
+QList<XMLTestFactory*> TaskTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_TaskStateOrder::createFactory());
     res.append(GTest_TaskCreateTest::createFactory());
     res.append(GTest_TaskAddSubtaskTest::createFactory());
@@ -646,6 +722,7 @@ QList<XMLTestFactory *> TaskTests::createTestFactories() {
     res.append(GTest_TaskCheckFlag::createFactory());
     res.append(GTest_TaskExec::createFactory());
     res.append(GTest_Wait::createFactory());
+    res.append(GTest_TaskCheckDynamicResources::createFactory());
     return res;
 }
 
