@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_TASK_TESTS_H_
-#define _U2_TASK_TESTS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -56,23 +55,22 @@ enum StateOrderType {
 
 class StateOrderTestTaskCallback {
 public:
-    virtual void func(StateOrderTestTask *t, StateOrderType st) = 0;
-    virtual ~StateOrderTestTaskCallback() {
-    }
+    virtual void func(StateOrderTestTask* t, StateOrderType st) = 0;
+    virtual ~StateOrderTestTaskCallback() = default;
 };
 
 class StateOrderTestTask : public Task {
     Q_OBJECT
 public:
-    StateOrderTestTask(StateOrderTestTaskCallback *ptr, TaskFlags _f);
+    StateOrderTestTask(StateOrderTestTaskCallback* ptr, TaskFlags _f);
     ~StateOrderTestTask();
-    void prepare();
-    void run();
-    Task::ReportResult report();
+    void prepare() override;
+    void run() override;
+    Task::ReportResult report() override;
     int step;
 
 private:
-    StateOrderTestTaskCallback *callback;
+    StateOrderTestTaskCallback* callback;
 };
 
 class GTest_TaskCreateTest : public XmlTest {
@@ -80,11 +78,11 @@ class GTest_TaskCreateTest : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_TaskCreateTest, "task-create");
 
-    ReportResult report();
-    void cleanup();
+    ReportResult report() override;
+    void cleanup() override;
 
 private:
-    Task *task;
+    Task* task;
     bool deleteTask;
     QString resultContextName;
 };
@@ -94,7 +92,7 @@ class GTest_TaskAddSubtaskTest : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_TaskAddSubtaskTest, "task-add-subtask");
 
-    ReportResult report();
+    ReportResult report() override;
 
 private:
     QString taskContextName;
@@ -106,7 +104,7 @@ class GTest_TaskCancelTest : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_TaskCancelTest, "task-cancel");
 
-    ReportResult report();
+    ReportResult report() override;
 
 private:
     QString objContextName;
@@ -117,7 +115,7 @@ class GTest_TaskCheckFlag : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_TaskCheckFlag, "task-check-flag");
 
-    ReportResult report();
+    ReportResult report() override;
 
 private:
     TaskFlags flag;
@@ -129,15 +127,13 @@ class GTest_TaskCheckState : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_TaskCheckState, "task-check-state");
 
-    ReportResult report();
+    ReportResult report() override;
 
 private:
     bool checkState;
     State taskState;
     bool checkProgress;
     bool checkCancelFlag;
-    bool checkError;
-    bool checkStateDesc;
     TaskStateInfo taskStateInfo;
     QString taskContextName;
 };
@@ -147,8 +143,8 @@ class GTest_TaskExec : public XmlTest {
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_TaskExec, "task-exec");
 
-    void prepare();
-    ReportResult report();
+    void prepare() override;
+    ReportResult report() override;
 
 private:
     QString taskContextName;
@@ -158,14 +154,14 @@ class GTest_TaskStateOrder : public XmlTest, public StateOrderTestTaskCallback {
     Q_OBJECT
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY_EXT(GTest_TaskStateOrder, "task-state-order-test", TaskFlags_FOSCOE);
-    void func(StateOrderTestTask *t, StateOrderType st);
-    Task::ReportResult report();
-    void run();
+    void func(StateOrderTestTask* t, StateOrderType st) override;
+    Task::ReportResult report() override;
+    void run() override;
 
 private:
     bool done_flag;
-    StateOrderTestTask *task;
-    QList<StateOrderTestTask *> subs;
+    StateOrderTestTask* task;
+    QList<StateOrderTestTask*> subs;
     int subtask_num;
     bool serial_flag;
     bool cancel_flag;
@@ -176,9 +172,9 @@ class GTest_Wait : public XmlTest {
     Q_OBJECT
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY_EXT(GTest_Wait, "wait", TaskFlags(TaskFlags_FOSCOE));
-    Task::ReportResult report();
-    void prepare();
-    void run();
+    Task::ReportResult report() override;
+    void prepare() override;
+    void run() override;
 public slots:
     void sl_WaitCond_StateChanged();
 
@@ -194,10 +190,15 @@ private:
     QString waitStateString;
 };
 
+class GTest_TaskCheckDynamicResources : public XmlTest {
+    Q_OBJECT
+public:
+    SIMPLE_XML_TEST_BODY_WITH_FACTORY_EXT(GTest_TaskCheckDynamicResources, "task-check-dynamic-resources", TaskFlags(TaskFlags_NR_FOSCOE));
+};
+
 class TaskTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-#endif
