@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_UTIL_TEST_ACTIONS_H_
-#define _U2_UTIL_TEST_ACTIONS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -36,7 +35,7 @@ public:
     ReportResult report();
 
 private:
-    bool copyDirectry(const QString &from, const QString &to);
+    bool copyDirectry(const QString& from, const QString& to);
 
     QString fromUrl;
     QString toUrl;
@@ -71,9 +70,7 @@ private:
 
 class UtilTestActions {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-
-#endif  // _U2_UTIL_TEST_ACTIONS_H_
