@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUI_DATABASE_CONFIG_H_
-#define _U2_GUI_DATABASE_CONFIG_H_
+#pragma once
 
 #include <QString>
 
@@ -38,9 +37,7 @@ public:
     static QString readOnlyLogin();
     static QString password();
 
-    static void initTestConnectionInfo(const QString &name, const QString &db = database(), bool withCredentials = true, bool readOnly = false);
+    static void initTestConnectionInfo(const QString& name, const QString& db = database(), bool withCredentials = true, bool readOnly = false);
 };
 
 }  // namespace U2
-
-#endif  // _U2_GUI_DATABASE_CONFIG_H_
