@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUI_ANNOTATIONS_HIGHLIGHTING_TREE_VIEW_UTILS_H_
-#define _U2_GUI_ANNOTATIONS_HIGHLIGHTING_TREE_VIEW_UTILS_H_
+#pragma once
 
 #include "GTGlobals.h"
 
@@ -31,21 +30,19 @@ namespace U2 {
 using namespace HI;
 class GTUtilsAnnotHighlightingTreeView {
 public:
-    static QTreeWidget *getTreeWidget(HI::GUITestOpStatus &os);
+    static QTreeWidget* getTreeWidget();
 
     // returns center or item's rect
     // fails if the item wasn't found
-    static QPoint getItemCenter(HI::GUITestOpStatus &os, const QString &itemName);
-    static void click(HI::GUITestOpStatus &os, const QString &itemName);
+    static QPoint getItemCenter(const QString& itemName);
+    static void click(const QString& itemName);
 
-    static QTreeWidgetItem *findItem(HI::GUITestOpStatus &os, const QString &itemName, const GTGlobals::FindOptions & = GTGlobals::FindOptions());
-    static QString getSelectedItem(HI::GUITestOpStatus &os);
+    static QTreeWidgetItem* findItem(const QString& itemName, const GTGlobals::FindOptions& = GTGlobals::FindOptions());
+    static QString getSelectedItem();
 
-    static QColor getItemColor(HI::GUITestOpStatus &os, const QString &itemName);
+    static QColor getItemColor(const QString& itemName);
 
     static const QString widgetName;
 };
 
 }  // namespace U2
-
-#endif
