@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUI_BOOKMARKS_TREE_VIEW_UTILS_H_
-#define _U2_GUI_BOOKMARKS_TREE_VIEW_UTILS_H_
+#pragma once
 
 #include <GTGlobals.h>
 
@@ -32,24 +31,25 @@ using namespace HI;
 
 class GTUtilsBookmarksTreeView {
 public:
-    static QTreeWidget *getTreeWidget(HI::GUITestOpStatus &os);
+    static QTreeWidget* getTreeWidget();
 
     // returns center or item's rect
     // fails if the item wasn't found
-    static QPoint getItemCenter(GUITestOpStatus &os, const QString &itemName);
+    static QPoint getItemCenter(const QString& itemName);
 
-    static QTreeWidgetItem *findItem(GUITestOpStatus &os, const QString &itemName, const GTGlobals::FindOptions & = GTGlobals::FindOptions());
-    static QString getSelectedItem(GUITestOpStatus &os);
+    static QTreeWidgetItem* findItem(const QString& itemName, const GTGlobals::FindOptions& = GTGlobals::FindOptions());
+    static QString getSelectedItem();
 
-    static void addBookmark(GUITestOpStatus &os, const QString &viewName, const QString &bookmarkName = QString());
-    static void deleteBookmark(GUITestOpStatus &os, const QString &bookmarkName);
+    static void addBookmark(const QString& viewName, const QString& bookmarkName = QString());
 
-    static void clickBookmark(GUITestOpStatus &os, const QString &bookmarkName);
-    static void doubleClickBookmark(GUITestOpStatus &os, const QString &bookmarkName);
+    // updates bookmark state
+    static void updateBookmark(const QString& bookmarkName);
+    static void deleteBookmark(const QString& bookmarkName);
+
+    static void clickBookmark(const QString& bookmarkName);
+    static void doubleClickBookmark(const QString& bookmarkName);
 
     static const QString widgetName;
 };
 
 }  // namespace U2
-
-#endif
