@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,8 +26,8 @@
 
 namespace U2 {
 
-GTUtilsEscClicker::GTUtilsEscClicker(HI::GUITestOpStatus &_os, const QString &menuObjectName, bool _mouse)
-    : Filler(_os, GUIDialogWaiter::WaitSettings(menuObjectName, GUIDialogWaiter::Popup)),
+GTUtilsEscClicker::GTUtilsEscClicker(const QString& menuObjectName, bool _mouse)
+    : Filler(GUIDialogWaiter::WaitSettings(menuObjectName, GUIDialogWaiter::DialogType::Popup)),
       mouse(_mouse) {
 }
 
