@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,8 +20,7 @@ k
  * MA 02110-1301, USA.
  */
 
-#ifndef GTUTILS_ESC_CLICKER_H_
-#define GTUTILS_ESC_CLICKER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -30,7 +29,7 @@ using namespace HI;
 
 class GTUtilsEscClicker : public Filler {
 public:
-    GTUtilsEscClicker(HI::GUITestOpStatus &_os, const QString &menuObjectName, bool _mouse = false);
+    GTUtilsEscClicker(const QString& menuObjectName, bool _mouse = false);
     void commonScenario();
 
 private:
@@ -38,5 +37,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // GTUTILS_ESC_CLICKER_H_
