@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,25 +28,22 @@
 #include <U2View/BaseWidthController.h>
 #include <U2View/McaEditorReferenceArea.h>
 #include <U2View/McaEditorSequenceArea.h>
-#include <U2View/McaEditorWgt.h>
 #include <U2View/ScrollController.h>
 
 #include "GTUtilsMcaEditor.h"
 #include "GTUtilsMcaEditorReference.h"
-#include "GTUtilsMcaEditorSequenceArea.h"
 
 using namespace HI;
 namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsMcaEditorReference"
 
-#define GT_METHOD_NAME "clickToPosition"
-void GTUtilsMcaEditorReference::clickToPosition(HI::GUITestOpStatus &os, int position) {
-    McaEditorReferenceArea *referenceArea = GTUtilsMcaEditor::getReferenceArea(os);
-    McaEditorWgt *mcaEditorWgt = GTUtilsMcaEditor::getEditorUi(os);
+void GTUtilsMcaEditorReference::clickToPosition(int position) {
+    McaEditorReferenceArea* referenceArea = GTUtilsMcaEditor::getReferenceArea();
+    McaEditorWgt* mcaEditorWgt = GTUtilsMcaEditor::getEditorUi();
     GT_CHECK(mcaEditorWgt->getSequenceArea()->isInRange(QPoint(position, 0)), QString("Position %1 is out of range").arg(position));
 
-    scrollToPosition(os, position);
+    scrollToPosition(position);
 
     const QPoint positionCenter(mcaEditorWgt->getBaseWidthController()->getBaseScreenCenter(position),
                                 referenceArea->height() / 2);
@@ -55,18 +52,14 @@ void GTUtilsMcaEditorReference::clickToPosition(HI::GUITestOpStatus &os, int pos
     GTMouseDriver::moveTo(referenceArea->mapToGlobal(positionCenter));
     GTMouseDriver::click();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "scrollToPosition"
-void GTUtilsMcaEditorReference::scrollToPosition(HI::GUITestOpStatus &os, int position) {
-    const int scrollBarValue = GTUtilsMcaEditor::getEditorUi(os)->getBaseWidthController()->getBaseGlobalRange(position).center() -
-                               GTUtilsMcaEditor::getEditorUi(os)->getSequenceArea()->width() / 2;
-    CHECK(!GTUtilsMcaEditor::getReferenceArea(os)->getVisibleRange().contains(position), );
-    GTScrollBar::moveSliderWithMouseToValue(os,
-                                            GTUtilsMcaEditor::getHorizontalScrollBar(os),
+void GTUtilsMcaEditorReference::scrollToPosition(int position) {
+    const int scrollBarValue = GTUtilsMcaEditor::getEditorUi()->getBaseWidthController()->getBaseGlobalRange(position).center() -
+                               GTUtilsMcaEditor::getEditorUi()->getSequenceArea()->width() / 2;
+    CHECK(!GTUtilsMcaEditor::getReferenceArea()->getVisibleRange().contains(position), );
+    GTScrollBar::moveSliderWithMouseToValue(GTUtilsMcaEditor::getHorizontalScrollBar(),
                                             scrollBarValue);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
