@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_UTILS_NOTIFICATIONS_H_
-#define _U2_GT_UTILS_NOTIFICATIONS_H_
+#pragma once
 
 #include "GTGlobals.h"
 #include "utils/GTUtilsDialog.h"
@@ -31,19 +30,18 @@ using namespace HI;
 class NotificationChecker : public QObject {
     Q_OBJECT
 public:
-    NotificationChecker(HI::GUITestOpStatus &_os);
+    NotificationChecker();
 
 public slots:
     void sl_checkNotification();
 
 private:
-    QTimer *t;
-    HI::GUITestOpStatus &os;
+    QTimer* t;
 };
 
 class NotificationDialogFiller : public Filler {
 public:
-    NotificationDialogFiller(HI::GUITestOpStatus &os, const QString &message = "");
+    NotificationDialogFiller(const QString& message = "");
 
     void commonScenario();
 
@@ -53,25 +51,29 @@ private:
 
 class GTUtilsNotifications {
 public:
-    static void waitForNotification(HI::GUITestOpStatus &os, bool dialogExpected = true, const QString &message = "");
+    static void waitForNotification(bool dialogExpected = true, const QString& message = "");
 
     /** Waits for notification, clicks it and checks that the notification report contains the required text tokens. */
-    static void checkNotificationReportText(HI::GUITestOpStatus &os, const QString &textToken);
-    static void checkNotificationReportText(HI::GUITestOpStatus &os, const QStringList &textTokenList);
+    static void checkNotificationReportText(const QString& textToken);
+    static void checkNotificationReportText(const QStringList& textTokenList);
 
     /** Waits for notification, clicks it and checks that the modal dialog has the required text. */
-    static void checkNotificationDialogText(HI::GUITestOpStatus &os, const QString &textToken);
+    static void checkNotificationDialogText(const QString& textToken);
 
     /** Clicks on the active (first) notification widget. */
-    static void clickOnNotificationWidget(HI::GUITestOpStatus &os);
+    static void clickOnNotificationWidget();
 
     /** Waits until all notification popups are closed. */
-    static void waitAllNotificationsClosed(HI::GUITestOpStatus &os);
+    static void waitAllNotificationsClosed();
 
     /** Checks that there are no notification balloons on the screen. */
-    static void checkNoVisibleNotifications(HI::GUITestOpStatus &os);
+    static void checkNoVisibleNotifications();
+
+    /** Returns text shown on the notification container button in the status bar. */
+    static QString getNotificationCounterValue();
+
+    /** Opens notification container widget and returns it. */
+    static QWidget* openNotificationContainerWidget();
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_UTILS_NOTIFICATIONS_H_
