@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -39,12 +39,11 @@ using namespace HI;
 
 #define GT_CLASS_NAME "GTUtilsOptionsPanel"
 
-#define GT_METHOD_NAME "runFindPatternWithHotKey"
-void GTUtilsOptionsPanel::runFindPatternWithHotKey(const QString &pattern, HI::GUITestOpStatus &os) {
+void GTUtilsOptionsPanel::runFindPatternWithHotKey(const QString& pattern) {
     GTKeyboardDriver::keyClick('f', Qt::ControlModifier);
     GTGlobals::sleep();
 
-    QWidget *w = QApplication::focusWidget();
+    QWidget* w = QApplication::focusWidget();
     GT_CHECK(w && w->objectName() == "textPattern", "Focus is not on FindPattern widget");
 
     GTKeyboardDriver::keySequence(pattern);
@@ -52,28 +51,22 @@ void GTUtilsOptionsPanel::runFindPatternWithHotKey(const QString &pattern, HI::G
     GTKeyboardDriver::keyClick(Qt::Key_Enter);
     GTThread::waitForMainThread();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "resizeToMaximum"
-void GTUtilsOptionsPanel::resizeToMaximum(GUITestOpStatus &os) {
-    QSplitter *optionsPanelSplitter = GTWidget::findExactWidget<QSplitter *>(os, "OPTIONS_PANEL_SPLITTER");
-    GT_CHECK(nullptr != optionsPanelSplitter, "Options panel splitter is nullptr");
-    QSplitterHandle *handle = optionsPanelSplitter->handle(1);
-    GT_CHECK(nullptr != handle, "Options panel splitter handle is nullptr");
+void GTUtilsOptionsPanel::resizeToMaximum() {
+    auto optionsPanelSplitter = GTWidget::findSplitter("OPTIONS_PANEL_SPLITTER");
+    QSplitterHandle* handle = optionsPanelSplitter->handle(1);
+    GT_CHECK(handle != nullptr, "Options panel splitter handle is nullptr");
 
     const QPoint handleCenter = optionsPanelSplitter->mapToGlobal(handle->geometry().center());
     const int delta = 500;
     GTMouseDriver::dragAndDrop(handleCenter, handleCenter - QPoint(delta, 0));
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "getActiveOptionsWidget"
-QWidget *GTUtilsOptionsPanel::getActiveOptionsWidget(GUITestOpStatus &os) {
-    QWidget *contentWidget = GTWidget::findWidget(os, "object_view_window_content_widget");
-    auto optionsPanelWidget = GTWidget::findWidgetByType<OptionsPanelWidget *>(os, contentWidget, "OptionsPanelWidget is not found!");
+QWidget* GTUtilsOptionsPanel::getActiveOptionsWidget() {
+    auto contentWidget = GTWidget::findWidget("object_view_window_content_widget");
+    auto optionsPanelWidget = GTWidget::findWidgetByType<OptionsPanelWidget*>(contentWidget, "OptionsPanelWidget is not found!");
     return optionsPanelWidget->getOptionsWidget();
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
