@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUI_OPTIONS_PANEL_UTILS_H_
-#define _U2_GUI_OPTIONS_PANEL_UTILS_H_
+#pragma once
 
 #include "GTGlobals.h"
 
@@ -28,14 +27,12 @@ namespace U2 {
 
 class GTUtilsOptionsPanel {
 public:
-    static void runFindPatternWithHotKey(const QString &pattern, HI::GUITestOpStatus &os);
+    static void runFindPatternWithHotKey(const QString& pattern);
 
-    static void resizeToMaximum(HI::GUITestOpStatus &os);
+    static void resizeToMaximum();
 
     /** Returns active opened options panel widget. Fails if there is no opened options panel. */
-    static QWidget *getActiveOptionsWidget(HI::GUITestOpStatus &os);
+    static QWidget* getActiveOptionsWidget();
 };
 
 }  // namespace U2
-
-#endif  //_U2_GUI_OPTIONS_PANEL_UTILS_H_
