@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _GTUTILS_PRIMER_LIBRARY_H_
-#define _GTUTILS_PRIMER_LIBRARY_H_
+#pragma once
 
 #include <GTGlobals.h>
 
@@ -38,24 +37,23 @@ public:
                   Remove,
                   Import,
                   Export,
-                  Close };
-    static QWidget *openLibrary(HI::GUITestOpStatus &os);
-    static void clickButton(HI::GUITestOpStatus &os, Button button);
-    static QAbstractButton *getButton(HI::GUITestOpStatus &os, Button button);
-    static int librarySize(HI::GUITestOpStatus &os);
-    static QString getPrimerSequence(HI::GUITestOpStatus &os, int number);
-    static QString getPrimerSequence(HI::GUITestOpStatus &os, const QString &name);
-    static QPoint getPrimerPoint(HI::GUITestOpStatus &os, int number);
-    static void clickPrimer(HI::GUITestOpStatus &os, int number);
-    static void clearLibrary(HI::GUITestOpStatus &os);
-    static void addPrimer(HI::GUITestOpStatus &os, const QString &name, const QString &data);
-    static void selectPrimers(HI::GUITestOpStatus &os, const QList<int> &numbers);
-    static void selectAll(HI::GUITestOpStatus &os);
+                  Close,
+                  Temperature };
+    static QWidget* openLibrary();
+    static void clickButton(Button button);
+    static QAbstractButton* getButton(Button button);
+    static int librarySize();
+    static QString getPrimerSequence(int number);
+    static QString getPrimerSequence(const QString& name);
+    static QPoint getPrimerPoint(int number);
+    static void clickPrimer(int number);
+    static void clearLibrary();
+    static void addPrimer(const QString& name, const QString& data);
+    static void selectPrimers(const QList<int>& numbers);
+    static void selectAll();
 
 private:
-    static QTableView *table(HI::GUITestOpStatus &os);
+    static QTableView* table();
 };
 
 }  // namespace U2
-
-#endif  // _GTUTILS_PRIMER_LIBRARY_H_
