@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,32 +19,29 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GT_UTILS_QUERY_DESIGNER_H
-#define GT_UTILS_QUERY_DESIGNER_H
+#pragma once
 
 #include <QTreeWidget>
 
 #include <U2View/MSAEditorSequenceArea.h>
 
 #include "GTGlobals.h"
-class QRectF;
 
 namespace U2 {
 
 class GTUtilsQueryDesigner {
 public:
-    static void openQueryDesigner(HI::GUITestOpStatus &os);
+    static void openQueryDesigner();
 
-    static QTreeWidgetItem *findAlgorithm(HI::GUITestOpStatus &os, QString itemName);
-    static void addAlgorithm(HI::GUITestOpStatus &os, QString algName);
-    static QPoint getItemCenter(HI::GUITestOpStatus &os, QString itemName);
-    static QRect getItemRect(HI::GUITestOpStatus &os, QString itemName);
+    static QTreeWidgetItem* findAlgorithm(const QString& itemName);
+    static void addAlgorithm(const QString& algName);
+    static QPoint getItemCenter(const QString& itemName);
+    static QRect getItemRect(const QString& itemName);
 
-    static int getItemLeft(HI::GUITestOpStatus &os, QString itemName);
-    static int getItemRight(HI::GUITestOpStatus &os, QString itemName);
-    static int getItemTop(HI::GUITestOpStatus &os, QString itemName);
-    static int getItemBottom(HI::GUITestOpStatus &os, QString itemName);
+    static int getItemLeft(const QString& itemName);
+    static int getItemRight(const QString& itemName);
+    static int getItemTop(const QString& itemName);
+    static int getItemBottom(const QString& itemName);
 };
 
 }  // namespace U2
-#endif  // GT_UTILS_QUERY_DESIGNER_H
