@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,17 +28,13 @@
 namespace U2 {
 #define GT_CLASS_NAME "GTUtilsStartPage"
 
-#define GT_METHOD_NAME "openStartPage"
-void GTUtilsStartPage::openStartPage(HI::GUITestOpStatus &os) {
-    GTUtilsMdi::activateWindow(os, "Start Page");
+void GTUtilsStartPage::openStartPage() {
+    GTUtilsMdi::activateWindow("Start Page");
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "checkRecentListUrl"
-void GTUtilsStartPage::checkRecentListUrl(HI::GUITestOpStatus &os, const QString &urlPart, bool isPresent) {
-    GTWidget::findLabelByText(os, urlPart, nullptr, {isPresent});
+void GTUtilsStartPage::checkRecentListUrl(const QString& urlPart, bool isPresent) {
+    GTWidget::findLabelByText(urlPart, nullptr, {isPresent});
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
