@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_UTILS_START_PAGE_
-#define _U2_GT_UTILS_START_PAGE_
+#pragma once
 
 #include "GTGlobals.h"
 
@@ -29,12 +28,10 @@ using namespace HI;
 
 class GTUtilsStartPage {
 public:
-    static void openStartPage(HI::GUITestOpStatus &os);
+    static void openStartPage();
 
     /** Checks if the 'urlPart' is present or not in the recent files list. */
-    static void checkRecentListUrl(HI::GUITestOpStatus &os, const QString &urlPart, bool isPresent);
+    static void checkRecentListUrl(const QString& urlPart, bool isPresent);
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_UTILS_START_PAGE_
