@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUITESTBASE_PLUGIN_H_
-#define _U2_GUITESTBASE_PLUGIN_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -43,13 +42,11 @@ private slots:
     void sl_showWindow();
 
 private:
-    void registerTests(UGUITestBase *guiTestBase);
-    void registerAdditionalActions(UGUITestBase *guiTestBase);
+    void registerTests(UGUITestBase* guiTestBase);
+    void registerAdditionalActions(UGUITestBase* guiTestBase);
 
-    QAction *openGUITestRunnerAction;
+    QAction* openGUITestRunnerAction;
     QPointer<GUITestRunner> view;
 };
 
 }  // namespace U2
-
-#endif
