@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,52 +31,43 @@ namespace U2 {
 using namespace HI;
 
 #define GT_CLASS_NAME "GTBaseCompleter"
-#define GT_METHOD_NAME "click"
-void GTBaseCompleter::click(HI::GUITestOpStatus &os, QWidget *widgetCompleterFor, const QString &seqName) {
-    QTreeWidget *tree = getCompleter(os, widgetCompleterFor);
+void GTBaseCompleter::click(QWidget* widgetCompleterFor, const QString& seqName) {
+    QTreeWidget* tree = getCompleter(widgetCompleterFor);
     GT_CHECK(tree != nullptr, "tree widget is NULL");
-    QTreeWidgetItem *item = GTTreeWidget::findItem(os, tree, seqName);
+    QTreeWidgetItem* item = GTTreeWidget::findItem(tree, seqName);
     GT_CHECK(item != nullptr, "item not found");
-    tree->scrollToItem(item);
-    GTGlobals::sleep(100);
+    GTTreeWidget::scrollToItem(item);
     QRect itemRect = tree->visualItemRect(item);
     QPoint globalCenter = tree->mapToGlobal(itemRect.center());
     GTMouseDriver::moveTo(globalCenter);
     GTMouseDriver::click();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "getNames"
-QStringList GTBaseCompleter::getNames(HI::GUITestOpStatus &os, QWidget *widgetCompleterFor) {
-    QTreeWidget *tree = getCompleter(os, widgetCompleterFor);
+QStringList GTBaseCompleter::getNames(QWidget* widgetCompleterFor) {
+    QTreeWidget* tree = getCompleter(widgetCompleterFor);
     GT_CHECK_RESULT(tree != nullptr, "tree widget is NULL", QStringList());
     QStringList result;
-    QList<QTreeWidgetItem *> items = GTTreeWidget::getItems(tree->invisibleRootItem());
-    foreach (QTreeWidgetItem *item, items) {
+    QList<QTreeWidgetItem*> items = GTTreeWidget::getItems(tree->invisibleRootItem());
+    foreach (QTreeWidgetItem* item, items) {
         result << item->text(0);
     }
     return result;
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "isEmpty"
-bool GTBaseCompleter::isEmpty(HI::GUITestOpStatus &os, QWidget *widgetCompleterFor) {
-    QTreeWidget *tree = getCompleter(os, widgetCompleterFor);
+bool GTBaseCompleter::isEmpty(QWidget* widgetCompleterFor) {
+    QTreeWidget* tree = getCompleter(widgetCompleterFor);
     GT_CHECK_RESULT(tree != nullptr, "tree widget is NULL", true);
-    QStringList items = getNames(os, widgetCompleterFor);
+    QStringList items = getNames(widgetCompleterFor);
     bool result = (items.count() == 1) && (items.at(0) == "");
     return result;
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "getCompleter"
-QTreeWidget *GTBaseCompleter::getCompleter(HI::GUITestOpStatus &os, QWidget *widgetCompleterFor) {
+QTreeWidget* GTBaseCompleter::getCompleter(QWidget* widgetCompleterFor) {
     GT_CHECK_RESULT(widgetCompleterFor != nullptr, "Widget associated with completer not found", nullptr);
-    QTreeWidget *completer = widgetCompleterFor->findChild<QTreeWidget *>();
+    QTreeWidget* completer = widgetCompleterFor->findChild<QTreeWidget*>();
     GT_CHECK_RESULT(completer != nullptr, "auto completer widget not found", nullptr);
     return completer;
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
