@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GTGRAPHICSITEM_H
-#define GTGRAPHICSITEM_H
+#pragma once
 
 #include <QGraphicsItem>
 
@@ -33,10 +32,8 @@ using namespace HI;
 
 class GTGraphicsItem {
 public:
-    static QRect getGraphicsItemRect(HI::GUITestOpStatus &os, QGraphicsItem *it);
-    static QPoint getItemCenter(HI::GUITestOpStatus &os, QGraphicsItem *it);
+    static QRect getGraphicsItemRect(QGraphicsItem* it);
+    static QPoint getItemCenter(QGraphicsItem* it);
 };
 
 }  // namespace U2
-
-#endif  // GTGRAPHICSITEM_H
