@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_MSAEDITOR_STATUSWIDGET_H_
-#define _U2_GT_MSAEDITOR_STATUSWIDGET_H_
+#pragma once
 
 #include <U2View/MaEditorStatusBar.h>
 
@@ -31,21 +30,20 @@ using namespace HI;
 
 class GTMSAEditorStatusWidget {
 public:
-    static QWidget *getStatusWidget(HI::GUITestOpStatus &os);
+    static QWidget* getStatusWidget();
 
     // fails if the widget is NULL or can't get length
-    static int length(HI::GUITestOpStatus &os, QWidget *w);
-    static int getSequencesCount(HI::GUITestOpStatus &os, QWidget *w);
+    static int length(QWidget* w);
+    static int getSequencesCount(QWidget* w);
 
-    static QString getRowNumberString(HI::GUITestOpStatus &os);
-    static QString getRowsCountString(HI::GUITestOpStatus &os);
+    static QString getRowNumberString();
+    static QString getRowsCountString();
 
-    static QString getColumnNumberString(HI::GUITestOpStatus &os);
-    static QString getColumnsCountString(HI::GUITestOpStatus &os);
+    static QString getColumnNumberString();
+    static QString getColumnsCountString();
 
-    static QString getSequenceUngappedPositionString(HI::GUITestOpStatus &os);
-    static QString getSequenceUngappedLengthString(HI::GUITestOpStatus &os);
+    static QString getSequenceUngappedPositionString();
+    static QString getSequenceUngappedLengthString();
 };
 
 }  // namespace U2
-#endif  // _U2_GT_MSAEDITOR_STATUSWIDGET_H_
