@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,19 +30,18 @@ using namespace HI;
 
 #define GT_CLASS_NAME "GTRegionSelector"
 
-#define GT_METHOD_NAME "setRegion"
-void GTRegionSelector::setRegion(HI::GUITestOpStatus &os, RegionSelector *regionSelector, const RegionSelectorSettings &s) {
+void GTRegionSelector::setRegion(RegionSelector* regionSelector, const RegionSelectorSettings& s) {
     GT_CHECK(regionSelector != nullptr, "RegionSelector is NULL");
 
-    CHECK_EXT(!s.isUnset(), uiLog.trace("GT_DEBUG_MESSAGE RegionSelectorSettings isUnset, returning"), );
+    if (s.isUnset()) {
+        uiLog.trace("GT_DEBUG_MESSAGE RegionSelectorSettings isUnset, returning");
+        return;
+    };
 
-    QLineEdit *startEdit = qobject_cast<QLineEdit *>(GTWidget::findWidget(os, "start_edit_line", regionSelector));
-    GTLineEdit::setText(os, startEdit, QString::number(s.start));
+    GTLineEdit::setText("start_edit_line", QString::number(s.start), regionSelector);
 
-    QLineEdit *endEdit = qobject_cast<QLineEdit *>(GTWidget::findWidget(os, "end_edit_line", regionSelector));
-    GTLineEdit::setText(os, endEdit, QString::number(s.end));
+    GTLineEdit::setText("end_edit_line", QString::number(s.end), regionSelector);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
