@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_REGIONSELECTOR_H_
-#define _U2_GT_REGIONSELECTOR_H_
+#pragma once
 
 #include <U2Gui/RegionSelector.h>
 
@@ -49,8 +48,7 @@ public:
         bool unset;
     };
 
-    static void setRegion(HI::GUITestOpStatus &os, RegionSelector *regionSelector, const RegionSelectorSettings &s);
+    static void setRegion(RegionSelector* regionSelector, const RegionSelectorSettings& s);
 };
 
 }  // namespace U2
-#endif  // _U2_GT_REGIONSELECTOR_H_
