@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GTSEQUENCEREADINGMODEDIALOG_H
-#define GTSEQUENCEREADINGMODEDIALOG_H
+#pragma once
 
 #include <QDialogButtonBox>
 #include <QString>
@@ -47,5 +46,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // GTSEQUENCEREADINGMODEDIALOG_H
