@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GTSEQUENCEREADINGMODEDIALOGUTILS_H
-#define GTSEQUENCEREADINGMODEDIALOGUTILS_H
+#pragma once
 
 #include <QSpinBox>
 
@@ -36,7 +35,7 @@ public:
     enum Button { Ok,
                   Cancel };
 
-    GTSequenceReadingModeDialogUtils(HI::GUITestOpStatus &os, CustomScenario *scenario = nullptr);
+    GTSequenceReadingModeDialogUtils(CustomScenario* scenario = nullptr);
     virtual void commonScenario();
 
 private:
@@ -46,11 +45,9 @@ private:
     void setNewDocumentName();
     void selectSaveDocument();
     void clickButton();
-    void changeSpinBoxValue(QSpinBox *, int);
+    void changeSpinBoxValue(QSpinBox*, int);
 
-    QWidget *dialog;
+    QWidget* dialog;
 };
 
 }  // namespace U2
-
-#endif  // GTSEQUENCEREADINGMODEDIALOGUTILS_H
