@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,6 +31,7 @@
 #include <U2Core/CMDLineCoreOptions.h>
 #include <U2Core/CmdlineTaskRunner.h>
 #include <U2Core/ExternalToolRegistry.h>
+#include <U2Core/IOAdapterUtils.h>
 #include <U2Core/Timer.h>
 #include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/U2SafePoints.h>
@@ -41,26 +42,26 @@
 
 namespace U2 {
 
-GUITestLauncher::GUITestLauncher(int suiteNumber, bool noIgnored, const QString &iniFileTemplate)
+GUITestLauncher::GUITestLauncher(int suiteNumber, bool noIgnored, const QString& iniFileTemplate)
     : Task("gui_test_launcher", TaskFlags(TaskFlag_ReportingIsSupported) | TaskFlag_ReportingIsEnabled),
       suiteNumber(suiteNumber), noIgnored(noIgnored), pathToSuite(""), iniFileTemplate(iniFileTemplate) {
     tpm = Task::Progress_Manual;
     testOutputDir = findAvailableTestOutputDir();
 
-    QWidget *splashScreen = QApplication::activeWindow();
+    QWidget* splashScreen = QApplication::activeWindow();
     if (splashScreen != nullptr) {
         splashScreen->hide();
     }
 }
 
-GUITestLauncher::GUITestLauncher(const QString &_pathToSuite, bool _noIgnored, const QString &_iniFileTemplate)
+GUITestLauncher::GUITestLauncher(const QString& _pathToSuite, bool _noIgnored, const QString& _iniFileTemplate)
     : Task("gui_test_launcher", TaskFlags(TaskFlag_ReportingIsSupported) | TaskFlag_ReportingIsEnabled),
       suiteNumber(0), noIgnored(_noIgnored), pathToSuite(_pathToSuite), iniFileTemplate(_iniFileTemplate) {
     tpm = Task::Progress_Manual;
     testOutputDir = findAvailableTestOutputDir();
 }
 
-bool GUITestLauncher::renameTestLog(const QString &testName, int testRunIteration) {
+bool GUITestLauncher::renameTestLog(const QString& testName, int testRunIteration) {
     QString outFileName = getTestOutputFileName(testName, testRunIteration);
     QString outFilePath = testOutputDir + QString("/logs/");
 
@@ -83,7 +84,7 @@ void GUITestLauncher::run() {
     qint64 suiteStartMicros = GTimer::currentTimeMicros();
 
     int finishedCount = 0;
-    for (GUITest *test : qAsConst(testList)) {
+    for (GUITest* test : qAsConst(testList)) {
         if (isCanceled()) {
             return;
         }
@@ -110,12 +111,13 @@ void GUITestLauncher::run() {
 
                 qint64 finishTime = GTimer::currentTimeMicros();
                 GUITestTeamcityLogger::teamCityLogResult(teamcityTestName, testResult, GTimer::millisBetween(startTime, finishTime));
-            } catch (const std::exception &exc) {
+            } catch (const std::exception& exc) {
                 coreLog.error("Got exception while running test: " + fullTestName);
                 coreLog.error("Exception text: " + QString(exc.what()));
             }
         } else if (isValidPlatform) {
             // If the test should run on the current platform but has ignored label -> report it to the teamcity.
+            coreLog.details("Test has ignored on the current platform: " + test->getFullName());
             GUITestTeamcityLogger::testIgnored(teamcityTestName, test->getDescription());
         }
 
@@ -126,55 +128,56 @@ void GUITestLauncher::run() {
     coreLog.info(QString("Suite %1 finished in %2 minutes").arg(suiteNumber).arg(suiteTimeMinutes));
 }
 
-void GUITestLauncher::firstTestRunCheck(const QString &testName) {
+void GUITestLauncher::firstTestRunCheck(const QString& testName) {
     QString testResult = testResultByFullTestNameMap[testName];
     Q_ASSERT(testResult.isEmpty());
 }
 
 /** Returns ideal tests list for the given suite or an empty list if there is no ideal configuration is found. */
-QList<GUITest *> getIdealNightlyTestsSplit(int suiteIndex, int suiteCount, const QList<GUITest *> &allTests) {
+QList<GUITest*> getIdealTestsSplit(int suiteIndex, int suiteCount, const QList<GUITest*>& allTests) {
     QList<int> testsPerSuite;
-    if (suiteCount == 3) {
-        testsPerSuite << 980 << 800 << -1;
+    if (suiteCount == 3) {  // Windows & Mac.
+        testsPerSuite << 950 << 910 << -1;
     } else if (suiteCount == 4) {
-        testsPerSuite << 640 << 680 << 640 << -1;
+        testsPerSuite << 670 << 670 << 730 << -1;
     } else if (suiteCount == 5) {
-        testsPerSuite << 550 << 575 << 480 << 550 << -1;
+        testsPerSuite << 550 << 580 << 500 << 570 << -1;  // Linux.
     }
-    QList<GUITest *> tests;
-    if (testsPerSuite.size() == suiteCount) {
-        SAFE_POINT(testsPerSuite.size() == suiteCount, QString("Illegal testsPerSuite size: %1").arg(testsPerSuite.size()), tests);
-        int offset = 0;
-        for (int i = 0; i < suiteIndex; i++) {
-            offset += testsPerSuite[i];
-        }
-        int testCount = testsPerSuite[suiteIndex];  // last index is -1 => list.mid(x, -1) returns a tail.
-        tests << allTests.mid(offset, testCount);
+    CHECK(suiteCount == testsPerSuite.size(), {});  // Check that we know the distribution. Return an empty list if we do not.
+    QList<GUITest*> tests;
+    int offset = 0;
+    for (int i = 0; i < suiteIndex; i++) {
+        offset += testsPerSuite[i];
     }
+    int testCount = testsPerSuite[suiteIndex];  // last index is -1 => list.mid(x, -1) returns a tail.
+    tests << allTests.mid(offset, testCount);
     return tests;
 }
 
 bool GUITestLauncher::initTestList() {
     testList.clear();
 
-    UGUITestBase *guiTestBase = UGUITestBase::getInstance();
+    UGUITestBase* guiTestBase = UGUITestBase::getInstance();
 
     // Label set to build a run-time test set is passed via environment variable.
     QString labelEnvVar = qgetenv("UGENE_GUI_TEST_LABEL");
     QStringList labelList = labelEnvVar.isEmpty() ? QStringList() : labelEnvVar.split(",");
 
     if (suiteNumber != 0) {
-        // If no label is provided 'Nightly' (UGUITestLabels::Nightly) label is used by default.
+        // If no label is provided 'Nightly' (UGUITestLabels::Precommit) label is used by default.
         if (labelList.isEmpty()) {
-            labelList << UGUITestLabels::Nightly;
+            labelList << UGUITestLabels::Precommit;
         }
         int testSuiteCount = 1;
-        if (labelList.contains(UGUITestLabels::Nightly)) {
-            // TODO: make configurable via ENV.
+        if (labelList.contains(UGUITestLabels::Precommit)) {
             testSuiteCount = isOsWindows() ? 3
-                             : isOsMac()   ? 4
+                             : isOsMac()   ? 3
                              : isOsLinux() ? 5
                                            : 1;
+            int testSuiteCountFromEnv = qgetenv("UGENE_GUI_TEST_SUITE_COUNT").toInt();
+            if (testSuiteCountFromEnv > 0) {
+                testSuiteCount = testSuiteCountFromEnv;
+            }
         }
 
         if (suiteNumber < 1 || suiteNumber > testSuiteCount) {
@@ -182,9 +185,9 @@ bool GUITestLauncher::initTestList() {
             return false;
         }
 
-        QList<GUITest *> labeledTestList = guiTestBase->getTests(UGUITestBase::Normal, labelList);
-        if (labelList.contains(UGUITestLabels::Nightly)) {
-            testList = getIdealNightlyTestsSplit(suiteNumber - 1, testSuiteCount, labeledTestList);
+        QList<GUITest*> labeledTestList = guiTestBase->getTests(UGUITestBase::Normal, labelList);
+        if (labelList.contains(UGUITestLabels::Precommit)) {
+            testList = getIdealTestsSplit(suiteNumber - 1, testSuiteCount, labeledTestList);
         }
         if (testList.isEmpty()) {
             // If there is no ideal test split for the given number -> distribute tests between suites evenly.
@@ -195,7 +198,7 @@ bool GUITestLauncher::initTestList() {
         coreLog.info(QString("Running suite %1-%2, Tests in the suite: %3, total tests: %4").arg(labelList.join(",")).arg(suiteNumber).arg(testList.size()).arg(labeledTestList.length()));
     } else if (!pathToSuite.isEmpty()) {
         // If a file with tests is specified we ignore labels and look-up in the complete tests set.
-        QList<GUITest *> allTestList = guiTestBase->getTests(UGUITestBase::Normal);
+        QList<GUITest*> allTestList = guiTestBase->getTests(UGUITestBase::Normal);
         QString absPath = QDir().absoluteFilePath(pathToSuite);
         QFile suite(absPath);
         if (!suite.open(QFile::ReadOnly)) {
@@ -209,7 +212,7 @@ bool GUITestLauncher::initTestList() {
                 continue;  // comment line or empty line.
             }
             bool added = false;
-            for (GUITest *test : qAsConst(allTestList)) {
+            for (GUITest* test : qAsConst(allTestList)) {
                 QString fullTestName = test->getFullName();
                 QString teamcityTestName = UGUITest::getTeamcityTestName(test->suite, test->name);
                 if (testName == fullTestName || testName == teamcityTestName) {
@@ -233,6 +236,28 @@ bool GUITestLauncher::initTestList() {
         testList = guiTestBase->getTests(UGUITestBase::Normal, labelList);
     }
 
+    // Apply dynamic ignore list. Ignored tests are reported to Teamcity as 'ignored' and are not run at all.
+    QString ignoreListFilePath = qgetenv("UGENE_GUI_TEST_IGNORE_LIST_FILE");
+    if (!ignoreListFilePath.isEmpty()) {
+        QString ignoreListFileContent = IOAdapterUtils::readTextFile(ignoreListFilePath);
+        coreLog.details("Applying ignore list:\n" + ignoreListFileContent);
+        int nIgnoredTests = 0;
+        QStringList ignoreListEntries = ignoreListFileContent.split("\n");
+        for (const QString& entry : qAsConst(ignoreListEntries)) {
+            if (entry.isEmpty() || entry.startsWith("#")) {
+                continue;
+            }
+            for (auto test : qAsConst(testList)) {
+                QString teamcityTestName = UGUITest::getTeamcityTestName(test->suite, test->name);
+                if (test->getFullName().startsWith(entry) || teamcityTestName.startsWith(entry)) {
+                    test->labelSet.insert(UGUITestLabels::Ignored);
+                    coreLog.details(QString("Adding Ignore label to test '%1', entry: '%2'").arg(teamcityTestName).arg(entry));
+                    nIgnoredTests++;
+                }
+            }
+        }
+        coreLog.details(QString("Matched %1 tests to ignore").arg(nIgnoredTests));
+    }
     return true;
 }
 
@@ -243,7 +268,7 @@ void GUITestLauncher::updateProgress(int finishedCount) {
     }
 }
 
-QString GUITestLauncher::getTestOutputFileName(const QString &testName, int testRunIteration) {
+QString GUITestLauncher::getTestOutputFileName(const QString& testName, int testRunIteration) {
     return QString("ugene_" + testName + "_r_" + QString::number(testRunIteration) + ".out").replace(':', '_');
 }
 
@@ -265,7 +290,7 @@ QString GUITestLauncher::findAvailableTestOutputDir() {
     return d.absolutePath();
 }
 
-static bool restoreTestDirWithExternalScript(const QString &pathToShellScript, const QString &iniFilePath) {
+static bool restoreTestDirWithExternalScript(const QString& pathToShellScript, const QString& iniFilePath) {
     QDir testsDir(qgetenv("UGENE_TESTS_PATH"));
     if (!testsDir.exists()) {
         coreLog.error("UGENE_TESTS_PATH is not set!");
@@ -286,15 +311,15 @@ static bool restoreTestDirWithExternalScript(const QString &pathToShellScript, c
     process.setProcessEnvironment(processEnv);
     QString restoreProcessWorkDir = QFileInfo(testsDir.absolutePath() + "/../").absolutePath();
     process.setWorkingDirectory(restoreProcessWorkDir);  // Parent dir of the test dir.
-//    coreLog.info("Running restore process, work dir: " + restoreProcessWorkDir +
-//                 ", tests dir: " + testsDir.dirName() +
-//                 ", data dir: " + dataDir.dirName() +
-//                 ", script: " + pathToShellScript);
-#ifdef Q_OS_WIN
-    process.start("cmd /C " + pathToShellScript);
-#else
-    process.start("/bin/bash", QStringList() << pathToShellScript);
-#endif
+    //    coreLog.info("Running restore process, work dir: " + restoreProcessWorkDir +
+    //                 ", tests dir: " + testsDir.dirName() +
+    //                 ", data dir: " + dataDir.dirName() +
+    //                 ", script: " + pathToShellScript);
+    if (isOsWindows()) {
+        process.start("cmd /C " + pathToShellScript);
+    } else {
+        process.start("/bin/bash", {pathToShellScript});
+    }
     qint64 processId = process.processId();
     bool isStarted = process.waitForStarted();
     if (!isStarted) {
@@ -317,7 +342,7 @@ static bool restoreTestDirWithExternalScript(const QString &pathToShellScript, c
     return true;
 }
 
-QProcessEnvironment GUITestLauncher::prepareTestRunEnvironment(const QString &testName, int testRunIteration) {
+QProcessEnvironment GUITestLauncher::prepareTestRunEnvironment(const QString& testName, int testRunIteration) {
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
 
     QDir().mkpath(testOutputDir + "/logs");
@@ -326,7 +351,13 @@ QProcessEnvironment GUITestLauncher::prepareTestRunEnvironment(const QString &te
     env.insert(ENV_USE_NATIVE_DIALOGS, "0");
     env.insert(U2_PRINT_TO_FILE, testOutputDir + "/logs/" + getTestOutputFileName(testName, testRunIteration));
 
-    QString iniFilePath = testOutputDir + "/inis/" + QString(testName).replace(':', '_') + "_r_" + QString::number(testRunIteration) + "_UGENE.ini";
+    // Some variables in UGENE are computed relative to the ini file folder (like MSA color schema dir).
+    // Use different folder for different runs.
+    QString iniFileDir = testOutputDir + "/inis/";
+    if (testRunIteration > 0) {
+        iniFileDir += QString::number(testRunIteration) + "/";
+    }
+    QString iniFilePath = iniFileDir + QString(testName).replace(':', '_') + "_r_" + QString::number(testRunIteration) + "_UGENE.ini";
     if (!iniFileTemplate.isEmpty() && QFile::exists(iniFileTemplate)) {
         QFile::copy(iniFileTemplate, iniFilePath);
     }
@@ -340,10 +371,11 @@ QProcessEnvironment GUITestLauncher::prepareTestRunEnvironment(const QString &te
     return env;
 }
 
-QString GUITestLauncher::runTest(const QString &testName, int timeoutMillis) {
+QString GUITestLauncher::runTest(const QString& testName, int timeoutMillis) {
     int maxReruns = qMax(qgetenv("UGENE_TEST_NUMBER_RERUN_FAILED_TEST").toInt(), 0);
     QString testOutput;
     bool isVideoRecordingOn = qgetenv("UGENE_TEST_ENABLE_VIDEO_RECORDING") == "1";
+    bool isVideoRecordingAlwaysOn = isVideoRecordingOn && qgetenv("UGENE_TEST_ENABLE_VIDEO_RECORDING_ALL_ITERATIONS") == "1";
     for (int iteration = 0; iteration < 1 + maxReruns; iteration++) {
         if (iteration >= 1) {
             coreLog.error(QString("Re-running the test. Current re-run: %1, max re-runs: %2, check logs in: %3")
@@ -352,7 +384,7 @@ QString GUITestLauncher::runTest(const QString &testName, int timeoutMillis) {
                               .arg(testOutputDir));
         }
         U2OpStatusImpl os;
-        testOutput = runTestOnce(os, testName, iteration, timeoutMillis, isVideoRecordingOn && iteration > 0);
+        testOutput = runTestOnce(os, testName, iteration, timeoutMillis, isVideoRecordingOn && (isVideoRecordingAlwaysOn || iteration > 0));
         bool isFailed = os.hasError() || GUITestTeamcityLogger::isTestFailed(testOutput);
         if (!isFailed) {
             break;
@@ -363,7 +395,7 @@ QString GUITestLauncher::runTest(const QString &testName, int timeoutMillis) {
     return testOutput;
 }
 
-QString GUITestLauncher::runTestOnce(U2OpStatus &os, const QString &testName, int iteration, const int timeout, bool enableVideoRecording) {
+QString GUITestLauncher::runTestOnce(U2OpStatus& os, const QString& testName, int iteration, const int timeout, bool enableVideoRecording) {
     QProcessEnvironment environment = prepareTestRunEnvironment(testName, iteration);
 
     QString ugeneUiPath = QCoreApplication::applicationFilePath();
@@ -412,7 +444,8 @@ QString GUITestLauncher::runTestOnce(U2OpStatus &os, const QString &testName, in
             screenRecorderProcess.kill();
             screenRecorderProcess.waitForFinished(2000);
         }
-        if (!GUITestTeamcityLogger::isTestFailed(testResult)) {
+        bool keepVideoFile = qgetenv("UGENE_TEST_KEEP_VIDEOS") == "1";
+        if (!keepVideoFile && !GUITestTeamcityLogger::isTestFailed(testResult)) {
             QFile(getVideoPath(testName)).remove();
         }
     }
@@ -430,12 +463,12 @@ QString GUITestLauncher::runTestOnce(U2OpStatus &os, const QString &testName, in
     return error;
 }
 
-QStringList GUITestLauncher::getTestProcessArguments(const QString &testName) {
+QStringList GUITestLauncher::getTestProcessArguments(const QString& testName) {
     QString guiTestOption = "--" + CMDLineCoreOptions::LAUNCH_GUI_TEST + "=" + testName;
     return {guiTestOption};
 }
 
-QString GUITestLauncher::readTestResult(const QByteArray &output) {
+QString GUITestLauncher::readTestResult(const QByteArray& output) {
     QString msg;
     QTextStream stream(output, QIODevice::ReadOnly);
 
@@ -471,7 +504,7 @@ QString GUITestLauncher::generateReport() const {
     return res;
 }
 
-QString GUITestLauncher::getScreenRecorderString(const QString &testName) {
+QString GUITestLauncher::getScreenRecorderString(const QString& testName) {
     QString result;
     QString videoFilePath = getVideoPath(testName);
     if (isOsLinux()) {
@@ -489,7 +522,7 @@ QString GUITestLauncher::getScreenRecorderString(const QString &testName) {
     return result;
 }
 
-QString GUITestLauncher::getVideoPath(const QString &testName) {
+QString GUITestLauncher::getVideoPath(const QString& testName) {
     QString dirPath = qgetenv("UGENE_GUI_TEST_VIDEO_DIR_PATH");
     if (dirPath.isEmpty()) {
         dirPath = QDir::currentPath() + "/videos";
