@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUI_TESTS_TEAMCITY_LOGGER_H_
-#define _U2_GUI_TESTS_TEAMCITY_LOGGER_H_
+#pragma once
 
 #include <QString>
 
@@ -28,17 +27,15 @@ namespace U2 {
 
 class GUITestTeamcityLogger {
 public:
-    static void testStarted(const QString &testName);
-    static void testIgnored(const QString &testName, const QString &ignoreReason);
-    static void teamCityLogResult(const QString &testName, const QString &testResult, qint64 testTimeMicros);
+    static void testStarted(const QString& testName);
+    static void testIgnored(const QString& testName, const QString& ignoreReason);
+    static void teamCityLogResult(const QString& testName, const QString& testResult, qint64 testTimeMicros);
 
     // private:
-    static QString escaped(const QString &s);  // returns valid teamcity log string with escaped symbols
-    static bool isTestFailed(const QString &testOutput);
+    static QString escaped(const QString& s);  // returns valid teamcity log string with escaped symbols
+    static bool isTestFailed(const QString& testOutput);
 
     static const QString successResult;
 };
 
 }  // namespace U2
-
-#endif
