@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -26,8 +26,8 @@
 namespace U2 {
 using namespace HI;
 
-EscapeClicker::EscapeClicker(HI::GUITestOpStatus &os, const QString &name, CustomScenario *scenario)
-    : Filler(os, name, scenario) {
+EscapeClicker::EscapeClicker(const QString& name, CustomScenario* scenario)
+    : Filler(name, scenario) {
 }
 
 void EscapeClicker::commonScenario() {
