@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef ESCAPECLICKER_H
-#define ESCAPECLICKER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -28,11 +27,9 @@ namespace U2 {
 using namespace HI;
 class EscapeClicker : public Filler {
 public:
-    EscapeClicker(HI::GUITestOpStatus &os, const QString &name = "", CustomScenario *scenario = nullptr);
+    EscapeClicker(const QString& name = "", CustomScenario* scenario = nullptr);
 
     void commonScenario();
 };
 
 }  // namespace U2
-
-#endif  // ESCAPECLICKER_H
