@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_ADD_NEW_DOCUMENT_DIALOG_FILLER_H_
-#define _U2_GT_ADD_NEW_DOCUMENT_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 
 class AddNewDocumentDialogFiller : public Filler {
 public:
-    AddNewDocumentDialogFiller(HI::GUITestOpStatus &os, const QString &format, const QString &path);
-    AddNewDocumentDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    AddNewDocumentDialogFiller(const QString& format, const QString& path);
+    AddNewDocumentDialogFiller(CustomScenario* scenario);
 
     void commonScenario();
 
@@ -40,5 +39,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_ADD_NEW_DOCUMENT_DIALOG_FILLER_H_
