@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,26 +32,22 @@ namespace U2 {
 using namespace HI;
 #define GT_CLASS_NAME "GTUtilsDialog::CommonImportOptionsDialogFiller"
 
-CommonImportOptionsDialogFiller::CommonImportOptionsDialogFiller(HI::GUITestOpStatus &os, const QVariantMap &data)
-    : Filler(os, "CommonImportOptionsDialog"),
+CommonImportOptionsDialogFiller::CommonImportOptionsDialogFiller(const QVariantMap& data)
+    : Filler("CommonImportOptionsDialog"),
       data(data) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void CommonImportOptionsDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(nullptr != dialog, "activeModalWidget is NULL");
-    GTWidget::clickWindowTitle(os, dialog);
+    QWidget* dialog = GTWidget::getActiveModalWidget();
+    GTWidget::clickWindowTitle(dialog);
 
-    ImportOptionsWidget *optionsWidget = qobject_cast<ImportOptionsWidget *>(GTWidget::findWidget(os, "optionsWidget", dialog));
-    GT_CHECK(nullptr != optionsWidget, "optionsWidget is NULL");
+    auto optionsWidget = GTWidget::findExactWidget<ImportOptionsWidget*>("optionsWidget", dialog);
 
-    ImportOptionsWidgetFiller::fill(os, optionsWidget, data);
+    ImportOptionsWidgetFiller::fill(optionsWidget, data);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
 
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
