@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,19 +29,16 @@
 namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::ConvertAssemblytoSamFiller"
-#define GT_METHOD_NAME "commonScenario"
 void ConvertAssemblyToSAMDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    GTFileDialogUtils *ob = new GTFileDialogUtils(os, databasePath, databaseFileName);
-    GTUtilsDialog::waitForDialog(os, ob);
-    GTWidget::click(os, GTWidget::findWidget(os, "setDbPathButton", dialog));
+    GTFileDialogUtils* ob = new GTFileDialogUtils(databasePath, databaseFileName);
+    GTUtilsDialog::waitForDialog(ob);
+    GTWidget::click(GTWidget::findWidget("setDbPathButton", dialog));
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
 
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
