@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_CREATE_ANNOTATIONS_WIDGET_FILLER_H_
-#define _U2_GT_RUNNABLES_CREATE_ANNOTATIONS_WIDGET_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,16 +28,16 @@ using namespace HI;
 
 class CreateAnnotationWidgetFiller : public Filler {
 public:
-    CreateAnnotationWidgetFiller(HI::GUITestOpStatus &os,
-                                 bool newTableRB,
-                                 const QString &groupName,
-                                 const QString &annotationName,
-                                 const QString &location,
-                                 const QString &saveTo = "",
-                                 const QString &description = "");
-    CreateAnnotationWidgetFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    CreateAnnotationWidgetFiller(
+        bool newTableRB,
+        const QString& groupName,
+        const QString& annotationName,
+        const QString& location,
+        const QString& saveTo = "",
+        const QString& description = "");
+    CreateAnnotationWidgetFiller(CustomScenario* scenario);
 
-    virtual void commonScenario();
+    void commonScenario() override;
 
 private:
     const QString groupName;
@@ -50,5 +49,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_RUNNABLES_CREATE_ANNOTATIONS_WIDGET_FILLER_H_
