@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_CREATE_DOCUMENT_FROM_TEST_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_CREATE_DOCUMENT_FROM_TEST_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -38,8 +37,8 @@ public:
                             StandardAmino,
                             AllSymbols };
 
-    CreateDocumentFiller(HI::GUITestOpStatus &_os, const QString &_pasteDataHere, bool customSettings, documentAlphabet _alphabet, bool skipUnknownSymbols, bool replaceUnknownSymbols, const QString symbol, const QString &_documentLocation, documentFormat _format, const QString &_sequenceName, bool saveFile, GTGlobals::UseMethod method = GTGlobals::UseMouse);
-    CreateDocumentFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    CreateDocumentFiller(const QString& _pasteDataHere, bool customSettings, documentAlphabet _alphabet, bool skipUnknownSymbols, bool replaceUnknownSymbols, const QString symbol, const QString& _documentLocation, documentFormat _format, const QString& _sequenceName, bool saveFile, GTGlobals::UseMethod method = GTGlobals::UseMouse);
+    CreateDocumentFiller(CustomScenario* scenario);
     void commonScenario();
 
 private:
@@ -69,7 +68,7 @@ public:
                             StandardAmino,
                             AllSymbols };
 
-    CancelCreateDocumentFiller(HI::GUITestOpStatus &_os, const QString &_pasteDataHere, bool customSettings, documentAlphabet _alphabet, bool skipUnknownSymbols, bool replaceUnknownSymbols, const QString symbol, const QString &_documentLocation, documentFormat _format, const QString &_sequenceName, bool saveFile, GTGlobals::UseMethod method = GTGlobals::UseMouse);
+    CancelCreateDocumentFiller(const QString& _pasteDataHere, bool customSettings, documentAlphabet _alphabet, bool skipUnknownSymbols, bool replaceUnknownSymbols, const QString symbol, const QString& _documentLocation, documentFormat _format, const QString& _sequenceName, bool saveFile, GTGlobals::UseMethod method = GTGlobals::UseMouse);
     void commonScenario();
 
 private:
@@ -89,5 +88,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
