@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_CREATE_OBJECT_RELATION_DIALOG_H_
-#define _U2_GT_RUNNABLES_CREATE_OBJECT_RELATION_DIALOG_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,14 +28,12 @@ using namespace HI;
 
 class CreateObjectRelationDialogFiller : public Filler {
 public:
-    CreateObjectRelationDialogFiller(HI::GUITestOpStatus &os);
-    CreateObjectRelationDialogFiller(HI::GUITestOpStatus &os, CustomScenario *sc)
-        : Filler(os, "CreateObjectRelationDialog", sc) {
+    CreateObjectRelationDialogFiller();
+    CreateObjectRelationDialogFiller(CustomScenario* sc)
+        : Filler("CreateObjectRelationDialog", sc) {
     }
 
     virtual void commonScenario();
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_RUNNABLES_CREATE_OBJECT_RELATION_DIALOG_H_
