@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_DOWNLOAD_REMOTE_FILE_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_DOWNLOAD_REMOTE_FILE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -48,36 +47,36 @@ public:
 
     typedef QPair<ActionType, QVariant> Action;
 
-    DownloadRemoteFileDialogFiller(HI::GUITestOpStatus &os, const QList<Action> &actions);
-    DownloadRemoteFileDialogFiller(HI::GUITestOpStatus &os, CustomScenario *c);
+    DownloadRemoteFileDialogFiller(const QList<Action>& actions);
+    DownloadRemoteFileDialogFiller(CustomScenario* c);
 
-    void commonScenario();
+    void commonScenario() override;
 
 private:
-    void setResourceIds(const QVariant &actionData);
-    void setDatabase(const QVariant &actionData);
-    void enterSaveToDirectoryPath(const QVariant &actionData);
-    void selectSaveToDirectoryPath(const QVariant &actionData);
-    void setOutputFormat(const QVariant &actionData);
-    void setForceSequenceDownload(const QVariant &actionData);
-    void checkDatabase(const QVariant &actionData);
-    void checkDatabasesCount(const QVariant &actionData);
-    void checkOutputFormatVisibility(const QVariant &actionData);
-    void checkOutputFormat(const QVariant &actionData);
-    void checkForceSequenceDownloadVisibility(const QVariant &actionData);
-    void checkForceSequenceDownload(const QVariant &actionData);
+    void setResourceIds(const QVariant& actionData);
+    void setDatabase(const QVariant& actionData);
+    void enterSaveToDirectoryPath(const QVariant& actionData);
+    void selectSaveToDirectoryPath(const QVariant& actionData);
+    void setOutputFormat(const QVariant& actionData);
+    void setForceSequenceDownload(const QVariant& actionData);
+    void checkDatabase(const QVariant& actionData);
+    void checkDatabasesCount(const QVariant& actionData);
+    void checkOutputFormatVisibility(const QVariant& actionData);
+    void checkOutputFormat(const QVariant& actionData);
+    void checkForceSequenceDownloadVisibility(const QVariant& actionData);
+    void checkForceSequenceDownload(const QVariant& actionData);
     void clickOk();
     void clickCancel();
 
     const QList<Action> actions;
-    QWidget *dialog;
+    QWidget* dialog = nullptr;
 };
 
 // Use DownloadRemoteFileDialogFiller instead
 class RemoteDBDialogFillerDeprecated : public Filler {
 public:
-    RemoteDBDialogFillerDeprecated(HI::GUITestOpStatus &_os, const QString _resID, int _DBItemNum, bool addToProject = true, bool forceGetSequence = true, bool _pressCancel = false, const QString _saveDirPath = QString(), GTGlobals::UseMethod _useMethod = GTGlobals::UseMouse, int _outFormatVal = -1)
-        : Filler(_os, "DownloadRemoteFileDialog"),
+    RemoteDBDialogFillerDeprecated(const QString _resID, int _DBItemNum, bool addToProject = true, bool forceGetSequence = true, bool _pressCancel = false, const QString _saveDirPath = QString(), GTGlobals::UseMethod _useMethod = GTGlobals::UseMouse, int _outFormatVal = -1)
+        : Filler("DownloadRemoteFileDialog"),
           resID(_resID),
           DBItemNum(_DBItemNum),
           addToProject(addToProject),
@@ -103,5 +102,3 @@ private:
 }  // namespace U2
 
 Q_DECLARE_METATYPE(QList<U2::DownloadRemoteFileDialogFiller::Action>)
-
-#endif  // _U2_GT_RUNNABLES_DOWNLOAD_REMOTE_FILE_DIALOG_FILLER_H_
