@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EDIT_GROUP_ANNOTATIONS_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EDIT_GROUP_ANNOTATIONS_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -28,8 +27,8 @@ namespace U2 {
 using namespace HI;
 class EditGroupAnnotationsFiller : public Filler {
 public:
-    EditGroupAnnotationsFiller(HI::GUITestOpStatus &_os, const QString &_groupName)
-        : Filler(_os, ""), groupName(_groupName) {
+    EditGroupAnnotationsFiller(const QString& _groupName)
+        : Filler(""), groupName(_groupName) {
     }
 
     void commonScenario();
@@ -39,5 +38,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
