@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -41,38 +41,27 @@ namespace U2 {
 using namespace HI;
 
 #define GT_CLASS_NAME "GTUtilsDialog::EditQualifierFiller"
-#define GT_METHOD_NAME "commonScenario"
 void EditQualifierFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *nameEdit = dialog->findChild<QLineEdit *>("nameEdit");
-    GT_CHECK(nameEdit != nullptr, "line edit not found");
-    GTLineEdit::setText(os, nameEdit, qualifierName, noCheck);
+    GTLineEdit::setText("nameEdit", qualifierName, dialog, noCheck);
 
-    QTextEdit *valueEdit = dialog->findChild<QTextEdit *>("valueEdit");
-    GT_CHECK(valueEdit != nullptr, "value line edit not found");
+    auto valueEdit = GTWidget::findTextEdit("valueEdit", dialog);
     if (!valueName.isEmpty()) {
-        GTTextEdit::setText(os, valueEdit, valueName);
+        GTTextEdit::setText(valueEdit, valueName);
     }
 
-    QDialogButtonBox *box = qobject_cast<QDialogButtonBox *>(GTWidget::findWidget(os, "buttonBox", dialog));
-    GT_CHECK(box != nullptr, "buttonBox is NULL");
-    QPushButton *button = box->button(QDialogButtonBox::Ok);
-    GT_CHECK(button != nullptr, "ok button is NULL");
-
     if (closeErrormessageBox) {
-        GTUtilsDialog::waitForDialog(os, new MessageBoxDialogFiller(os, QMessageBox::Ok));
+        GTUtilsDialog::waitForDialog(new MessageBoxDialogFiller(QMessageBox::Ok));
         GTGlobals::sleep();
         GTKeyboardDriver::keyClick(Qt::Key_Enter);
         GTGlobals::sleep();
 
-        GTLineEdit::setText(os, nameEdit, "nice_name", noCheck);
-        GTTextEdit::setText(os, valueEdit, "nice_val");
+        GTLineEdit::setText("nameEdit", "nice_name", dialog, noCheck);
+        GTTextEdit::setText(valueEdit, "nice_val");
     }
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
