@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EDIT_QUALIFIER_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EDIT_QUALIFIER_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -28,16 +27,16 @@ namespace U2 {
 using namespace HI;
 class EditQualifierFiller : public Filler {
 public:
-    EditQualifierFiller(HI::GUITestOpStatus &_os, const QString &_qualifierName, const QString &_valueName, bool _noCheck = false, bool _closeErrorMessageBox = false)
-        : Filler(_os, "EditQualifierDialog"),
+    EditQualifierFiller(const QString& _qualifierName, const QString& _valueName, bool _noCheck = false, bool _closeErrorMessageBox = false)
+        : Filler("EditQualifierDialog"),
           qualifierName(_qualifierName),
           valueName(_valueName),
           noCheck(_noCheck),
           closeErrormessageBox(_closeErrorMessageBox) {
     }
 
-    EditQualifierFiller(HI::GUITestOpStatus &_os, const QString &_qualifierName, bool _noCheck = false, bool _closeErrorMessageBox = false)
-        : Filler(_os, "EditQualifierDialog"),
+    EditQualifierFiller(const QString& _qualifierName, bool _noCheck = false, bool _closeErrorMessageBox = false)
+        : Filler("EditQualifierDialog"),
           qualifierName(_qualifierName),
           noCheck(_noCheck),
           closeErrormessageBox(_closeErrorMessageBox) {
@@ -53,5 +52,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
