@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EDIT_SEQUENCE_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EDIT_SEQUENCE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -36,7 +35,7 @@ public:
                                SplitJoin,
                                SplitSeparate };
 
-    InsertSequenceFiller(HI::GUITestOpStatus &_os, const QString &_pasteDataHere, RegionResolvingMode _regionResolvingMode = Resize, int _insertPosition = 1, const QString &_documentLocation = "", documentFormat _format = FASTA, bool _saveToNewFile = false, bool _mergeAnnotations = false, GTGlobals::UseMethod method = GTGlobals::UseMouse, bool _wrongInput = false, bool recalculateQuals = false);
+    InsertSequenceFiller(const QString& _pasteDataHere, RegionResolvingMode _regionResolvingMode = Resize, int _insertPosition = 1, const QString& _documentLocation = "", documentFormat _format = FASTA, bool _saveToNewFile = false, bool _mergeAnnotations = false, GTGlobals::UseMethod method = GTGlobals::UseMouse, bool _wrongInput = false, bool recalculateQuals = false);
     void commonScenario();
 
 private:
@@ -55,5 +54,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
