@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,6 +21,7 @@
 
 #include <primitives/GTCheckBox.h>
 #include <primitives/GTRadioButton.h>
+#include <primitives/GTWidget.h>
 
 #include <QApplication>
 
@@ -29,18 +30,16 @@
 namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::ExportChromatogramFiller"
-EditSettingsDialogFiller::EditSettingsDialogFiller(HI::GUITestOpStatus &_os,
-                                                   AnnotationPolicy _policy,
-                                                   bool _recalculateQualifiers)
-    : Filler(_os, "EditSettingDialogForm"),
+EditSettingsDialogFiller::EditSettingsDialogFiller(
+    AnnotationPolicy _policy,
+    bool _recalculateQualifiers)
+    : Filler("EditSettingDialogForm"),
       policy(_policy),
       recalculateQualifiers(_recalculateQualifiers) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void EditSettingsDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
     QString radioButtonName;
     switch (policy) {
@@ -57,16 +56,15 @@ void EditSettingsDialogFiller::commonScenario() {
             radioButtonName = "split_separateRadioButton";
             break;
         default:
-            GT_CHECK(false, "An unexpected AnnotationPolicy");
+            GT_FAIL("An unexpected AnnotationPolicy", );
     }
 
-    GTRadioButton::click(os, radioButtonName, dialog);
+    GTRadioButton::click(radioButtonName, dialog);
 
-    GTCheckBox::setChecked(os, "recalculateQuals", recalculateQualifiers, dialog);
+    GTCheckBox::setChecked("recalculateQuals", recalculateQualifiers, dialog);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
