@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EDIT_SETTINGS_DIALOG_FILLER_H_
-#define _U2_EDIT_SETTINGS_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -36,7 +35,7 @@ public:
         SplitSeparateAnnotationParts
     };
 
-    EditSettingsDialogFiller(HI::GUITestOpStatus &os, AnnotationPolicy policy, bool recalculateQualifiers);
+    EditSettingsDialogFiller(AnnotationPolicy policy, bool recalculateQualifiers);
 
     void commonScenario();
 
@@ -46,5 +45,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_EDIT_SETTINGS_DIALOG_FILLER_H_
