@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,48 +34,45 @@ namespace U2 {
 using namespace HI;
 
 #define GT_CLASS_NAME "GTUtilsDialog::ExportChromatogramFiller"
-ExportChromatogramFiller::ExportChromatogramFiller(HI::GUITestOpStatus &_os, const QString &_path, const QString &_name, ExportChromatogramFiller::FormatToUse _format, bool reversed, bool complement, bool addDocumentToProject, GTGlobals::UseMethod method)
-    : Filler(_os, "ExportChromatogramDialog"), name(_name), useMethod(method), format(_format), reversed(reversed),
+ExportChromatogramFiller::ExportChromatogramFiller(const QString& _path, const QString& _name, ExportChromatogramFiller::FormatToUse _format, bool reversed, bool complement, bool addDocumentToProject, GTGlobals::UseMethod method)
+    : Filler("ExportChromatogramDialog"), name(_name), useMethod(method), format(_format), reversed(reversed),
       complement(complement), addDocumentToProject(addDocumentToProject) {
     path = _path;
     comboBoxItems[SCF] = "SCF";
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void ExportChromatogramFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *lineEdit = dialog->findChild<QLineEdit *>();
+    QLineEdit* lineEdit = dialog->findChild<QLineEdit*>();
     GT_CHECK(lineEdit != nullptr, "line edit not found");
 
-    GTLineEdit::setText(os, lineEdit, path + name);
+    GTLineEdit::setText(lineEdit, path + name);
 
-    QComboBox *comboBox = dialog->findChild<QComboBox *>();
+    QComboBox* comboBox = dialog->findChild<QComboBox*>();
     GT_CHECK(comboBox != nullptr, "ComboBox not found");
 
     int index = comboBox->findText(comboBoxItems[format]);
     GT_CHECK(index != -1, QString("item \"%1\" in combobox not found").arg(comboBoxItems[format]));
-    GTComboBox::selectItemByIndex(os, comboBox, index, useMethod);
+    GTComboBox::selectItemByIndex(comboBox, index, useMethod);
 
     if (addDocumentToProject) {
-        QCheckBox *checkBox = dialog->findChild<QCheckBox *>(QString::fromUtf8("addToProjectBox"));
-        GTCheckBox::setChecked(os, checkBox, addDocumentToProject);
+        auto checkBox = GTWidget::findCheckBox("addToProjectBox", dialog);
+        GTCheckBox::setChecked(checkBox, addDocumentToProject);
     }
 
     if (reversed) {
-        QCheckBox *checkBoxReversed = dialog->findChild<QCheckBox *>(QString::fromUtf8("reverseBox"));
-        GTCheckBox::setChecked(os, checkBoxReversed, reversed);
+        auto checkBoxReversed = GTWidget::findCheckBox("reverseBox", dialog);
+        GTCheckBox::setChecked(checkBoxReversed, reversed);
     }
 
     if (complement) {
-        QCheckBox *checkBoxComplement = dialog->findChild<QCheckBox *>(QString::fromUtf8("complementBox"));
-        GTCheckBox::setChecked(os, checkBoxComplement, complement);
+        auto checkBoxComplement = GTWidget::findCheckBox("complementBox", dialog);
+        GTCheckBox::setChecked(checkBoxComplement, complement);
     }
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
