@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EXPORT_CHROMATOGRAM_FILLER_H_
-#define _U2_GT_RUNNABLES_EXPORT_CHROMATOGRAM_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -30,7 +29,7 @@ using namespace HI;
 class ExportChromatogramFiller : public Filler {
 public:
     enum FormatToUse { SCF };
-    ExportChromatogramFiller(HI::GUITestOpStatus &_os, const QString &_path, const QString &_name, ExportChromatogramFiller::FormatToUse _format, bool reversed, bool complement, bool addDocumentToProject, GTGlobals::UseMethod method = GTGlobals::UseMouse);
+    ExportChromatogramFiller(const QString& _path, const QString& _name, ExportChromatogramFiller::FormatToUse _format, bool reversed, bool complement, bool addDocumentToProject, GTGlobals::UseMethod method = GTGlobals::UseMouse);
     void commonScenario();
 
 private:
@@ -43,5 +42,3 @@ private:
     QMap<FormatToUse, QString> comboBoxItems;
 };
 }  // namespace U2
-
-#endif
