@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_COPY_DOCUMENT_FILLER_H_
-#define _U2_GT_RUNNABLES_COPY_DOCUMENT_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -44,11 +43,9 @@ public:
         VectorNTI
     };
 
-    ExportDocumentDialogFiller(HI::GUITestOpStatus &_os, const QString &_path = "", const QString &_name = "", ExportDocumentDialogFiller::FormatToUse _format = ExportDocumentDialogFiller::Genbank, bool compressFile = false, bool addToProject = false, GTGlobals::UseMethod method = GTGlobals::UseMouse);
+    ExportDocumentDialogFiller(const QString& _path = "", const QString& _name = "", ExportDocumentDialogFiller::FormatToUse _format = ExportDocumentDialogFiller::Genbank, bool compressFile = false, bool addToProject = false, GTGlobals::UseMethod method = GTGlobals::UseMouse);
     void commonScenario();
 
-    static QString defaultExportString;
-
 private:
     QString path, name;
     GTGlobals::UseMethod useMethod;
@@ -58,5 +55,3 @@ private:
     QMap<FormatToUse, QString> comboBoxItems;
 };
 }  // namespace U2
-
-#endif
