@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EXPORT_IMAGE_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EXPORT_IMAGE_DIALOG_FILLER_H_
+#pragma once
 
 #include <utils/GTUtilsDialog.h>
 
@@ -33,8 +32,8 @@ using namespace HI;
 
 class ExportImage : public Filler {
 public:
-    ExportImage(HI::GUITestOpStatus &os, const QString &filePath, const QString &comboValue = "", int spinValue = 0);
-    ExportImage(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    ExportImage(const QString& filePath, const QString& comboValue = "", int spinValue = 0);
+    ExportImage(CustomScenario* scenario);
 
     void commonScenario();
 
@@ -46,15 +45,15 @@ protected:
 
 class CircularViewExportImage : public Filler {
 public:
-    CircularViewExportImage(HI::GUITestOpStatus &_os, QString _filePath, QString _comboValue = "", QString exportedSequenceName = "", int _spinValue = 0)
-        : Filler(_os, "ImageExportForm"),
+    CircularViewExportImage(QString _filePath, QString _comboValue = "", QString exportedSequenceName = "", int _spinValue = 0)
+        : Filler("ImageExportForm"),
           filePath(QDir::toNativeSeparators(_filePath)),
           comboValue(_comboValue),
           spinValue(_spinValue),
           exportedSequenceName(exportedSequenceName) {
     }
-    CircularViewExportImage(HI::GUITestOpStatus &os, CustomScenario *scenario)
-        : Filler(os, "ImageExportForm", scenario), spinValue(0) {
+    CircularViewExportImage(CustomScenario* scenario)
+        : Filler("ImageExportForm", scenario), spinValue(0) {
     }
     void commonScenario();
 
@@ -65,8 +64,8 @@ protected:
 };
 
 struct RegionMsa {
-    RegionMsa(const U2Region &region = U2Region(),
-              const QStringList &seqList = QStringList())
+    RegionMsa(const U2Region& region = U2Region(),
+              const QStringList& seqList = QStringList())
         : region(region),
           sequences(seqList) {
     }
@@ -79,41 +78,45 @@ public:
     struct Settings {
         Settings(bool includeNames = false,
                  bool includeConsensus = false,
-                 bool includeRuler = true)
+                 bool includeRuler = true,
+                 bool multilineMode = false,
+                 int basesPerLine = 0)
             : includeNames(includeNames),
               includeConsensus(includeConsensus),
-              includeRuler(includeRuler) {
+              includeRuler(includeRuler),
+              multilineMode(multilineMode),
+              basesPerLine(basesPerLine) {
         }
         bool includeNames;
         bool includeConsensus;
         bool includeRuler;
+        bool multilineMode;
+        int basesPerLine;
     };
 
     // default
-    ExportMsaImage(HI::GUITestOpStatus &os, QString filePath, QString comboValue = "", int spinValue = 0)
-        : ExportImage(os, filePath, comboValue, spinValue),
-          exportWholeAlignment(true),
-          exportCurrentSelection(false) {
+    ExportMsaImage(QString filePath, QString comboValue = "", int spinValue = 0)
+        : ExportImage(filePath, comboValue, spinValue) {
     }
 
     //  exportWholeAlignment = false,   exportCurrentSelection = false  : export of specified msa region, there should be no any selection on msa
     //  exportWholeAlignment = false,   exportCurrentSelection = true   : export of currently selected region, selection must be
     //  exportWholeAlignment = true,    exportCurrentSelection = false  : whole selection export
     //  exportWholeAlignment = true,    exportCurrentSelection = true   : error
-    ExportMsaImage(HI::GUITestOpStatus &os, QString filePath, Settings settings, bool exportWholeAlignment = true, bool exportCurrentSelection = false, RegionMsa region = RegionMsa(), QString comboValue = "", int spinValue = 0)
-        : ExportImage(os, filePath, comboValue, spinValue),
+    ExportMsaImage(QString filePath, Settings settings, bool exportWholeAlignment = true, bool exportCurrentSelection = false, RegionMsa region = RegionMsa(), QString comboValue = "", int spinValue = 0)
+        : ExportImage(filePath, comboValue, spinValue),
           settings(settings),
           exportWholeAlignment(exportWholeAlignment),
           exportCurrentSelection(exportCurrentSelection),
           region(region) {
     }
 
-    void commonScenario();
+    void commonScenario() override;
 
 private:
     Settings settings;
-    bool exportWholeAlignment;
-    bool exportCurrentSelection;
+    bool exportWholeAlignment = true;
+    bool exportCurrentSelection = false;
     RegionMsa region;
 };
 
@@ -134,12 +137,12 @@ public:
         U2Region region;
     };
 
-    ExportSequenceImage(HI::GUITestOpStatus &os, QString filePath, QString comboValue = "", int spinValue = 0)
-        : ExportImage(os, filePath, comboValue, spinValue) {
+    ExportSequenceImage(QString filePath, QString comboValue = "", int spinValue = 0)
+        : ExportImage(filePath, comboValue, spinValue) {
     }
 
-    ExportSequenceImage(HI::GUITestOpStatus &os, QString filePath, Settings settings, QString comboValue = "", int spinValue = 0)
-        : ExportImage(os, filePath, comboValue, spinValue),
+    ExportSequenceImage(QString filePath, Settings settings, QString comboValue = "", int spinValue = 0)
+        : ExportImage(filePath, comboValue, spinValue),
           settings(settings) {
     }
 
@@ -151,8 +154,8 @@ private:
 
 class SelectSubalignmentFiller : public Filler {
 public:
-    SelectSubalignmentFiller(HI::GUITestOpStatus &_os, const RegionMsa &regionMsa)
-        : Filler(_os, "SelectSubalignmentDialog"),
+    SelectSubalignmentFiller(const RegionMsa& regionMsa)
+        : Filler("SelectSubalignmentDialog"),
           msaRegion(regionMsa) {
     }
     void commonScenario();
@@ -178,7 +181,7 @@ public:
         QString format;
     };
 
-    ImageExportFormFiller(HI::GUITestOpStatus &os, const Parameters &parameters);
+    ImageExportFormFiller(const Parameters& parameters);
     void commonScenario();
 
 private:
@@ -186,5 +189,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  //_U2_GT_RUNNABLES_EXPORT_IMAGE_DIALOG_FILLER_H_
