@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_FIND_QUALIFIER_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_FIND_QUALIFIER_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 class FindQualifierFiller : public Filler {
 public:
     struct FindQualifierFillerSettings {
-        FindQualifierFillerSettings(const QString &name = QString(),
-                                    const QString &value = QString(),
+        FindQualifierFillerSettings(const QString& name = QString(),
+                                    const QString& value = QString(),
                                     bool exactMatch = true,
                                     bool nextQualifier = true,
                                     unsigned int nextCount = 1,
@@ -57,8 +56,8 @@ public:
         bool selectAll;
     };
 
-    FindQualifierFiller(HI::GUITestOpStatus &os, const FindQualifierFillerSettings &settings = FindQualifierFillerSettings());
-    FindQualifierFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    FindQualifierFiller(const FindQualifierFillerSettings& settings = FindQualifierFillerSettings());
+    FindQualifierFiller(CustomScenario* scenario);
 
     void commonScenario();
 
@@ -67,5 +66,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_RUNNABLES_FIND_QUALIFIER_DIALOG_FILLER_H_
