@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_FIND_TANDEMS_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_FIND_TANDEMS_DIALOG_FILLER_H_
+#pragma once
 
 #include "api/GTRegionSelector.h"
 #include "utils/GTUtilsDialog.h"
@@ -33,8 +32,8 @@ public:
     enum Button { Start,
                   Cancel };
 
-    FindTandemsDialogFiller(HI::GUITestOpStatus &_os, const QString &_resultFilesPath);
-    FindTandemsDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    FindTandemsDialogFiller(const QString& _resultFilesPath);
+    FindTandemsDialogFiller(CustomScenario* scenario);
 
     virtual void commonScenario();
     Button button;
@@ -44,5 +43,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_RUNNABLES_FIND_TANDEMS_DIALOG_FILLER_H_
