@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GRAPH_SETTINGS_DIALOG_FILLER_H_
-#define _U2_GRAPH_SETTINGS_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,15 +28,15 @@ using namespace HI;
 
 class GraphSettingsDialogFiller : public Filler {
 public:
-    GraphSettingsDialogFiller(HI::GUITestOpStatus &os,
-                              int window = -1,
-                              int steps = -1,
-                              double cutoff_min = 0,
-                              double cutoff_max = 0,
-                              int r = -1,
-                              int g = -1,
-                              int b = -1);
-    GraphSettingsDialogFiller(HI::GUITestOpStatus &os, CustomScenario *c);
+    GraphSettingsDialogFiller(
+        int window = -1,
+        int steps = -1,
+        double cutoff_min = 0,
+        double cutoff_max = 0,
+        int r = -1,
+        int g = -1,
+        int b = -1);
+    GraphSettingsDialogFiller(CustomScenario* c);
 
     virtual void commonScenario();
 
@@ -52,4 +51,3 @@ private:
 };
 
 }  // namespace U2
-#endif  // GRAPHSETTINGSDIALOGFILLER_H
