@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_IMPORT_APR_FILE_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_IMPORT_APR_FILE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,12 +28,12 @@ using namespace HI;
 
 class ImportAPRFileFiller : public Filler {
 public:
-    ImportAPRFileFiller(HI::GUITestOpStatus &os,
-                        bool isReadOnly,
-                        QString dstUrl = QString(),
-                        QString formatToConvertTo = "fasta",
-                        int timeoutMs = 120000);
-    ImportAPRFileFiller(HI::GUITestOpStatus &os, CustomScenario *_c);
+    ImportAPRFileFiller(
+        bool isReadOnly,
+        QString dstUrl = QString(),
+        QString formatToConvertTo = "fasta",
+        int timeoutMs = 120000);
+    ImportAPRFileFiller(CustomScenario* _c);
 
     virtual void commonScenario();
 
@@ -45,5 +44,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_RUNNABLES_IMPORT_APR_FILE_DIALOG_FILLER_H_
