@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_IMPORT_BAM_FILE_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_IMPORT_BAM_FILE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 
 class ImportBAMFileFiller : public Filler {
 public:
-    ImportBAMFileFiller(HI::GUITestOpStatus &os, const QString destinationUrl = "", const QString referenceFolderPath = "", const QString referenceFileName = "", bool importUnmappedReads = false, int timeoutMs = 120000);
-    ImportBAMFileFiller(HI::GUITestOpStatus &os, CustomScenario *_c);
+    ImportBAMFileFiller(const QString destinationUrl = "", const QString referenceFolderPath = "", const QString referenceFileName = "", bool importUnmappedReads = false, bool deselectAll = false, int timeoutMs = 120000);
+    ImportBAMFileFiller(CustomScenario* _c);
 
     virtual void commonScenario();
 
@@ -39,8 +38,7 @@ private:
     const QString referenceFileName;
     const QString destinationUrl;
     const bool importUnmappedReads;
+    const bool deselectAll;
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_RUNNABLES_IMPORT_BAM_FILE_DIALOG_FILLER_H_
