@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_TO_DATABASE_DIALOG_FILLER_H_
-#define _U2_IMPORT_TO_DATABASE_DIALOG_FILLER_H_
+#pragma once
 
 #include <QPointer>
 
@@ -49,7 +48,7 @@ public:
             CANCEL  // close the dialog the "Cancel" button
         };
 
-        Action(Type type, const QVariantMap &data);
+        Action(Type type, const QVariantMap& data);
         Type type;
         QVariantMap data;
 
@@ -60,34 +59,32 @@ public:
         static const QString ACTION_DATA__PROJECT_ITEMS_LIST;
     };
 
-    ImportToDatabaseDialogFiller(HI::GUITestOpStatus &os, const QList<Action> &actions);
-    ImportToDatabaseDialogFiller(HI::GUITestOpStatus &os, CustomScenario *c)
-        : Filler(os, "ImportToDatabaseDialog", c) {
+    ImportToDatabaseDialogFiller(const QList<Action>& actions);
+    ImportToDatabaseDialogFiller(CustomScenario* c)
+        : Filler("ImportToDatabaseDialog", c) {
     }
 
     void commonScenario();
 
 private:
-    void addFiles(const Action &action);
-    void addDirs(const Action &action);
-    void addProjectItems(const Action &action);
-    void selectItems(const Action &action);
-    void editDestinationFolder(const Action &action);
-    void editGeneralOptions(const Action &action);
-    void editPrivateOptions(const Action &action);
-    void resetPrivateOptions(const Action &action);
-    void remove(const Action &action);
-    void import(const Action &action);
-    void cancel(const Action &action);
+    void addFiles(const Action& action);
+    void addDirs(const Action& action);
+    void addProjectItems(const Action& action);
+    void selectItems(const Action& action);
+    void editDestinationFolder(const Action& action);
+    void editGeneralOptions(const Action& action);
+    void editPrivateOptions(const Action& action);
+    void resetPrivateOptions(const Action& action);
+    void remove(const Action& action);
+    void import(const Action& action);
+    void cancel(const Action& action);
 
-    QPoint getItemCenter(const QString &text);
-    QPoint getFolderColumnCenter(const QString &text);
-    QTreeWidgetItem *findItem(const QString &text);
+    QPoint getItemCenter(const QString& text);
+    QPoint getFolderColumnCenter(const QString& text);
+    QTreeWidgetItem* findItem(const QString& text);
 
     QPointer<QWidget> dialog;
     QList<Action> actions;
 };
 
 }  // namespace U2
-
-#endif  // _U2_IMPORT_TO_DATABASE_DIALOG_FILLER_H_
