@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,22 +32,18 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::ItemToImportEditDialogFiller"
 
-ItemToImportEditDialogFiller::ItemToImportEditDialogFiller(HI::GUITestOpStatus &os, const QVariantMap &data)
-    : Filler(os, "ItemToImportEditDialog"),
+ItemToImportEditDialogFiller::ItemToImportEditDialogFiller(const QVariantMap& data)
+    : Filler("ItemToImportEditDialog"),
       data(data) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void ItemToImportEditDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(nullptr != dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    ImportOptionsWidget *optionsWidget = qobject_cast<ImportOptionsWidget *>(GTWidget::findWidget(os, "optionsWidget", dialog));
-    GT_CHECK(nullptr != optionsWidget, "optionsWidget is NULL");
+    auto optionsWidget = GTWidget::findExactWidget<ImportOptionsWidget*>("optionsWidget", dialog);
 
-    ImportOptionsWidgetFiller::fill(os, optionsWidget, data);
+    ImportOptionsWidgetFiller::fill(optionsWidget, data);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
