@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ITEM_TO_IMPORT_EDIT_DIALOG_FILLER_H_
-#define _U2_ITEM_TO_IMPORT_EDIT_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -28,7 +27,7 @@ namespace U2 {
 using namespace HI;
 class ItemToImportEditDialogFiller : public Filler {
 public:
-    ItemToImportEditDialogFiller(HI::GUITestOpStatus &os, const QVariantMap &data);
+    ItemToImportEditDialogFiller(const QVariantMap& data);
 
     void commonScenario();
 
@@ -37,5 +36,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_ITEM_TO_IMPORT_EDIT_DIALOG_FILLER_H_
