@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,7 +20,6 @@
  */
 
 #include "PositionSelectorFiller.h"
-#include <drivers/GTKeyboardDriver.h>
 #include <primitives/GTLineEdit.h>
 #include <primitives/GTWidget.h>
 
@@ -30,19 +29,12 @@
 namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::GoToDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void GoToDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *posEdit = dialog->findChild<QLineEdit *>("go_to_pos_line_edit");
-    GT_CHECK(posEdit != nullptr, "Line edit not found");
-
-    GTLineEdit::setText(os, posEdit, QString::number(goTo));
-
-    GTWidget::click(os, GTWidget::findButtonByText(os, "Go!", dialog));
+    GTLineEdit::setText("go_to_pos_line_edit", QString::number(goTo), dialog);
+    GTWidget::click(GTWidget::findButtonByText("Go", dialog));
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
