@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_PREDICT_SECONDARY_STRUCTURE_DIALOG_FILLER_H_
-#define _U2_GT_PREDICT_SECONDARY_STRUCTURE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,17 +28,15 @@ using namespace HI;
 
 class PredictSecondaryStructureDialogFiller : public Filler {
 public:
-    PredictSecondaryStructureDialogFiller(HI::GUITestOpStatus &os, int startPos, int endPos, bool onlyPressOk = false);
-    PredictSecondaryStructureDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    PredictSecondaryStructureDialogFiller(int startPos, int endPos, bool onlyPressOk = false);
+    PredictSecondaryStructureDialogFiller(CustomScenario* scenario);
 
-    virtual void commonScenario();
+    void commonScenario() override;
 
 private:
-    int startPos;
-    int endPos;
-    bool onlyPressOk;
+    int startPos = 0;
+    int endPos = 0;
+    bool onlyPressOk = false;
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_PREDICT_SECONDARY_STRUCTURE_DIALOG_FILLER_H_
