@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_PROJECT_TREE_ITEM_SELECTOR_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_PROJECT_TREE_ITEM_SELECTOR_DIALOG_FILLER_H_
+#pragma once
 
 #include "GTUtilsProjectTreeView.h"
 #include "utils/GTUtilsDialog.h"
@@ -35,9 +34,9 @@ public:
         Continuous
     };
 
-    ProjectTreeItemSelectorDialogFiller(HI::GUITestOpStatus &os, const QString &documentName, const QString &objectName, const QSet<GObjectType> &acceptableTypes = QSet<GObjectType>(), SelectionMode mode = Single, int expectedDocCount = -1);
-    ProjectTreeItemSelectorDialogFiller(HI::GUITestOpStatus &os, const QMap<QString, QStringList> &itemsToSelect, const QSet<GObjectType> &acceptableTypes = QSet<GObjectType>(), SelectionMode mode = Single, int expectedDocCount = -1);
-    ProjectTreeItemSelectorDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    ProjectTreeItemSelectorDialogFiller(const QString& documentName, const QString& objectName, const QSet<GObjectType>& acceptableTypes = QSet<GObjectType>(), SelectionMode mode = Single, int expectedDocCount = -1);
+    ProjectTreeItemSelectorDialogFiller(const QMap<QString, QStringList>& itemsToSelect, const QSet<GObjectType>& acceptableTypes = QSet<GObjectType>(), SelectionMode mode = Single, int expectedDocCount = -1);
+    ProjectTreeItemSelectorDialogFiller(CustomScenario* scenario);
 
     virtual void commonScenario();
 
@@ -49,5 +48,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
