@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_REMOVE_PART_FROM_SEQUENCE_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_REMOVE_PART_FROM_SEQUENCE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -34,9 +33,9 @@ public:
     enum FormatToUse { FASTA,
                        Genbank };
 
-    RemovePartFromSequenceDialogFiller(HI::GUITestOpStatus &_os, QString _range, bool recalculateQuals = false);
-    RemovePartFromSequenceDialogFiller(HI::GUITestOpStatus &_os, RemoveType _removeType, bool _saveNew, const QString &_saveToFile, FormatToUse _format);
-    RemovePartFromSequenceDialogFiller(HI::GUITestOpStatus &_os, RemoveType _removeType);
+    RemovePartFromSequenceDialogFiller(QString _range, bool recalculateQuals = false);
+    RemovePartFromSequenceDialogFiller(RemoveType _removeType, bool _saveNew, const QString& _saveToFile, FormatToUse _format);
+    RemovePartFromSequenceDialogFiller(RemoveType _removeType);
 
     void commonScenario();
 
@@ -51,5 +50,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
