@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,19 +29,16 @@
 namespace U2 {
 
 #define GT_CLASS_NAME "SetSequenceOriginDialogFiller"
-#define GT_METHOD_NAME "run"
 
 void SetSequenceOriginDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QSpinBox *seqOriginBox = GTWidget::findExactWidget<QSpinBox *>(os, "seqOriginBox", dialog);
-    GTSpinBox::setValue(os, seqOriginBox, start, GTGlobals::UseKeyBoard);
+    auto seqOriginBox = GTWidget::findSpinBox("seqOriginBox", dialog);
+    GTSpinBox::setValue(seqOriginBox, start, GTGlobals::UseKeyBoard);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
 
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
