@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SET_SEQUENCE_ORIGIN_DIALOG_FILLER_H_
-#define _U2_SET_SEQUENCE_ORIGIN_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 
 class SetSequenceOriginDialogFiller : public Filler {
 public:
-    SetSequenceOriginDialogFiller(HI::GUITestOpStatus &os, int _start)
-        : Filler(os, "SetSequenceOriginDialog"), start(_start) {
+    SetSequenceOriginDialogFiller(int _start)
+        : Filler("SetSequenceOriginDialog"), start(_start) {
     }
     virtual void commonScenario();
 
@@ -39,4 +38,3 @@ private:
 };
 
 }  // namespace U2
-#endif  // SETSEQUENCEORIGINDIALOGFILLER_H
