@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -33,14 +33,12 @@
 namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::RenamesequenceFiller"
-#define GT_METHOD_NAME "run"
 
 void RenameSequenceFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
     GT_CHECK(dialog->windowTitle() == "Rename Read" || dialog->windowTitle() == "Rename Sequence", "dialog not found");
 
-    QLineEdit *nameEdit = dialog->findChild<QLineEdit *>();
+    QLineEdit* nameEdit = dialog->findChild<QLineEdit*>();
     GT_CHECK(nameEdit != nullptr, "Line edit not found");
 
     if (!oldName.isEmpty()) {
@@ -50,17 +48,16 @@ void RenameSequenceFiller::commonScenario() {
 
     if (oldName != newName) {
         // if filler used not for checking sequence name
-        GTLineEdit::setText(os, nameEdit, newName, false, useCopyPaste);
+        GTLineEdit::setText(nameEdit, newName, false, useCopyPaste);
     }
 
-    GTWidget::click(os, GTWidget::findButtonByText(os, "OK", dialog));
+    GTWidget::click(GTWidget::findButtonByText("OK", dialog));
     GTGlobals::sleep(500);
-    if (nullptr != QApplication::activeModalWidget()) {
-        GTWidget::click(os, GTWidget::findButtonByText(os, "OK", QApplication::activeModalWidget()));
+    if (QApplication::activeModalWidget() != nullptr) {
+        GTWidget::click(GTWidget::findButtonByText("OK", QApplication::activeModalWidget()));
     }
 }
 
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
