@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_RENAME_SEQUENCE_FILLER_H_
-#define _U2_GT_RUNNABLES_RENAME_SEQUENCE_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -30,21 +29,15 @@ using namespace HI;
 class RenameSequenceFiller : public Filler {
 public:
     // class can be used for checking name if newName == oldName
-    RenameSequenceFiller(HI::GUITestOpStatus &_os, QString _newName, QString _oldName = QString(), bool useCopyPaste = false)
-        : Filler(_os, ""), os(_os), newName(_newName), oldName(_oldName), useCopyPaste(useCopyPaste) {
+    RenameSequenceFiller(QString _newName, QString _oldName = QString(), bool _useCopyPaste = false)
+        : Filler(""), newName(_newName), oldName(_oldName), useCopyPaste(_useCopyPaste) {
     }
-    RenameSequenceFiller(HI::GUITestOpStatus &_os, CustomScenario *c)
-        : Filler(_os, "", c), os(_os) {
-    }
-    virtual void commonScenario();
+    void commonScenario() override;
 
 private:
-    HI::GUITestOpStatus &os;
     QString newName;
     QString oldName;
-    bool useCopyPaste;
+    bool useCopyPaste = false;
 };
 
 }  // namespace U2
-
-#endif
