@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_CONSENSUS_DIALOG_FILLER_H_
-#define _U2_EXPORT_CONSENSUS_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,12 +28,10 @@ using namespace HI;
 
 class ExportConsensusDialogFiller : public Filler {
 public:
-    ExportConsensusDialogFiller(HI::GUITestOpStatus &os, CustomScenario *_c)
-        : Filler(os, "ExportConsensusDialog", _c) {
+    ExportConsensusDialogFiller(CustomScenario* _c)
+        : Filler("ExportConsensusDialog", _c) {
     }
     void commonScenario();
 };
 
 }  // namespace U2
-
-#endif  // EXPORTCONSENSUSDIALOG_H
