@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_COVERAGE_DIALOG_FILLER_H_
-#define _U2_EXPORT_COVERAGE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -52,34 +51,32 @@ public:
 
     typedef QPair<ActionType, QVariant> Action;
 
-    ExportCoverageDialogFiller(HI::GUITestOpStatus &os, const QList<Action> &actions);
+    ExportCoverageDialogFiller(const QList<Action>& actions);
 
     void commonScenario();
 
 private:
-    void enterFilePath(const QVariant &actionData);
-    void selectFile(const QVariant &actionData);
-    void setFormat(const QVariant &actionData);
-    void setCompress(const QVariant &actionData);
-    void setExportCoverage(const QVariant &actionData);
-    void setExportBasesQuantity(const QVariant &actionData);
-    void setThreshold(const QVariant &actionData);
-    void checkFilePath(const QVariant &actionData);
-    void checkFormat(const QVariant &actionData);
-    void checkCompress(const QVariant &actionData);
-    void checkOptionsVisibility(const QVariant &actionData);
-    void checkExportCoverage(const QVariant &actionData);
-    void checkExportBasesQuantity(const QVariant &actionData);
-    void checkThreshold(const QVariant &actionData);
-    void checkThresholdBounds(const QVariant &actionData);
+    void enterFilePath(const QVariant& actionData);
+    void selectFile(const QVariant& actionData);
+    void setFormat(const QVariant& actionData);
+    void setCompress(const QVariant& actionData);
+    void setExportCoverage(const QVariant& actionData);
+    void setExportBasesQuantity(const QVariant& actionData);
+    void setThreshold(const QVariant& actionData);
+    void checkFilePath(const QVariant& actionData);
+    void checkFormat(const QVariant& actionData);
+    void checkCompress(const QVariant& actionData);
+    void checkOptionsVisibility(const QVariant& actionData);
+    void checkExportCoverage(const QVariant& actionData);
+    void checkExportBasesQuantity(const QVariant& actionData);
+    void checkThreshold(const QVariant& actionData);
+    void checkThresholdBounds(const QVariant& actionData);
     void expectMessageBox();
     void clickOk();
     void clickCancel();
 
-    QWidget *dialog;
+    QWidget* dialog;
     const QList<Action> actions;
 };
 
 }  // namespace U2
-
-#endif  // _U2_EXPORT_COVERAGE_DIALOG_FILLER_H_
