@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,34 +34,27 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::ExportReadsDialogFiller"
 
-ExportReadsDialogFiller::ExportReadsDialogFiller(HI::GUITestOpStatus &os, const QString &filePath, const QString format, bool addToProject)
-    : Filler(os, "ExportReadsDialog"),
+ExportReadsDialogFiller::ExportReadsDialogFiller(const QString& filePath, const QString format, bool addToProject)
+    : Filler("ExportReadsDialog"),
       filePath(filePath),
       format(format),
       addToProject(addToProject) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void ExportReadsDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *fileLineEdit = dialog->findChild<QLineEdit *>("filepathLineEdit");
-    GT_CHECK(fileLineEdit != nullptr, "File path lineEdit not found");
-    GTLineEdit::setText(os, fileLineEdit, filePath);
+    GTLineEdit::setText("filepathLineEdit", filePath, dialog);
 
-    QComboBox *formatComboBox = dialog->findChild<QComboBox *>("documentFormatComboBox");
-    GT_CHECK(formatComboBox != nullptr, "Format comboBox not found");
-    GTComboBox::selectItemByText(os, formatComboBox, format);
+    auto formatComboBox = GTWidget::findComboBox("documentFormatComboBox", dialog);
+    GTComboBox::selectItemByText(formatComboBox, format);
 
-    QCheckBox *addToPrj = dialog->findChild<QCheckBox *>("addToProjectCheckBox");
-    GT_CHECK(addToPrj != nullptr, "Add to project check box not found");
-    GTCheckBox::setChecked(os, addToPrj, addToProject);
+    auto addToPrj = GTWidget::findCheckBox("addToProjectCheckBox", dialog);
+    GTCheckBox::setChecked(addToPrj, addToProject);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
 
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
