@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_READS_DIALOG_FILLER_H_
-#define _U2_EXPORT_READS_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,7 +28,7 @@ using namespace HI;
 
 class ExportReadsDialogFiller : public Filler {
 public:
-    ExportReadsDialogFiller(HI::GUITestOpStatus &os, const QString &filePath, const QString format = "FASTA", bool addToProject = true);
+    ExportReadsDialogFiller(const QString& filePath, const QString format = "FASTA", bool addToProject = true);
     void commonScenario();
 
 private:
@@ -39,5 +38,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_EXPORT_READS_DIALOG_FILLER_H_
