@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_BUILD_TREE_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_BUILD_TREE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -36,9 +35,9 @@ public:
         M1
     };
 
-    BuildTreeDialogFiller(HI::GUITestOpStatus &os, const QString &saveTree = "default", int model = 0, double alpha = 0, bool displayWithMsa = false);
-    BuildTreeDialogFiller(HI::GUITestOpStatus &os, int replicates = 0, const QString &saveTree = "default", int seed = 5, ConsensusType type = MAJORITYEXT, double fraction = 0.5);
-    BuildTreeDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    BuildTreeDialogFiller(const QString& saveTree = "default", int model = 0, double alpha = 0, bool displayWithMsa = false);
+    BuildTreeDialogFiller(int replicates, const QString& saveTree = "default", int seed = 5, ConsensusType type = MAJORITYEXT, double fraction = 0.5);
+    BuildTreeDialogFiller(CustomScenario* scenario);
 
     void commonScenario();
 
@@ -55,7 +54,7 @@ private:
 
 class BuildTreeDialogFillerPhyML : public Filler {
 public:
-    BuildTreeDialogFillerPhyML(HI::GUITestOpStatus &os, bool _freqOptimRadioPressed, int bootstrap = -1);
+    BuildTreeDialogFillerPhyML(bool _freqOptimRadioPressed, int bootstrap = -1);
     void commonScenario();
 
 private:
@@ -64,5 +63,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_RUNNABLES_BUILD_TREE_DIALOG_FILLER_H_
