@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -33,48 +33,37 @@
 namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::DeleteGapsDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void DeleteGapsDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
     if (radioButNum == 1) {
-        QRadioButton *allColumnsOfGaps = dialog->findChild<QRadioButton *>("allRadioButton");
-        GTRadioButton::click(os, allColumnsOfGaps);
+        auto allColumnsOfGaps = GTWidget::findRadioButton("allRadioButton", dialog);
+        GTRadioButton::click(allColumnsOfGaps);
     } else {
-        QRadioButton *withNumberOfGaps = dialog->findChild<QRadioButton *>("absoluteRadioButton");
-        GTRadioButton::click(os, withNumberOfGaps);
+        auto withNumberOfGaps = GTWidget::findRadioButton("absoluteRadioButton", dialog);
+        GTRadioButton::click(withNumberOfGaps);
     }
-
-    QDialogButtonBox *box = qobject_cast<QDialogButtonBox *>(GTWidget::findWidget(os, "buttonBox", dialog));
-    GT_CHECK(box != nullptr, "buttonBox is NULL");
-    QPushButton *button = box->button(QDialogButtonBox::Ok);
-    GT_CHECK(button != nullptr, "cancel button is NULL");
-    GTWidget::click(os, button);
+    GTUtilsDialog::clickButtonBox(QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 #define GT_CLASS_NAME "GTUtilsDialog::RemoveGapColsDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void RemoveGapColsDialogFiller::commonScenario() {
     GTGlobals::sleep(1000);
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QRadioButton *radio = dialog->findChild<QRadioButton *>(radioMap[button]);
-    GTRadioButton::click(os, radio);
+    auto radio = GTWidget::findRadioButton(radioMap[button], dialog);
+    GTRadioButton::click(radio);
 
     if (button == Number) {
-        QSpinBox *box = dialog->findChild<QSpinBox *>("absoluteSpinBox");
-        GTSpinBox::setValue(os, box, spinValue);
+        auto box = GTWidget::findSpinBox("absoluteSpinBox", dialog);
+        GTSpinBox::setValue(box, spinValue);
     } else if (button == Percent) {
-        QSpinBox *box = dialog->findChild<QSpinBox *>("relativeSpinBox");
-        GTSpinBox::setValue(os, box, spinValue);
+        auto box = GTWidget::findSpinBox("relativeSpinBox", dialog);
+        GTSpinBox::setValue(box, spinValue);
     }
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 }  // namespace U2
