@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_DELETE_GAPS_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_DELETE_GAPS_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 
 class DeleteGapsDialogFiller : public Filler {
 public:
-    DeleteGapsDialogFiller(HI::GUITestOpStatus &os, int _radioButNum = 0)
-        : Filler(os, "DeleteGapsDialog"),
+    DeleteGapsDialogFiller(int _radioButNum = 0)
+        : Filler("DeleteGapsDialog"),
           radioButNum(_radioButNum) {
     }
     void commonScenario();
@@ -44,8 +43,8 @@ public:
     enum Radio { Number,
                  Percent,
                  Column };
-    RemoveGapColsDialogFiller(HI::GUITestOpStatus &os, Radio _button, int _spinValue = 1)
-        : Filler(os, "DeleteGapsDialog"),
+    RemoveGapColsDialogFiller(Radio _button, int _spinValue = 1)
+        : Filler("DeleteGapsDialog"),
           button(_button), spinValue(_spinValue) {
         radioMap[Number] = "absoluteRadioButton";
         radioMap[Percent] = "relativeRadioButton";
@@ -59,5 +58,3 @@ private:
     QMap<Radio, QString> radioMap;
 };
 }  // namespace U2
-
-#endif
