@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -18,8 +18,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA 02110-1301, USA.
  */
-#ifndef DISTANCEMATRIXDIALOGFILLER_H
-#define DISTANCEMATRIXDIALOGFILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 namespace U2 {
@@ -33,9 +32,9 @@ public:
         NONE
     };
 
-    DistanceMatrixDialogFiller(HI::GUITestOpStatus &os, bool hamming = true, bool counts = true, bool excludeGaps = true);
-    DistanceMatrixDialogFiller(HI::GUITestOpStatus &os, SaveFormat format, QString path);
-    DistanceMatrixDialogFiller(HI::GUITestOpStatus &os, CustomScenario *c);
+    DistanceMatrixDialogFiller(bool hamming = true, bool counts = true, bool excludeGaps = true);
+    DistanceMatrixDialogFiller(SaveFormat format, QString path);
+    DistanceMatrixDialogFiller(CustomScenario* c);
 
     virtual void commonScenario();
 
@@ -49,5 +48,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif  // DISTANCEMATRIXDIALOGFILLER_H
