@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EXTRACT_SELECTED_AS_MSA_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EXTRACT_SELECTED_AS_MSA_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -33,24 +32,24 @@ public:
      * Initialize the default filler scenario for the dialog.
      * If 'useDefaultSequenceSelection' is 'true' ignores 'selectedSequenceNameList' values and re-uses currently checked values by MSA editor.
      */
-    ExtractSelectedAsMSADialogFiller(HI::GUITestOpStatus &os,
-                                     const QString &filepath,
-                                     const QStringList &selectedSequenceNameList = QStringList(),
-                                     int from = 0,
-                                     int to = 0,
-                                     bool addToProj = true,
-                                     bool invertButtonPress = false,
-                                     bool allButtonPress = false,
-                                     bool noneButtonPress = false,
-                                     bool dontCheckFilepath = false,
-                                     const QString &format = "",
-                                     bool useDefaultSequenceSelectionFlag = false);
+    ExtractSelectedAsMSADialogFiller(
+        const QString& filepath,
+        const QStringList& selectedSequenceNameList = QStringList(),
+        int from = 0,
+        int to = 0,
+        bool addToProj = true,
+        bool invertButtonPress = false,
+        bool allButtonPress = false,
+        bool noneButtonPress = false,
+        bool dontCheckFilepath = false,
+        const QString& format = "",
+        bool useDefaultSequenceSelectionFlag = false);
 
-    ExtractSelectedAsMSADialogFiller(HI::GUITestOpStatus &os, CustomScenario *c);
+    ExtractSelectedAsMSADialogFiller(CustomScenario* c);
 
     void commonScenario() override;
 
-    static QStringList getSequences(HI::GUITestOpStatus &os, bool selected = true);
+    static QStringList getSequences(bool selected = true);
 
     void setUseDefaultSequenceSelection(bool flag);
 
@@ -69,5 +68,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
