@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GENERATEALIGNMENTPROFILEDIALOGFILLER_H
-#define GENERATEALIGNMENTPROFILEDIALOGFILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -32,8 +31,8 @@ public:
     enum saveFormat { NONE,
                       HTML,
                       CSV };
-    GenerateAlignmentProfileDialogFiller(HI::GUITestOpStatus &os, bool _counts = true, saveFormat _format = NONE, QString _filePath = "")
-        : Filler(os, "DNAStatMSAProfileDialog"),
+    GenerateAlignmentProfileDialogFiller(bool _counts = true, saveFormat _format = NONE, QString _filePath = "")
+        : Filler("DNAStatMSAProfileDialog"),
           counts(_counts),
           gapScore(false),
           symdolScore(false),
@@ -45,8 +44,8 @@ public:
         checkBoxItems[CSV] = "csvRB";
     }
 
-    GenerateAlignmentProfileDialogFiller(HI::GUITestOpStatus &os, bool _gapsScore, bool _symbolScore, bool _skipGaps)
-        : Filler(os, "DNAStatMSAProfileDialog"),
+    GenerateAlignmentProfileDialogFiller(bool _gapsScore, bool _symbolScore, bool _skipGaps)
+        : Filler("DNAStatMSAProfileDialog"),
           counts(true),
           gapScore(_gapsScore),
           symdolScore(_symbolScore),
@@ -54,8 +53,8 @@ public:
           format(NONE) {
     }
 
-    GenerateAlignmentProfileDialogFiller(HI::GUITestOpStatus &os, CustomScenario *customScenario)
-        : Filler(os, "DNAStatMSAProfileDialog", customScenario),
+    GenerateAlignmentProfileDialogFiller(CustomScenario* customScenario)
+        : Filler("DNAStatMSAProfileDialog", customScenario),
           counts(true),
           gapScore(false),
           symdolScore(false),
@@ -77,5 +76,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // GENERATEALIGNMENTPROFILEDIALOGFILLER_H
