@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,21 +31,18 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::GenerateAlignmentProfileDialogFiller"
 
-LicenseAgreementDialogFiller::LicenseAgreementDialogFiller(HI::GUITestOpStatus &os)
-    : Filler(os, "LicenseDialog") {
+LicenseAgreementDialogFiller::LicenseAgreementDialogFiller()
+    : Filler("LicenseDialog") {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void LicenseAgreementDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
     GTGlobals::sleep();
 
-    QPushButton *accept = dialog->findChild<QPushButton *>("acceptButton");
-    GTWidget::click(os, accept);
+    auto accept = GTWidget::findPushButton("acceptButton", dialog);
+    GTWidget::click(accept);
     GTThread::waitForMainThread();
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
