@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,23 +30,18 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::FindAnnotationCollocationsDialogFiller"
 
-#define GT_METHOD_NAME "commonScenario"
 void FindAnnotationCollocationsDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Cancel);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Cancel);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "getPlusButton"
-QToolButton *FindAnnotationCollocationsDialogFiller::getPlusButton() const {
-    QToolButton *result = nullptr;
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK_RESULT(dialog, "activeModalWidget is NULL", nullptr);
+QToolButton* FindAnnotationCollocationsDialogFiller::getPlusButton() const {
+    QToolButton* result = nullptr;
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QList<QToolButton *> toolList = dialog->findChildren<QToolButton *>();
-    foreach (QToolButton *but, toolList) {
+    QList<QToolButton*> toolList = dialog->findChildren<QToolButton*>();
+    foreach (QToolButton* but, toolList) {
         if (but->text() == "+") {
             result = but;
         }
@@ -55,16 +50,13 @@ QToolButton *FindAnnotationCollocationsDialogFiller::getPlusButton() const {
     GT_CHECK_RESULT(result, "PlusButton not found", nullptr);
     return result;
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "getMinusButtons"
-QList<QToolButton *> FindAnnotationCollocationsDialogFiller::getMinusButtons() const {
-    QList<QToolButton *> result;
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK_RESULT(dialog, "activeModalWidget is NULL", result);
+QList<QToolButton*> FindAnnotationCollocationsDialogFiller::getMinusButtons() const {
+    QList<QToolButton*> result;
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QList<QToolButton *> toolList = dialog->findChildren<QToolButton *>();
-    foreach (QToolButton *but, toolList) {
+    QList<QToolButton*> toolList = dialog->findChildren<QToolButton*>();
+    foreach (QToolButton* but, toolList) {
         if (but->text() == "-") {
             result << but;
         }
@@ -72,7 +64,6 @@ QList<QToolButton *> FindAnnotationCollocationsDialogFiller::getMinusButtons() c
 
     return result;
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
