@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_ANNOTATION_COLLOCATIONS_DIALOG_FILLER_H_
-#define _U2_FIND_ANNOTATION_COLLOCATIONS_DIALOG_FILLER_H_
+#pragma once
 
 #include <QToolButton>
 
@@ -31,14 +30,12 @@ using namespace HI;
 
 class FindAnnotationCollocationsDialogFiller : public Filler {
 public:
-    FindAnnotationCollocationsDialogFiller(HI::GUITestOpStatus &os)
-        : Filler(os, "FindAnnotationCollocationsDialog") {
+    FindAnnotationCollocationsDialogFiller()
+        : Filler("FindAnnotationCollocationsDialog") {
     }
     void commonScenario();
-    QToolButton *getPlusButton() const;
-    QList<QToolButton *> getMinusButtons() const;
+    QToolButton* getPlusButton() const;
+    QList<QToolButton*> getMinusButtons() const;
 };
 
 }  // namespace U2
-
-#endif  // _U2_FIND_ANNOTATION_COLLOCATIONS_DIALOG_FILLER_H_
