@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CAP3_SUPPORT_DIALOG_FILLER_H_
-#define _U2_CAP3_SUPPORT_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,11 +28,11 @@ using namespace HI;
 
 class CAP3SupportDialogFiller : public Filler {
 public:
-    CAP3SupportDialogFiller(HI::GUITestOpStatus &os, QStringList _input, const QString &_output)
-        : Filler(os, "CAP3SupportDialog"), input(_input), output(_output) {
+    CAP3SupportDialogFiller(QStringList _input, const QString& _output)
+        : Filler("CAP3SupportDialog"), input(_input), output(_output) {
     }
-    CAP3SupportDialogFiller(HI::GUITestOpStatus &os, CustomScenario *c)
-        : Filler(os, "CAP3SupportDialog", c) {
+    CAP3SupportDialogFiller(CustomScenario* c)
+        : Filler("CAP3SupportDialog", c) {
     }
     void commonScenario();
 
@@ -42,4 +41,3 @@ private:
     QString output;
 };
 }  // namespace U2
-#endif  // CAP3SUPPORTDIALOGFILLER_H
