@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,24 +30,21 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::ExportAnnotationsFiller"
 
-ExportBlastResultDialogFiller::ExportBlastResultDialogFiller(HI::GUITestOpStatus &os, const QString &filePath, bool _addRefBoxChecked)
-    : Filler(os, "ExportBlastResultDialog"),
+ExportBlastResultDialogFiller::ExportBlastResultDialogFiller(const QString& filePath, bool _addRefBoxChecked)
+    : Filler("ExportBlastResultDialog"),
       filePath(filePath),
       addRefBoxChecked(_addRefBoxChecked) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void ExportBlastResultDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(nullptr != dialog, "Active modal widget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    GTLineEdit::setText(os, GTWidget::findExactWidget<QLineEdit *>(os, "fileNameEdit", dialog), filePath);
+    GTLineEdit::setText("fileNameEdit", filePath, dialog);
 
-    GTCheckBox::setChecked(os, GTWidget::findExactWidget<QCheckBox *>(os, "addRefBox", dialog), addRefBoxChecked);
+    GTCheckBox::setChecked(GTWidget::findCheckBox("addRefBox", dialog), addRefBoxChecked);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
