@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -36,8 +36,8 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::ExportToSequenceFormatFiller"
 
-ExportMSA2MSADialogFiller::ExportMSA2MSADialogFiller(HI::GUITestOpStatus &_os, int _formatVal, QString _path, bool _includeGaps, bool _unknownAsGaps, int _frame)
-    : Filler(_os, "U2__ExportMSA2MSADialog"),
+ExportMSA2MSADialogFiller::ExportMSA2MSADialogFiller(int _formatVal, QString _path, bool _includeGaps, bool _unknownAsGaps, int _frame)
+    : Filler("U2__ExportMSA2MSADialog"),
       formatVal(_formatVal),
       path(_path),
       includeGaps(_includeGaps),
@@ -45,24 +45,21 @@ ExportMSA2MSADialogFiller::ExportMSA2MSADialogFiller(HI::GUITestOpStatus &_os, i
       frame(_frame) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void ExportMSA2MSADialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
     if (!path.isEmpty()) {
-        QLineEdit *fileNameEdit = GTWidget::findExactWidget<QLineEdit *>(os, "fileNameEdit", dialog);
-        GTLineEdit::setText(os, fileNameEdit, path);
+        GTLineEdit::setText("fileNameEdit", path, dialog);
     }
     if (formatVal >= 0) {
-        QComboBox *formatCombo = GTWidget::findExactWidget<QComboBox *>(os, "formatCombo", dialog);
-        GTComboBox::selectItemByIndex(os, formatCombo, formatVal);
+        auto formatCombo = GTWidget::findComboBox("formatCombo", dialog);
+        GTComboBox::selectItemByIndex(formatCombo, formatVal);
     }
     if (includeGaps) {
-        GTCheckBox::setChecked(os, "cbIncludeGaps", dialog);
+        GTCheckBox::setChecked("cbIncludeGaps", dialog);
 
         if (unknownAsGaps) {
-            GTRadioButton::click(os, "rbUseGaps", dialog);
+            GTRadioButton::click("rbUseGaps", dialog);
         }
     }
 
@@ -80,13 +77,12 @@ void ExportMSA2MSADialogFiller::commonScenario() {
     } else if (frame == -3) {
         widgetName = "rbThirdComplementFrame";
     } else {
-        GT_CHECK(false, "incorrect frame");
+        GT_FAIL("incorrect frame", );
     }
-    GTRadioButton::click(os, widgetName, dialog);
+    GTRadioButton::click(widgetName, dialog);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
