@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EXPORT_MSA2SEQUENCES_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EXPORT_MSA2SEQUENCES_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -35,10 +34,9 @@ public:
                           GFF,
                           Genbank,
                           Swiss_Prot };
-    ExportToSequenceFormatFiller(HI::GUITestOpStatus &os, const QString &path, const QString &name, documentFormat format, bool saveFile, bool keepCharacters, GTGlobals::UseMethod method = GTGlobals::UseMouse);
-    ExportToSequenceFormatFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    ExportToSequenceFormatFiller(const QString& path, const QString& name, documentFormat format, bool saveFile, bool keepCharacters, GTGlobals::UseMethod method = GTGlobals::UseMouse);
 
-    void commonScenario();
+    void commonScenario() override;
 
 private:
     QString path, name;
@@ -50,5 +48,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
