@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -35,8 +35,8 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::exportSelectedSequenceFromAlignment"
 
-ExportSelectedSequenceFromAlignment::ExportSelectedSequenceFromAlignment(HI::GUITestOpStatus &_os, const QString &_path, documentFormat _format, bool _keepGaps, bool _addToProj)
-    : Filler(_os, "U2__SaveSelectedSequenceFromMSADialog"),
+ExportSelectedSequenceFromAlignment::ExportSelectedSequenceFromAlignment(const QString& _path, documentFormat _format, bool _keepGaps, bool _addToProj)
+    : Filler("U2__SaveSelectedSequenceFromMSADialog"),
       path(_path),
       format(_format),
       keepGaps(_keepGaps),
@@ -50,39 +50,35 @@ ExportSelectedSequenceFromAlignment::ExportSelectedSequenceFromAlignment(HI::GUI
     comboBoxItems[Ugene_db] = "UGENE Database";
 }
 
-ExportSelectedSequenceFromAlignment::ExportSelectedSequenceFromAlignment(HI::GUITestOpStatus &os, CustomScenario *scenario)
-    : Filler(os, "U2__SaveSelectedSequenceFromMSADialog", scenario),
+ExportSelectedSequenceFromAlignment::ExportSelectedSequenceFromAlignment(CustomScenario* scenario)
+    : Filler("U2__SaveSelectedSequenceFromMSADialog", scenario),
       format(EMBL),
       keepGaps(false),
       addToProj(false) {
 }
 
-#define GT_METHOD_NAME "run"
 void ExportSelectedSequenceFromAlignment::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *lineEdit = dialog->findChild<QLineEdit *>();
+    QLineEdit* lineEdit = dialog->findChild<QLineEdit*>();
     GT_CHECK(lineEdit != nullptr, "line edit not found");
-    GTLineEdit::setText(os, lineEdit, path);
+    GTLineEdit::setText(lineEdit, path);
 
-    QComboBox *comboBox = dialog->findChild<QComboBox *>("formatCombo");
-    GT_CHECK(comboBox != nullptr, "ComboBox not found");
+    auto comboBox = GTWidget::findComboBox("formatCombo", dialog);
 
     int index = comboBox->findText(comboBoxItems[format]);
     GT_CHECK(index != -1, QString("item \"%1\" in combobox not found").arg(comboBoxItems[format]));
-    GTComboBox::selectItemByIndex(os, comboBox, index);
+    GTComboBox::selectItemByIndex(comboBox, index);
 
-    QCheckBox *addToProjectBox = dialog->findChild<QCheckBox *>("addToProjectBox");
-    GTCheckBox::setChecked(os, addToProjectBox, addToProj);
+    auto addToProjectBox = GTWidget::findCheckBox("addToProjectBox", dialog);
+    GTCheckBox::setChecked(addToProjectBox, addToProj);
 
-    QCheckBox *keepGapsBox = dialog->findChild<QCheckBox *>("keepGapsBox");
-    GTCheckBox::setChecked(os, keepGapsBox, keepGaps);
+    auto keepGapsBox = GTWidget::findCheckBox("keepGapsBox", dialog);
+    GTCheckBox::setChecked(keepGapsBox, keepGaps);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
 
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
