@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef EXPORT_SELECTED_SEQUENCE_FROM_ALIGNMENT_DIALOG_FILLER_H
-#define EXPORT_SELECTED_SEQUENCE_FROM_ALIGNMENT_DIALOG_FILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -36,8 +35,8 @@ public:
                           Genbank,
                           Swiss_Prot,
                           Ugene_db };
-    ExportSelectedSequenceFromAlignment(HI::GUITestOpStatus &_os, const QString &_path, documentFormat _format = FASTA, bool _keepGaps = true, bool _addToProj = true);
-    ExportSelectedSequenceFromAlignment(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    ExportSelectedSequenceFromAlignment(const QString& _path, documentFormat _format = FASTA, bool _keepGaps = true, bool _addToProj = true);
+    ExportSelectedSequenceFromAlignment(CustomScenario* scenario);
 
     void commonScenario();
 
@@ -49,5 +48,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // EXPORT_SELECTED_SEQUENCE_FROM_ALIGNMENT_DIALOG_FILLER_H
