@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EXPORT_SEQUENCES_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EXPORT_SEQUENCES_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,15 +28,13 @@ using namespace HI;
 
 class ExportSelectedRegionFiller : public Filler {
 public:
-    ExportSelectedRegionFiller(HI::GUITestOpStatus &_os, const QString &_path, const QString &_name, bool translate = false, const QString &seqName = QString(), bool saveAllAminoFrames = true);
-    ExportSelectedRegionFiller(HI::GUITestOpStatus &os, const QString &filePath);
-    ExportSelectedRegionFiller(HI::GUITestOpStatus &os, CustomScenario *customScenario);
+    ExportSelectedRegionFiller(const QString& _path, const QString& _name, bool translate = false, const QString& seqName = QString(), bool saveAllAminoFrames = true);
+    ExportSelectedRegionFiller(const QString& filePath);
+    ExportSelectedRegionFiller(CustomScenario* customScenario);
 
     void commonScenario();
-    void setPath(const QString &value);
-    void setName(const QString &value);
-
-    static QString defaultExportPath;
+    void setPath(const QString& value);
+    void setName(const QString& value);
 
 private:
     QString path, name;
@@ -54,7 +51,16 @@ public:
                        Genbank };
     enum MergeOptions { SaveAsSeparate,
                         Merge };
-    ExportSequenceOfSelectedAnnotationsFiller(HI::GUITestOpStatus &_os, const QString &_path, FormatToUse _format, MergeOptions _options, int _gapLength = 0, bool _addDocToProject = true, bool _exportWithAnnotations = false, GTGlobals::UseMethod method = GTGlobals::UseMouse);
+
+    ExportSequenceOfSelectedAnnotationsFiller(
+        const QString& _path,
+        FormatToUse _format,
+        MergeOptions _options,
+        int _gapLength = 0,
+        bool _addDocToProject = true,
+        bool _exportWithAnnotations = false,
+        GTGlobals::UseMethod method = GTGlobals::UseMouse,
+        bool translate = false);
     void commonScenario();
 
 private:
@@ -65,10 +71,9 @@ private:
     bool exportWithAnnotations;
     MergeOptions options;
     GTGlobals::UseMethod useMethod;
+    bool translate = false;
     QMap<FormatToUse, QString> comboBoxItems;
     QMap<MergeOptions, QString> mergeRadioButtons;
 };
 
 }  // namespace U2
-
-#endif
