@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_IMPORT_ANNOTATIONS_TO_CSV_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_IMPORT_ANNOTATIONS_TO_CSV_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -44,11 +43,11 @@ public:
                       Genbank,
                       Swiss_Prot };
     struct RoleColumnParameter {
-        RoleColumnParameter(int _column, RoleParameter *_p)
+        RoleColumnParameter(int _column, RoleParameter* _p)
             : column(_column), parameter(_p) {
         }
         int column;
-        RoleParameter *parameter;
+        RoleParameter* parameter;
     };
     typedef QList<RoleColumnParameter> RoleParameters;
 
@@ -85,27 +84,27 @@ public:
     };
 
     struct QualifierParameter : public RoleParameter {
-        QualifierParameter(const QString &_name)
+        QualifierParameter(const QString& _name)
             : name(_name) {
         }
         QString name;
     };
 
-    ImportAnnotationsToCsvFiller(HI::GUITestOpStatus &_os,
-                                 const QString &_fileToRead,
-                                 const QString &_resultFile,
-                                 ImportAnnotationsToCsvFiller::fileFormat _format,
-                                 bool _addResultFileToProject,
-                                 bool _columnSeparator,
-                                 const QString &_separator,
-                                 int _numberOfLines,
-                                 const QString &_skipAllLinesStartsWith,
-                                 bool _interpretMultipleAsSingle,
-                                 bool _removeQuotesButton,
-                                 const QString &_defaultAnnotationName,
-                                 const RoleParameters &roleParameters = RoleParameters(),
-                                 GTGlobals::UseMethod method = GTGlobals::UseMouse);
-    ImportAnnotationsToCsvFiller(HI::GUITestOpStatus &_os, CustomScenario *c);
+    ImportAnnotationsToCsvFiller(
+        const QString& _fileToRead,
+        const QString& _resultFile,
+        ImportAnnotationsToCsvFiller::fileFormat _format,
+        bool _addResultFileToProject,
+        bool _columnSeparator,
+        const QString& _separator,
+        int _numberOfLines,
+        const QString& _skipAllLinesStartsWith,
+        bool _interpretMultipleAsSingle,
+        bool _removeQuotesButton,
+        const QString& _defaultAnnotationName,
+        const RoleParameters& roleParameters = RoleParameters(),
+        GTGlobals::UseMethod method = GTGlobals::UseMouse);
+    ImportAnnotationsToCsvFiller(CustomScenario* c);
 
     virtual void commonScenario();
 
@@ -128,19 +127,17 @@ private:
 
 class RoleFiller : public Filler {
 public:
-    RoleFiller(HI::GUITestOpStatus &os, ImportAnnotationsToCsvFiller::RoleParameter *_parameter)
-        : Filler(os, "CSVColumnConfigurationDialog"), parameter(_parameter) {
+    RoleFiller(ImportAnnotationsToCsvFiller::RoleParameter* _parameter)
+        : Filler("CSVColumnConfigurationDialog"), parameter(_parameter) {
     }
-    RoleFiller(HI::GUITestOpStatus &os, CustomScenario *c)
-        : Filler(os, "CSVColumnConfigurationDialog", c), parameter(nullptr) {
+    RoleFiller(CustomScenario* c)
+        : Filler("CSVColumnConfigurationDialog", c), parameter(nullptr) {
     }
 
     virtual void commonScenario();
 
 private:
-    ImportAnnotationsToCsvFiller::RoleParameter *parameter;
+    ImportAnnotationsToCsvFiller::RoleParameter* parameter;
 };
 
 }  // namespace U2
-
-#endif  // _U2_GT_RUNNABLES_IMPORT_ANNOTATIONS_TO_CSV_DIALOG_FILLER_H_
