@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,10 +31,9 @@
 namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::DotPlotFiller"
-#define GT_METHOD_NAME "commonScenario"
 
-DotPlotFiller::DotPlotFiller(HI::GUITestOpStatus &_os, CustomScenario *customScenario)
-    : Filler(_os, "DotPlotDialog", customScenario),
+DotPlotFiller::DotPlotFiller(CustomScenario* customScenario)
+    : Filler("DotPlotDialog", customScenario),
       minLen(100),
       identity(0),
       invertedRepeats(false),
@@ -42,28 +41,26 @@ DotPlotFiller::DotPlotFiller(HI::GUITestOpStatus &_os, CustomScenario *customSce
 }
 
 void DotPlotFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QSpinBox *minLenBox = qobject_cast<QSpinBox *>(GTWidget::findWidget(os, "minLenBox", dialog));
+    auto minLenBox = GTWidget::findSpinBox("minLenBox", dialog);
     if (but1kpressed) {
-        GTWidget::click(os, GTWidget::findWidget(os, "minLenHeuristicsButton", dialog));
+        GTWidget::click(GTWidget::findWidget("minLenHeuristicsButton", dialog));
         GTGlobals::sleep();
         GT_CHECK(minLenBox->value() == 2, "minLem not 2, 1k button works wrong");
     } else
-        GTSpinBox::setValue(os, minLenBox, minLen, GTGlobals::UseKeyBoard);
+        GTSpinBox::setValue(minLenBox, minLen, GTGlobals::UseKeyBoard);
 
     if (identity) {
-        QSpinBox *identityBox = qobject_cast<QSpinBox *>(GTWidget::findWidget(os, "identityBox", dialog));
-        GTSpinBox::setValue(os, identityBox, identity, GTGlobals::UseKeyBoard);
+        auto identityBox = GTWidget::findSpinBox("identityBox", dialog);
+        GTSpinBox::setValue(identityBox, identity, GTGlobals::UseKeyBoard);
     }
 
-    QCheckBox *invertedCheckBox = qobject_cast<QCheckBox *>(GTWidget::findWidget(os, "invertedCheckBox", dialog));
-    GTCheckBox::setChecked(os, invertedCheckBox, invertedRepeats);
+    auto invertedCheckBox = GTWidget::findCheckBox("invertedCheckBox", dialog);
+    GTCheckBox::setChecked(invertedCheckBox, invertedRepeats);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
