@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,6 @@
 #include <primitives/GTTreeWidget.h>
 #include <primitives/GTWidget.h>
 
-#include <QApplication>
 #include <QTreeWidget>
 
 #include <U2Core/U2SafePoints.h>
@@ -32,24 +31,18 @@ namespace U2 {
 
 #define GT_CLASS_NAME "ConstructMoleculeDialogFiller"
 
-ConstructMoleculeDialogFiller::ConstructMoleculeDialogFiller(HI::GUITestOpStatus &os, const QList<Action> &actions)
-    : Filler(os, "ConstructMoleculeDialog"),
-      dialog(nullptr),
-      actions(actions) {
+ConstructMoleculeDialogFiller::ConstructMoleculeDialogFiller(const QList<Action>& actions)
+    : Filler("ConstructMoleculeDialog"), actions(actions) {
 }
 
-ConstructMoleculeDialogFiller::ConstructMoleculeDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario)
-    : Filler(os, "ConstructMoleculeDialog", scenario), dialog(nullptr) {
+ConstructMoleculeDialogFiller::ConstructMoleculeDialogFiller(CustomScenario* scenario)
+    : Filler("ConstructMoleculeDialog", scenario) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void ConstructMoleculeDialogFiller::commonScenario() {
-    dialog = QApplication::activeModalWidget();
-    GT_CHECK(nullptr != dialog, "activeModalWidget is NULL");
-
-    foreach (const Action &action, actions) {
-        CHECK_OP(os, );
+    dialog = GTWidget::getActiveModalWidget();
 
+    foreach (const Action& action, actions) {
         switch (action.first) {
             case AddAllFragments:
                 addAllFragments();
@@ -64,39 +57,32 @@ void ConstructMoleculeDialogFiller::commonScenario() {
                 clickOk();
                 break;
             default:
-                GT_CHECK(false, "An unrecognized action type");
+                GT_FAIL("An unrecognized action type", );
         }
     }
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "addAllFragments"
 void ConstructMoleculeDialogFiller::addAllFragments() {
-    GTWidget::click(os, GTWidget::findWidget(os, "takeAllButton", dialog));
+    GTWidget::click(GTWidget::findWidget("takeAllButton", dialog));
     GTGlobals::sleep();
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "invertAddedFragment"
-void ConstructMoleculeDialogFiller::invertAddedFragment(const QVariant &actionData) {
+void ConstructMoleculeDialogFiller::invertAddedFragment(const QVariant& actionData) {
     GT_CHECK(actionData.canConvert<QString>(), "Can't get a fragment name's part from the action data");
     GTGlobals::FindOptions options;
     options.matchPolicy = Qt::MatchContains;
-    GTTreeWidget::checkItem(os, GTTreeWidget::findItem(os, GTWidget::findExactWidget<QTreeWidget *>(os, "molConstructWidget", dialog), actionData.toString(), nullptr, 1, options), 3);
+    QTreeWidgetItem* item = GTTreeWidget::findItem(GTWidget::findTreeWidget("molConstructWidget", dialog), actionData.toString(), nullptr, 1, options);
+    bool isCheck = item->data(3, Qt::CheckStateRole).toInt() == Qt::Unchecked;
+    GTTreeWidget::checkItem(item, 3, GTGlobals::UseMouse, isCheck, false);  // Do not validate the result. The item is replaced on toggle.
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "clickCancel"
 void ConstructMoleculeDialogFiller::clickCancel() {
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Cancel);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Cancel);
 }
-#undef GT_METHOD_NAME
 
-#define GT_METHOD_NAME "clickOk"
 void ConstructMoleculeDialogFiller::clickOk() {
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
