@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CONSTRUCT_MOLECULE_DIALOG_FILLER_H_
-#define _U2_CONSTRUCT_MOLECULE_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -37,21 +36,19 @@ public:
     };
     typedef QPair<ActionType, QVariant> Action;
 
-    ConstructMoleculeDialogFiller(HI::GUITestOpStatus &os, const QList<Action> &actions);
-    ConstructMoleculeDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    ConstructMoleculeDialogFiller(const QList<Action>& actions);
+    ConstructMoleculeDialogFiller(CustomScenario* scenario);
 
     void commonScenario();
 
 private:
     void addAllFragments();
-    void invertAddedFragment(const QVariant &actionData);
+    void invertAddedFragment(const QVariant& actionData);
     void clickCancel();
     void clickOk();
 
-    QWidget *dialog;
+    QWidget* dialog = nullptr;
     const QList<Action> actions;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CONSTRUCT_MOLECULE_DIALOG_FILLER_H_
