@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,28 +20,19 @@
  */
 
 #include "CreateFragmentDialogFiller.h"
-
-#include <QApplication>
+#include <primitives/GTWidget.h>
 
 namespace U2 {
 
-CreateFragmentDialogFiller::CreateFragmentDialogFiller(HI::GUITestOpStatus &os)
-    : Filler(os, "CreateFragmentDialog") {
-}
-
-CreateFragmentDialogFiller::CreateFragmentDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario)
-    : Filler(os, "CreateFragmentDialog", scenario) {
+CreateFragmentDialogFiller::CreateFragmentDialogFiller(CustomScenario* scenario)
+    : Filler("CreateFragmentDialog", scenario) {
 }
 
 #define GT_CLASS_NAME "GTUtilsDialog::CreateFragmentDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void CreateFragmentDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
-
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    QWidget* dialog = GTWidget::getActiveModalWidget();
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
