@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,20 +29,17 @@ namespace U2 {
 
 #define GT_CLASS_NAME "DigestSequenceDialogFiller"
 
-DigestSequenceDialogFiller::DigestSequenceDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario)
-    : Filler(os, "DigestSequenceDialog", scenario) {
+DigestSequenceDialogFiller::DigestSequenceDialogFiller(CustomScenario* scenario)
+    : Filler("DigestSequenceDialog", scenario) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void DigestSequenceDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(nullptr != dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    GTWidget::click(os, GTWidget::findWidget(os, "addAllButton", dialog));
+    GTWidget::click(GTWidget::findWidget("addAllButton", dialog));
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
