@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ALIGN_TO_REFERENCE_BLAST_DIALOG_FILLER_
-#define _U2_ALIGN_TO_REFERENCE_BLAST_DIALOG_FILLER_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -46,19 +45,17 @@ public:
         bool addResultToProject;
     };
 
-    AlignToReferenceBlastDialogFiller(const Settings &settings, HI::GUITestOpStatus &os);
-    AlignToReferenceBlastDialogFiller(HI::GUITestOpStatus &os, CustomScenario *c);
+    AlignToReferenceBlastDialogFiller(const Settings& settings);
+    AlignToReferenceBlastDialogFiller(CustomScenario* c);
 
     void commonScenario();
 
-    static void setReference(HI::GUITestOpStatus &os, const QString &referenceUrl, QWidget *dialog);
-    static void setReads(HI::GUITestOpStatus &os, const QStringList &readUrls, QWidget *dialog);
-    static void setDestination(HI::GUITestOpStatus &os, const QString &destinationUrl, QWidget *dialog);
+    static void setReference(const QString& referenceUrl, QWidget* dialog);
+    static void setReads(const QStringList& readUrls, QWidget* dialog);
+    static void setDestination(const QString& destinationUrl, QWidget* dialog);
 
 private:
     Settings settings;
 };
 
 }  // namespace U2
-
-#endif  // _U2_ALIGN_TO_REFERENCE_BLAST_DIALOG_FILLER_
