@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_REMOTE_BLAST_DIALOG_FILLER_H_
-#define _U2_REMOTE_BLAST_DIALOG_FILLER_H_
+#pragma once
 
 #include <base_dialogs/GTFileDialog.h>
 
@@ -31,12 +30,10 @@ using namespace HI;
 
 class RemoteBLASTDialogFiller : public Filler {
 public:
-    RemoteBLASTDialogFiller(HI::GUITestOpStatus &os);
-    RemoteBLASTDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+    RemoteBLASTDialogFiller();
+    RemoteBLASTDialogFiller(CustomScenario* scenario);
 
     virtual void commonScenario();
 };
 
 }  // namespace U2
-
-#endif  // _U2_REMOTE_BLAST_DIALOG_FILLER_H_
