@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,35 +29,31 @@
 #include "primitives/GTTableView.h"
 #include "primitives/GTWidget.h"
 
-//#include <U2
+// #include <U2
 
 namespace U2 {
 using namespace HI;
 
-SnpEffDatabaseDialogFiller::SnpEffDatabaseDialogFiller(GUITestOpStatus &os, const QString &dbName, bool dbShouldBeFound)
-    : Filler(os, "SnpEffDatabaseDialog"),
+SnpEffDatabaseDialogFiller::SnpEffDatabaseDialogFiller(const QString& dbName, bool dbShouldBeFound)
+    : Filler("SnpEffDatabaseDialog"),
       dbName(dbName),
       dbShouldBeFound(dbShouldBeFound) {
 }
 
 #define GT_CLASS_NAME "SnpEffDatabaseDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void SnpEffDatabaseDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *lineEdit = GTWidget::findExactWidget<QLineEdit *>(os, "lineEdit", dialog);
-    GT_CHECK(lineEdit, "lineEdit is NULL");
-    GTLineEdit::setText(os, lineEdit, dbName, false, true);
+    GTLineEdit::setText("lineEdit", dbName, dialog, false, true);
     GTGlobals::sleep();
 
-    QTableView *table = dynamic_cast<QTableView *>(GTWidget::findWidget(os, "tableView"));
+    auto table = dynamic_cast<QTableView*>(GTWidget::findWidget("tableView"));
     GT_CHECK(table, "tableView is NULL");
 
-    QAbstractItemModel *model = table->model();
+    QAbstractItemModel* model = table->model();
     GT_CHECK(model, "model is NULL");
 
-    int rowCount = GTTableView::rowCount(os, table);
+    int rowCount = GTTableView::rowCount(table);
     int row = -1;
     for (int i = 0; i < rowCount; i++) {
         QModelIndex idx = model->index(i, 0);
@@ -70,13 +66,13 @@ void SnpEffDatabaseDialogFiller::commonScenario() {
     if (dbShouldBeFound) {
         GT_CHECK(row != -1, QString("Genome %1 is not found in the table").arg(dbName));
 
-        GTMouseDriver::moveTo(GTTableView::getCellPoint(os, table, row, 0));
+        GTMouseDriver::moveTo(GTTableView::getCellPoint(table, row, 0));
         GTMouseDriver::click();
 
-        GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+        GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
     } else {
         GT_CHECK(row == -1, QString("Genome %1 is unexpectedly found").arg(dbName));
-        GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Cancel);
+        GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Cancel);
     }
 }
 
