@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,6 +20,7 @@
  */
 
 #include "OrfDialogFiller.h"
+#include <primitives/GTWidget.h>
 
 #include <QApplication>
 
@@ -27,22 +28,19 @@ namespace U2 {
 
 #define GT_CLASS_NAME "OrfDialogFiller"
 
-OrfDialogFiller::OrfDialogFiller(GUITestOpStatus &os)
-    : Filler(os, "ORFDialogBase") {
+OrfDialogFiller::OrfDialogFiller()
+    : Filler("ORFDialogBase") {
 }
 
-OrfDialogFiller::OrfDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario)
-    : Filler(os, "ORFDialogBase", scenario) {
+OrfDialogFiller::OrfDialogFiller(CustomScenario* scenario)
+    : Filler("ORFDialogBase", scenario) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void OrfDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(nullptr != dialog, "Active modal widget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
