@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_PRIMERS_DIALOG_FILLER_H_
-#define _U2_EXPORT_PRIMERS_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,21 +28,13 @@ using namespace HI;
 
 class ExportPrimersDialogFiller : public Filler {
 public:
-    enum ExportTarget { LocalFile,
-                        SharedDb };
+    ExportPrimersDialogFiller(CustomScenario* scenario = nullptr);
 
-    ExportPrimersDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario = nullptr);
+    void commonScenario() override;
 
-    void commonScenario();
-
-    static QWidget *getDialog(HI::GUITestOpStatus &os);
-    static void setExportTarget(HI::GUITestOpStatus &os, ExportTarget exportTarget);
-    static void setFormat(HI::GUITestOpStatus &os, const QString &format);
-    static void setFilePath(HI::GUITestOpStatus &os, const QString &filePath);
-    static void setDatabase(HI::GUITestOpStatus &os, const QString &database);
-    static void setFolder(HI::GUITestOpStatus &os, const QString &folder);
+    static QWidget* getDialog();
+    static void setFormat(const QString& format);
+    static void setFilePath(const QString& filePath);
 };
 
 }  // namespace U2
-
-#endif  // _U2_EXPORT_PRIMERS_DIALOG_FILLER_H_
