@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PRIMER_LIBRARY_SELECTOR_FILLER_H_
-#define _U2_PRIMER_LIBRARY_SELECTOR_FILLER_H_
+#pragma once
 
 #include <base_dialogs/GTFileDialog.h>
 
@@ -31,7 +30,7 @@ using namespace HI;
 
 class PrimerLibrarySelectorFiller : public Filler {
 public:
-    PrimerLibrarySelectorFiller(HI::GUITestOpStatus &os, int number, bool doubleClick);
+    PrimerLibrarySelectorFiller(int number, bool doubleClick);
 
     void commonScenario();
 
@@ -41,5 +40,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_PRIMER_LIBRARY_SELECTOR_FILLER_H_
