@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,28 +20,26 @@
  */
 
 #include "PrimersDetailsDialogFiller.h"
+#include <primitives/GTWidget.h>
 
 #include <QApplication>
 
 namespace U2 {
 
-PrimersDetailsDialogFiller::PrimersDetailsDialogFiller(HI::GUITestOpStatus &os)
-    : Filler(os, "PrimersDetailsDialog") {
+PrimersDetailsDialogFiller::PrimersDetailsDialogFiller()
+    : Filler("PrimersDetailsDialog") {
 }
 
-PrimersDetailsDialogFiller::PrimersDetailsDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario)
-    : Filler(os, "PrimersDetailsDialog", scenario) {
+PrimersDetailsDialogFiller::PrimersDetailsDialogFiller(CustomScenario* scenario)
+    : Filler("PrimersDetailsDialog", scenario) {
 }
 
 #define GT_CLASS_NAME "GTUtilsDialog::PrimersDetailsDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void PrimersDetailsDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
