@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,8 +23,8 @@
 
 namespace U2 {
 
-PwmSearchDialogFiller::PwmSearchDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario)
-    : Filler(os, "PWMSearchDialog", scenario) {
+PwmSearchDialogFiller::PwmSearchDialogFiller(CustomScenario* scenario)
+    : Filler("PWMSearchDialog", scenario) {
 }
 
 }  // namespace U2
