@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef ALIASESDIALOGFILLER_H
-#define ALIASESDIALOGFILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,14 +28,13 @@ using namespace HI;
 
 class AliasesDialogFiller : public Filler {
 public:
-    AliasesDialogFiller(HI::GUITestOpStatus &_os, QMap<QPoint *, QString> _map)
-        : Filler(_os, "SchemaAliasesConfigurationDialog"),
+    AliasesDialogFiller(QMap<QPoint*, QString> _map)
+        : Filler("SchemaAliasesConfigurationDialog"),
           map(_map) {
     }
     void commonScenario();
 
 private:
-    QMap<QPoint *, QString> map;
+    QMap<QPoint*, QString> map;
 };
 }  // namespace U2
-#endif  // ALIASESDIALOGFILLER_H
