@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef CONFIGURATIONWIZARDFILLER_H
-#define CONFIGURATIONWIZARDFILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,18 +28,16 @@ using namespace HI;
 
 class ConfigurationWizardFiller : public Filler {
 public:
-    ConfigurationWizardFiller(HI::GUITestOpStatus &os, QString name, QStringList _radioNames)
-        : Filler(os, name), radioNames(_radioNames) {
+    ConfigurationWizardFiller(QString name, QStringList _radioNames)
+        : Filler(name), radioNames(_radioNames) {
     }
-    ConfigurationWizardFiller(HI::GUITestOpStatus &os, QString name, CustomScenario *c)
-        : Filler(os, name, c) {
+    ConfigurationWizardFiller(QString name, CustomScenario* c)
+        : Filler(name, c) {
     }
-    virtual void commonScenario();
+    void commonScenario() override;
 
 private:
     QStringList radioNames;
 };
 
 }  // namespace U2
-
-#endif  // CONFIGURATIONWIZARDFILLER_H
