@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef CREATEELEMENTWITHSCRIPTDIALOGFILLER_H
-#define CREATEELEMENTWITHSCRIPTDIALOGFILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 
 class CreateElementWithScriptDialogFiller : public Filler {
 public:
-    CreateElementWithScriptDialogFiller(HI::GUITestOpStatus &os, QString _name)
-        : Filler(os, "CreateScriptBlockDialog"),
+    CreateElementWithScriptDialogFiller(QString _name)
+        : Filler("CreateScriptBlockDialog"),
           name(_name) {
     }
     void commonScenario();
@@ -41,8 +40,8 @@ private:
 
 class ScriptEditorDialogFiller : public Filler {
 public:
-    ScriptEditorDialogFiller(HI::GUITestOpStatus &os, QString _url = "", QString _text = "", bool _checkSyntax = false, QString _checkSyntaxResult = "")
-        : Filler(os, "ScriptEditorDialog"),
+    ScriptEditorDialogFiller(QString _url = "", QString _text = "", bool _checkSyntax = false, QString _checkSyntaxResult = "")
+        : Filler("ScriptEditorDialog"),
           url(_url),
           text(_text),
           checkSyntaxResult(_checkSyntaxResult),
@@ -59,8 +58,8 @@ private:
 
 class ScriptEditorDialogSyntaxChecker : public Filler {
 public:
-    ScriptEditorDialogSyntaxChecker(HI::GUITestOpStatus &os, QString _text = "", QString _message = "")
-        : Filler(os, "ScriptEditorDialog"),
+    ScriptEditorDialogSyntaxChecker(QString _text = "", QString _message = "")
+        : Filler("ScriptEditorDialog"),
           text(_text),
           message(_message) {
     }
@@ -70,5 +69,3 @@ private:
     QString text, message;
 };
 }  // namespace U2
-
-#endif  // CREATEELEMENTWITHSCRIPTDIALOGFILLER_H
