@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DASHBOARDS_MANAGER_DIALOG_FILLER_H_
-#define _U2_DASHBOARDS_MANAGER_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,17 +28,15 @@ using namespace HI;
 
 class DashboardsManagerDialogFiller : public Filler {
 public:
-    DashboardsManagerDialogFiller(HI::GUITestOpStatus &os, CustomScenario *_c = nullptr)
-        : Filler(os, "DashboardsManagerDialog", _c) {
+    DashboardsManagerDialogFiller(CustomScenario* _c = nullptr)
+        : Filler("DashboardsManagerDialog", _c) {
     }
 
     virtual void commonScenario();
 
-    static void selectDashboards(HI::GUITestOpStatus &os, QStringList names);
-    static bool isDashboardPresent(HI::GUITestOpStatus &os, QString name);
-    static QList<QPair<QString, bool>> getDashboardsState(HI::GUITestOpStatus &os);  // returns map dashboard_name->is_checked
+    static void selectDashboards(QStringList names);
+    static bool isDashboardPresent(QString name);
+    static QList<QPair<QString, bool>> getDashboardsState();  // returns map dashboard_name->is_checked
 };
 
 }  // namespace U2
-
-#endif  // DASHBOARDSMANAGERDIALOGFILLER_H
