@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,19 +31,16 @@ namespace U2 {
 using namespace HI;
 
 #define GT_CLASS_NAME "DatasetNameEditDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void DatasetNameEditDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
     if (!datasetName.isEmpty()) {
-        QLineEdit *line = dialog->findChild<QLineEdit *>();
+        QLineEdit* line = dialog->findChild<QLineEdit*>();
         GT_CHECK(line, "lineEdit not found");
-        GTLineEdit::setText(os, line, datasetName);
+        GTLineEdit::setText(line, datasetName);
     }
-    GTWidget::click(os, GTWidget::findButtonByText(os, "OK", dialog));
+    GTWidget::click(GTWidget::findButtonByText("OK", dialog));
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
