@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,12 +25,12 @@
 
 namespace U2 {
 
-DefaultWizardFiller::DefaultWizardFiller(HI::GUITestOpStatus &os, const QString &wizardName)
-    : Filler(os, wizardName) {
+DefaultWizardFiller::DefaultWizardFiller(const QString& wizardName)
+    : Filler(wizardName) {
 }
 
 void DefaultWizardFiller::commonScenario() {
-    GTUtilsWizard::clickButton(os, GTUtilsWizard::Cancel);
+    GTUtilsWizard::clickButton(GTUtilsWizard::Cancel);
 }
 
 }  // namespace U2
