@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,37 +34,28 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::StartupDialogFiller"
 
-StartupDialogFiller::StartupDialogFiller(HI::GUITestOpStatus &os, const QString &path, bool isPathValid)
-    : Filler(os, "StartupDialog"),
+StartupDialogFiller::StartupDialogFiller(const QString& path, bool isPathValid)
+    : Filler("StartupDialog"),
       path(path),
       isPathValid(isPathValid) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void StartupDialogFiller::commonScenario() {
-    GTGlobals::sleep(1000);
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
-
+    QWidget* dialog = GTWidget::getActiveModalWidget();
     if (path != UGUITest::sandBoxDir) {
-        QLineEdit *pathEdit = GTWidget::findExactWidget<QLineEdit *>(os, "pathEdit", dialog);
-        CHECK(nullptr != pathEdit, );
-
-        const QString rightPath = GTLineEdit::getText(os, pathEdit);
-        GTLineEdit::setText(os, pathEdit, path);
+        QString originalPath = GTLineEdit::getText("pathEdit", dialog);
+        GTLineEdit::setText("pathEdit", path, dialog);
 
         if (!isPathValid) {
-            GTUtilsDialog::waitForDialog(os, new MessageBoxDialogFiller(os, QMessageBox::Ok));
-            GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
-            CHECK_OP(os, );
+            GTUtilsDialog::waitForDialog(new MessageBoxDialogFiller(QMessageBox::Ok));
+            GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 
-            GTLineEdit::setText(os, pathEdit, rightPath);
+            GTLineEdit::setText("pathEdit", originalPath, dialog);
         }
     }
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 
 #undef GT_CLASS_NAME
 
