@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_STARTUP_DIALOG_FILLER_H_
-#define _U2_STARTUP_DIALOG_FILLER_H_
+#pragma once
 
 #include <core/GUITestOpStatus.h>
 #include <harness/UGUITestBase.h>
@@ -35,7 +34,7 @@ using namespace HI;
 
 class StartupDialogFiller : public Filler {
 public:
-    StartupDialogFiller(HI::GUITestOpStatus &os, const QString &path = UGUITest::sandBoxDir, bool isPathValid = true);
+    StartupDialogFiller(const QString& path = UGUITest::sandBoxDir, bool isPathValid = true);
     void commonScenario();
 
 private:
@@ -44,5 +43,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_STARTUP_DIALOG_FILLER_H_
