@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_WIZARD_FILLER_H_
-#define _U2_GT_RUNNABLES_WIZARD_FILLER_H_
+#pragma once
 
 #include <QPushButton>
 #include <QToolButton>
@@ -32,18 +31,17 @@ using namespace HI;
 
 class WizardFiller : public Filler {
 public:
-    WizardFiller(HI::GUITestOpStatus &_os, QString name, QList<QStringList> _inputFiles = QList<QStringList>(), QMap<QString, QVariant> _map = (QMap<QString, QVariant>()))
-        : Filler(_os, name), inputFiles(_inputFiles), map(_map) {
+    WizardFiller(QString name, QList<QStringList> _inputFiles = QList<QStringList>(), QMap<QString, QVariant> _map = (QMap<QString, QVariant>()))
+        : Filler(name), inputFiles(_inputFiles), map(_map) {
     }
-    WizardFiller(HI::GUITestOpStatus &_os, QString name, QStringList _inputFiles, QMap<QString, QVariant> _map = (QMap<QString, QVariant>()))
-        : Filler(_os, name), inputFiles(QList<QStringList>() << _inputFiles), map(_map) {
+    WizardFiller(QString name, QStringList _inputFiles, QMap<QString, QVariant> _map = (QMap<QString, QVariant>()))
+        : Filler(name), inputFiles(QList<QStringList>() << _inputFiles), map(_map) {
     }
-    WizardFiller(HI::GUITestOpStatus &_os, QString name, CustomScenario *c)
-        : Filler(_os, name, c) {
+    WizardFiller(QString name, CustomScenario* c)
+        : Filler(name, c) {
     }
-    void commonScenario();
 
-    static QToolButton *getExpandButton(HI::GUITestOpStatus &_os);
+    void commonScenario() override;
 
 private:
     QList<QStringList> inputFiles;
@@ -51,5 +49,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
