@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,21 +29,13 @@
 
 namespace U2 {
 #define GT_CLASS_NAME "GTUtilsDialog::StartupDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void WorkflowMetaDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *urlEdit = qobject_cast<QLineEdit *>(GTWidget::findWidget(os, "urlEdit", dialog));
-    GT_CHECK(urlEdit, "urlEdit not found");
-    GTLineEdit::setText(os, urlEdit, url, false, true);
+    GTLineEdit::setText("urlEdit", url, dialog, false, true);
+    GTLineEdit::setText("nameEdit", name, dialog);
 
-    QLineEdit *nameEdit = qobject_cast<QLineEdit *>(GTWidget::findWidget(os, "nameEdit", dialog));
-    GT_CHECK(nameEdit, "urlEdit not found");
-    GTLineEdit::setText(os, nameEdit, name);
-
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 }  // namespace U2
