@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef WORKFLOWMETADIALOGFILLER_H
-#define WORKFLOWMETADIALOGFILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 
 class WorkflowMetaDialogFiller : public Filler {
 public:
-    WorkflowMetaDialogFiller(HI::GUITestOpStatus &os, QString _url, QString _name)
-        : Filler(os, "WorkflowMetaDialog"),
+    WorkflowMetaDialogFiller(QString _url, QString _name)
+        : Filler("WorkflowMetaDialog"),
           url(_url),
           name(_name) {
     }
@@ -40,4 +39,3 @@ private:
     QString url, name;
 };
 }  // namespace U2
-#endif  // WORKFLOWMETADIALOGFILLER_H
