@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUI_MAFFT_SUPPORT_RUN_DIALOG_FILLER_H_
-#define _U2_GUI_MAFFT_SUPPORT_RUN_DIALOG_FILLER_H_
+#pragma once
 
 #include <base_dialogs/GTFileDialog.h>
 #include <utils/GTUtilsDialog.h>
@@ -42,15 +41,13 @@ public:
         int spin_maxNumberIterRefinementSpinBox_value;
     };
 
-    MAFFTSupportRunDialogFiller(GUITestOpStatus &os, Parameters *parameters);
-    MAFFTSupportRunDialogFiller(GUITestOpStatus &os, CustomScenario *scenario);
+    MAFFTSupportRunDialogFiller(Parameters* parameters);
+    MAFFTSupportRunDialogFiller(CustomScenario* scenario);
 
     void commonScenario();
 
 private:
-    Parameters *parameters;
+    Parameters* parameters;
 };
 
 }  // namespace U2
-
-#endif  // _U2_GUI_MAFFT_SUPPORT_RUN_DIALOG_FILLER_H_
