@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,31 +32,23 @@ namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::ClustalWDialogFiller"
 
-ClustalWDialogFiller::ClustalWDialogFiller(HI::GUITestOpStatus &_os, int _gapOpenVal)
-    : Filler(_os, "ClustalWSupportRunDialog"),
+ClustalWDialogFiller::ClustalWDialogFiller(int _gapOpenVal)
+    : Filler("ClustalWSupportRunDialog"),
       gapOpenVal(_gapOpenVal) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void ClustalWDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
     if (gapOpenVal) {
-        QCheckBox *gapOpenCheckBox = dialog->findChild<QCheckBox *>("gapOpenCheckBox");
-        GTCheckBox::setChecked(os, gapOpenCheckBox, true);
+        auto gapOpenCheckBox = GTWidget::findCheckBox("gapOpenCheckBox", dialog);
+        GTCheckBox::setChecked(gapOpenCheckBox, true);
 
-        QDoubleSpinBox *gapOpenSpinBox = dialog->findChild<QDoubleSpinBox *>("gapOpenSpinBox");
-        GTDoubleSpinbox::setValue(os, gapOpenSpinBox, gapOpenVal, GTGlobals::UseKeyBoard);
+        auto gapOpenSpinBox = GTWidget::findDoubleSpinBox("gapOpenSpinBox", dialog);
+        GTDoubleSpinbox::setValue(gapOpenSpinBox, gapOpenVal, GTGlobals::UseKeyBoard);
     }
-
-    QDialogButtonBox *box = qobject_cast<QDialogButtonBox *>(GTWidget::findWidget(os, "buttonBox", dialog));
-    GT_CHECK(box != nullptr, "buttonBox is NULL");
-    QPushButton *button = box->button(QDialogButtonBox::Ok);
-    GT_CHECK(button != nullptr, "cancel button is NULL");
-    GTWidget::click(os, button);
+    GTUtilsDialog::clickButtonBox(QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
