@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,25 +29,19 @@
 namespace U2 {
 
 #define GT_CLASS_NAME "UHMM3SearchDialogFiller"
-#define GT_METHOD_NAME "run"
 
 void HmmerSearchDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *queryHmmFileEdit = GTWidget::findExactWidget<QLineEdit *>(os, "queryHmmFileEdit", dialog);
-    GTLineEdit::setText(os, queryHmmFileEdit, profile);
+    GTLineEdit::setText("queryHmmFileEdit", profile, dialog);
 
-    QRadioButton *radio = GTWidget::findExactWidget<QRadioButton *>(os, "rbCreateNewTable", dialog);
-    CHECK_SET_ERR(radio != nullptr, "rbCreateNewTable not found!");
-    GTRadioButton::click(os, radio);
+    auto radio = GTWidget::findRadioButton("rbCreateNewTable", dialog);
+    GTRadioButton::click(radio);
 
-    QLineEdit *newFilePathle = GTWidget::findExactWidget<QLineEdit *>(os, "leNewTablePath", dialog);
-    GTLineEdit::setText(os, newFilePathle, newFilePath);
+    GTLineEdit::setText("leNewTablePath", newFilePath, dialog);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
 
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 }  // namespace U2
