@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_HMMER_SEARCH_DIALOG_FILLER_H_
-#define _U2_HMMER_SEARCH_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 namespace U2 {
@@ -28,8 +27,8 @@ using namespace HI;
 
 class HmmerSearchDialogFiller : public Filler {
 public:
-    HmmerSearchDialogFiller(HI::GUITestOpStatus &os, QString _profile, QString _newFilePath)
-        : Filler(os, "HmmerSearchDialog"),
+    HmmerSearchDialogFiller(QString _profile, QString _newFilePath)
+        : Filler("HmmerSearchDialog"),
           profile(_profile),
           newFilePath(_newFilePath) {
     }
@@ -39,4 +38,3 @@ private:
     QString profile, newFilePath;
 };
 }  // namespace U2
-#endif  // _U2_UHMM3_SEARCH_DIALOG_FILLER_H_
