@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,32 +21,23 @@
 
 #include "UHMM3PhmmerDialogFiller.h"
 #include <primitives/GTLineEdit.h>
-#include <primitives/GTTabBar.h>
+#include <primitives/GTTabWidget.h>
 #include <primitives/GTWidget.h>
 
-#include <QApplication>
-#include <QTabWidget>
-
 namespace U2 {
 
 #define GT_CLASS_NAME "UHMM3PhmmerDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 
 void UHMM3PhmmerDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    auto dialog = GTWidget::getActiveModalWidget();
 
-    GTGlobals::sleep(1000);
-    QTabWidget *tabWidget = GTWidget::findExactWidget<QTabWidget *>(os, "mainTabWidget", dialog);
+    GTTabWidget::setCurrentIndex(GTWidget::findTabWidget("mainTabWidget", dialog), 0);
 
-    tabWidget->setCurrentIndex(0);
-    QLineEdit *queryLineEdit = GTWidget::findExactWidget<QLineEdit *>(os, "queryLineEdit", dialog);
-    GTLineEdit::setText(os, queryLineEdit, input);
+    GTLineEdit::setText("queryLineEdit", input, dialog);
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
 
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
