@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_UHMM3_PHMMER_DIALOG_FILLER_H_
-#define _U2_UHMM3_PHMMER_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 
 class UHMM3PhmmerDialogFiller : public Filler {
 public:
-    UHMM3PhmmerDialogFiller(HI::GUITestOpStatus &os, QString _input)
-        : Filler(os, "PhmmerSearchDialog"), input(_input) {
+    UHMM3PhmmerDialogFiller(QString _input)
+        : Filler("PhmmerSearchDialog"), input(_input) {
     }
     void commonScenario();
 
@@ -38,4 +37,3 @@ private:
     QString input;
 };
 }  // namespace U2
-#endif  // _U2_UHMM3_PHMMER_DIALOG_FILLER_H_
