@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,38 +24,27 @@
 #include <primitives/GTDoubleSpinBox.h>
 #include <primitives/GTWidget.h>
 
-#include <QApplication>
 #include <QDialogButtonBox>
-#include <QPushButton>
 
 namespace U2 {
 
 #define GT_CLASS_NAME "GTUtilsDialog::KalignDialogFiller"
 
-KalignDialogFiller::KalignDialogFiller(HI::GUITestOpStatus &_os, int _gapOpenVal, bool _toAmino)
-    : Filler(_os, "KalignDialog"),
-      gapOpenVal(_gapOpenVal), toAmino(_toAmino) {
+KalignDialogFiller::KalignDialogFiller(int _gapOpenVal)
+    : Filler("KalignSupportRunDialog"),
+      gapOpenVal(_gapOpenVal) {
 }
 
-#define GT_METHOD_NAME "commonScenario"
 void KalignDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog != nullptr, "dialog not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    if (gapOpenVal) {
-        QCheckBox *gapOpenCheckBox = dialog->findChild<QCheckBox *>("gapOpenCheckBox");
-        GTCheckBox::setChecked(os, gapOpenCheckBox, true);
-
-        QDoubleSpinBox *gapOpenSpinBox = dialog->findChild<QDoubleSpinBox *>("gapOpenSpinBox");
-        GTDoubleSpinbox::setValue(os, gapOpenSpinBox, gapOpenVal, GTGlobals::UseKeyBoard);
+    if (gapOpenVal > 0) {
+        GTCheckBox::setChecked("gapOpenPenaltyCheckBox", true, dialog);
+        GTDoubleSpinbox::setValue("gapOpenPenaltySpinBox", gapOpenVal, GTGlobals::UseKeyBoard, dialog);
     }
 
-    QCheckBox *translateCheckBox = GTWidget::findExactWidget<QCheckBox *>(os, "translateCheckBox", dialog);
-    GTCheckBox::setChecked(os, translateCheckBox, toAmino);
-
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
