@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_PLUGINS_3RDPARTY_KALIGN_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_PLUGINS_3RDPARTY_KALIGN_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,14 +28,11 @@ using namespace HI;
 
 class KalignDialogFiller : public Filler {
 public:
-    KalignDialogFiller(HI::GUITestOpStatus &_os, int _gapOpenVal = 0, bool _toAmino = false);
-    void commonScenario();
+    KalignDialogFiller(int _gapOpenVal = 0);
+    void commonScenario() override;
 
 private:
-    int gapOpenVal;
-    bool toAmino;
+    int gapOpenVal = 0;
 };
 
 }  // namespace U2
-
-#endif
