@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,9 +27,8 @@
 
 namespace U2 {
 void AnyDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    CHECK_SET_ERR(dialog, "active modal widjet not found");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    GTUtilsDialog::clickButtonBox(os, dialog, b);
+    GTUtilsDialog::clickButtonBox(dialog, b);
 }
 }  // namespace U2
