@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef ANYDIALOGFILLER_H
-#define ANYDIALOGFILLER_H
+#pragma once
 
 #include <QDialogButtonBox>
 
@@ -31,8 +30,8 @@ using namespace HI;
 
 class AnyDialogFiller : public Filler {
 public:
-    AnyDialogFiller(HI::GUITestOpStatus &os, const QString &objectName, QDialogButtonBox::StandardButton _b)
-        : Filler(os, objectName), b(_b) {
+    AnyDialogFiller(const QString& objectName, QDialogButtonBox::StandardButton _b)
+        : Filler(objectName), b(_b) {
     }
     void commonScenario();
 
@@ -40,4 +39,3 @@ private:
     QDialogButtonBox::StandardButton b;
 };
 }  // namespace U2
-#endif  // ANYDIALOGFILLER_H
