@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef CONVERTACETOSQLITEDIALOGFILLER_H
-#define CONVERTACETOSQLITEDIALOGFILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -33,8 +32,8 @@ public:
                          REPLACE,
                          APPEND,
                          CANCEL };
-    ConvertAceToSqliteDialogFiller(HI::GUITestOpStatus &_os, QString _leDest, OutFileAction action = NOT_SET)
-        : Filler(_os, "AceImportDialog"),
+    ConvertAceToSqliteDialogFiller(QString _leDest, OutFileAction action = NOT_SET)
+        : Filler("AceImportDialog"),
           leDestUrl(_leDest), action(action) {
     }
     void commonScenario();
@@ -44,4 +43,3 @@ private:
     OutFileAction action;
 };
 }  // namespace U2
-#endif  // CONVERTACETOSQLITEDIALOGFILLER_H
