@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_CREATE_NEW_PROJECT_WIDGET_FILLER_H_
-#define _U2_GT_RUNNABLES_CREATE_NEW_PROJECT_WIDGET_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -28,8 +27,8 @@ namespace U2 {
 using namespace HI;
 class SaveProjectAsDialogFiller : public Filler {
 public:
-    SaveProjectAsDialogFiller(HI::GUITestOpStatus &_os, const QString &_projectName, const QString &_projectFile)
-        : Filler(_os, "CreateNewProjectDialog"), projectName(_projectName), projectFile(_projectFile) {
+    SaveProjectAsDialogFiller(const QString& _projectName, const QString& _projectFile)
+        : Filler("CreateNewProjectDialog"), projectName(_projectName), projectFile(_projectFile) {
     }
     void commonScenario();
 
@@ -38,5 +37,3 @@ private:
     const QString projectFile;
 };
 }  // namespace U2
-
-#endif
