@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef DOCUMENTFORMATSELECTORDIALOGFILLER_H
-#define DOCUMENTFORMATSELECTORDIALOGFILLER_H
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -31,17 +30,17 @@ using namespace HI;
 
 class DocumentFormatSelectorDialogFiller : public Filler {
 public:
-    DocumentFormatSelectorDialogFiller(HI::GUITestOpStatus &os,
-                                       const QString &_format,
-                                       const int _score = -1,
-                                       const int _formatLineLable = -1)
-        : Filler(os, "DocumentFormatSelectorDialog"),
+    DocumentFormatSelectorDialogFiller(
+        const QString& _format,
+        const int _score = -1,
+        const int _formatLineLable = -1)
+        : Filler("DocumentFormatSelectorDialog"),
           format(_format),
           score(_score),
           formatLineLable(_formatLineLable) {
     }
-    DocumentFormatSelectorDialogFiller(HI::GUITestOpStatus &os, CustomScenario *custom)
-        : Filler(os, "DocumentFormatSelectorDialog", custom) {
+    DocumentFormatSelectorDialogFiller(CustomScenario* custom)
+        : Filler("DocumentFormatSelectorDialog", custom) {
     }
     virtual void commonScenario();
 
@@ -49,9 +48,7 @@ private:
     QString format;
     int score;
     int formatLineLable;
-    QRadioButton *getButton(HI::GUITestOpStatus &os);
+    QRadioButton* getButton();
 };
 
 }  // namespace U2
-
-#endif  // DOCUMENTFORMATSELECTORDIALOGFILLER_H
