@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOCUMENT_PROVIDER_SELECTOR_DIALOG_FILLER_H_
-#define _U2_DOCUMENT_PROVIDER_SELECTOR_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -31,8 +30,8 @@ class DocumentProviderSelectorDialogFiller : public Filler {
 public:
     enum OpenWith { AlignmentEditor,
                     AssemblyBrowser };
-    DocumentProviderSelectorDialogFiller(HI::GUITestOpStatus &os, OpenWith _openWith)
-        : Filler(os, "DocumentProviderSelectorDialog"),
+    DocumentProviderSelectorDialogFiller(OpenWith _openWith)
+        : Filler("DocumentProviderSelectorDialog"),
           openWith(_openWith) {
     }
     virtual void commonScenario();
@@ -43,5 +42,3 @@ private:
     static QMap<OpenWith, QString> initMap();
 };
 }  // namespace U2
-
-#endif  // _U2_DOCUMENT_PROVIDER_SELECTOR_DIALOG_FILLER_H_
