@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -33,38 +33,26 @@ namespace U2 {
 using namespace HI;
 
 #define GT_CLASS_NAME "GTUtilsDialog::ExportProjectDialogChecker"
-#define GT_METHOD_NAME "commonScenario"
 void ExportProjectDialogChecker::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *projectFileLineEdit = qobject_cast<QLineEdit *>(GTWidget::findWidget(os, "projectFilePathEdit", dialog));
-    GT_CHECK(projectFileLineEdit != nullptr, "projectFilePathEdit is not found");
-
-    QString fullPath = projectFileLineEdit->text();
+    QString fullPath = GTLineEdit::getText("projectFilePathEdit", dialog);
     QString actualName = projectName.contains('/') ? fullPath : QFileInfo(fullPath).fileName();
     GT_CHECK(actualName == projectName, QString("Expected project name: %1, got: %2").arg(projectName, actualName));
 
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Cancel);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Cancel);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 #define GT_CLASS_NAME "GTUtilsDialog::ExportProjectDialogFiller"
-#define GT_METHOD_NAME "commonScenario"
 void ExportProjectDialogFiller::commonScenario() {
-    QWidget *dialog = QApplication::activeModalWidget();
-    GT_CHECK(dialog, "activeModalWidget is NULL");
+    QWidget* dialog = GTWidget::getActiveModalWidget();
 
-    QLineEdit *projectFileLineEdit = qobject_cast<QLineEdit *>(GTWidget::findWidget(os, "projectFilePathEdit", dialog));
-    GT_CHECK(projectFileLineEdit != nullptr, "LineEdit is NULL");
     if (!projectName.isEmpty()) {
-        GTLineEdit::setText(os, projectFileLineEdit, projectName);
+        GTLineEdit::setText("projectFilePathEdit", projectName, dialog);
     }
-
-    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
+    GTUtilsDialog::clickButtonBox(dialog, QDialogButtonBox::Ok);
 }
-#undef GT_METHOD_NAME
 #undef GT_CLASS_NAME
 
 }  // namespace U2
