@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EXPORT_PROJECT_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EXPORT_PROJECT_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -29,8 +28,8 @@ using namespace HI;
 
 class ExportProjectDialogFiller : public Filler {
 public:
-    ExportProjectDialogFiller(HI::GUITestOpStatus &_os, const QString &_projectName = "")
-        : Filler(_os, "ExportProjectDialog"), projectName(_projectName) {
+    ExportProjectDialogFiller(const QString& _projectName = "")
+        : Filler("ExportProjectDialog"), projectName(_projectName) {
     }
     void commonScenario();
 
@@ -40,8 +39,8 @@ private:
 
 class ExportProjectDialogChecker : public Filler {
 public:
-    ExportProjectDialogChecker(HI::GUITestOpStatus &_os, const QString &_projectName)
-        : Filler(_os, "ExportProjectDialog"), projectName(_projectName) {
+    ExportProjectDialogChecker(const QString& _projectName)
+        : Filler("ExportProjectDialog"), projectName(_projectName) {
     }
     void commonScenario();
 
@@ -50,5 +49,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
