@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_SEQUENCE_READING_MODE_SELECTOR_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_SEQUENCE_READING_MODE_SELECTOR_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
@@ -28,17 +27,23 @@ namespace U2 {
 using namespace HI;
 class SequenceReadingModeSelectorDialogFiller : public Filler {
 public:
-    enum ReadingMode { Separate,
-                       Merge,
-                       Join,
-                       Align };
+    enum ReadingMode {
+        /** Opens as separate sequences. */
+        Separate,
+        /** Merges sequences into a single sequence. */
+        Merge,
+        /** Joins sequences into an alignment. */
+        Join,
+        /** Aligns sequences to a reference. */
+        Align
+    };
 
-    SequenceReadingModeSelectorDialogFiller(HI::GUITestOpStatus &_os, ReadingMode _mode = Separate, int _bases = 10, bool cancel = false)
-        : Filler(_os, "SequenceReadingModeSelectorDialog"), readingMode(_mode), bases(_bases), cancel(cancel) {
+    SequenceReadingModeSelectorDialogFiller(ReadingMode _mode = Separate, int _bases = 10, bool cancel = false)
+        : Filler("SequenceReadingModeSelectorDialog"), readingMode(_mode), bases(_bases), cancel(cancel) {
     }
-    SequenceReadingModeSelectorDialogFiller(HI::GUITestOpStatus &_os, CustomScenario *c);
+    SequenceReadingModeSelectorDialogFiller(CustomScenario* c);
 
-    virtual void commonScenario();
+    void commonScenario() override;
 
 private:
     ReadingMode readingMode;
@@ -46,5 +51,3 @@ private:
     bool cancel;
 };
 }  // namespace U2
-
-#endif
