@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GUITESTRUNNER_H
-#define GUITESTRUNNER_H
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -34,23 +33,21 @@ class GUITestRunner : public QWidget, public Ui_GUITestRunner {
     Q_OBJECT
 
 public:
-    explicit GUITestRunner(UGUITestBase *guiTestBase, QWidget *parent = 0);
+    explicit GUITestRunner(UGUITestBase* guiTestBase, QWidget* parent = 0);
     ~GUITestRunner();
 
 private slots:
     void sl_runSelected();
     void sl_runAllGUITests();
     void sl_testFinished();
-    void sl_filterChanged(const QString &nameFilter);
+    void sl_filterChanged(const QString& nameFilter);
     void sl_filterCleared();
 
 private:
-    void revisible(const QString &nameFilter);
+    void revisible(const QString& nameFilter);
 
-    UGUITestBase *guiTestBase;
-    QAction *delTextAction;
+    UGUITestBase* guiTestBase;
+    QAction* delTextAction;
 };
 
 }  // namespace U2
-
-#endif  // GUITESTRUNNER_H
