@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -34,8 +34,6 @@
 #include <U2Core/AppContext.h>
 #include <U2Core/Log.h>
 
-#include <U2Gui/MainWindow.h>
-
 #include "GTUtilsTaskTreeView.h"
 #include "PreliminaryActions.h"
 
@@ -49,24 +47,17 @@ PRELIMINARY_ACTION_DEFINITION(pre_action_0000) {
     // Release mouse and keyboard buttons
     // Start dialogs hang checking
 
-    GTUtilsTaskTreeView::waitTaskFinished(os);
+    qputenv("UGENE_GUI_TEST_SHUTDOWN", "0");
+    GTUtilsTaskTreeView::waitTaskFinished();
 
-#ifdef Q_OS_WIN
-    QProcess::execute("closeAllErrors.exe");  // this exe file, compiled Autoit script
-#endif
+    if (isOsWindows()) {
+        QProcess::execute("closeAllErrors.exe");  // this exe file, compiled Autoit script
+    }
 
-    GTUtilsDialog::cleanup(os, GTUtilsDialog::NoFailOnUnfinished);
-
-#ifndef Q_OS_WIN
-    GTMouseDriver::release(Qt::RightButton);
-    GTMouseDriver::release();
-    GTKeyboardDriver::keyRelease(Qt::Key_Control);
-    GTKeyboardDriver::keyRelease(Qt::Key_Shift);
-    GTKeyboardDriver::keyRelease(Qt::Key_Alt);
     uiLog.trace(QString("pre_action_0000: next keyboard modifiers are pressed before test: %1").arg(QGuiApplication::queryKeyboardModifiers()));
-#endif
-
-    GTUtilsDialog::startHangChecking(os);
+    GTUtilsDialog::cleanup();
+    GTMouseDriver::releasePressedButtons();
+    GTKeyboardDriver::releasePressedKeys();
 }
 
 PRELIMINARY_ACTION_DEFINITION(pre_action_0001) {
@@ -76,14 +67,11 @@ PRELIMINARY_ACTION_DEFINITION(pre_action_0001) {
 
 PRELIMINARY_ACTION_DEFINITION(pre_action_0002) {
     // Maximize the main window
-
-    Q_UNUSED(os);
-    QMainWindow *mainWindow = AppContext::getMainWindow()->getQMainWindow();
+    QMainWindow* mainWindow = AppContext::getMainWindow()->getQMainWindow();
     CHECK_SET_ERR(mainWindow != nullptr, "main window is NULL");
 
     if (!mainWindow->isMaximized()) {
-        GTWidget::showMaximized(os, mainWindow);
-        GTGlobals::sleep(1000);
+        GTWidget::showMaximized(mainWindow);
     }
 }
 
@@ -94,22 +82,23 @@ PRELIMINARY_ACTION_DEFINITION(pre_action_0003) {
     }
     // Backup some files used in tests directly.
     if (QDir(testDir).exists()) {
-        GTFile::backup(os, testDir + "_common_data/scenarios/project/proj1.uprj");
-        GTFile::backup(os, testDir + "_common_data/scenarios/project/proj2-1.uprj");
-        GTFile::backup(os, testDir + "_common_data/scenarios/project/proj2.uprj");
-        GTFile::backup(os, testDir + "_common_data/scenarios/project/proj3.uprj");
-        GTFile::backup(os, testDir + "_common_data/scenarios/project/proj4.uprj");
-        GTFile::backup(os, testDir + "_common_data/scenarios/project/proj5.uprj");
+        GTFile::backup(testDir + "_common_data/scenarios/project/proj1.uprj");
+        GTFile::backup(testDir + "_common_data/scenarios/project/proj2-1.uprj");
+        GTFile::backup(testDir + "_common_data/scenarios/project/proj2.uprj");
+        GTFile::backup(testDir + "_common_data/scenarios/project/proj3.uprj");
+        GTFile::backup(testDir + "_common_data/scenarios/project/proj4.uprj");
+        GTFile::backup(testDir + "_common_data/scenarios/project/proj5.uprj");
 
         // Files from the projects above.
-        GTFile::backup(os, testDir + "_common_data/scenarios/project/1.gb");
+        GTFile::backup(testDir + "_common_data/scenarios/project/1.gb");
+
+        GTFile::backup(dataDir + "workflow_samples/NGS/consensus.uwl");
     }
 }
 
 PRELIMINARY_ACTION_DEFINITION(pre_action_0004) {
     // create a directory for screenshots
 
-    Q_UNUSED(os);
     QDir dir(QDir().absoluteFilePath(screenshotDir));
     if (!dir.exists(dir.absoluteFilePath(screenshotDir))) {
         dir.mkpath(dir.path());
@@ -117,13 +106,13 @@ PRELIMINARY_ACTION_DEFINITION(pre_action_0004) {
 }
 
 PRELIMINARY_ACTION_DEFINITION(pre_action_0005) {
-    // Click somewhere to the main window in mac to be sure that the focus is on the application
+    // Click somewhere to the main window on Mac or Windows to be sure that the focus is on the application
 
-    QMainWindow *mw = AppContext::getMainWindow()->getQMainWindow();
+    QMainWindow* mw = AppContext::getMainWindow()->getQMainWindow();
     CHECK_SET_ERR(mw != nullptr, "main window is NULL");
-#ifdef Q_OS_DARWIN
-    GTWidget::click(os, mw, Qt::LeftButton, QPoint(200, 200));
-#endif
+    if (isOsMac() || isOsWindows()) {
+        GTWidget::click(mw, Qt::LeftButton, QPoint(200, 200));
+    }
 }
 
 }  // namespace GUITest_preliminary_actions
