@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PRELIMINARY_ACTIONS_H_
-#define _U2_PRELIMINARY_ACTIONS_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -34,16 +33,14 @@ namespace GUITest_preliminary_actions {
 #define GUI_TEST_SUITE "GUITest_preliminary_actions"
 
 // 'Pre action' do some actions that are needed to prepare UGENE for testing
-GUI_TEST_CLASS_DECLARATION(pre_action_0000)
-GUI_TEST_CLASS_DECLARATION(pre_action_0001)
-GUI_TEST_CLASS_DECLARATION(pre_action_0002)
-GUI_TEST_CLASS_DECLARATION(pre_action_0003)
-GUI_TEST_CLASS_DECLARATION(pre_action_0004)
-GUI_TEST_CLASS_DECLARATION(pre_action_0005)
+PRELIMINARY_ACTION_DECLARATION(pre_action_0000)
+PRELIMINARY_ACTION_DECLARATION(pre_action_0001)
+PRELIMINARY_ACTION_DECLARATION(pre_action_0002)
+PRELIMINARY_ACTION_DECLARATION(pre_action_0003)
+PRELIMINARY_ACTION_DECLARATION(pre_action_0004)
+PRELIMINARY_ACTION_DECLARATION(pre_action_0005)
 
 #undef GUI_TEST_SUITE
 
 }  // namespace GUITest_preliminary_actions
 }  // namespace U2
-
-#endif  // _U2_PRELIMINARY_ACTIONS_H_
