@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,8 +20,7 @@ k
  * MA 02110-1301, USA.
  */
 
-#ifndef U2_GUITEST_ASSEMBLY_BROWSER_H_
-#define U2_GUITEST_ASSEMBLY_BROWSER_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -63,10 +62,9 @@ GUI_TEST_CLASS_DECLARATION(test_0034)
 GUI_TEST_CLASS_DECLARATION(test_0035)
 GUI_TEST_CLASS_DECLARATION(test_0036)
 GUI_TEST_CLASS_DECLARATION(test_0037)
+GUI_TEST_CLASS_DECLARATION(test_0038)
 
 #undef GUI_TEST_SUITE
 }  // namespace GUITest_Assembly_browser
 
 }  // namespace U2
-
-#endif  // GTTESTSMSAEDITOR_H
