@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_TESTS_ANNOTATIONS_QUALIFIERS_H_
-#define _U2_GT_TESTS_ANNOTATIONS_QUALIFIERS_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -40,8 +39,6 @@ GUI_TEST_CLASS_DECLARATION(test_0003)
 GUI_TEST_CLASS_DECLARATION(test_0003_1)
 GUI_TEST_CLASS_DECLARATION(test_0003_2)
 GUI_TEST_CLASS_DECLARATION(test_0004)
-GUI_TEST_CLASS_DECLARATION(test_0004_1)
-GUI_TEST_CLASS_DECLARATION(test_0004_2)
 GUI_TEST_CLASS_DECLARATION(test_0005)
 GUI_TEST_CLASS_DECLARATION(test_0005_1)
 GUI_TEST_CLASS_DECLARATION(test_0005_2)
@@ -56,5 +53,3 @@ GUI_TEST_CLASS_DECLARATION(test_0009)
 }  // namespace GUITest_common_scenarios_annotations_qualifiers
 
 }  // namespace U2
-
-#endif  // GTTESTSMSAEDITOR_H
