@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_TESTS_DOCUMENT_FROM_TEXT_H_
-#define _U2_GT_TESTS_DOCUMENT_FROM_TEXT_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -84,5 +83,3 @@ GUI_TEST_CLASS_DECLARATION(test_0019)
 }  // namespace GUITest_common_scenarios_document_from_text
 
 }  // namespace U2
-
-#endif  // GTTESTSDOCUMENTFROMTEXT_H
