@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GTTESTSMSAEDITOR_H
-#define GTTESTSMSAEDITOR_H
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -56,15 +55,9 @@ GUI_TEST_CLASS_DECLARATION(test_0006_1)
 GUI_TEST_CLASS_DECLARATION(test_0006_2)
 
 GUI_TEST_CLASS_DECLARATION(test_0007)
-GUI_TEST_CLASS_DECLARATION(test_0007_1)
-GUI_TEST_CLASS_DECLARATION(test_0007_2)
-GUI_TEST_CLASS_DECLARATION(test_0007_3)
-GUI_TEST_CLASS_DECLARATION(test_0007_4)
 
 GUI_TEST_CLASS_DECLARATION(test_0008)
 GUI_TEST_CLASS_DECLARATION(test_0008_1)
-GUI_TEST_CLASS_DECLARATION(test_0008_2)
-GUI_TEST_CLASS_DECLARATION(test_0008_3)
 
 GUI_TEST_CLASS_DECLARATION(test_0009)
 GUI_TEST_CLASS_DECLARATION(test_0009_1)
@@ -93,8 +86,6 @@ GUI_TEST_CLASS_DECLARATION(test_0015_1)
 GUI_TEST_CLASS_DECLARATION(test_0015_2)
 
 GUI_TEST_CLASS_DECLARATION(test_0016)
-GUI_TEST_CLASS_DECLARATION(test_0016_1)
-GUI_TEST_CLASS_DECLARATION(test_0016_2)
 
 GUI_TEST_CLASS_DECLARATION(test_0017)
 GUI_TEST_CLASS_DECLARATION(test_0017_1)
@@ -261,5 +252,3 @@ GUI_TEST_CLASS_DECLARATION(test_0096)
 }  // namespace GUITest_common_scenarios_msa_editor
 
 }  // namespace U2
-
-#endif  // GTTESTSMSAEDITOR_H
