@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,8 +20,7 @@ k
  * MA 02110-1301, USA.
  */
 
-#ifndef GTTESTS_MSA_EDITOR_CONSENSUS_H_
-#define GTTESTS_MSA_EDITOR_CONSENSUS_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -32,19 +31,15 @@ namespace GUITest_common_scenarios_msa_editor_consensus {
 #define GUI_TEST_SUITE "GUITest_common_scenarios_msa_editor_consensus"
 
 GUI_TEST_CLASS_DECLARATION(test_0001)
-
 GUI_TEST_CLASS_DECLARATION(test_0002)
 GUI_TEST_CLASS_DECLARATION(test_0002_1)
 GUI_TEST_CLASS_DECLARATION(test_0002_2)
-
 GUI_TEST_CLASS_DECLARATION(test_0003)
 GUI_TEST_CLASS_DECLARATION(test_0003_1)
 GUI_TEST_CLASS_DECLARATION(test_0003_2)
-
 GUI_TEST_CLASS_DECLARATION(test_0004)
 GUI_TEST_CLASS_DECLARATION(test_0004_1)
 GUI_TEST_CLASS_DECLARATION(test_0004_2)
-
 GUI_TEST_CLASS_DECLARATION(test_0005)
 GUI_TEST_CLASS_DECLARATION(test_0006)
 
@@ -52,5 +47,3 @@ GUI_TEST_CLASS_DECLARATION(test_0006)
 }  // namespace GUITest_common_scenarios_msa_editor_consensus
 
 }  // namespace U2
-
-#endif  // GTTESTS_MSA_EDITOR_CONSENSUS_H_
