@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _GTTESTS_IN_SILICO_PCR_H_
-#define _GTTESTS_IN_SILICO_PCR_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -47,8 +46,10 @@ GUI_TEST_CLASS_DECLARATION(test_0014)
 GUI_TEST_CLASS_DECLARATION(test_0015)
 GUI_TEST_CLASS_DECLARATION(test_0016)
 GUI_TEST_CLASS_DECLARATION(test_0017)
+GUI_TEST_CLASS_DECLARATION(test_0018)
+GUI_TEST_CLASS_DECLARATION(test_0019)
+GUI_TEST_CLASS_DECLARATION(test_0020)
+GUI_TEST_CLASS_DECLARATION(test_0021)
 
 }  // namespace GUITest_common_scenarios_in_silico_pcr
 }  // namespace U2
-
-#endif  // _GTTESTS_IN_SILICO_PCR_H_
