@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,46 +21,50 @@
 
 #include <GTGlobals.h>
 #include <base_dialogs/GTFileDialog.h>
+#include <primitives/GTComboBox.h>
+#include <primitives/GTLabel.h>
 #include <primitives/GTMenu.h>
 #include <primitives/GTTreeWidget.h>
 
 #include <QDir>
 
 #include <U2View/AnnotatedDNAViewFactory.h>
+#include <U2View/AnnotationsTreeView.h>
 #include <U2View/MaEditorFactory.h>
 
 #include "GTTestsProjectRemoteRequest.h"
+#include "GTUtilsAnnotationsTreeView.h"
 #include "GTUtilsDocument.h"
 #include "GTUtilsMdi.h"
+#include "GTUtilsNotifications.h"
 #include "GTUtilsProjectTreeView.h"
 #include "GTUtilsSequenceView.h"
 #include "GTUtilsTaskTreeView.h"
 #include "GTUtilsWorkflowDesigner.h"
 #include "runnables/ugene/corelibs/U2Gui/DownloadRemoteFileDialogFiller.h"
+#include "runnables/ugene/plugins/dna_export/GetSequenceByIdFiller.h"
 #include "runnables/ugene/ugeneui/DocumentFormatSelectorDialogFiller.h"
 #include "runnables/ugene/ugeneui/NCBISearchDialogFiller.h"
+
 namespace U2 {
 
 namespace GUITest_common_scenarios_project_remote_request {
 
 GUI_TEST_CLASS_DEFINITION(test_0001) {
-    GTUtilsTaskTreeView::openView(os);
+    GTUtilsTaskTreeView::openView();
 
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "3EZB", 3));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...",
-                              GTGlobals::UseKey);
-    GTUtilsTaskTreeView::cancelTask(os, "Download remote documents");
-    GTUtilsTaskTreeView::waitTaskFinished(os);
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("3EZB", 3));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::cancelTask("Download remote documents");
+    GTUtilsTaskTreeView::waitTaskFinished();
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0002) {
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "NC_001363", 0));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...");
-    GTUtilsSequenceView::checkSequenceViewWindowIsActive(os);
-    GTUtilsDocument::isDocumentLoaded(os, "NC_001363.gb");
-    GTUtilsDocument::checkDocument(os, "NC_001363.gb", AnnotatedDNAViewFactory::ID);
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("NC_001363", 0));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."});
+    GTUtilsSequenceView::checkSequenceViewWindowIsActive();
+    GTUtilsDocument::isDocumentLoaded("NC_001363.gb");
+    GTUtilsDocument::checkDocument("NC_001363.gb", AnnotatedDNAViewFactory::ID);
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0003) {
@@ -76,20 +80,19 @@ GUI_TEST_CLASS_DEFINITION(test_0003) {
     QDir().mkpath(sandBoxDir + "remote_request/test_0003");
     QList<DownloadRemoteFileDialogFiller::Action> actions;
 
-    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, QStringList() << "NC_017775");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, {"NC_017775"});
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "NCBI GenBank (DNA sequence)");
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir + "remote_request/test_0003");
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetForceSequenceDownload, false);
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
 
-    GTUtilsDialog::waitForDialog(os, new DownloadRemoteFileDialogFiller(os, actions));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...");
-    GTUtilsTaskTreeView::waitTaskFinished(os);
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."});
+    GTUtilsTaskTreeView::waitTaskFinished();
 
     QSet<GObjectType> acceptableTypes;
     acceptableTypes.insert(GObjectTypes::ANNOTATION_TABLE);
-    GTUtilsProjectTreeView::checkObjectTypes(os, acceptableTypes, GTUtilsProjectTreeView::findIndex(os, "NC_017775.gb"));
+    GTUtilsProjectTreeView::checkObjectTypes(acceptableTypes, GTUtilsProjectTreeView::findIndex("NC_017775.gb"));
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0004) {
@@ -105,19 +108,18 @@ GUI_TEST_CLASS_DEFINITION(test_0004) {
     QDir().mkpath(sandBoxDir + "remote_request/test_0004");
     QList<DownloadRemoteFileDialogFiller::Action> actions;
 
-    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, QStringList() << "NC_017775");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, {"NC_017775"});
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "NCBI GenBank (DNA sequence)");
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir + "remote_request/test_0004");
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetForceSequenceDownload, true);
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
 
-    GTUtilsDialog::waitForDialog(os, new DownloadRemoteFileDialogFiller(os, actions));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...");
-    GTUtilsTaskTreeView::waitTaskFinished(os);
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."});
+    GTUtilsTaskTreeView::waitTaskFinished();
 
-    GTUtilsDocument::isDocumentLoaded(os, "NC_017775.gb");
-    GTUtilsDocument::checkDocument(os, "NC_017775.gb", AnnotatedDNAViewFactory::ID);
+    GTUtilsDocument::isDocumentLoaded("NC_017775.gb");
+    GTUtilsDocument::checkDocument("NC_017775.gb", AnnotatedDNAViewFactory::ID);
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0005) {
@@ -130,18 +132,17 @@ GUI_TEST_CLASS_DEFINITION(test_0005) {
 
     QDir().mkpath(sandBoxDir + "remote_request/test_0005");
 
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "ENSG00000205571 ENSG00000146463", 2, true, true, false, sandBoxDir + "remote_request/test_0005"));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...");
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("ENSG00000205571 ENSG00000146463", 2, true, true, false, sandBoxDir + "remote_request/test_0005"));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."});
 
-    GTUtilsSequenceView::checkSequenceViewWindowIsActive(os);
-    GTUtilsTaskTreeView::waitTaskFinished(os);
+    GTUtilsSequenceView::checkSequenceViewWindowIsActive();
+    GTUtilsTaskTreeView::waitTaskFinished();
 
-    GTUtilsDocument::isDocumentLoaded(os, "ENSG00000205571.fa");
-    GTUtilsDocument::checkDocument(os, "ENSG00000205571.fa", AnnotatedDNAViewFactory::ID);
+    GTUtilsDocument::isDocumentLoaded("ENSG00000205571.fa");
+    GTUtilsDocument::checkDocument("ENSG00000205571.fa", AnnotatedDNAViewFactory::ID);
 
-    GTUtilsDocument::isDocumentLoaded(os, "ENSG00000146463.fa");
-    GTUtilsDocument::checkDocument(os, "ENSG00000146463.fa", AnnotatedDNAViewFactory::ID);
+    GTUtilsDocument::isDocumentLoaded("ENSG00000146463.fa");
+    GTUtilsDocument::checkDocument("ENSG00000146463.fa", AnnotatedDNAViewFactory::ID);
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0006) {
@@ -153,17 +154,16 @@ GUI_TEST_CLASS_DEFINITION(test_0006) {
     //    Expected state: after the downloading task finish a new documents appears in the project
 
     QDir().mkpath(sandBoxDir + "remote_request/test_0006");
-    GTUtilsDialog::waitForDialog(os, new DocumentFormatSelectorDialogFiller(os, "Swiss-Prot"));
+    GTUtilsDialog::waitForDialog(new DocumentFormatSelectorDialogFiller("Swiss-Prot"));
 
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "Q9IGQ6;A0N8V2", 4, true, true, false, sandBoxDir + "remote_request/test_0006"));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...");
-    GTUtilsTaskTreeView::waitTaskFinished(os);
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("Q9IGQ6;A0N8V2", 4, true, true, false, sandBoxDir + "remote_request/test_0006"));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."});
+    GTUtilsTaskTreeView::waitTaskFinished();
 
-    GTUtilsDocument::isDocumentLoaded(os, "Q9IGQ6.txt");
-    GTUtilsDocument::checkDocument(os, "Q9IGQ6.txt", AnnotatedDNAViewFactory::ID);
-    GTUtilsDocument::isDocumentLoaded(os, "A0N8V2.txt");
-    GTUtilsDocument::checkDocument(os, "A0N8V2.txt", AnnotatedDNAViewFactory::ID);
+    GTUtilsDocument::isDocumentLoaded("Q9IGQ6.txt");
+    GTUtilsDocument::checkDocument("Q9IGQ6.txt", AnnotatedDNAViewFactory::ID);
+    GTUtilsDocument::isDocumentLoaded("A0N8V2.txt");
+    GTUtilsDocument::checkDocument("A0N8V2.txt", AnnotatedDNAViewFactory::ID);
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0007) {
@@ -188,10 +188,8 @@ GUI_TEST_CLASS_DEFINITION(test_0007) {
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::CheckForceSequenceDownloadVisibility, false);
     actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickCancel, "");
 
-    GTUtilsDialog::waitForDialog(os, new DownloadRemoteFileDialogFiller(os, actions));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...",
-                              GTGlobals::UseKey);
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0008) {
@@ -225,9 +223,8 @@ GUI_TEST_CLASS_DEFINITION(test_0008) {
     searchActions << NcbiSearchDialogFiller::Action(NcbiSearchDialogFiller::ClickDownload, qVariantFromValue(downloadActions));
     searchActions << NcbiSearchDialogFiller::Action(NcbiSearchDialogFiller::ClickClose, "");
 
-    GTUtilsDialog::waitForDialog(os, new NcbiSearchDialogFiller(os, searchActions));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Search NCBI GenBank...");
+    GTUtilsDialog::waitForDialog(new NcbiSearchDialogFiller(searchActions));
+    GTMenu::clickMainMenuItem({"File", "Search NCBI GenBank..."});
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0009) {
@@ -261,9 +258,8 @@ GUI_TEST_CLASS_DEFINITION(test_0009) {
     searchActions << NcbiSearchDialogFiller::Action(NcbiSearchDialogFiller::ClickDownload, qVariantFromValue(downloadActions));
     searchActions << NcbiSearchDialogFiller::Action(NcbiSearchDialogFiller::ClickClose, "");
 
-    GTUtilsDialog::waitForDialog(os, new NcbiSearchDialogFiller(os, searchActions));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Search NCBI GenBank...");
+    GTUtilsDialog::waitForDialog(new NcbiSearchDialogFiller(searchActions));
+    GTMenu::clickMainMenuItem({"File", "Search NCBI GenBank..."});
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0010) {
@@ -281,26 +277,26 @@ GUI_TEST_CLASS_DEFINITION(test_0010) {
     //    Expected state:
     //        Resource ID(s): invisible;
     //        File with resource IDs: required, visible.
-    GTUtilsWorkflowDesigner::openWorkflowDesigner(os);
-    GTUtilsWorkflowDesigner::addAlgorithm(os, "Read Sequence from Remote Database");
-    GTUtilsWorkflowDesigner::click(os, "Read Sequence from Remote Database");
+    GTUtilsWorkflowDesigner::openWorkflowDesigner();
+    GTUtilsWorkflowDesigner::addAlgorithm("Read Sequence from Remote Database");
+    GTUtilsWorkflowDesigner::click("Read Sequence from Remote Database");
 
-    const QString database = GTUtilsWorkflowDesigner::getParameter(os, "Database");
-    const QString source = GTUtilsWorkflowDesigner::getParameter(os, "Read resource ID(s) from source");
+    const QString database = GTUtilsWorkflowDesigner::getParameter("Database");
+    const QString source = GTUtilsWorkflowDesigner::getParameter("Read resource ID(s) from source");
     CHECK_SET_ERR("NCBI GenBank (DNA sequence)" == database, QString("An unexpected default 'Database' value: expect '%1', got'%2'").arg("NCBI GenBank (DNA sequence)").arg(database));
     CHECK_SET_ERR("List of IDs" == source, QString("An unexpected default 'Read resource ID(s) from source' value: expect '%1', got'%2'").arg("List of IDs").arg(source));
 
-    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired(os, "Database"), "The 'Database' parameter is not required unexpectedly");
-    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired(os, "Read resource ID(s) from source"), "The 'Read resource ID(s) from source' parameter is not required unexpectedly");
-    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired(os, "Resource ID(s)"), "The 'Resource ID(s)' parameter is not required unexpectedly");
-    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired(os, "Save file to folder"), "The 'Save file to folder' parameter is not required unexpectedly");
-    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterVisible(os, "Resource ID(s)"), "The 'Resource ID(s)' parameter is not visible unexpectedly");
-    CHECK_SET_ERR(!GTUtilsWorkflowDesigner::isParameterVisible(os, "File with resource IDs"), "The 'File with resource IDs' parameter is visible unexpectedly");
+    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired("Database"), "The 'Database' parameter is not required unexpectedly");
+    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired("Read resource ID(s) from source"), "The 'Read resource ID(s) from source' parameter is not required unexpectedly");
+    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired("Resource ID(s)"), "The 'Resource ID(s)' parameter is not required unexpectedly");
+    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired("Save file to folder"), "The 'Save file to folder' parameter is not required unexpectedly");
+    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterVisible("Resource ID(s)"), "The 'Resource ID(s)' parameter is not visible unexpectedly");
+    CHECK_SET_ERR(!GTUtilsWorkflowDesigner::isParameterVisible("File with resource IDs"), "The 'File with resource IDs' parameter is visible unexpectedly");
 
-    GTUtilsWorkflowDesigner::setParameter(os, "Read resource ID(s) from source", 0, GTUtilsWorkflowDesigner::comboValue);
-    CHECK_SET_ERR(!GTUtilsWorkflowDesigner::isParameterVisible(os, "Resource ID(s)"), "The 'Resource ID(s)' parameter is visible unexpectedly");
-    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired(os, "File with resource IDs"), "The 'File with resource IDs' parameter is not required unexpectedly");
-    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterVisible(os, "File with resource IDs"), "The 'File with resource IDs' parameter is not visible unexpectedly");
+    GTUtilsWorkflowDesigner::setParameter("Read resource ID(s) from source", 0, GTUtilsWorkflowDesigner::comboValue);
+    CHECK_SET_ERR(!GTUtilsWorkflowDesigner::isParameterVisible("Resource ID(s)"), "The 'Resource ID(s)' parameter is visible unexpectedly");
+    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterRequired("File with resource IDs"), "The 'File with resource IDs' parameter is not required unexpectedly");
+    CHECK_SET_ERR(GTUtilsWorkflowDesigner::isParameterVisible("File with resource IDs"), "The 'File with resource IDs' parameter is not visible unexpectedly");
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0011) {
@@ -311,13 +307,11 @@ GUI_TEST_CLASS_DEFINITION(test_0011) {
     //        Open.
     //    3.  Expected state: 1ezg appears in a project view.
 
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "1ezg", 3, true, true, false, sandBoxDir));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...",
-                              GTGlobals::UseKey);
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("1ezg", 3, true, true, false, sandBoxDir));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
 
-    GTUtilsSequenceView::checkSequenceViewWindowIsActive(os);
-    GTUtilsDocument::isDocumentLoaded(os, "1ezg.pdb");
+    GTUtilsSequenceView::checkSequenceViewWindowIsActive();
+    GTUtilsDocument::isDocumentLoaded("1ezg.pdb");
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0012) {
@@ -328,20 +322,16 @@ GUI_TEST_CLASS_DEFINITION(test_0012) {
     //        Open.
     //    3.  Expected state: 1ezg doesn't appear in a project view.
 
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "1ezg", 3, false, true, false, sandBoxDir));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...",
-                              GTGlobals::UseKey);
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("1ezg", 3, false, true, false, sandBoxDir));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
 
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "1CRN", 3, true, true, false, sandBoxDir));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...",
-                              GTGlobals::UseKey);
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("1CRN", 3, true, true, false, sandBoxDir));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
 
-    GTUtilsDocument::isDocumentLoaded(os, "1CRN.pdb");
+    GTUtilsDocument::isDocumentLoaded("1CRN.pdb");
 
-    GTUtilsTaskTreeView::waitTaskFinished(os);
-    GTUtilsProjectTreeView::checkNoItem(os, "1ezg.pdb");
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsProjectTreeView::checkNoItem("1ezg.pdb");
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0013) {
@@ -355,14 +345,13 @@ GUI_TEST_CLASS_DEFINITION(test_0013) {
     QDir().mkpath(sandBoxDir + "remote_request/test_0013");
     QList<DownloadRemoteFileDialogFiller::Action> actions;
 
-    GTUtilsDialog::waitForDialog(os, new DocumentFormatSelectorDialogFiller(os, "Swiss-Prot"));
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "P16152", 5, true, true, false, sandBoxDir));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...");
-    GTUtilsTaskTreeView::waitTaskFinished(os);
+    GTUtilsDialog::waitForDialog(new DocumentFormatSelectorDialogFiller("Swiss-Prot"));
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("P16152", 5, true, true, false, sandBoxDir));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."});
+    GTUtilsTaskTreeView::waitTaskFinished();
 
-    GTUtilsDocument::isDocumentLoaded(os, "P16152.txt");
-    GTUtilsDocument::checkDocument(os, "P16152.txt", AnnotatedDNAViewFactory::ID);
+    GTUtilsDocument::isDocumentLoaded("P16152.txt");
+    GTUtilsDocument::checkDocument("P16152.txt", AnnotatedDNAViewFactory::ID);
 }
 GUI_TEST_CLASS_DEFINITION(test_0014) {
     //    1. Select {File -> Access remote database} menu item in the main menu.
@@ -373,15 +362,179 @@ GUI_TEST_CLASS_DEFINITION(test_0014) {
     //    Expected state: after the downloading task finish a new documents appears in the project
 
     QDir().mkpath(sandBoxDir + "remote_request/test_0014");
-    GTUtilsDialog::waitForDialog(os, new DocumentFormatSelectorDialogFiller(os, "Swiss-Prot"));
+    GTUtilsDialog::waitForDialog(new DocumentFormatSelectorDialogFiller("Swiss-Prot"));
 
-    GTUtilsDialog::waitForDialog(os, new RemoteDBDialogFillerDeprecated(os, "D0VTW9", 6, true, true, false, sandBoxDir));
-    GTMenu::clickMainMenuItem(os, QStringList() << "File"
-                                                << "Access remote database...");
-    GTUtilsTaskTreeView::waitTaskFinished(os);
+    GTUtilsDialog::waitForDialog(new RemoteDBDialogFillerDeprecated("D0VTW9", 6, true, true, false, sandBoxDir));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."});
+    GTUtilsTaskTreeView::waitTaskFinished();
 
-    GTUtilsDocument::isDocumentLoaded(os, "D0VTW9.txt");
-    GTUtilsDocument::checkDocument(os, "D0VTW9.txt", AnnotatedDNAViewFactory::ID);
+    GTUtilsDocument::isDocumentLoaded("D0VTW9.txt");
+    GTUtilsDocument::checkDocument("D0VTW9.txt", AnnotatedDNAViewFactory::ID);
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0015) {
+    GTUtilsTaskTreeView::openView();
+
+    class CheckLinks : public CustomScenario {
+        void run() override {
+            QWidget* dialog = GTWidget::getActiveModalWidget();
+
+            static const QMap<QString, QString> DATABASE_LINK_MAP = {{"NCBI GenBank (DNA sequence)", "https://www.ncbi.nlm.nih.gov/nucleotide"},
+                                                                     {"NCBI protein sequence database", "https://www.ncbi.nlm.nih.gov/protein"},
+                                                                     {"ENSEMBL", "https://www.ensembl.org"},
+                                                                     {"PDB", "https://www.rcsb.org"},
+                                                                     {"SWISS-PROT", "https://www.uniprot.org"},
+                                                                     {"UniProtKB/Swiss-Prot", "https://www.uniprot.org"},
+                                                                     {"UniProtKB/TrEMBL", "https://www.uniprot.org"}};
+
+            auto dbs = GTComboBox::getValues(GTWidget::findComboBox("databasesBox", dialog));
+            CHECK_SET_ERR(dbs.size() == DATABASE_LINK_MAP.size(), "Unexpected DBs size");
+
+            for (const auto& db : qAsConst(dbs)) {
+                const auto& link = DATABASE_LINK_MAP.value(db);
+                CHECK_SET_ERR(!link.isEmpty(), QString("Unexpected db: %1").arg(db));
+
+                GTComboBox::selectItemByText("databasesBox", dialog, db);
+                auto text = GTLabel::getText("lbExternalLink", dialog);
+                CHECK_SET_ERR(text.contains(link), QString("The %1 has no link, text: %2").arg(db).arg(text));
+            }
+
+            GTUtilsDialog::clickButtonBox(QDialogButtonBox::Cancel);
+        }
+    };
+
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(new CheckLinks));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0016_1) {
+    QList<DownloadRemoteFileDialogFiller::Action> actions;
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "NCBI GenBank (DNA sequence)");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, "NC_001363");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir);
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
+
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.ncbi.nlm.nih.gov/nucleotide/NC_001363?report=genbank");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0016_2) {
+    QList<DownloadRemoteFileDialogFiller::Action> actions;
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "NCBI protein sequence database");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, "AAA59172.1");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir);
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
+
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.ncbi.nlm.nih.gov/protein/AAA59172.1?report=genbank");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0016_3) {
+    QList<DownloadRemoteFileDialogFiller::Action> actions;
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "ENSEMBL");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, "ENSG00000205571");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir);
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
+
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.ensembl.org/id/ENSG00000205571");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0016_4) {
+    QList<DownloadRemoteFileDialogFiller::Action> actions;
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "PDB");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, "3INS");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir);
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
+
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.rcsb.org/structure/3INS");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0016_5) {
+    QList<DownloadRemoteFileDialogFiller::Action> actions;
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "SWISS-PROT");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, "Q9IGQ6");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir);
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
+
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTUtilsDialog::add(new DocumentFormatSelectorDialogFiller("Swiss-Prot"));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.uniprot.org/uniprotkb/Q9IGQ6/entry");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0016_6) {
+    QList<DownloadRemoteFileDialogFiller::Action> actions;
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "UniProtKB/Swiss-Prot");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, "P16152");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir);
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
+
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTUtilsDialog::add(new DocumentFormatSelectorDialogFiller("Swiss-Prot"));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.uniprot.org/uniprotkb/P16152/entry");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0016_7) {
+    QList<DownloadRemoteFileDialogFiller::Action> actions;
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "UniProtKB/TrEMBL");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, "D0VTW9");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::EnterSaveToDirectoryPath, sandBoxDir);
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
+
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTUtilsDialog::add(new DocumentFormatSelectorDialogFiller("Swiss-Prot"));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.uniprot.org/uniprotkb/D0VTW9/entry");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0017) {
+    GTFileDialog::openFile(testDir + "_common_data/genbank/murine_cut.gb");
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsAnnotationsTreeView::expandItem("CDS");
+    GTTreeWidget::click(GTUtilsAnnotationsTreeView::findItem("db_xref"), AnnotationsTreeView::COLUMN_VALUE);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.uniprot.org/uniprotkb/P03334/entry");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0018) {
+    GTFileDialog::openFile(dataDir + "samples/Genbank/murine.gb");
+    GTUtilsTaskTreeView::waitTaskFinished();
+
+    GTUtilsSequenceView::clickAnnotationPan("CDS", 1042);
+    GTUtilsDialog::waitForDialog(new GetSequenceByIdFiller(sandBoxDir, true));
+    GTUtilsDialog::waitForDialog(new PopupChooserByText({"Fetch sequences from remote database",
+                                                         "Fetch sequences by 'db_xref' from 'CDS'"}));
+    GTMenu::showContextMenu(GTUtilsSequenceView::getPanOrDetView());
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText("https://www.uniprot.org/uniprotkb/P03334/entry");
+}
+
+GUI_TEST_CLASS_DEFINITION(test_0019) {
+    QList<DownloadRemoteFileDialogFiller::Action> actions;
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetDatabase, "NCBI GenBank (DNA sequence)");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::SetResourceIds, "qwerty,NC_001363");
+    actions << DownloadRemoteFileDialogFiller::Action(DownloadRemoteFileDialogFiller::ClickOk, "");
+
+    // GTUtilsNotifications::waitForNotification(false, "Failed to download");
+    GTUtilsDialog::waitForDialog(new DownloadRemoteFileDialogFiller(actions));
+    GTMenu::clickMainMenuItem({"File", "Access remote database..."}, GTGlobals::UseKey);
+    GTUtilsTaskTreeView::waitTaskFinished();
+    GTUtilsNotifications::checkNotificationReportText({"Failed to download",
+                                                       "https://www.ncbi.nlm.nih.gov/nucleotide/NC_001363?report=genbank"});
 }
 
 }  // namespace GUITest_common_scenarios_project_remote_request
