@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUI_TEST_SEQUENCE_SELECTION_H_
-#define _U2_GUI_TEST_SEQUENCE_SELECTION_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -47,5 +46,3 @@ GUI_TEST_CLASS_DECLARATION(one_click_test_0005)
 }  // namespace GUITest_common_scenarios_sequence_selection
 
 }  // namespace U2
-
-#endif
