@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GUI_TEST_SEQUENCE_VIEW_H_
-#define _U2_GUI_TEST_SEQUENCE_VIEW_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -47,7 +46,6 @@ GUI_TEST_CLASS_DECLARATION(test_0018)
 
 GUI_TEST_CLASS_DECLARATION(test_0021)
 GUI_TEST_CLASS_DECLARATION(test_0022)
-GUI_TEST_CLASS_DECLARATION(test_0023)
 GUI_TEST_CLASS_DECLARATION(test_0024)
 GUI_TEST_CLASS_DECLARATION(test_0025)
 GUI_TEST_CLASS_DECLARATION(test_0026)
@@ -110,10 +108,16 @@ GUI_TEST_CLASS_DECLARATION(test_0075)
 GUI_TEST_CLASS_DECLARATION(test_0076)
 GUI_TEST_CLASS_DECLARATION(test_0077)
 GUI_TEST_CLASS_DECLARATION(test_0078)
+GUI_TEST_CLASS_DECLARATION(test_0079_1)
+GUI_TEST_CLASS_DECLARATION(test_0079_2)
+GUI_TEST_CLASS_DECLARATION(test_0080)
+GUI_TEST_CLASS_DECLARATION(test_0081)
+GUI_TEST_CLASS_DECLARATION(test_0082)
+GUI_TEST_CLASS_DECLARATION(test_0083)
+GUI_TEST_CLASS_DECLARATION(test_0084)
+GUI_TEST_CLASS_DECLARATION(test_0085)
 
 #undef GUI_TEST_SUITE
 }  // namespace GUITest_common_scenarios_sequence_view
 
 }  // namespace U2
-
-#endif
