@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2018 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_TESTS_WORKFLOW_DASHBOARD_H_
-#define _U2_GT_TESTS_WORKFLOW_DASHBOARD_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -35,7 +34,6 @@ GUI_TEST_CLASS_DECLARATION(misc_test_0002)
 GUI_TEST_CLASS_DECLARATION(misc_test_0003)
 GUI_TEST_CLASS_DECLARATION(misc_test_0004)
 
-GUI_TEST_CLASS_DECLARATION(tree_nodes_creation_test_0001)
 GUI_TEST_CLASS_DECLARATION(tree_nodes_creation_test_0002)
 GUI_TEST_CLASS_DECLARATION(tree_nodes_creation_test_0003)
 GUI_TEST_CLASS_DECLARATION(tree_nodes_creation_test_0004)
@@ -53,7 +51,6 @@ GUI_TEST_CLASS_DECLARATION(tool_launch_nodes_test_0010)
 GUI_TEST_CLASS_DECLARATION(tool_launch_nodes_test_0011)
 GUI_TEST_CLASS_DECLARATION(tool_launch_nodes_test_0012)
 GUI_TEST_CLASS_DECLARATION(tool_launch_nodes_test_0013)
-GUI_TEST_CLASS_DECLARATION(tool_launch_nodes_test_0014)
 GUI_TEST_CLASS_DECLARATION(tool_launch_nodes_test_0015)
 GUI_TEST_CLASS_DECLARATION(tool_launch_nodes_test_0016)
 GUI_TEST_CLASS_DECLARATION(tool_launch_nodes_test_0017)
@@ -77,5 +74,3 @@ GUI_TEST_CLASS_DECLARATION(output_dir_scanning_test_0008)
 }  // namespace GUITest_common_scenarios_workflow_dashboard
 
 }  // namespace U2
-
-#endif  // _U2_GT_TESTS_WORKFLOW_DASHBOARD_H_
