@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -39,35 +39,35 @@ using namespace HI;
 GUI_TEST_CLASS_DEFINITION(test_0001) {
     // 1. Open WD.
     // 2. Open any NGS pipeline, e.g. Call Variants.
-    GTUtilsWorkflowDesigner::openWorkflowDesigner(os);
-    GTUtilsWorkflowDesigner::addSample(os, "Call variants with SAMtools");
+    GTUtilsWorkflowDesigner::openWorkflowDesigner();
+    GTUtilsWorkflowDesigner::addSample("Call variants with SAMtools");
     GTKeyboardDriver::keyClick(Qt::Key_Escape);
 
     // 3. Click an "Estimate scheme" button on the toolbar.
     // Expected state: a warning message box appears: user should fix all errors.
-    GTUtilsDialog::waitForDialog(os, new MessageBoxDialogFiller(os, QMessageBox::Ok, "Please fix issues listed in the error list (located under workflow)."));
-    GTWidget::click(os, GTAction::button(os, "Estimate workflow"));
+    GTUtilsDialog::waitForDialog(new MessageBoxDialogFiller(QMessageBox::Ok, "Please fix issues listed in the error list (located under workflow)."));
+    GTWidget::click(GTAction::button("Estimate workflow"));
 }
 
 GUI_TEST_CLASS_DEFINITION(test_0002) {
     // 1. Open WD.
     // 2. Open any NGS pipeline, e.g. Call Variants.
-    GTUtilsWorkflowDesigner::openWorkflowDesigner(os);
-    GTUtilsWorkflowDesigner::addSample(os, "Call variants with SAMtools");
+    GTUtilsWorkflowDesigner::openWorkflowDesigner();
+    GTUtilsWorkflowDesigner::addSample("Call variants with SAMtools");
     GTKeyboardDriver::keyClick(Qt::Key_Escape);
 
     //    3. Set valid input data.
-    GTMouseDriver::moveTo(GTUtilsWorkflowDesigner::getItemCenter(os, "Read Assembly (BAM/SAM)"));
+    GTMouseDriver::moveTo(GTUtilsWorkflowDesigner::getItemCenter("Read Assembly (BAM/SAM)"));
     GTMouseDriver::click();
-    GTUtilsWorkflowDesigner::setDatasetInputFile(os, testDir + "_common_data/bam/accepted_hits_with_gaps.bam");
+    GTUtilsWorkflowDesigner::setDatasetInputFile(testDir + "_common_data/bam/accepted_hits_with_gaps.bam");
 
-    GTMouseDriver::moveTo(GTUtilsWorkflowDesigner::getItemCenter(os, "Read Sequence"));
+    GTMouseDriver::moveTo(GTUtilsWorkflowDesigner::getItemCenter("Read Sequence"));
     GTMouseDriver::click();
-    GTUtilsWorkflowDesigner::setDatasetInputFile(os, testDir + "_common_data/fasta/reference_ACGT_rand_1000.fa");
+    GTUtilsWorkflowDesigner::setDatasetInputFile(testDir + "_common_data/fasta/reference_ACGT_rand_1000.fa");
     //    4. Click an "Estimate scheme" button on the toolbar.
     //    Expected state: an info message box appears: there is a time estimation for the set input data and two buttons: close and run.
-    GTUtilsDialog::waitForDialog(os, new MessageBoxDialogFiller(os, QMessageBox::Close, "Approximate estimation time of the workflow run is"));
-    GTWidget::click(os, GTAction::button(os, "Estimate workflow"));
+    GTUtilsDialog::waitForDialog(new MessageBoxDialogFiller(QMessageBox::Close, "Approximate estimation time of the workflow run is"));
+    GTWidget::click(GTAction::button("Estimate workflow"));
 }
 
 }  // namespace GUITest_common_scenarios_workflow_estimating
