@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,8 +20,7 @@ k
  * MA 02110-1301, USA.
  */
 
-#ifndef GTTESTS_WORKFLOW_NAME_FILTER_H_
-#define GTTESTS_WORKFLOW_NAME_FILTER_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -39,5 +38,3 @@ GUI_TEST_CLASS_DECLARATION(test_0003)
 }  // namespace GUITest_common_scenarios_workflow_name_filter
 
 }  // namespace U2
-
-#endif  // GTTESTS_WORKFLOW_NAME_FILTER_H_
