@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,8 +20,7 @@ k
  * MA 02110-1301, USA.
  */
 
-#ifndef _GTTESTS_WORKFLOW_SCRIPTING_H_
-#define _GTTESTS_WORKFLOW_SCRIPTING_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
 
@@ -40,5 +39,3 @@ GUI_TEST_CLASS_DECLARATION(test_0004)
 
 }  // namespace GUITest_common_scenarios_workflow_scripting
 }  // namespace U2
-
-#endif  // _GTTESTS_WORKFLOW_SCRIPTING_H_
