@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -38,31 +38,31 @@ int randInt(int low, int high) {
     return qrand() % ((high + 1) - low) + low;
 }
 
-GTAbstractGUIAction *GTRandomGUIActionFactory::create(QObject *obj) {
-    SAFE_POINT(nullptr != obj, "", nullptr);
+GTAbstractGUIAction* GTRandomGUIActionFactory::create(QObject* obj) {
+    SAFE_POINT(obj != nullptr, "", nullptr);
 
-    GTAbstractGUIAction *action = nullptr;
-    for (const QMetaObject *metaObj = obj->metaObject(); metaObj != nullptr; metaObj = metaObj->superClass()) {
+    GTAbstractGUIAction* action = nullptr;
+    for (const QMetaObject* metaObj = obj->metaObject(); metaObj != nullptr; metaObj = metaObj->superClass()) {
         QString className = metaObj->className();
         uiLog.trace(QString("Searching GTAbstractGUIAction for %1").arg(className));
 
         GTAbstractGUIActionMap::const_iterator mappedIterator = actionMap.constFind(className);
-        const GTAbstractGUIAction *mappedAction = actionMap.constEnd() == mappedIterator ? nullptr : actionMap[className];
-        if (nullptr != mappedAction) {
+        const GTAbstractGUIAction* mappedAction = actionMap.constEnd() == mappedIterator ? nullptr : actionMap[className];
+        if (mappedAction != nullptr) {
             uiLog.trace(QString("Found GUIAction for %1").arg(className));
             action = mappedAction->clone();
             action->init(obj);
             break;
         }
     }
-    if (nullptr == action) {
+    if (action == nullptr) {
         uiLog.trace("Not found GUIAction");
     }
     uiLog.trace("-----------------------");
     return action;
 }
 
-QMap<QString, const GTAbstractGUIAction *> GTRandomGUIActionFactory::actionMap;
+QMap<QString, const GTAbstractGUIAction*> GTRandomGUIActionFactory::actionMap;
 
 class GTAbstractGUIAction_QWidget : public GTAbstractGUIAction {
 public:
@@ -70,13 +70,13 @@ public:
         : GTAbstractGUIAction(priority) {
     }
     virtual void run() {
-        QWidget *objCasted = qobject_cast<QWidget *>(obj);
-        SAFE_POINT(nullptr != objCasted, "", );
+        auto objCasted = qobject_cast<QWidget*>(obj);
+        SAFE_POINT(objCasted != nullptr, "", );
 
-        GTWidget::click(os, objCasted);
+        GTWidget::click(objCasted);
     }
 
-    virtual GTAbstractGUIAction_QWidget *clone() const {
+    virtual GTAbstractGUIAction_QWidget* clone() const {
         return new GTAbstractGUIAction_QWidget(*this);
     }
 };
@@ -88,8 +88,8 @@ public:
         : GTAbstractGUIAction(priority) {
     }
     virtual void run() {
-        QFileDialog *objCasted = qobject_cast<QFileDialog *>(obj);
-        SAFE_POINT(nullptr != objCasted, "", );
+        auto objCasted = qobject_cast<QFileDialog*>(obj);
+        SAFE_POINT(objCasted != nullptr, "", );
 
         QString findPath = UGUITest::dataDir;
         QDir dir(findPath);
@@ -106,11 +106,11 @@ public:
         int filesListId = randInt(0, files.size() - 1);
         QString randomFilePath = files[filesListId];
 
-        GTFileDialogUtils *u = new GTFileDialogUtils(os, randomFilePath);
+        GTFileDialogUtils* u = new GTFileDialogUtils(randomFilePath);
         u->run();
     }
 
-    virtual GTAbstractGUIAction_QFileDialog *clone() const {
+    virtual GTAbstractGUIAction_QFileDialog* clone() const {
         return new GTAbstractGUIAction_QFileDialog(*this);
     }
 };
