@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RANDOM_GUI_ACTION_FACTORY_H_
-#define _U2_GT_RANDOM_GUI_ACTION_FACTORY_H_
+#pragma once
 
 #include "GTAbstractGUIAction.h"
 
@@ -32,7 +31,7 @@ int randInt(int low, int high);
 
 class GTRandomGUIActionFactory {
 public:
-    static GTAbstractGUIAction *create(QObject *obj);
+    static GTAbstractGUIAction* create(QObject* obj);
 
     static GTAbstractGUIActionMap actionMap;
 };
@@ -40,5 +39,3 @@ public:
 }  // namespace GUITest_crazy_user
 
 }  // namespace U2
-
-#endif
