@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,11 +19,10 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_TESTS_CRAZY_USER_H_
-#define _U2_GT_TESTS_CRAZY_USER_H_
+#pragma once
 
 #include <harness/UGUITestBase.h>
-//#include <U2Core/U2OpStatus.h>
+// #include <U2Core/U2OpStatus.h>
 #include "utils/GTUtilsDialog.h"
 
 namespace U2 {
@@ -50,11 +49,11 @@ public slots:
     void checkActiveWidget();
 
 private:
-    GTCrazyUserMonitor(const GTCrazyUserMonitor &);
-    GTCrazyUserMonitor &operator=(const GTCrazyUserMonitor &);
+    GTCrazyUserMonitor(const GTCrazyUserMonitor&);
+    GTCrazyUserMonitor& operator=(const GTCrazyUserMonitor&);
 
-    QTimer *timer;
-    QList<GTAbstractGUIAction *> formGUIActions(QWidget *widget) const;
+    QTimer* timer;
+    QList<GTAbstractGUIAction*> formGUIActions(QWidget* widget) const;
 };
 
 class simple_crazy_user : public HI::GUITest {
@@ -64,11 +63,9 @@ public:
     }
 
 protected:
-    virtual void run(HI::GUITestOpStatus &os);
+    virtual void run();
 };
 
 }  // namespace GUITest_crazy_user
 
 }  // namespace U2
-
-#endif
