@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -45,8 +45,8 @@
 
 namespace U2 {
 
-extern "C" Q_DECL_EXPORT Plugin *U2_PLUGIN_INIT_FUNC() {
-    AnnotatorPlugin *plug = new AnnotatorPlugin();
+extern "C" Q_DECL_EXPORT Plugin* U2_PLUGIN_INIT_FUNC() {
+    AnnotatorPlugin* plug = new AnnotatorPlugin();
     return plug;
 }
 
@@ -58,7 +58,7 @@ AnnotatorPlugin::AnnotatorPlugin()
         SharedFeatureStore store(new FeatureStore(PLASMID_FEATURES_GROUP_NAME, plasmidFeaturesPath));
         store->load();
         if (store->isLoaded()) {
-            CustomPatternAutoAnnotationUpdater *aaUpdater = new CustomPatternAutoAnnotationUpdater(store);
+            CustomPatternAutoAnnotationUpdater* aaUpdater = new CustomPatternAutoAnnotationUpdater(store);
             AppContext::getAutoAnnotationsSupport()->registerAutoAnnotationsUpdater(aaUpdater);
         }
 
@@ -69,46 +69,47 @@ AnnotatorPlugin::AnnotatorPlugin()
     LocalWorkflow::GeneByGeneReportWorkerFactory::init();
 
     // Annotator test
-    GTestFormatRegistry *tfr = AppContext::getTestFramework()->getTestFormatRegistry();
-    XMLTestFormat *xmlTestFormat = qobject_cast<XMLTestFormat *>(tfr->findFormat("XML"));
+    GTestFormatRegistry* tfr = AppContext::getTestFramework()->getTestFormatRegistry();
+    auto xmlTestFormat = qobject_cast<XMLTestFormat*>(tfr->findFormat("XML"));
     assert(xmlTestFormat != nullptr);
 
-    GAutoDeleteList<XMLTestFactory> *l = new GAutoDeleteList<XMLTestFactory>(this);
+    GAutoDeleteList<XMLTestFactory>* l = new GAutoDeleteList<XMLTestFactory>(this);
     l->qlist = AnnotatorTests::createTestFactories();
 
-    foreach (XMLTestFactory *f, l->qlist) {
+    foreach (XMLTestFactory* f, l->qlist) {
         bool res = xmlTestFormat->registerTestFactory(f);
         Q_UNUSED(res);
         assert(res);
     }
 }
 
-AnnotatorViewContext::AnnotatorViewContext(QObject *p, bool customAutoAnnotations)
+AnnotatorViewContext::AnnotatorViewContext(QObject* p, bool customAutoAnnotations)
     : GObjectViewWindowContext(p, ANNOTATED_DNA_VIEW_FACTORY_ID), customFeaturesAvailable(customAutoAnnotations) {
 }
 
-void AnnotatorViewContext::initViewContext(GObjectView *v) {
-    AnnotatedDNAView *av = qobject_cast<AnnotatedDNAView *>(v);
-    ADVGlobalAction *findRegionsAction = new ADVGlobalAction(av, QIcon(":annotator/images/regions.png"), tr("Find annotated regions..."), 30);
+void AnnotatorViewContext::initViewContext(GObjectViewController* v) {
+    auto av = qobject_cast<AnnotatedDNAView*>(v);
+    ADVGlobalAction* findRegionsAction = new ADVGlobalAction(av, QIcon(":annotator/images/regions.png"), tr("Find annotated regions..."), 30);
     connect(findRegionsAction, SIGNAL(triggered()), SLOT(sl_showCollocationDialog()));
 
     if (customFeaturesAvailable) {
-        ADVGlobalAction *annotatePlasmidAction = new ADVGlobalAction(av, QIcon(":annotator/images/plasmid_features.png"), tr("Annotate plasmid..."), 31);
+        ADVGlobalAction* annotatePlasmidAction = new ADVGlobalAction(av, QIcon(":annotator/images/plasmid_features.png"), tr("Annotate plasmid..."), 31);
         annotatePlasmidAction->addAlphabetFilter(DNAAlphabet_NUCL);
         connect(annotatePlasmidAction, SIGNAL(triggered()), SLOT(sl_showCustomAutoAnnotationDialog()));
     }
 }
 
 void AnnotatorViewContext::sl_showCollocationDialog() {
-    QAction *a = (QAction *)sender();
-    GObjectViewAction *viewAction = qobject_cast<GObjectViewAction *>(a);
-    AnnotatedDNAView *av = qobject_cast<AnnotatedDNAView *>(viewAction->getObjectView());
+    QAction* a = (QAction*)sender();
+    auto viewAction = qobject_cast<GObjectViewAction*>(a);
+    auto av = qobject_cast<AnnotatedDNAView*>(viewAction->getObjectView());
     assert(av);
 
     QSet<QString> allNames;
 
-    foreach (AnnotationTableObject *ao, av->getAnnotationObjects()) {
-        foreach (Annotation *annotation, ao->getAnnotations()) {
+    foreach (AnnotationTableObject* ao, av->getAnnotationObjects()) {
+        QList<Annotation*> annotations = ao->getAnnotations();
+        for (Annotation* annotation : qAsConst(annotations)) {
             allNames.insert(annotation->getName());
         }
     }
@@ -117,7 +118,7 @@ void AnnotatorViewContext::sl_showCollocationDialog() {
         return;
     }
 
-    ADVSequenceObjectContext *seqCtx = av->getActiveSequenceContext();
+    ADVSequenceObjectContext* seqCtx = av->getActiveSequenceContext();
     if (seqCtx == nullptr) {
         return;
     }
@@ -127,12 +128,12 @@ void AnnotatorViewContext::sl_showCollocationDialog() {
 }
 
 void AnnotatorViewContext::sl_showCustomAutoAnnotationDialog() {
-    QAction *a = (QAction *)sender();
-    GObjectViewAction *viewAction = qobject_cast<GObjectViewAction *>(a);
-    AnnotatedDNAView *av = qobject_cast<AnnotatedDNAView *>(viewAction->getObjectView());
+    QAction* a = (QAction*)sender();
+    auto viewAction = qobject_cast<GObjectViewAction*>(a);
+    auto av = qobject_cast<AnnotatedDNAView*>(viewAction->getObjectView());
     assert(av);
 
-    ADVSequenceObjectContext *seqCtx = av->getActiveSequenceContext();
+    ADVSequenceObjectContext* seqCtx = av->getActiveSequenceContext();
     if (seqCtx == nullptr) {
         return;
     }
@@ -141,8 +142,8 @@ void AnnotatorViewContext::sl_showCustomAutoAnnotationDialog() {
     dlg->exec();
 }
 
-QList<XMLTestFactory *> AnnotatorTests::createTestFactories() {
-    QList<XMLTestFactory *> res;
+QList<XMLTestFactory*> AnnotatorTests::createTestFactories() {
+    QList<XMLTestFactory*> res;
     res.append(GTest_AnnotatorSearch::createFactory());
     res.append(GTest_GeneByGeneApproach::createFactory());
     res.append(GTest_CustomAutoAnnotation::createFactory());
