@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATION_COLLOCATOR_PLUGIN_H_
-#define _U2_ANNOTATION_COLLOCATOR_PLUGIN_H_
+#pragma once
 
 #include <U2Core/PluginModel.h>
 
@@ -36,13 +35,13 @@ public:
     AnnotatorPlugin();
 
 private:
-    GObjectViewWindowContext *viewCtx;
+    GObjectViewWindowContext* viewCtx;
 };
 
 class AnnotatorViewContext : public GObjectViewWindowContext {
     Q_OBJECT
 public:
-    AnnotatorViewContext(QObject *p, bool customFeaturesAvailable);
+    AnnotatorViewContext(QObject* p, bool customFeaturesAvailable);
 
 private:
     bool customFeaturesAvailable;
@@ -52,13 +51,12 @@ protected slots:
     void sl_showCustomAutoAnnotationDialog();
 
 protected:
-    void initViewContext(GObjectView *view) override;
+    void initViewContext(GObjectViewController* view) override;
 };
 
 class AnnotatorTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-#endif
