@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATOR_TESTS_H_
-#define _U2_ANNOTATOR_TESTS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -50,7 +49,7 @@ private:
     QSet<QString> groupsToSearch;
     int regionSize;
     CollocationsAlgorithm::SearchType st;
-    CollocationSearchTask *searchTask;
+    CollocationSearchTask* searchTask;
     QVector<U2Region> expectedResults;
 };
 
@@ -67,7 +66,7 @@ private:
     QString docName;
     QString resultDocContextName;
     bool isCircular;
-    CustomPatternAnnotationTask *searchTask;
+    CustomPatternAnnotationTask* searchTask;
 };
 
 class GTest_GeneByGeneApproach : public XmlTest {
@@ -87,5 +86,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
