@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ANNOTATOR_WORKER_H_
-#define _U2_ANNOTATOR_WORKER_H_
+#pragma once
 
 #include <U2Lang/LocalDomain.h>
 #include <U2Lang/WorkflowUtils.h>
@@ -37,7 +36,7 @@ typedef PrompterBase<CollocationPrompter> CollocationPrompterBase;
 class CollocationPrompter : public CollocationPrompterBase {
     Q_OBJECT
 public:
-    CollocationPrompter(Actor *p = 0)
+    CollocationPrompter(Actor* p = 0)
         : CollocationPrompterBase(p) {
     }
     virtual ~CollocationPrompter() {
@@ -50,13 +49,13 @@ protected:
 class CollocationWorker : public BaseWorker {
     Q_OBJECT
 public:
-    CollocationWorker(Actor *a)
+    CollocationWorker(Actor* a)
         : BaseWorker(a), input(nullptr), output(nullptr) {
     }
     virtual ~CollocationWorker() {
     }
     virtual void init();
-    virtual Task *tick();
+    virtual Task* tick();
     virtual void cleanup() {
     }
 private slots:
@@ -76,12 +75,10 @@ public:
     }
     virtual ~CollocationWorkerFactory() {
     }
-    virtual Worker *createWorker(Actor *a) {
+    virtual Worker* createWorker(Actor* a) {
         return new CollocationWorker(a);
     }
 };
 
 }  // namespace LocalWorkflow
 }  // namespace U2
-
-#endif
