@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_COLLOCATION_DIALOG_CONTROLLER_H_
-#define _U2_COLLOCATION_DIALOG_CONTROLLER_H_
+#pragma once
 
 #include <QDialog>
 #include <QMutex>
@@ -45,7 +44,7 @@ class CollocationSearchTask;
 class CollocationsDialogController : public QDialog, Ui_FindAnnotationCollocationsDialog {
     Q_OBJECT
 public:
-    CollocationsDialogController(QStringList names, ADVSequenceObjectContext *ctx);
+    CollocationsDialogController(QStringList names, ADVSequenceObjectContext* ctx);
 
 public slots:
     void reject();
@@ -56,9 +55,9 @@ private slots:
     void sl_plusClicked();
     void sl_minusClicked();
     void sl_addName();
-    void sl_onTaskFinished(Task *);
+    void sl_onTaskFinished(Task*);
     void sl_onTimer();
-    void sl_onResultActivated(QListWidgetItem *item);
+    void sl_onResultActivated(QListWidgetItem* item);
     void sl_clearClicked();
     void sl_saveClicked();
 
@@ -69,17 +68,17 @@ private:
 
     QStringList allNames;
     QSet<QString> usedNames;
-    ADVSequenceObjectContext *ctx;
-    QToolButton *plusButton;
-    CollocationSearchTask *task;
-    QTimer *timer;
-    QPushButton *searchButton;
-    QPushButton *cancelButton;
+    ADVSequenceObjectContext* ctx;
+    QToolButton* plusButton;
+    CollocationSearchTask* task;
+    QTimer* timer;
+    QPushButton* searchButton;
+    QPushButton* cancelButton;
 };
 
 class CDCResultItem : public QListWidgetItem {
 public:
-    CDCResultItem(const U2Region &_r);
+    CDCResultItem(const U2Region& _r);
     U2Region r;
 };
 
@@ -89,19 +88,19 @@ public:
 class CollocationSearchTask : public Task, public CollocationsAlgorithmListener {
     Q_OBJECT
 public:
-    CollocationSearchTask(const QList<AnnotationTableObject *> &table, const QSet<QString> &names, const CollocationsAlgorithmSettings &cfg);
-    CollocationSearchTask(const QList<SharedAnnotationData> &table, const QSet<QString> &names, const CollocationsAlgorithmSettings &cfg, bool keepSourceAnns = false);
+    CollocationSearchTask(const QList<AnnotationTableObject*>& table, const QSet<QString>& names, const CollocationsAlgorithmSettings& cfg);
+    CollocationSearchTask(const QList<SharedAnnotationData>& table, const QSet<QString>& names, const CollocationsAlgorithmSettings& cfg, bool keepSourceAnns = false);
     void run();
 
     QVector<U2Region> popResults();
     QList<SharedAnnotationData> popResultAnnotations();
 
-    virtual void onResult(const U2Region &r);
+    virtual void onResult(const U2Region& r);
 
 private:
-    CollocationsAlgorithmItem &getItem(const QString &name);
-    bool isSuitableRegion(const U2Region &r, const QVector<U2Region> &resultRegions) const;
-    U2Region cutResult(const U2Region &res) const;
+    CollocationsAlgorithmItem& getItem(const QString& name);
+    bool isSuitableRegion(const U2Region& r, const QVector<U2Region>& resultRegions) const;
+    U2Region cutResult(const U2Region& res) const;
 
     QMap<QString, CollocationsAlgorithmItem> items;
     CollocationsAlgorithmSettings cfg;
@@ -113,5 +112,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
