@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_COLLOCATION_SEARCH_ALGORITHM_H_
-#define _U2_COLLOCATION_SEARCH_ALGORITHM_H_
+#pragma once
 
 #include <U2Core/SequenceWalkerTask.h>
 #include <U2Core/Task.h>
@@ -31,14 +30,14 @@ namespace U2 {
 class CollocationsAlgorithmListener {
 public:
     virtual ~CollocationsAlgorithmListener() {};
-    virtual void onResult(const U2Region &r) = 0;
+    virtual void onResult(const U2Region& r) = 0;
 };
 
 class CollocationsAlgorithmItem {
 public:
     CollocationsAlgorithmItem() {
     }
-    CollocationsAlgorithmItem(const QString &_name)
+    CollocationsAlgorithmItem(const QString& _name)
         : name(_name) {
     }
 
@@ -52,11 +51,11 @@ class CollocationsAlgorithm {
 public:
     enum SearchType { NormalSearch,
                       PartialSearch };
-    static void find(const QList<CollocationsAlgorithmItem> &items, TaskStateInfo &si, CollocationsAlgorithmListener *l, const CollocationsAlgorithmSettings &cfg);
+    static void find(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si, CollocationsAlgorithmListener* l, const CollocationsAlgorithmSettings& cfg);
 
 private:
-    static void findN(const QList<CollocationsAlgorithmItem> &items, TaskStateInfo &si, CollocationsAlgorithmListener *l, const U2Region &searchRegion, qint64 distance);
-    static void findP(const QList<CollocationsAlgorithmItem> &items, TaskStateInfo &si, CollocationsAlgorithmListener *l, const U2Region &searchRegion, qint64 distance);
+    static void findN(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si, CollocationsAlgorithmListener* l, const U2Region& searchRegion, qint64 distance);
+    static void findP(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si, CollocationsAlgorithmListener* l, const U2Region& searchRegion, qint64 distance);
 };
 
 class CollocationsAlgorithmSettings {
@@ -73,4 +72,3 @@ public:
 };
 
 }  // namespace U2
-#endif
