@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CUSTOM_AUTO_ANNOTATION_DIALOG_H_
-#define _U2_CUSTOM_AUTO_ANNOTATION_DIALOG_H_
+#pragma once
 
 #include <ui_CustomAutoAnnotationDialog.h>
 
@@ -31,15 +30,13 @@ class ADVSequenceObjectContext;
 class CustomAutoAnnotationDialog : public QDialog, Ui_CustomAutoAnnotationDialog {
     Q_OBJECT
 public:
-    CustomAutoAnnotationDialog(ADVSequenceObjectContext *ctx);
+    CustomAutoAnnotationDialog(ADVSequenceObjectContext* ctx);
     virtual void accept();
 
 private:
-    ADVSequenceObjectContext *seqCtx;
+    ADVSequenceObjectContext* seqCtx;
     void loadSettings();
     void saveSettings();
 };
 
 }  // namespace U2
-
-#endif
