@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CUSTOM_PATTERN_ANNOTATION_TASK_H_
-#define _U2_CUSTOM_PATTERN_ANNOTATION_TASK_H_
+#pragma once
 
 #include <QSharedPointer>
 
@@ -61,7 +60,7 @@ class FeatureStore {
     int minFeatureSize;
 
 public:
-    FeatureStore(const QString &storeName, const QString &filePath)
+    FeatureStore(const QString& storeName, const QString& filePath)
         : name(storeName), path(filePath), minFeatureSize(0) {
     }
     void load();
@@ -70,9 +69,9 @@ public:
 
     int getMinFeatureSize() const;
 
-    const QString &getName() const;
+    const QString& getName() const;
 
-    const QList<FeaturePattern> &getFeatures() const;
+    const QList<FeaturePattern>& getFeatures() const;
 };
 
 typedef QSharedPointer<FeatureStore> SharedFeatureStore;
@@ -80,10 +79,10 @@ typedef QSharedPointer<FeatureStore> SharedFeatureStore;
 class CustomPatternAnnotationTask : public Task {
     Q_OBJECT
 public:
-    CustomPatternAnnotationTask(AnnotationTableObject *aobj, const U2EntityRef &entityRef, const SharedFeatureStore &store, const QStringList &filteredFeatures = QStringList());
+    CustomPatternAnnotationTask(AnnotationTableObject* aobj, const U2EntityRef& entityRef, const SharedFeatureStore& store, const QStringList& filteredFeatures = QStringList());
 
     void prepare();
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
 
     struct PatternInfo {
         QString name;
@@ -91,17 +90,17 @@ public:
         PatternInfo()
             : forwardStrand(true) {
         }
-        PatternInfo(const QString &nm, bool isForward)
+        PatternInfo(const QString& nm, bool isForward)
             : name(nm), forwardStrand(isForward) {
         }
     };
 
 private:
     QSharedPointer<SArrayIndex> index;
-    QMap<Task *, PatternInfo> taskFeatureNames;
+    QMap<Task*, PatternInfo> taskFeatureNames;
     QList<SharedAnnotationData> annotations;
     U2SequenceObject dnaObj;
-    AnnotationTableObject *aTableObj;
+    QPointer<AnnotationTableObject> annotationTableObject;
     QByteArray sequence;
     SharedFeatureStore featureStore;
     QStringList filteredFeatures;
@@ -112,11 +111,9 @@ class CustomPatternAutoAnnotationUpdater : public AutoAnnotationsUpdater {
     SharedFeatureStore featureStore;
 
 public:
-    CustomPatternAutoAnnotationUpdater(const SharedFeatureStore &store);
-    Task *createAutoAnnotationsUpdateTask(const AutoAnnotationObject *aa);
-    bool checkConstraints(const AutoAnnotationConstraints &constraints);
+    CustomPatternAutoAnnotationUpdater(const SharedFeatureStore& store);
+    Task* createAutoAnnotationsUpdateTask(const AutoAnnotationObject* aa);
+    bool checkConstraints(const AutoAnnotationConstraints& constraints);
 };
 
 }  // namespace U2
-
-#endif  // _U2_CUSTOM_PATTERN_ANNOTATION_TASK_H_
