@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GENEBYGENEREPORT_WORKER_H_
-#define _U2_GENEBYGENEREPORT_WORKER_H_
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -36,17 +35,17 @@ namespace LocalWorkflow {
 class GeneByGeneReportWorker : public BaseWorker {
     Q_OBJECT
 public:
-    GeneByGeneReportWorker(Actor *p);
+    GeneByGeneReportWorker(Actor* p);
 
     virtual void init();
-    virtual Task *tick();
+    virtual Task* tick();
     virtual void cleanup();
 
     // for files in the report
     virtual QStringList getOutputFiles();
 
 private:
-    IntegralBus *inChannel;
+    IntegralBus* inChannel;
     QStringList outFiles;
     QMap<QString, QPair<DNASequence, QList<SharedAnnotationData>>> geneData;
 
@@ -62,13 +61,13 @@ public:
         : DomainFactory(ACTOR_ID) {
     }
     static void init();
-    virtual Worker *createWorker(Actor *a);
+    virtual Worker* createWorker(Actor* a);
 };  // GeneByGeneReportWorkerFactory
 
 class GeneByGeneReportPrompter : public PrompterBase<GeneByGeneReportPrompter> {
     Q_OBJECT
 public:
-    GeneByGeneReportPrompter(Actor *p = nullptr)
+    GeneByGeneReportPrompter(Actor* p = nullptr)
         : PrompterBase<GeneByGeneReportPrompter>(p) {
     }
 
@@ -79,5 +78,3 @@ protected:
 
 }  // namespace LocalWorkflow
 }  // namespace U2
-
-#endif  //_U2_GENEBYGENEREPORT_WORKER_H_
