@@ -133,12 +133,12 @@
         <translation>Автоматический поиск плазмид...</translation>
     </message>
     <message>
-        <location filename="../src/AnnotatorPlugin.cpp" line="116"/>
+        <location filename="../src/AnnotatorPlugin.cpp" line="117"/>
         <source>Warning</source>
         <translation>Предупреждение</translation>
     </message>
     <message>
-        <location filename="../src/AnnotatorPlugin.cpp" line="116"/>
+        <location filename="../src/AnnotatorPlugin.cpp" line="117"/>
         <source>No annotations found</source>
         <translation>Аннотаций не найдено</translation>
     </message>
@@ -147,7 +147,7 @@
     <name>U2::CollocationSearchTask</name>
     <message>
         <location filename="../src/CollocationsDialogController.cpp" line="315"/>
-        <location filename="../src/CollocationsDialogController.cpp" line="343"/>
+        <location filename="../src/CollocationsDialogController.cpp" line="344"/>
         <source>Search for annotated regions</source>
         <translation>Поиск сгруппированных аннотаций</translation>
     </message>
@@ -216,11 +216,16 @@
         <source>Custom pattern annotation</source>
         <translation>Пользовательская аннотация</translation>
     </message>
+    <message>
+        <location filename="../src/CustomPatternAnnotationTask.cpp" line="112"/>
+        <source>Object with annotations was removed</source>
+        <translation>Объект с аннотациями был удалён</translation>
+    </message>
 </context>
 <context>
     <name>U2::CustomPatternAutoAnnotationUpdater</name>
     <message>
-        <location filename="../src/CustomPatternAnnotationTask.cpp" line="219"/>
+        <location filename="../src/CustomPatternAnnotationTask.cpp" line="222"/>
         <source>Plasmid features</source>
         <translation>Аннотирование плазмид</translation>
     </message>
@@ -238,12 +243,12 @@
     <message>
         <location filename="../src/CollocationWorker.cpp" line="148"/>
         <source> sequence from &lt;u&gt;%1&lt;/u&gt;</source>
-        <translation>последовательности из &lt;u&gt;%1&lt;/u&gt;</translation>
+        <translation> последовательности из &lt;u&gt;%1&lt;/u&gt;</translation>
     </message>
     <message>
         <location filename="../src/CollocationWorker.cpp" line="151"/>
         <source> set of annotations from &lt;u&gt;%1&lt;/u&gt;</source>
-        <translation>набора аннотаций из &lt;u&gt;%1&lt;/u&gt;</translation>
+        <translation> набора аннотаций из &lt;u&gt;%1&lt;/u&gt;</translation>
     </message>
     <message>
         <location filename="../src/CollocationWorker.cpp" line="158"/>
@@ -258,7 +263,7 @@
     <message>
         <location filename="../src/CollocationWorker.cpp" line="176"/>
         <source> Annotations themselves may not span beyond the region.</source>
-        <translation>целиком.</translation>
+        <translation> целиком.</translation>
     </message>
     <message>
         <location filename="../src/CollocationWorker.cpp" line="180"/>
@@ -389,7 +394,7 @@
     <message>
         <location filename="../src/GeneByGeneReportWorker.cpp" line="232"/>
         <source> With sequence identity of &lt;u&gt;%1&lt;/u&gt;.</source>
-        <translation>С идентичностью последовательности &lt;u&gt;%1&lt;/u&gt;.</translation>
+        <translation> С идентичностью последовательности &lt;u&gt;%1&lt;/u&gt;.</translation>
     </message>
     <message>
         <location filename="../src/GeneByGeneReportWorker.cpp" line="233"/>
