@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_UNIT_TEST_SUITE_H_
-#define _U2_UNIT_TEST_SUITE_H_
+#pragma once
 
 #include <U2Test/XMLTestUtils.h>
 
@@ -36,7 +35,7 @@ public:
 
 protected:
     void runAllTests();
-    void runTest(const QString &testName);
+    void runTest(const QString& testName);
 
     QMap<QString, QStringList> tests;
 
@@ -47,5 +46,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
