@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_ROW_UNIT_TESTS_H_
-#define _U2_MSA_ROW_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -30,13 +29,13 @@ namespace U2 {
 
 class MsaRowTestUtils {
 public:
-    static MultipleSequenceAlignmentRow initTestRowWithGaps(MultipleSequenceAlignment &ma);
-    static MultipleSequenceAlignmentRow initTestRowWithGapsInMiddle(MultipleSequenceAlignment &ma);
-    static MultipleSequenceAlignmentRow initTestRowWithTrailingGaps(MultipleSequenceAlignment &ma);
-    static MultipleSequenceAlignmentRow initTestRowWithoutGaps(MultipleSequenceAlignment &ma);
-    static MultipleSequenceAlignmentRow initTestRowForModification(MultipleSequenceAlignment &ma);
-    static MultipleSequenceAlignmentRow initEmptyRow(MultipleSequenceAlignment &ma);
-    static QString getRowData(const MultipleSequenceAlignmentRow &row);
+    static MultipleSequenceAlignmentRow initTestRowWithGaps(MultipleSequenceAlignment& ma);
+    static MultipleSequenceAlignmentRow initTestRowWithGapsInMiddle(MultipleSequenceAlignment& ma);
+    static MultipleSequenceAlignmentRow initTestRowWithTrailingGaps(MultipleSequenceAlignment& ma);
+    static MultipleSequenceAlignmentRow initTestRowWithoutGaps(MultipleSequenceAlignment& ma);
+    static MultipleSequenceAlignmentRow initTestRowForModification(MultipleSequenceAlignment& ma);
+    static MultipleSequenceAlignmentRow initEmptyRow(MultipleSequenceAlignment& ma);
+    static QString getRowData(const MultipleSequenceAlignmentRow& row);
 
     static const int rowWithGapsLength;
     static const int rowWithGapsInMiddleLength;
@@ -456,5 +455,3 @@ DECLARE_METATYPE(MsaRowUnitTests, replaceChars_nothingToReplace)
 DECLARE_METATYPE(MsaRowUnitTests, replaceChars_tildasToGapsNoGaps)
 DECLARE_METATYPE(MsaRowUnitTests, replaceChars_tildasToGapsWithGaps)
 DECLARE_METATYPE(MsaRowUnitTests, replaceChars_trailingGaps)
-
-#endif
