@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_UNIT_TESTS_H_
-#define _U2_MSA_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -31,8 +30,8 @@ namespace U2 {
 class MsaTestUtils {
 public:
     static MultipleSequenceAlignment initTestAlignment();
-    static QString getRowData(const MultipleSequenceAlignment &, int rowNum);
-    static bool testAlignmentNotChanged(const MultipleSequenceAlignment &);
+    static QString getRowData(const MultipleSequenceAlignment&, int rowNum);
+    static bool testAlignmentNotChanged(const MultipleSequenceAlignment&);
 
     static const int rowsNum;
     static const int firstRowLength;
@@ -338,5 +337,3 @@ DECLARE_METATYPE(MsaUnitTests, operNotEqual_equal);
 DECLARE_METATYPE(MsaUnitTests, operNotEqual_notEqual);
 DECLARE_METATYPE(MsaUnitTests, hasEmptyGapModel_gaps);
 DECLARE_METATYPE(MsaUnitTests, hasEmptyGapModel_noGaps);
-
-#endif
