@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -41,13 +41,13 @@ TestDbiProvider::TestDbiProvider()
 TestDbiProvider::~TestDbiProvider() {
     close();
 }
-bool TestDbiProvider::init(const QString &dbiFileName, bool _useConnectionPool) {
+bool TestDbiProvider::init(const QString& dbiFileName, bool _useConnectionPool) {
     if (initialized) {
         close();
         initialized = false;
     }
 
-    TestRunnerSettings *trs = AppContext::getAppSettings()->getTestRunnerSettings();
+    TestRunnerSettings* trs = AppContext::getAppSettings()->getTestRunnerSettings();
     QString originalFile = trs->getVar("COMMON_DATA_DIR") + "/unit_tests/" + dbiFileName;
 
     QString tmpFile = QDir::temp().absoluteFilePath(QFileInfo(originalFile).fileName());
@@ -66,7 +66,7 @@ bool TestDbiProvider::init(const QString &dbiFileName, bool _useConnectionPool)
     dbUrl = tmpFile;
     useConnectionPool = _useConnectionPool;
 
-    U2DbiFactory *factory = AppContext::getDbiRegistry()->getDbiFactoryById(SQLITE_DBI_ID);
+    U2DbiFactory* factory = AppContext::getDbiRegistry()->getDbiFactoryById(SQLITE_DBI_ID);
     SAFE_POINT(factory != nullptr, "No dbi factory", false);
     U2OpStatusImpl opStatus;
 
@@ -78,7 +78,7 @@ bool TestDbiProvider::init(const QString &dbiFileName, bool _useConnectionPool)
         CHECK_OP(opStatus, false);
     } else {
         dbi = factory->createDbi();
-        SAFE_POINT(nullptr != dbi, "dbi not created", false);
+        SAFE_POINT(dbi != nullptr, "dbi not created", false);
         QHash<QString, QString> properties;
         if (_create) {
             properties[U2DbiOptions::U2_DBI_OPTION_CREATE] = U2DbiOptions::U2_DBI_VALUE_ON;
@@ -88,8 +88,8 @@ bool TestDbiProvider::init(const QString &dbiFileName, bool _useConnectionPool)
         dbi->init(properties, persistentData, opStatus);
         SAFE_POINT_OP(opStatus, false);
     }
-    U2ObjectDbi *objDbi = dbi->getObjectDbi();
-    SAFE_POINT(nullptr != objDbi, "object dbi not loaded", false);
+    U2ObjectDbi* objDbi = dbi->getObjectDbi();
+    SAFE_POINT(objDbi != nullptr, "object dbi not loaded", false);
 
     initialized = true;
     return true;
@@ -98,8 +98,8 @@ void TestDbiProvider::close() {
     U2OpStatusImpl opStatus;
     if (dbi) {
         if (useConnectionPool) {
-            U2DbiRegistry *dbiReg = AppContext::getDbiRegistry();
-            if (nullptr != dbiReg) {
+            U2DbiRegistry* dbiReg = AppContext::getDbiRegistry();
+            if (dbiReg != nullptr) {
                 dbiReg->getGlobalDbiPool()->releaseDbi(dbi, opStatus);
             }
         } else {
@@ -111,7 +111,7 @@ void TestDbiProvider::close() {
     dbi = nullptr;
     initialized = false;
 }
-U2Dbi *TestDbiProvider::getDbi() {
+U2Dbi* TestDbiProvider::getDbi() {
     SAFE_POINT(initialized, "Dbi Provider is not initialized", nullptr);
     return dbi;
 }
