@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef DBITEST_H
-#define DBITEST_H
+#pragma once
 
 #include <unittest.h>
 
@@ -37,26 +36,24 @@ public:
     TestDbiProvider();
     ~TestDbiProvider();
 
-    bool init(const QString &dbiFileName, bool useConnectionPool);
+    bool init(const QString& dbiFileName, bool useConnectionPool);
     void close();
-    U2Dbi *getDbi();
+    U2Dbi* getDbi();
 
 private:
     bool initialized;
     bool useConnectionPool;
     QString dbUrl;
-    U2Dbi *dbi;
+    U2Dbi* dbi;
 };
 
 template<>
-inline QString toString<U2DataId>(const U2DataId &a) {
+inline QString toString<U2DataId>(const U2DataId& a) {
     return "0x" + QString(a.toHex());
 }
 template<>
-inline QString toString<U2Region>(const U2Region &r) {
+inline QString toString<U2Region>(const U2Region& r) {
     return r.toString();
 }
 
 }  // namespace U2
-
-#endif  // DBITEST_H
