@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _ASSEMBLY_DBI_TEST_UTIL_H_
-#define _ASSEMBLY_DBI_TEST_UTIL_H_
+#pragma once
 
 #include <U2Core/U2Assembly.h>
 
@@ -28,22 +27,20 @@ namespace U2 {
 
 class AssemblyDbiTestUtil {
 public:
-    static bool compareCigar(const QList<U2CigarToken> &c1, const QList<U2CigarToken> &c2);
+    static bool compareCigar(const QList<U2CigarToken>& c1, const QList<U2CigarToken>& c2);
 
-    static bool compareReads(const U2AssemblyRead &r1, const U2AssemblyRead &r2);
+    static bool compareReads(const U2AssemblyRead& r1, const U2AssemblyRead& r2);
 
-    static bool findRead(const U2AssemblyRead &subj, QList<U2AssemblyRead> &reads);
+    static bool findRead(const U2AssemblyRead& subj, QList<U2AssemblyRead>& reads);
 
-    static bool compareReadLists(U2DbiIterator<U2AssemblyRead> *iter, QList<U2AssemblyRead> &expectedReads);
+    static bool compareReadLists(U2DbiIterator<U2AssemblyRead>* iter, QList<U2AssemblyRead>& expectedReads);
 
-    static void var2readList(const QVariantList &varList, QList<U2AssemblyRead> &reads);
+    static void var2readList(const QVariantList& varList, QList<U2AssemblyRead>& reads);
 
 public:
-    static const char *ERR_INVALID_ASSEMBLY_ID;
+    static const char* ERR_INVALID_ASSEMBLY_ID;
 };
 
 }  // namespace U2
 
 Q_DECLARE_METATYPE(U2::U2AssemblyRead);
-
-#endif
