@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ASSEMBLY_DBI_UNIT_TESTS_H_
-#define _U2_ASSEMBLY_DBI_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -38,17 +37,17 @@ class AssemblyTestData {
 public:
     static void init();
     static void shutdown();
-    static U2AssemblyDbi *getAssemblyDbi();
+    static U2AssemblyDbi* getAssemblyDbi();
     static void close();
-    static QList<U2DataId> *getAssemblyIds() {
+    static QList<U2DataId>* getAssemblyIds() {
         return assemblyIds;
     };
 
 public:
-    static U2AssemblyDbi *assemblyDbi;
-    static QList<U2DataId> *assemblyIds;
+    static U2AssemblyDbi* assemblyDbi;
+    static QList<U2DataId>* assemblyIds;
 
-    static const QString &ASS_DB_URL;
+    static const QString& ASS_DB_URL;
 
 protected:
     static TestDbiProvider dbiProvider;
@@ -195,5 +194,3 @@ Q_DECLARE_METATYPE(U2::AssemblyDbiUnitTests_pack);
 Q_DECLARE_METATYPE(U2::AssemblyDbiUnitTests_packInvalid);
 Q_DECLARE_METATYPE(U2::AssemblyDbiUnitTests_removeReads);
 Q_DECLARE_METATYPE(U2::AssemblyDbiUnitTests_removeReadsInvalid);
-
-#endif  //_U2_ASSEMBLY_DBI_UNITTESTS_H_
