@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FEATURES_DBI_UNIT_TESTS_H_
-#define _U2_FEATURES_DBI_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -36,14 +35,14 @@ class U2SequenceDbi;
 
 class FeatureTestData {
 public:
-    static U2FeatureDbi *getFeatureDbi();
-    static U2SequenceDbi *getSequenceDbi();
-    static U2FeatureDbi *getSubgroupDbi();
+    static U2FeatureDbi* getFeatureDbi();
+    static U2SequenceDbi* getSequenceDbi();
+    static U2FeatureDbi* getSubgroupDbi();
 
-    static U2Feature createTestFeature1(const U2Sequence &seq, U2OpStatus &os, const U2Feature &parentFeature = U2Feature());
-    static U2Feature createTestFeature2(const U2Sequence &seq, U2OpStatus &os, const U2Feature &parentFeature = U2Feature());
-    static U2Feature createTestFeature3(const U2Sequence &seq, U2OpStatus &os, const U2Feature &parentFeature = U2Feature());
-    static U2Feature createTestFeatureWithoutKeys(const U2Sequence &seq, U2OpStatus &os, const U2Feature &parentFeature = U2Feature());
+    static U2Feature createTestFeature1(const U2Sequence& seq, U2OpStatus& os, const U2Feature& parentFeature = U2Feature());
+    static U2Feature createTestFeature2(const U2Sequence& seq, U2OpStatus& os, const U2Feature& parentFeature = U2Feature());
+    static U2Feature createTestFeature3(const U2Sequence& seq, U2OpStatus& os, const U2Feature& parentFeature = U2Feature());
+    static U2Feature createTestFeatureWithoutKeys(const U2Sequence& seq, U2OpStatus& os, const U2Feature& parentFeature = U2Feature());
 
     static void shutdown();
 
@@ -54,9 +53,9 @@ private:
     static TestDbiProvider subgroupsDbiProvider;
     static const QString featureDbiUrl;
     static const QString subgroupDbiUrl;
-    static U2FeatureDbi *featureDbi;
-    static U2FeatureDbi *subgroupDbi;
-    static U2SequenceDbi *sequenceDbi;
+    static U2FeatureDbi* featureDbi;
+    static U2FeatureDbi* subgroupDbi;
+    static U2SequenceDbi* sequenceDbi;
 };
 
 /** Creates new feature in DB */
@@ -111,5 +110,3 @@ DECLARE_METATYPE(FeatureDbiUnitTests, getFeaturesByRegion);
 DECLARE_METATYPE(FeatureDbiUnitTests, getSubFeatures);
 DECLARE_METATYPE(FeatureDbiUnitTests, getFeaturesBySequence);
 DECLARE_METATYPE(FeatureDbiUnitTests, sortingSubgroups);
-
-#endif  // _U2_FEATURES_DBI_UNIT_TESTS_H_
