@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,28 +32,28 @@
 namespace U2 {
 
 TestDbiProvider MsaTestData::dbiProvider = TestDbiProvider();
-const QString &MsaTestData::MSA_DB_URL("msa-dbi.ugenedb");
-U2MsaDbi *MsaTestData::msaDbi = nullptr;
-U2SequenceDbi *MsaTestData::sequenceDbi = nullptr;
+const QString& MsaTestData::MSA_DB_URL("msa-dbi.ugenedb");
+U2MsaDbi* MsaTestData::msaDbi = nullptr;
+U2SequenceDbi* MsaTestData::sequenceDbi = nullptr;
 
 void MsaTestData::init() {
-    SAFE_POINT(nullptr == msaDbi, "msaDbi has been already initialized!", );
-    SAFE_POINT(nullptr == sequenceDbi, "sequenceDbi has been already initialized!", );
+    SAFE_POINT(msaDbi == nullptr, "msaDbi has been already initialized!", );
+    SAFE_POINT(sequenceDbi == nullptr, "sequenceDbi has been already initialized!", );
 
     bool ok = dbiProvider.init(MSA_DB_URL, false);
     SAFE_POINT(ok, "Dbi provider failed to initialize in MsaTestData::init()!", );
 
-    U2Dbi *dbi = dbiProvider.getDbi();
+    U2Dbi* dbi = dbiProvider.getDbi();
     msaDbi = dbi->getMsaDbi();
-    SAFE_POINT(nullptr != msaDbi, "Failed to get msaDbi!", );
+    SAFE_POINT(msaDbi != nullptr, "Failed to get msaDbi!", );
 
     sequenceDbi = dbi->getSequenceDbi();
-    SAFE_POINT(nullptr != sequenceDbi, "Failed to get sequenceDbi!", );
+    SAFE_POINT(sequenceDbi != nullptr, "Failed to get sequenceDbi!", );
 }
 
 void MsaTestData::shutdown() {
-    if (nullptr != msaDbi) {
-        SAFE_POINT(nullptr != sequenceDbi, "sequenceDbi must also be not NULL on this step!", );
+    if (msaDbi != nullptr) {
+        SAFE_POINT(sequenceDbi != nullptr, "sequenceDbi must also be not NULL on this step!", );
 
         U2OpStatusImpl os;
         dbiProvider.close();
@@ -63,22 +63,22 @@ void MsaTestData::shutdown() {
     }
 }
 
-U2MsaDbi *MsaTestData::getMsaDbi() {
-    if (nullptr == msaDbi) {
+U2MsaDbi* MsaTestData::getMsaDbi() {
+    if (msaDbi == nullptr) {
         init();
     }
     return msaDbi;
 }
 
-U2SequenceDbi *MsaTestData::getSequenceDbi() {
-    if (nullptr == sequenceDbi) {
+U2SequenceDbi* MsaTestData::getSequenceDbi() {
+    if (sequenceDbi == nullptr) {
         init();
     }
     return sequenceDbi;
 }
 
 IMPLEMENT_TEST(MsaDbiUnitTests, createMsaObject) {
-    U2MsaDbi *msaDbi = MsaTestData::getMsaDbi();
+    U2MsaDbi* msaDbi = MsaTestData::getMsaDbi();
 
     U2AlphabetId testAlphabet = BaseDNAAlphabetIds::AMINO_DEFAULT();
 
@@ -86,7 +86,7 @@ IMPLEMENT_TEST(MsaDbiUnitTests, createMsaObject) {
     U2DataId msaId = msaDbi->createMsaObject("", "Test name", testAlphabet, os);
     CHECK_NO_ERROR(os);
 
-    const U2Msa &actual = msaDbi->getMsaObject(msaId, os);
+    const U2Msa& actual = msaDbi->getMsaObject(msaId, os);
     CHECK_NO_ERROR(os);
 
     CHECK_EQUAL(testAlphabet.id, actual.alphabet.id, "alphabet");
@@ -99,7 +99,7 @@ IMPLEMENT_TEST(MsaDbiUnitTests, createMsaObject) {
 
 IMPLEMENT_TEST(MsaDbiUnitTests, addRows) {
     U2OpStatusImpl os;
-    U2MsaDbi *msaDbi = MsaTestData::getMsaDbi();
+    U2MsaDbi* msaDbi = MsaTestData::getMsaDbi();
 
     // Create an alignment
     U2AlphabetId alphabet = BaseDNAAlphabetIds::NUCL_DNA_DEFAULT();
@@ -107,7 +107,7 @@ IMPLEMENT_TEST(MsaDbiUnitTests, addRows) {
     CHECK_NO_ERROR(os);
 
     // Create sequences
-    U2SequenceDbi *sequenceDbi = MsaTestData::getSequenceDbi();
+    U2SequenceDbi* sequenceDbi = MsaTestData::getSequenceDbi();
     U2Sequence seq1;
     U2Sequence seq2;
     sequenceDbi->createSequenceObject(seq1, "", os);
@@ -123,7 +123,7 @@ IMPLEMENT_TEST(MsaDbiUnitTests, addRows) {
 
     U2MsaGap row1gap1(0, 2);
     U2MsaGap row1gap2(3, 1);
-    QList<U2MsaGap> row1gaps;
+    QVector<U2MsaGap> row1gaps;
     row1gaps << row1gap1 << row1gap2;
 
     row1.gaps = row1gaps;
@@ -148,20 +148,20 @@ IMPLEMENT_TEST(MsaDbiUnitTests, addRows) {
     CHECK_NO_ERROR(os);
     CHECK_EQUAL(2, actualRows.count(), "number of rows");
 
-    const U2MsaRow &actualRow1 = actualRows[0];
+    const U2MsaRow& actualRow1 = actualRows[0];
     CHECK_EQUAL(rows.at(0).rowId, actualRow1.rowId, "first row id");
     CHECK_EQUAL(seq1.id, actualRow1.sequenceId, "first row sequence id");
     CHECK_EQUAL(0, actualRow1.gstart, "first row global start");
     CHECK_EQUAL(5, actualRow1.gend, "first row global end");
     CHECK_EQUAL(2, actualRow1.gaps.count(), "first row gaps count");
     U2MsaGap actualRow1Gap1 = actualRow1.gaps[0];
-    CHECK_EQUAL(0, actualRow1Gap1.offset, "first row gap1 offset");
-    CHECK_EQUAL(2, actualRow1Gap1.gap, "first row gap1 length");
+    CHECK_EQUAL(0, actualRow1Gap1.startPos, "first row gap1 offset");
+    CHECK_EQUAL(2, actualRow1Gap1.length, "first row gap1 length");
     U2MsaGap actualRow1Gap2 = actualRow1.gaps[1];
-    CHECK_EQUAL(3, actualRow1Gap2.offset, "first row gap2 offset");
-    CHECK_EQUAL(1, actualRow1Gap2.gap, "first row gap2 length");
+    CHECK_EQUAL(3, actualRow1Gap2.startPos, "first row gap2 offset");
+    CHECK_EQUAL(1, actualRow1Gap2.length, "first row gap2 length");
 
-    const U2MsaRow &actualRow2 = actualRows[1];
+    const U2MsaRow& actualRow2 = actualRows[1];
     CHECK_EQUAL(rows.at(1).rowId, actualRow2.rowId, "second row id");
     CHECK_EQUAL(seq2.id, actualRow2.sequenceId, "second row sequence id");
     CHECK_EQUAL(2, actualRow2.gstart, "second row global start");
@@ -171,14 +171,14 @@ IMPLEMENT_TEST(MsaDbiUnitTests, addRows) {
 
 IMPLEMENT_TEST(MsaDbiUnitTests, removeRows) {
     U2OpStatusImpl os;
-    U2MsaDbi *msaDbi = MsaTestData::getMsaDbi();
+    U2MsaDbi* msaDbi = MsaTestData::getMsaDbi();
 
     // Create an alignment
     U2DataId msaId = msaDbi->createMsaObject("", "Test name", BaseDNAAlphabetIds::NUCL_DNA_DEFAULT(), os);
     CHECK_NO_ERROR(os);
 
     // Create sequences
-    U2SequenceDbi *sequenceDbi = MsaTestData::getSequenceDbi();
+    U2SequenceDbi* sequenceDbi = MsaTestData::getSequenceDbi();
     U2Sequence seq1;
     U2Sequence seq2;
     U2Sequence seq3;
@@ -198,7 +198,7 @@ IMPLEMENT_TEST(MsaDbiUnitTests, removeRows) {
 
     U2MsaGap row1gap1(0, 2);
     U2MsaGap row1gap2(3, 1);
-    QList<U2MsaGap> row1gaps;
+    QVector<U2MsaGap> row1gaps;
     row1gaps << row1gap1 << row1gap2;
 
     row1.gaps = row1gaps;
@@ -209,7 +209,7 @@ IMPLEMENT_TEST(MsaDbiUnitTests, removeRows) {
     row2.gend = 4;
 
     U2MsaGap row2gap(1, 2);
-    QList<U2MsaGap> row2gaps;
+    QVector<U2MsaGap> row2gaps;
     row2gaps << row2gap;
 
     row2.gaps = row2gaps;
@@ -241,15 +241,15 @@ IMPLEMENT_TEST(MsaDbiUnitTests, removeRows) {
     CHECK_NO_ERROR(os);
     CHECK_EQUAL(1, actualRows.count(), "number of rows");
 
-    const U2MsaRow &actualRow = actualRows[0];
+    const U2MsaRow& actualRow = actualRows[0];
     CHECK_EQUAL(rows.at(1).rowId, actualRow.rowId, "row id");
     CHECK_EQUAL(seq2.id, actualRow.sequenceId, "row sequence id");
     CHECK_EQUAL(2, actualRow.gstart, "row global start");
     CHECK_EQUAL(4, actualRow.gend, "row global end");
     CHECK_EQUAL(1, actualRow.gaps.count(), "row gaps");
     U2MsaGap actualRowGap = actualRow.gaps[0];
-    CHECK_EQUAL(1, actualRowGap.offset, "row gap offset");
-    CHECK_EQUAL(2, actualRowGap.gap, "row gap length");
+    CHECK_EQUAL(1, actualRowGap.startPos, "row gap offset");
+    CHECK_EQUAL(2, actualRowGap.length, "row gap length");
 }
 
 }  // namespace U2
