@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_DBI_UNIT_TESTS_H_
-#define _U2_MSA_DBI_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -36,14 +35,14 @@ public:
     static void init();
     static void shutdown();
 
-    static U2MsaDbi *getMsaDbi();
-    static U2SequenceDbi *getSequenceDbi();
+    static U2MsaDbi* getMsaDbi();
+    static U2SequenceDbi* getSequenceDbi();
 
 private:
     static TestDbiProvider dbiProvider;
-    static const QString &MSA_DB_URL;
-    static U2MsaDbi *msaDbi;
-    static U2SequenceDbi *sequenceDbi;
+    static const QString& MSA_DB_URL;
+    static U2MsaDbi* msaDbi;
+    static U2SequenceDbi* sequenceDbi;
 };
 
 /** Create and get a MSA */
@@ -60,5 +59,3 @@ DECLARE_TEST(MsaDbiUnitTests, removeRows);
 DECLARE_METATYPE(MsaDbiUnitTests, createMsaObject);
 DECLARE_METATYPE(MsaDbiUnitTests, addRows);
 DECLARE_METATYPE(MsaDbiUnitTests, removeRows);
-
-#endif
