@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_DBI_UNITTESTS_H_
-#define _U2_SEQUENCE_DBI_UNITTESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -46,19 +45,19 @@ class SequenceTestData {
 public:
     static void init();
     static void shutdown();
-    static U2SequenceDbi *getSequenceDbi();
-    static QList<U2DataId> *getSequences() {
+    static U2SequenceDbi* getSequenceDbi();
+    static QList<U2DataId>* getSequences() {
         return sequences;
     };
-    static bool compareSequences(const U2Sequence &s1, const U2Sequence &s2);
-    static void checkUpdateSequence(UnitTest *t, const UpdateSequenceArgs &args);
-    static void replaceRegion(UnitTest *t, const QByteArray &originalSequence, const QByteArray &dataToInsert, const U2Region &region, QByteArray &resultSequence);
+    static bool compareSequences(const U2Sequence& s1, const U2Sequence& s2);
+    static void checkUpdateSequence(UnitTest* t, const UpdateSequenceArgs& args);
+    static void replaceRegion(UnitTest* t, const QByteArray& originalSequence, const QByteArray& dataToInsert, const U2Region& region, QByteArray& resultSequence);
 
 public:
-    static U2SequenceDbi *sequenceDbi;
-    static QList<U2DataId> *sequences;
+    static U2SequenceDbi* sequenceDbi;
+    static QList<U2DataId>* sequences;
 
-    static const QString &SEQ_DB_URL;
+    static const QString& SEQ_DB_URL;
 
 protected:
     static TestDbiProvider dbiProvider;
@@ -141,5 +140,3 @@ Q_DECLARE_METATYPE(U2::SequenceDbiUnitTests_updateHugeSequenceData);
 Q_DECLARE_METATYPE(U2::SequenceDbiUnitTests_updateSequenceData);
 Q_DECLARE_METATYPE(U2::SequenceDbiUnitTests_updateSequenceObject);
 Q_DECLARE_METATYPE(U2::SequenceDbiUnitTests_updateSequencesData);
-
-#endif  //_U2_SEQUENCE_DBI_UNITTESTS_H_
