@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -50,18 +50,18 @@ static QString getCommonDataDir() {
 
 static const QString WD_SCHEMES_PATH = getCommonDataDir() + "cmdline/wd-sas-schemes/";
 
-static U2ErrorType getActorDisplayName(const QString &actorId, QString &actorName) {
-    U2::Workflow::ActorPrototypeRegistry *prototypeRegistry = U2::Workflow::WorkflowEnv::getProtoRegistry();
-    CHECK(nullptr != prototypeRegistry, U2_INVALID_CALL);
-    U2::Workflow::ActorPrototype *prototype = prototypeRegistry->getProto(actorId);
-    CHECK(nullptr != prototype, U2_UNKNOWN_ELEMENT);
+static U2ErrorType getActorDisplayName(const QString& actorId, QString& actorName) {
+    U2::Workflow::ActorPrototypeRegistry* prototypeRegistry = U2::Workflow::WorkflowEnv::getProtoRegistry();
+    CHECK(prototypeRegistry != nullptr, U2_INVALID_CALL);
+    U2::Workflow::ActorPrototype* prototype = prototypeRegistry->getProto(actorId);
+    CHECK(prototype != nullptr, U2_UNKNOWN_ELEMENT);
     actorName = prototype->getDisplayName();
     return U2_OK;
 }
 
-static wchar_t *toDisposableWString(const QString &source) {
+static wchar_t* toDisposableWString(const QString& source) {
     CHECK(!source.isEmpty(), nullptr);
-    wchar_t *result = new wchar_t[source.size() + 1];
+    wchar_t* result = new wchar_t[source.size() + 1];
     source.toWCharArray(result);
     result[source.size()] = '\0';
     return result;
@@ -166,25 +166,7 @@ IMPLEMENT_TEST(CInterfaceSasTests, align_with_muscle_sas) {
 
     releaseScheme(scheme);
 }
-IMPLEMENT_TEST(CInterfaceSasTests, align_with_tcoffee_sas) {
-    SchemeHandle scheme = nullptr;
-    U2ErrorType error = createSas(L"tcoffee", nullptr, nullptr, &scheme);
-    CHECK_U2_ERROR(error);
-    QString readerName;
-    error = getActorDisplayName("read-msa", readerName);
-    CHECK_U2_ERROR(error);
-    gauto_array<wchar_t> wReaderName(toDisposableWString(readerName));
-    error = setSchemeElementAttribute(scheme, wReaderName.get(), L"url-in.dataset", L"Dataset 1");
-    CHECK_U2_ERROR(error);
 
-    U2OpStatusImpl stateInfo;
-    SchemeSimilarityUtils::checkSchemesSimilarity(scheme,
-                                                  WD_SCHEMES_PATH + "align_with_tcoffee.uwl",
-                                                  stateInfo);
-    CHECK_NO_ERROR(stateInfo);
-
-    releaseScheme(scheme);
-}
 IMPLEMENT_TEST(CInterfaceSasTests, annotate_with_uql_sas) {
     SchemeHandle scheme = nullptr;
     U2ErrorType error = createSas(L"query", nullptr, nullptr, &scheme);
@@ -423,7 +405,7 @@ IMPLEMENT_TEST(CInterfaceSasTests, join_sequences_into_alignment_sas) {
     releaseScheme(scheme);
 }
 
-IMPLEMENT_TEST(CInterfaceSasTests, local_blast_plus_search_sas) {
+IMPLEMENT_TEST(CInterfaceSasTests, local_blast_search_sas) {
     SchemeHandle scheme = nullptr;
     U2ErrorType error = createSas(L"blast-plus", nullptr, nullptr, &scheme);
     CHECK_U2_ERROR(error);
