@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GENBANK_LOCATION_PARSER_UNIT_TESTS_H_
-#define _U2_GENBANK_LOCATION_PARSER_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -88,5 +87,3 @@ DECLARE_METATYPE(LocationParserTestData, locationParserGreaterInvalid);
 DECLARE_METATYPE(LocationParserTestData, locationParserName);
 DECLARE_METATYPE(LocationParserTestData, locationParserNameInvalid);
 DECLARE_METATYPE(LocationParserTestData, locationBuildStringNumberInvalid);
-
-#endif
