@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_DBI_SQLITE_SPECIFIC_UNIT_TESTS_H_
-#define _U2_MSA_DBI_SQLITE_SPECIFIC_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -37,23 +36,23 @@ public:
     static void init();
     static void shutdown();
 
-    static SQLiteDbi *getSQLiteDbi();
+    static SQLiteDbi* getSQLiteDbi();
 
-    static qint64 getModStepsNum(const U2DataId &objId, U2OpStatus &os);
+    static qint64 getModStepsNum(const U2DataId& objId, U2OpStatus& os);
 
-    static U2DataId createTestMsa(bool enableModTracking, U2OpStatus &os);
-    static U2DataId createNotSoSmallTestMsa(bool enableModTracking, U2OpStatus &os);
-    static U2DataId createTestSequence(bool enableModTracking, qint64 seqLength, U2OpStatus &os);
-    static U2MsaRow createRow(qint64 seqLength, U2OpStatus &os);
+    static U2DataId createTestMsa(bool enableModTracking, U2OpStatus& os);
+    static U2DataId createNotSoSmallTestMsa(bool enableModTracking, U2OpStatus& os);
+    static U2DataId createTestSequence(bool enableModTracking, qint64 seqLength, U2OpStatus& os);
+    static U2MsaRow createRow(qint64 seqLength, U2OpStatus& os);
 
     static const QString TEST_MSA_NAME;
 
 private:
-    static U2MsaRow addRow(const U2DataId &msaId, const QByteArray &name, const QByteArray &seq, const QList<U2MsaGap> &gaps, U2OpStatus &os);
+    static U2MsaRow addRow(const U2DataId& msaId, const QByteArray& name, const QByteArray& seq, const QVector<U2MsaGap>& gaps, U2OpStatus& os);
 
     static TestDbiProvider dbiProvider;
-    static const QString &SQLITE_MSA_DB_URL;
-    static SQLiteDbi *sqliteDbi;
+    static const QString& SQLITE_MSA_DB_URL;
+    static SQLiteDbi* sqliteDbi;
 };
 
 ///////////////////////////////////////////////////////////////
@@ -209,5 +208,3 @@ DECLARE_METATYPE(MsaDbiSQLiteSpecificUnitTests, removeRows_redo);
 DECLARE_METATYPE(MsaDbiSQLiteSpecificUnitTests, addRows_noModTrack);
 DECLARE_METATYPE(MsaDbiSQLiteSpecificUnitTests, addRows_undo);
 DECLARE_METATYPE(MsaDbiSQLiteSpecificUnitTests, addRows_redo);
-
-#endif
