@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -37,21 +37,21 @@
 namespace U2 {
 
 TestDbiProvider SQLiteObjectDbiTestData::dbiProvider = TestDbiProvider();
-const QString &SQLiteObjectDbiTestData::SQLITE_OBJ_DB_URL("sqlite-obj-dbi.ugenedb");
-U2AttributeDbi *SQLiteObjectDbiTestData::attributeDbi = nullptr;
-U2MsaDbi *SQLiteObjectDbiTestData::msaDbi = nullptr;
-U2SequenceDbi *SQLiteObjectDbiTestData::sequenceDbi = nullptr;
-SQLiteDbi *SQLiteObjectDbiTestData::sqliteDbi = nullptr;
-SQLiteObjectDbi *SQLiteObjectDbiTestData::sqliteObjectDbi = nullptr;
+const QString& SQLiteObjectDbiTestData::SQLITE_OBJ_DB_URL("sqlite-obj-dbi.ugenedb");
+U2AttributeDbi* SQLiteObjectDbiTestData::attributeDbi = nullptr;
+U2MsaDbi* SQLiteObjectDbiTestData::msaDbi = nullptr;
+U2SequenceDbi* SQLiteObjectDbiTestData::sequenceDbi = nullptr;
+SQLiteDbi* SQLiteObjectDbiTestData::sqliteDbi = nullptr;
+SQLiteObjectDbi* SQLiteObjectDbiTestData::sqliteObjectDbi = nullptr;
 
 void SQLiteObjectDbiTestData::init() {
-    SAFE_POINT(nullptr == sqliteDbi, "sqliteDbi has already been initialized!", );
+    SAFE_POINT(sqliteDbi == nullptr, "sqliteDbi has already been initialized!", );
 
     // Get URL
     bool ok = dbiProvider.init(SQLITE_OBJ_DB_URL, false);
     SAFE_POINT(ok, "Dbi provider failed to initialize in MsaTestData::init()!", );
 
-    U2Dbi *dbi = dbiProvider.getDbi();
+    U2Dbi* dbi = dbiProvider.getDbi();
     QString url = dbi->getDbiRef().dbiId;
     dbiProvider.close();
 
@@ -64,20 +64,20 @@ void SQLiteObjectDbiTestData::init() {
     SAFE_POINT_OP(os, );
 
     sqliteObjectDbi = sqliteDbi->getSQLiteObjectDbi();
-    SAFE_POINT(nullptr != sqliteObjectDbi, "Failed to get sqliteObjectDbi!", );
+    SAFE_POINT(sqliteObjectDbi != nullptr, "Failed to get sqliteObjectDbi!", );
 
     attributeDbi = sqliteDbi->getAttributeDbi();
-    SAFE_POINT(nullptr != attributeDbi, "Failed to get attributeDbi!", );
+    SAFE_POINT(attributeDbi != nullptr, "Failed to get attributeDbi!", );
 
     msaDbi = sqliteDbi->getMsaDbi();
-    SAFE_POINT(nullptr != msaDbi, "Failed to get msaDbi!", );
+    SAFE_POINT(msaDbi != nullptr, "Failed to get msaDbi!", );
 
     sequenceDbi = sqliteDbi->getSequenceDbi();
-    SAFE_POINT(nullptr != sequenceDbi, "Failed to get sequenceDbi!", );
+    SAFE_POINT(sequenceDbi != nullptr, "Failed to get sequenceDbi!", );
 }
 
 void SQLiteObjectDbiTestData::shutdown() {
-    if (nullptr != sqliteDbi) {
+    if (sqliteDbi != nullptr) {
         delete sqliteDbi;
 
         sqliteDbi = nullptr;
@@ -88,42 +88,42 @@ void SQLiteObjectDbiTestData::shutdown() {
     }
 }
 
-SQLiteDbi *SQLiteObjectDbiTestData::getSQLiteDbi() {
-    if (nullptr == sqliteDbi) {
+SQLiteDbi* SQLiteObjectDbiTestData::getSQLiteDbi() {
+    if (sqliteDbi == nullptr) {
         init();
     }
     return sqliteDbi;
 }
 
-SQLiteObjectDbi *SQLiteObjectDbiTestData::getSQLiteObjectDbi() {
-    if (nullptr == sqliteObjectDbi) {
+SQLiteObjectDbi* SQLiteObjectDbiTestData::getSQLiteObjectDbi() {
+    if (sqliteObjectDbi == nullptr) {
         init();
     }
     return sqliteObjectDbi;
 }
 
-U2AttributeDbi *SQLiteObjectDbiTestData::getAttributeDbi() {
-    if (nullptr == attributeDbi) {
+U2AttributeDbi* SQLiteObjectDbiTestData::getAttributeDbi() {
+    if (attributeDbi == nullptr) {
         init();
     }
     return attributeDbi;
 }
 
-U2MsaDbi *SQLiteObjectDbiTestData::getMsaDbi() {
-    if (nullptr == msaDbi) {
+U2MsaDbi* SQLiteObjectDbiTestData::getMsaDbi() {
+    if (msaDbi == nullptr) {
         init();
     }
     return msaDbi;
 }
 
-U2SequenceDbi *SQLiteObjectDbiTestData::getSequenceDbi() {
-    if (nullptr == sequenceDbi) {
+U2SequenceDbi* SQLiteObjectDbiTestData::getSequenceDbi() {
+    if (sequenceDbi == nullptr) {
         init();
     }
     return sequenceDbi;
 }
 
-U2DataId SQLiteObjectDbiTestData::createTestMsa(bool enableModTracking, U2OpStatus &os) {
+U2DataId SQLiteObjectDbiTestData::createTestMsa(bool enableModTracking, U2OpStatus& os) {
     // Create an alignment
     U2AlphabetId alphabet = BaseDNAAlphabetIds::NUCL_DNA_DEFAULT();
     U2DataId msaId = sqliteDbi->getMsaDbi()->createMsaObject("", "Test alignment", alphabet, os);
@@ -137,7 +137,7 @@ U2DataId SQLiteObjectDbiTestData::createTestMsa(bool enableModTracking, U2OpStat
     return msaId;
 }
 
-void SQLiteObjectDbiTestData::addTestRow(const U2DataId &msaId, U2OpStatus &os) {
+void SQLiteObjectDbiTestData::addTestRow(const U2DataId& msaId, U2OpStatus& os) {
     U2Sequence seq;
     seq.alphabet = BaseDNAAlphabetIds::NUCL_DNA_DEFAULT();
     seq.circular = false;
@@ -158,7 +158,7 @@ void SQLiteObjectDbiTestData::addTestRow(const U2DataId &msaId, U2OpStatus &os)
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, removeMsaObject) {
     U2OpStatusImpl os;
-    U2MsaDbi *msaDbi = SQLiteObjectDbiTestData::getMsaDbi();
+    U2MsaDbi* msaDbi = SQLiteObjectDbiTestData::getMsaDbi();
 
     // FIRST ALIGNMENT
     // Create an alignment
@@ -167,12 +167,12 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, removeMsaObject) {
 
     // Add alignment info
     U2StringAttribute attr(msaId, "MSA1 info key", "MSA1 info value");
-    U2AttributeDbi *attrDbi = SQLiteObjectDbiTestData::getAttributeDbi();
+    U2AttributeDbi* attrDbi = SQLiteObjectDbiTestData::getAttributeDbi();
     attrDbi->createStringAttribute(attr, os);
     CHECK_NO_ERROR(os);
 
     // Create sequences
-    U2SequenceDbi *sequenceDbi = SQLiteObjectDbiTestData::getSequenceDbi();
+    U2SequenceDbi* sequenceDbi = SQLiteObjectDbiTestData::getSequenceDbi();
     U2Sequence seq1;
     U2Sequence seq2;
     sequenceDbi->createSequenceObject(seq1, "", os);
@@ -189,7 +189,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, removeMsaObject) {
 
     U2MsaGap row1gap1(0, 2);
     U2MsaGap row1gap2(3, 1);
-    QList<U2MsaGap> row1gaps;
+    QVector<U2MsaGap> row1gaps;
     row1gaps << row1gap1 << row1gap2;
 
     row1.gaps = row1gaps;
@@ -201,7 +201,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, removeMsaObject) {
     row2.gend = 4;
 
     U2MsaGap row2gap(1, 2);
-    QList<U2MsaGap> row2gaps;
+    QVector<U2MsaGap> row2gaps;
     row2gaps << row2gap;
 
     row2.gaps = row2gaps;
@@ -235,7 +235,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, removeMsaObject) {
     al2Row.gend = 15;
 
     U2MsaGap al2RowGap(1, 12);
-    QList<U2MsaGap> al2RowGaps;
+    QVector<U2MsaGap> al2RowGaps;
     al2RowGaps << al2RowGap;
 
     al2Row.gaps = al2RowGaps;
@@ -247,11 +247,11 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, removeMsaObject) {
     CHECK_NO_ERROR(os);
 
     // REMOVE THE FIRST ALIGNMENT OBJECT
-    SQLiteObjectDbi *sqliteObjectDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    SQLiteObjectDbi* sqliteObjectDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
     sqliteObjectDbi->removeObject(msaId, os);
 
     // VERIFY THAT THERE IS ONLY THE SECOND ALIGNMENT'S RECORDS LEFT IN TABLES
-    SQLiteDbi *sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
+    SQLiteDbi* sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
 
     // "Attribute"
     SQLiteReadQuery qAttr("SELECT COUNT(*) FROM Attribute WHERE name = ?1", sqliteDbi->getDbRef(), os);
@@ -341,13 +341,13 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, removeMsaObject) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, setTrackModType) {
     U2OpStatusImpl os;
-    U2MsaDbi *msaDbi = SQLiteObjectDbiTestData::getMsaDbi();
-    SQLiteObjectDbi *objectDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    U2MsaDbi* msaDbi = SQLiteObjectDbiTestData::getMsaDbi();
+    SQLiteObjectDbi* objectDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
 
     // Create alignment 1
     U2DataId msaId1 = msaDbi->createMsaObject("", "Test name 1", BaseDNAAlphabetIds::NUCL_DNA_DEFAULT(), os);
     CHECK_NO_ERROR(os);
-    Utils::addRow(msaDbi->getRootDbi(), msaId1, "1", "ACGTACGT", QList<U2MsaGap>(), os);
+    Utils::addRow(msaDbi->getRootDbi(), msaId1, "1", "ACGTACGT", QVector<U2MsaGap>(), os);
     CHECK_NO_ERROR(os);
     QList<U2MsaRow> rows1 = msaDbi->getRows(msaId1, os);
     CHECK_NO_ERROR(os);
@@ -355,7 +355,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, setTrackModType) {
     // Create alignment 2
     U2DataId msaId2 = msaDbi->createMsaObject("", "Test name 2", BaseDNAAlphabetIds::NUCL_DNA_DEFAULT(), os);
     CHECK_NO_ERROR(os);
-    Utils::addRow(msaDbi->getRootDbi(), msaId2, "2", "CCCCCCC", QList<U2MsaGap>(), os);
+    Utils::addRow(msaDbi->getRootDbi(), msaId2, "2", "CCCCCCC", QVector<U2MsaGap>(), os);
     CHECK_NO_ERROR(os);
     QList<U2MsaRow> rows2 = msaDbi->getRows(msaId2, os);
     CHECK_NO_ERROR(os);
@@ -385,7 +385,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, setTrackModType) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_noTrack) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(false, os);
@@ -406,7 +406,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_noTrack) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_noAction) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -423,7 +423,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_noAction) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_lastState) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -444,7 +444,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_lastState) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_firstState) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -467,7 +467,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_firstState) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_midState) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -493,7 +493,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_midState) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_oneUserStep) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -534,8 +534,8 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, canUndoRedo_oneUserStep) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_user3Multi) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
-    SQLiteDbi *sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    SQLiteDbi* sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -622,8 +622,8 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_user3Multi) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionAfterUndo) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
-    SQLiteDbi *sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    SQLiteDbi* sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -709,8 +709,8 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionAfterUndo) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo1) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
-    SQLiteDbi *sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    SQLiteDbi* sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -783,8 +783,8 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo1) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo2) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
-    SQLiteDbi *sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    SQLiteDbi* sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -843,8 +843,8 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo2) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo3) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
-    SQLiteDbi *sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    SQLiteDbi* sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -910,8 +910,8 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo3) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo4) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
-    SQLiteDbi *sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    SQLiteDbi* sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -977,8 +977,8 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo4) {
 
 IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_user3Single6) {
     U2OpStatusImpl os;
-    U2ObjectDbi *objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
-    SQLiteDbi *sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
+    U2ObjectDbi* objDbi = SQLiteObjectDbiTestData::getSQLiteObjectDbi();
+    SQLiteDbi* sqliteDbi = SQLiteObjectDbiTestData::getSQLiteDbi();
 
     // Create test msa
     U2DataId msaId = SQLiteObjectDbiTestData::createTestMsa(true, os);
@@ -1041,7 +1041,7 @@ IMPLEMENT_TEST(SQLiteObjectDbiUnitTests, commonUndoRedo_user3Single6) {
         sqliteDbi->getMsaDbi()->addRow(msaId, -1, row, os);  // multi/single step 4
         CHECK_NO_ERROR(os);
 
-        sqliteDbi->getMsaDbi()->updateRowContent(msaId, row.rowId, "ACGT", QList<U2MsaGap>(), os);  // multi step 5, single steps 5-6
+        sqliteDbi->getMsaDbi()->updateRowContent(msaId, row.rowId, "ACGT", QVector<U2MsaGap>(), os);  // multi step 5, single steps 5-6
         CHECK_NO_ERROR(os);
     }
 
