@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SQLITE_OBJECT_DBI_UNIT_TESTS_H_
-#define _U2_SQLITE_OBJECT_DBI_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -40,23 +39,23 @@ public:
 
     static void shutdown();
 
-    static SQLiteDbi *getSQLiteDbi();
-    static SQLiteObjectDbi *getSQLiteObjectDbi();
-    static U2AttributeDbi *getAttributeDbi();
-    static U2MsaDbi *getMsaDbi();
-    static U2SequenceDbi *getSequenceDbi();
+    static SQLiteDbi* getSQLiteDbi();
+    static SQLiteObjectDbi* getSQLiteObjectDbi();
+    static U2AttributeDbi* getAttributeDbi();
+    static U2MsaDbi* getMsaDbi();
+    static U2SequenceDbi* getSequenceDbi();
 
-    static U2DataId createTestMsa(bool enableModTracking, U2OpStatus &os);
-    static void addTestRow(const U2DataId &msaId, U2OpStatus &os);
+    static U2DataId createTestMsa(bool enableModTracking, U2OpStatus& os);
+    static void addTestRow(const U2DataId& msaId, U2OpStatus& os);
 
 private:
     static TestDbiProvider dbiProvider;
-    static const QString &SQLITE_OBJ_DB_URL;
-    static U2AttributeDbi *attributeDbi;
-    static U2MsaDbi *msaDbi;
-    static U2SequenceDbi *sequenceDbi;
-    static SQLiteObjectDbi *sqliteObjectDbi;
-    static SQLiteDbi *sqliteDbi;
+    static const QString& SQLITE_OBJ_DB_URL;
+    static U2AttributeDbi* attributeDbi;
+    static U2MsaDbi* msaDbi;
+    static U2SequenceDbi* sequenceDbi;
+    static SQLiteObjectDbi* sqliteObjectDbi;
+    static SQLiteDbi* sqliteDbi;
 };
 
 /**
@@ -133,5 +132,3 @@ DECLARE_METATYPE(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo2)
 DECLARE_METATYPE(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo3);
 DECLARE_METATYPE(SQLiteObjectDbiUnitTests, commonUndoRedo_actionUndoActionUndo4);
 DECLARE_METATYPE(SQLiteObjectDbiUnitTests, commonUndoRedo_user3Single6);
-
-#endif
