@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_DBI_SQLITE_SPECIFIC_UNIT_TESTS_H_
-#define _U2_SEQUENCE_DBI_SQLITE_SPECIFIC_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -36,19 +35,19 @@ public:
     static void init();
     static void shutdown();
 
-    static SQLiteDbi *getSQLiteDbi();
+    static SQLiteDbi* getSQLiteDbi();
 
-    static U2DataId createTestSequence(bool enableModTracking, qint64 seqLength, U2OpStatus &os);
-    static U2DataId createTestSequence(bool enableModTracking, const QByteArray &seqData, U2OpStatus &os);
+    static U2DataId createTestSequence(bool enableModTracking, qint64 seqLength, U2OpStatus& os);
+    static U2DataId createTestSequence(bool enableModTracking, const QByteArray& seqData, U2OpStatus& os);
 
-    static qint64 getModStepsNum(const U2DataId &objId, U2OpStatus &os);
+    static qint64 getModStepsNum(const U2DataId& objId, U2OpStatus& os);
 
     static const QString TEST_SEQUENCE_NAME;
 
 private:
     static TestDbiProvider dbiProvider;
-    static const QString &SQLITE_SEQUENCE_DB_URL;
-    static SQLiteDbi *sqliteDbi;
+    static const QString& SQLITE_SEQUENCE_DB_URL;
+    static SQLiteDbi* sqliteDbi;
 };
 
 ///////////////////////////////////////////////////////////////
@@ -125,5 +124,3 @@ DECLARE_METATYPE(SequenceDbiSQLiteSpecificUnitTests, updateSeqData_begin_redo);
 DECLARE_METATYPE(SequenceDbiSQLiteSpecificUnitTests, updateSeqData_middle_redo);
 DECLARE_METATYPE(SequenceDbiSQLiteSpecificUnitTests, updateSeqData_middle_middleNoLength_redo);
 DECLARE_METATYPE(SequenceDbiSQLiteSpecificUnitTests, updateSeqData_end_redo);
-
-#endif  // _U2_SEQUENCE_DBI_SQLITE_SPECIFIC_UNIT_TESTS_H_
