@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,12 +22,10 @@
 #include "FeaturesTableObjectUnitTest.h"
 
 #include <QBitArray>
-#include <QDir>
 #include <QScopedPointer>
 
 #include <U2Core/AnnotationTableObjectConstraints.h>
 #include <U2Core/AppContext.h>
-#include <U2Core/AppSettings.h>
 #include <U2Core/U2FeatureDbi.h>
 #include <U2Core/U2FeatureKeys.h>
 #include <U2Core/U2FeatureUtils.h>
@@ -35,12 +33,10 @@
 #include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/U2SafePoints.h>
 
-#include <U2Test/TestRunnerSettings.h>
-
 namespace U2 {
 
 template<>
-QString toString<U2FeatureLocation>(const U2FeatureLocation &loc) {
+QString toString<U2FeatureLocation>(const U2FeatureLocation& loc) {
     QString strand = loc.strand == U2Strand::Direct ? "direct" : loc.strand == U2Strand::Complementary ? "complement"
                                                                                                        : "nostrand";
     return QString("%1-%2").arg(loc.region.toString()).arg(strand);
@@ -50,7 +46,7 @@ namespace {
 const QString FEATURE_DB_URL("feature-dbi.ugenedb");
 }
 
-U2FeatureDbi *FeaturesTableObjectTestData::featureDbi = nullptr;
+U2FeatureDbi* FeaturesTableObjectTestData::featureDbi = nullptr;
 TestDbiProvider FeaturesTableObjectTestData::dbiProvider;
 
 void FeaturesTableObjectTestData::init() {
@@ -58,11 +54,11 @@ void FeaturesTableObjectTestData::init() {
     SAFE_POINT(ok, "dbi provider failed to initialize", );
 
     featureDbi = dbiProvider.getDbi()->getFeatureDbi();
-    SAFE_POINT(nullptr != featureDbi, "feature database not loaded", );
+    SAFE_POINT(featureDbi != nullptr, "feature database not loaded", );
 }
 
-U2FeatureDbi *FeaturesTableObjectTestData::getFeatureDbi() {
-    if (nullptr == featureDbi) {
+U2FeatureDbi* FeaturesTableObjectTestData::getFeatureDbi() {
+    if (featureDbi == nullptr) {
         init();
     }
     return featureDbi;
@@ -73,7 +69,7 @@ static U2DbiRef getDbiRef() {
 }
 
 void FeaturesTableObjectTestData::shutdown() {
-    if (nullptr != featureDbi) {
+    if (featureDbi != nullptr) {
         U2OpStatusImpl opStatus;
         dbiProvider.close();
         featureDbi = nullptr;
@@ -82,20 +78,20 @@ void FeaturesTableObjectTestData::shutdown() {
 }
 
 IMPLEMENT_TEST(FeatureTableObjectUnitTest, createEmptyFeaturesTableObject) {
-    U2FeatureDbi *featureDbi = FeaturesTableObjectTestData::getFeatureDbi();
+    U2FeatureDbi* featureDbi = FeaturesTableObjectTestData::getFeatureDbi();
 
     AnnotationTableObject ft("empty", getDbiRef());
-    const U2DataId &objRootFeatureId = ft.getRootFeatureId();
+    const U2DataId& objRootFeatureId = ft.getRootFeatureId();
     CHECK_TRUE(!objRootFeatureId.isEmpty(), "invalid root feature id");
 
     U2OpStatusImpl os;
-    const U2Feature &actual = featureDbi->getFeature(objRootFeatureId, os);
+    const U2Feature& actual = featureDbi->getFeature(objRootFeatureId, os);
     CHECK_NO_ERROR(os);
     CHECK_EQUAL(objRootFeatureId, actual.id, "root feature id");
 }
 
 IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationSingleRegion) {
-    U2FeatureDbi *featureDbi = FeaturesTableObjectTestData::getFeatureDbi();
+    U2FeatureDbi* featureDbi = FeaturesTableObjectTestData::getFeatureDbi();
 
     const QString aname = "aname_single";
     const QString grname = "agroupename_single";
@@ -112,7 +108,7 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationSingleRegion) {
     AnnotationTableObject ft("aname_table_single", dbiRef);
     ft.addAnnotations(QList<SharedAnnotationData>() << anData, grname);
 
-    const U2DataId &objRootFeatureId = ft.getRootFeatureId();
+    const U2DataId& objRootFeatureId = ft.getRootFeatureId();
     CHECK_TRUE(!objRootFeatureId.isEmpty(), "invalid root feature id");
 
     U2OpStatusImpl os;
@@ -134,7 +130,7 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationSingleRegion) {
     // check groups and qualifiers
     const QList<U2FeatureKey> fkeys = featureDbi->getFeatureKeys(subAnnotation.id, os);
     bool hasQual = false;
-    foreach (const U2FeatureKey &fkey, fkeys) {
+    foreach (const U2FeatureKey& fkey, fkeys) {
         if (fkey.name == qualname && !hasQual) {
             hasQual = fkey.value == qualval;
         }
@@ -143,7 +139,7 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationSingleRegion) {
 }
 
 IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationMultipleRegion) {
-    U2FeatureDbi *featureDbi = FeaturesTableObjectTestData::getFeatureDbi();
+    U2FeatureDbi* featureDbi = FeaturesTableObjectTestData::getFeatureDbi();
 
     const QString fname = "aname_table_multy";
     const QString aname = "aname_multy";
@@ -163,11 +159,11 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationMultipleRegion) {
     AnnotationTableObject ft(fname, dbiRef);
     ft.addAnnotations(QList<SharedAnnotationData>() << anData, grname);
 
-    const U2DataId &objRootFeatureId = ft.getRootFeatureId();
+    const U2DataId& objRootFeatureId = ft.getRootFeatureId();
     CHECK_TRUE(!objRootFeatureId.isEmpty(), "invalid root feature id");
 
     U2OpStatusImpl os;
-    const QList<U2Feature> annSubfeatures = U2FeatureUtils::getSubAnnotations(objRootFeatureId, dbiRef, os, Recursive, Root);
+    QList<U2Feature> annSubfeatures = U2FeatureUtils::getSubAnnotations(objRootFeatureId, dbiRef, os, Recursive, Root);
     CHECK_NO_ERROR(os);
     CHECK_EQUAL(1, annSubfeatures.size(), "annotating subfeatures of root feature");
 
@@ -175,17 +171,17 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationMultipleRegion) {
     CHECK_NO_ERROR(os);
     CHECK_EQUAL(1, groupSubfeatures.size(), "group subfeatures of root feature");
 
-    const U2Feature subAnnotation = annSubfeatures.first();
-    const U2Feature subGroup = groupSubfeatures.first();
+    U2Feature subAnnotation = annSubfeatures.first();
+    U2Feature subGroup = groupSubfeatures.first();
 
     CHECK_EQUAL(aname, subAnnotation.name, "feature name");
-    CHECK_EQUAL(U2Region(), subAnnotation.location.region, "feature region");
+    CHECK_EQUAL(U2Region(1, 2), subAnnotation.location.region, "feature region");
     CHECK_EQUAL(subGroup.id, subAnnotation.parentFeatureId, "feature parent id");
 
     // check groups and qualifiers
     const QList<U2FeatureKey> fkeys = featureDbi->getFeatureKeys(subAnnotation.id, os);
     bool hasQual = false;
-    foreach (const U2FeatureKey &fkey, fkeys) {
+    foreach (const U2FeatureKey& fkey, fkeys) {
         if (fkey.name == qualname && !hasQual) {
             hasQual = fkey.value == qualval;
         }
@@ -198,7 +194,7 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationMultipleRegion) {
     CHECK_EQUAL(3, processedData->location->regions.size(), "subfeatures of multi-region feature");
 
     QBitArray regs(3, false);
-    foreach (const U2Region &reg, processedData->location->regions) {
+    foreach (const U2Region& reg, processedData->location->regions) {
         if (reg == areg1) {
             regs.setBit(0, true);
         } else if (reg == areg2) {
@@ -233,11 +229,11 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, getAnnotations) {
     AnnotationTableObject ft("ftable_name", dbiRef);
     ft.addAnnotations(QList<SharedAnnotationData>() << anData1 << anData2 << anData3, grname);
 
-    const QList<Annotation *> annotations = ft.getAnnotations();
+    const QList<Annotation*> annotations = ft.getAnnotations();
     CHECK_EQUAL(3, annotations.size(), "annotation count");
 
     QBitArray annotationMatches(3, false);
-    foreach (Annotation *annotation, annotations) {
+    foreach (Annotation* annotation, annotations) {
         if (annotation->getName() == aname1) {
             annotationMatches.setBit(0, true);
         } else if (annotation->getName() == aname2) {
@@ -262,10 +258,10 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, getRootGroup) {
     AnnotationTableObject ft("ftable_name", dbiRef);
     ft.addAnnotations(QList<SharedAnnotationData>() << anData, grname);
 
-    AnnotationGroup *rootGroup = ft.getRootGroup();
+    AnnotationGroup* rootGroup = ft.getRootGroup();
     CHECK_TRUE(rootGroup->hasValidId(), "root group ID");
 
-    const QList<AnnotationGroup *> subgroups = rootGroup->getSubgroups();
+    const QList<AnnotationGroup*> subgroups = rootGroup->getSubgroups();
     CHECK_EQUAL(1, subgroups.size(), "count of annotation groups");
     CHECK_EQUAL(grname, subgroups.first()->getName(), "group's name");
 }
@@ -295,25 +291,25 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationsToRootGroup) {
     AnnotationTableObject ft("ftable_name", dbiRef);
     ft.addAnnotations(annotations);
 
-    AnnotationGroup *rootGroup = ft.getRootGroup();
+    AnnotationGroup* rootGroup = ft.getRootGroup();
     CHECK_TRUE(rootGroup->hasValidId(), "root group ID");
 
-    const QList<AnnotationGroup *> subgroups = rootGroup->getSubgroups();
+    const QList<AnnotationGroup*> subgroups = rootGroup->getSubgroups();
     CHECK_EQUAL(2, subgroups.size(), "root annotation group has subgroups");
 
     QBitArray groupMatches(2, false);
-    foreach (AnnotationGroup *group, subgroups) {
+    foreach (AnnotationGroup* group, subgroups) {
         if (group->getName() == aname1) {
             groupMatches.setBit(0, true);
 
-            const QList<Annotation *> anns = group->getAnnotations();
+            const QList<Annotation*> anns = group->getAnnotations();
             CHECK_EQUAL(1, anns.size(), "count of annotations");
 
             CHECK_EQUAL(2, anns.first()->getLocation()->regions.size(), "count of annotation regions");
         } else if (group->getName() == aname2) {
             groupMatches.setBit(1, true);
 
-            const QList<Annotation *> anns = group->getAnnotations();
+            const QList<Annotation*> anns = group->getAnnotations();
             CHECK_EQUAL(2, anns.size(), "count of annotations");
         }
     }
@@ -347,19 +343,19 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, addAnnotationsToSubgroup) {
     AnnotationTableObject ft("ftable_name", dbiRef);
     ft.addAnnotations(annotations, grname);
 
-    AnnotationGroup *rootGroup = ft.getRootGroup();
+    AnnotationGroup* rootGroup = ft.getRootGroup();
     CHECK_TRUE(rootGroup->hasValidId(), "root group ID");
 
-    const QList<AnnotationGroup *> subgroup1 = rootGroup->getSubgroups();
+    const QList<AnnotationGroup*> subgroup1 = rootGroup->getSubgroups();
     CHECK_EQUAL(1, subgroup1.size(), "root group's subgroups");
 
-    const QList<Annotation *> anns1 = subgroup1.first()->getAnnotations();
+    const QList<Annotation*> anns1 = subgroup1.first()->getAnnotations();
     CHECK_EQUAL(0, anns1.size(), "annotation count");
 
-    const QList<AnnotationGroup *> subgroup2 = subgroup1.first()->getSubgroups();
+    const QList<AnnotationGroup*> subgroup2 = subgroup1.first()->getSubgroups();
     CHECK_EQUAL(1, subgroup2.size(), "subgroup count");
 
-    const QList<Annotation *> anns2 = subgroup2.first()->getAnnotations();
+    const QList<Annotation*> anns2 = subgroup2.first()->getAnnotations();
     CHECK_EQUAL(3, anns2.size(), "annotation count");
 }
 
@@ -390,17 +386,17 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, removeAnnotation) {
     U2OpStatusImpl os;
     ft.addAnnotations(annotations, grname);
 
-    AnnotationGroup *rootGroup = ft.getRootGroup();
+    AnnotationGroup* rootGroup = ft.getRootGroup();
     CHECK_TRUE(rootGroup->hasValidId(), "root group ID");
 
-    const QList<AnnotationGroup *> subgroup = rootGroup->getSubgroups();
+    const QList<AnnotationGroup*> subgroup = rootGroup->getSubgroups();
     CHECK_EQUAL(1, subgroup.size(), "root group's subgroups");
 
-    const QList<Annotation *> annsBefore = subgroup.first()->getAnnotations();
+    const QList<Annotation*> annsBefore = subgroup.first()->getAnnotations();
     CHECK_EQUAL(3, annsBefore.size(), "annotation count");
 
-    QList<Annotation *> annsToRemove;
-    foreach (Annotation *ann, annsBefore) {
+    QList<Annotation*> annsToRemove;
+    foreach (Annotation* ann, annsBefore) {
         if (aname1 == ann->getName()) {
             annsToRemove.append(ann);
         }
@@ -438,13 +434,13 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, removeAnnotations) {
     AnnotationTableObject ft("ftable_name", dbiRef);
     ft.addAnnotations(annotations, grname);
 
-    AnnotationGroup *rootGroup = ft.getRootGroup();
+    AnnotationGroup* rootGroup = ft.getRootGroup();
     CHECK_TRUE(rootGroup->hasValidId(), "root group ID");
 
-    const QList<AnnotationGroup *> subgroup = rootGroup->getSubgroups();
+    const QList<AnnotationGroup*> subgroup = rootGroup->getSubgroups();
     CHECK_EQUAL(1, subgroup.size(), "root group's subgroups");
 
-    const QList<Annotation *> annsBefore = subgroup.first()->getAnnotations();
+    const QList<Annotation*> annsBefore = subgroup.first()->getAnnotations();
     CHECK_EQUAL(3, annsBefore.size(), "annotation count");
 
     ft.removeAnnotations(annsBefore);
@@ -458,7 +454,6 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, removeAnnotations) {
 IMPLEMENT_TEST(FeatureTableObjectUnitTest, clone) {
     const QString aname1 = "aname1";
     const QString aname2 = "aname2";
-    const QString aname3 = "aname3";
     const U2Region areg1(7, 100);
     const U2Region areg2(1000, 200);
     const U2DbiRef dbiRef(getDbiRef());
@@ -481,28 +476,28 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, clone) {
     AnnotationTableObject ft("ftable_name", dbiRef);
     ft.addAnnotations(annotations);
 
-    AnnotationGroup *sourceRootGroup = ft.getRootGroup();
+    AnnotationGroup* sourceRootGroup = ft.getRootGroup();
 
     U2OpStatusImpl os;
-    QScopedPointer<AnnotationTableObject> clonedTable(dynamic_cast<AnnotationTableObject *>(ft.clone(dbiRef, os)));
+    QScopedPointer<AnnotationTableObject> clonedTable(dynamic_cast<AnnotationTableObject*>(ft.clone(dbiRef, os)));
     CHECK_NO_ERROR(os);
 
-    AnnotationGroup *clonedRootGroup = clonedTable->getRootGroup();
+    AnnotationGroup* clonedRootGroup = clonedTable->getRootGroup();
     CHECK_TRUE(clonedRootGroup->hasValidId(), "cloned root group ID");
     CHECK_NOT_EQUAL(clonedRootGroup->id, sourceRootGroup->id, "root group");
 
-    const QList<AnnotationGroup *> clonedSubgroups = clonedRootGroup->getSubgroups();
-    QList<AnnotationGroup *> sourceSubgroups = sourceRootGroup->getSubgroups();
+    const QList<AnnotationGroup*> clonedSubgroups = clonedRootGroup->getSubgroups();
+    QList<AnnotationGroup*> sourceSubgroups = sourceRootGroup->getSubgroups();
     CHECK_EQUAL(sourceSubgroups.size(), clonedSubgroups.size(), "root group's subgroups");
 
-    foreach (AnnotationGroup *clonedSubgroup, clonedSubgroups) {
-        const QList<Annotation *> clonedAnns = clonedSubgroup->getAnnotations();
+    foreach (AnnotationGroup* clonedSubgroup, clonedSubgroups) {
+        const QList<Annotation*> clonedAnns = clonedSubgroup->getAnnotations();
 
         bool groupMatched = false;
-        foreach (AnnotationGroup *sourceSubgroup, sourceSubgroups) {
+        for (AnnotationGroup* sourceSubgroup : qAsConst(sourceSubgroups)) {
             if (sourceSubgroup->getName() == clonedSubgroup->getName()) {
                 groupMatched = true;
-                const QList<Annotation *> sourceAnns = sourceSubgroup->getAnnotations();
+                const QList<Annotation*> sourceAnns = sourceSubgroup->getAnnotations();
                 CHECK_EQUAL(sourceAnns.size(), clonedAnns.size(), "annotation count");
                 break;
             }
@@ -537,12 +532,12 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, getAnnotationsByName) {
     AnnotationTableObject ft("ftable_name", dbiRef);
     ft.addAnnotations(annotations);
 
-    const QList<Annotation *> anns1 = ft.getAnnotationsByName(aname2);
+    const QList<Annotation*> anns1 = ft.getAnnotationsByName(aname2);
     CHECK_EQUAL(2, anns1.size(), "annotation count");
 
     ft.addAnnotations(annotations, grname);
 
-    const QList<Annotation *> anns2 = ft.getAnnotationsByName(aname2);
+    const QList<Annotation*> anns2 = ft.getAnnotationsByName(aname2);
     CHECK_EQUAL(4, anns2.size(), "annotation count");
 }
 
@@ -571,15 +566,15 @@ IMPLEMENT_TEST(FeatureTableObjectUnitTest, getAnnotationsByRegion) {
     AnnotationTableObject ft("ftable_name", dbiRef);
     ft.addAnnotations(annotations);
 
-    const QList<Annotation *> anns1 = ft.getAnnotationsByRegion(U2Region(500, 500), false);
+    const QList<Annotation*> anns1 = ft.getAnnotationsByRegion(U2Region(500, 500), false);
     CHECK_EQUAL(0, anns1.size(), "annotation count");
 
-    const QList<Annotation *> anns2 = ft.getAnnotationsByRegion(U2Region(500, 500), true);
+    const QList<Annotation*> anns2 = ft.getAnnotationsByRegion(U2Region(500, 500), true);
     CHECK_EQUAL(0, anns2.size(), "annotation count");
 
-    const QList<Annotation *> anns3 = ft.getAnnotationsByRegion(U2Region(0, 500), false);
+    const QList<Annotation*> anns3 = ft.getAnnotationsByRegion(U2Region(0, 500), false);
     CHECK_EQUAL(2, anns3.size(), "annotation count");
-    foreach (Annotation *ann, anns3) {
+    foreach (Annotation* ann, anns3) {
         CHECK_TRUE(ann->getRegions().contains(areg1), "count of annotation regions");
     }
 }
