@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FEATURE_TABLE_OBJECT_TESTS_H_
-#define _U2_FEATURE_TABLE_OBJECT_TESTS_H_
+#pragma once
 
 #include <core/dbi/DbiTest.h>
 #include <unittest.h>
@@ -34,13 +33,13 @@ public:
     static void init();
     static void shutdown();
 
-    static U2FeatureDbi *getFeatureDbi();
+    static U2FeatureDbi* getFeatureDbi();
 
 protected:
     static TestDbiProvider dbiProvider;
 
 private:
-    static U2FeatureDbi *featureDbi;
+    static U2FeatureDbi* featureDbi;
 };
 
 DECLARE_TEST(FeatureTableObjectUnitTest, createEmptyFeaturesTableObject);
@@ -73,5 +72,3 @@ DECLARE_METATYPE(FeatureTableObjectUnitTest, clone)
 DECLARE_METATYPE(FeatureTableObjectUnitTest, getAnnotationsByName)
 DECLARE_METATYPE(FeatureTableObjectUnitTest, getAnnotationsByRegion)
 DECLARE_METATYPE(FeatureTableObjectUnitTest, checkConstraints)
-
-#endif  //_U2_FEATURE_TABLE_OBJECT_TESTS_H_
