@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _MSA_OBEJCT_UNIT_TESTS_H_
-#define _MSA_OBEJCT_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -40,13 +39,13 @@ public:
 
     static U2DbiRef getDbiRef();
 
-    static MultipleSequenceAlignmentObject *getTestAlignmentObject(const U2DbiRef &dbiRef, const QString &name, U2OpStatus &os);
-    static U2EntityRef getTestAlignmentRef(const U2DbiRef &dbiRef, const QString &name, U2OpStatus &os);
-    static MultipleSequenceAlignment getTestAlignment(const U2DbiRef &dbiRef, const QString &name, U2OpStatus &os);
+    static MultipleSequenceAlignmentObject* getTestAlignmentObject(const U2DbiRef& dbiRef, const QString& name, U2OpStatus& os);
+    static U2EntityRef getTestAlignmentRef(const U2DbiRef& dbiRef, const QString& name, U2OpStatus& os);
+    static MultipleSequenceAlignment getTestAlignment(const U2DbiRef& dbiRef, const QString& name, U2OpStatus& os);
 
 private:
     static TestDbiProvider dbiProvider;
-    static const QString &MAL_OBJ_DB_URL;
+    static const QString& MAL_OBJ_DB_URL;
     static U2DbiRef dbiRef;
 };
 
@@ -63,5 +62,3 @@ DECLARE_METATYPE(MsaObjectUnitTests, setMAlignment);
 DECLARE_METATYPE(MsaObjectUnitTests, deleteGap_trailingGaps);
 DECLARE_METATYPE(MsaObjectUnitTests, deleteGap_regionWithNonGapSymbols);
 DECLARE_METATYPE(MsaObjectUnitTests, deleteGap_gapRegion);
-
-#endif
