@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -49,14 +49,14 @@ U2EntityRef PhyTreeObjectTestData::getObjRef() {
     return objRef;
 }
 
-U2ObjectDbi *PhyTreeObjectTestData::getObjDbi() {
+U2ObjectDbi* PhyTreeObjectTestData::getObjDbi() {
     if (!inited) {
         init();
     }
     return dbiProvider.getDbi()->getObjectDbi();
 }
 
-UdrDbi *PhyTreeObjectTestData::getUdrDbi() {
+UdrDbi* PhyTreeObjectTestData::getUdrDbi() {
     if (!inited) {
         init();
     }
@@ -99,17 +99,14 @@ void PhyTreeObjectTestData::shutdown() {
 namespace {
 PhyTree createTree() {
     PhyTree result(new PhyTreeData());
-    PhyNode *root = new PhyNode();
-    root->setName("ROOT");
+    auto root = new PhyNode();
+    root->name = "ROOT";
     result->setRootNode(root);
-    QStringList names;
-    names << "A"
-          << "B"
-          << "C";
-    foreach (const QString &name, names) {
-        PhyNode *node = new PhyNode();
-        node->setName(name);
-        result->addBranch(root, node, 5.1);
+    QStringList names = {"A", "B", "C"};
+    for (const QString& name : qAsConst(names)) {
+        auto node = new PhyNode();
+        node->name = name;
+        PhyTreeUtils::addBranch(root, node, 5.1);
     }
     return result;
 }
@@ -120,7 +117,7 @@ IMPLEMENT_TEST(PhyTreeObjectUnitTests, createInstance) {
     QScopedPointer<PhyTreeObject> object(PhyTreeObject::createInstance(createTree(), "object", PhyTreeObjectTestData::getDbiRef(), os));
     CHECK_NO_ERROR(os);
 
-    CHECK_TRUE(nullptr != object->getTree().data(), "tree");
+    CHECK_TRUE(object->getTree().data() != nullptr, "tree");
 }
 
 IMPLEMENT_TEST(PhyTreeObjectUnitTests, createInstance_WrongDbi) {
@@ -131,7 +128,7 @@ IMPLEMENT_TEST(PhyTreeObjectUnitTests, createInstance_WrongDbi) {
 
 IMPLEMENT_TEST(PhyTreeObjectUnitTests, getTree) {
     PhyTreeObject object("object", PhyTreeObjectTestData::getObjRef());
-    CHECK_TRUE(nullptr != object.getTree().data(), "tree");
+    CHECK_TRUE(object.getTree().data() != nullptr, "tree");
 }
 
 IMPLEMENT_TEST(PhyTreeObjectUnitTests, getTree_Null) {
@@ -139,7 +136,7 @@ IMPLEMENT_TEST(PhyTreeObjectUnitTests, getTree_Null) {
     objRef.entityId = "some id";
 
     PhyTreeObject object("object", objRef);
-    CHECK_TRUE(nullptr == object.getTree().data(), "tree");
+    CHECK_TRUE(object.getTree().data() == nullptr, "tree");
 }
 
 IMPLEMENT_TEST(PhyTreeObjectUnitTests, setTree) {
@@ -156,8 +153,8 @@ IMPLEMENT_TEST(PhyTreeObjectUnitTests, clone) {
     PhyTreeObject object("object", PhyTreeObjectTestData::getObjRef());
 
     U2OpStatusImpl os;
-    GObject *clonedGObj = object.clone(PhyTreeObjectTestData::getDbiRef(), os);
-    QScopedPointer<PhyTreeObject> cloned(dynamic_cast<PhyTreeObject *>(clonedGObj));
+    GObject* clonedGObj = object.clone(PhyTreeObjectTestData::getDbiRef(), os);
+    QScopedPointer<PhyTreeObject> cloned(dynamic_cast<PhyTreeObject*>(clonedGObj));
     CHECK_NO_ERROR(os);
 
     PhyTree clonedTree = createTree();
@@ -171,7 +168,7 @@ IMPLEMENT_TEST(PhyTreeObjectUnitTests, clone_NullDbi) {
     PhyTreeObject object("object", PhyTreeObjectTestData::getObjRef());
 
     U2OpStatusImpl os;
-    GObject *clonedGObj = object.clone(U2DbiRef(), os);
+    GObject* clonedGObj = object.clone(U2DbiRef(), os);
     Q_UNUSED(clonedGObj);
     CHECK_TRUE(os.hasError(), "no error");
 }
@@ -182,7 +179,7 @@ IMPLEMENT_TEST(PhyTreeObjectUnitTests, clone_NullObj) {
     PhyTreeObject object("object", objRef);
 
     U2OpStatusImpl os;
-    GObject *clonedGObj = object.clone(PhyTreeObjectTestData::getDbiRef(), os);
+    GObject* clonedGObj = object.clone(PhyTreeObjectTestData::getDbiRef(), os);
     Q_UNUSED(clonedGObj);
     CHECK_TRUE(os.hasError(), "no error");
 }
