@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PHY_TREE_OBJECT_UNIT_TESTS_H_
-#define _U2_PHY_TREE_OBJECT_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -36,8 +35,8 @@ public:
     static void shutdown();
     static U2DbiRef getDbiRef();
     static U2EntityRef getObjRef();
-    static U2ObjectDbi *getObjDbi();
-    static UdrDbi *getUdrDbi();
+    static U2ObjectDbi* getObjDbi();
+    static UdrDbi* getUdrDbi();
 
 private:
     static TestDbiProvider dbiProvider;
@@ -80,5 +79,3 @@ DECLARE_METATYPE(PhyTreeObjectUnitTests, clone);
 DECLARE_METATYPE(PhyTreeObjectUnitTests, clone_NullDbi);
 DECLARE_METATYPE(PhyTreeObjectUnitTests, clone_NullObj);
 DECLARE_METATYPE(PhyTreeObjectUnitTests, remove);
-
-#endif  // _U2_PHY_TREE_OBJECT_UNIT_TESTS_H_
