@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DATATYPE_SERIALIZE_UTILS_UNIT_TESTS_H_
-#define _U2_DATATYPE_SERIALIZE_UTILS_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -32,7 +31,7 @@ namespace U2 {
 
 class CompareUtils {
 public:
-    static void checkEqual(const DNAChromatogram &chr1, const DNAChromatogram &chr2, U2OpStatus &os);
+    static void checkEqual(const DNAChromatogram& chr1, const DNAChromatogram& chr2, U2OpStatus& os);
 };
 
 /* DNAChromatogramSerializer 1 */
@@ -68,5 +67,3 @@ DECLARE_METATYPE(DatatypeSerializeUtilsUnitTest, WMatrixSerializer);
 DECLARE_METATYPE(DatatypeSerializeUtilsUnitTest, WMatrixSerializer_failed);
 DECLARE_METATYPE(DatatypeSerializeUtilsUnitTest, FMatrixSerializer);
 DECLARE_METATYPE(DatatypeSerializeUtilsUnitTest, FMatrixSerializer_failed);
-
-#endif  // _U2_DATATYPE_SERIALIZE_UTILS_UNIT_TESTS_H_
