@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MSA_IMPORTER_EXPORTER_UNIT_TESTS_H_
-#define _U2_MSA_IMPORTER_EXPORTER_UNIT_TESTS_H_
+#pragma once
 
 #include <unittest.h>
 
@@ -34,11 +33,11 @@ class MsaImporterExporterTestData {
 public:
     static void init();
 
-    static const U2DbiRef &getDbiRef();
+    static const U2DbiRef& getDbiRef();
 
 private:
     static TestDbiProvider dbiProvider;
-    static const QString &IMP_EXP_DB_URL;
+    static const QString& IMP_EXP_DB_URL;
     static U2DbiRef dbiRef;
 };
 
@@ -47,5 +46,3 @@ DECLARE_TEST(MsaImporterExporterUnitTests, importExportAlignment);
 }  // namespace U2
 
 DECLARE_METATYPE(MsaImporterExporterUnitTests, importExportAlignment);
-
-#endif
