@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_UNIT_TEST_H_
-#define _U2_UNIT_TEST_H_
+#pragma once
 
 #include <QMetaType>
 #include <QString>
@@ -71,7 +70,7 @@ public:
     }
     virtual void TearDown() {
     }
-    virtual void SetError(const QString &err) {
+    virtual void SetError(const QString& err) {
         error = err;
     }
     virtual QString GetError() {
@@ -83,10 +82,8 @@ protected:
 };
 
 template<class T>
-QString toString(const T &t) {
+QString toString(const T& t) {
     return QString("%1").arg(t);
 }
 
 }  // namespace U2
-
-#endif
