@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,6 @@
  * MA 02110-1301, USA.
  */
 
-#include <time.h>
-
 #include <U2Core/BioStruct3D.h>
 #include <U2Core/Log.h>
 
@@ -39,7 +37,7 @@ QMutex BallAndStickGLRenderer::mutex;
 
 #define MAX_OPEN_VIEWS_NUMBER 8086
 
-BallAndStickGLRenderer::BallAndStickGLRenderer(const BioStruct3D &struc, const BioStruct3DColorScheme *s, const QList<int> &shownModels, const BioStruct3DRendererSettings *settings)
+BallAndStickGLRenderer::BallAndStickGLRenderer(const BioStruct3D& struc, const BioStruct3DColorScheme* s, const QList<int>& shownModels, const BioStruct3DRendererSettings* settings)
     : BioStruct3DGLRenderer(struc, s, shownModels, settings),
       inited(false) {
 }
@@ -105,8 +103,8 @@ void BallAndStickGLRenderer::init() {
     create();
 }
 
-static void drawAtomsBonds(const Color4f &viewAtomColor, float renderDetailLevel, const Molecule3DModel &model, const BioStruct3DColorScheme *colorScheme) {
-    GLUquadricObj *pObj = gluNewQuadric();
+static void drawAtomsBonds(const Color4f& viewAtomColor, float renderDetailLevel, const Molecule3DModel& model, const BioStruct3DColorScheme* colorScheme) {
+    GLUquadricObj* pObj = gluNewQuadric();
     gluQuadricNormals(pObj, GLU_SMOOTH);
 
     glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, viewAtomColor.getConstData());
@@ -131,8 +129,8 @@ static void drawAtomsBonds(const Color4f &viewAtomColor, float renderDetailLevel
         const SharedAtom a1 = bond.getAtom1();
         const SharedAtom a2 = bond.getAtom2();
 
-        const Color4f &a1Color = colorScheme->getAtomColor(a1);
-        const Color4f &a2Color = colorScheme->getAtomColor(a2);
+        const Color4f& a1Color = colorScheme->getAtomColor(a1);
+        const Color4f& a2Color = colorScheme->getAtomColor(a2);
 
         Vector3D middle = (a1->coord3d + a2->coord3d) / 2;
 
@@ -165,15 +163,12 @@ void BallAndStickGLRenderer::createDisplayList() {
 
     glNewList(dl, GL_COMPILE);
 
-    foreach (const SharedMolecule mol, bioStruct.moleculeMap) {
-        foreach (int index, shownModels) {
-            const Molecule3DModel &model = mol->models.value(index);
-
+    for (const SharedMolecule& mol : qAsConst(bioStruct.moleculeMap)) {
+        foreach (int index, shownModelsIds) {
+            const Molecule3DModel& model = mol->models.value(index);
             colors.clear();
-
-            foreach (const SharedAtom atom, model.atoms) {
+            for (const SharedAtom& atom : qAsConst(model.atoms)) {
                 Color4f atomColor = colorScheme->getAtomColor(atom);
-
                 if (colors.contains(atomColor)) {
                     continue;  // Atom and bonds with this color has been already viewed
                 } else {
