@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
-#define _U2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
+#pragma once
 
 #include <GraphicUtils.h>
 
@@ -30,7 +29,7 @@ namespace U2 {
 
 class BallAndStickGLRenderer : public BioStruct3DGLRenderer {
 protected:
-    BallAndStickGLRenderer(const BioStruct3D &struc, const BioStruct3DColorScheme *s, const QList<int> &shownModels, const BioStruct3DRendererSettings *settings);
+    BallAndStickGLRenderer(const BioStruct3D& struc, const BioStruct3DColorScheme* s, const QList<int>& shownModels, const BioStruct3DRendererSettings* settings);
 
 public:
     virtual ~BallAndStickGLRenderer();
@@ -58,5 +57,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
