@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,11 +19,10 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BIOSTRUCT3D_RENDERER_H_
-#define _U2_BIOSTRUCT3D_RENDERER_H_
+#pragma once
 
-#include <QString>
 #include <QMap>
+#include <QString>
 
 namespace U2 {
 
@@ -43,19 +42,16 @@ public:
     static const QList<QString> factoriesNames();
 
     //! @return Concreete factory by name.
-    static const BioStruct3DGLRendererFactory* getFactory(const QString &name);
+    static const BioStruct3DGLRendererFactory* getFactory(const QString& name);
 
     //! @return Constructed renderer by factory name.
-    static BioStruct3DGLRenderer* createRenderer(const QString &name,   const BioStruct3D&,
-                                                                        const BioStruct3DColorScheme*,
-                                                                        const QList<int>&,
-                                                                        const BioStruct3DRendererSettings*);
+    static BioStruct3DGLRenderer* createRenderer(const QString& name, const BioStruct3D&, const BioStruct3DColorScheme*, const QList<int>&, const BioStruct3DRendererSettings*);
 
     /** Check if biostruct can be drawn with renderer */
-    static bool isAvailableFor(const QString &name, const BioStruct3D &biostruct);
+    static bool isAvailableFor(const QString& name, const BioStruct3D& biostruct);
 
     /** @returns List of renderer names available for biostruct */
-    static QList<QString> getRenderersAvailableFor(const BioStruct3D &biostruct);
+    static QList<QString> getRenderersAvailableFor(const BioStruct3D& biostruct);
 
 private:
     //! Hidden constructor. Called by getInstance()
@@ -71,51 +67,51 @@ private:
     QMap<QString, BioStruct3DGLRendererFactory*> factories;
 };  // class BioStruct3DGLRendererRegistry
 
-
 /** BioStruct3DGLRenderer abstract factory */
 class BioStruct3DGLRendererFactory {
 public:
-    BioStruct3DGLRendererFactory(const QString &_name) : name(_name) {}
+    BioStruct3DGLRendererFactory(const QString& _name)
+        : name(_name) {
+    }
 
     /** @returns Factory name */
-    const QString getName() const { return name; }
+    const QString getName() const;
 
     /** Check if biostruct can be drawn with renderer */
-    virtual bool isAvailableFor(const BioStruct3D &biostruct) const = 0;
+    virtual bool isAvailableFor(const BioStruct3D& biostruct) const = 0;
 
     /** @returns Contructed renderer */
-    virtual BioStruct3DGLRenderer* createInstance(const BioStruct3D&, const BioStruct3DColorScheme*, const
-                                                  QList<int> &shownModels, const BioStruct3DRendererSettings*) const = 0;
+    virtual BioStruct3DGLRenderer* createInstance(const BioStruct3D&, const BioStruct3DColorScheme*, const QList<int>& shownModels, const BioStruct3DRendererSettings*) const = 0;
 
 private:
     QString name;
-
 };
 
 /** Macro helper for factories defining */
 #define RENDERER_FACTORY(c) \
 public: \
     static const QString ID; \
-    \
-class Factory : public BioStruct3DGLRendererFactory { \
-public: \
-    Factory(const QString &name) : BioStruct3DGLRendererFactory(name) {} \
-    \
-    virtual BioStruct3DGLRenderer* createInstance(const BioStruct3D &biostruct, const BioStruct3DColorScheme *cscheme, \
-                                          const QList<int> &shownModels, const BioStruct3DRendererSettings *settings) const { \
-        return new c(biostruct, cscheme, shownModels, settings); \
-    } \
-    \
-    virtual bool isAvailableFor(const BioStruct3D &biostruct) const { \
-        return c::isAvailableFor(biostruct); \
-    } \
-};
+\
+    class Factory : public BioStruct3DGLRendererFactory { \
+    public: \
+        Factory(const QString& name) : BioStruct3DGLRendererFactory(name) { \
+        } \
+\
+        virtual BioStruct3DGLRenderer* createInstance(const BioStruct3D& biostruct, const BioStruct3DColorScheme* cscheme, const QList<int>& shownModels, const BioStruct3DRendererSettings* settings) const { \
+            return new c(biostruct, cscheme, shownModels, settings); \
+        } \
+\
+        virtual bool isAvailableFor(const BioStruct3D& biostruct) const { \
+            return c::isAvailableFor(biostruct); \
+        } \
+    };
 
 /** Settings common for all renderers */
 class BioStruct3DRendererSettings {
 public:
     BioStruct3DRendererSettings(float _detailLevel)
-            : detailLevel(_detailLevel) {}
+        : detailLevel(_detailLevel) {
+    }
 
     float detailLevel;
 };
@@ -123,10 +119,11 @@ public:
 //! Abstract biological 3D structure OpenGL renderer
 class BioStruct3DGLRenderer {
 protected:
-    BioStruct3DGLRenderer(const BioStruct3D &biostruct, const BioStruct3DColorScheme *scheme, const QList<int> &shownModels, const BioStruct3DRendererSettings *settings);
+    BioStruct3DGLRenderer(const BioStruct3D& biostruct, const BioStruct3DColorScheme* scheme, const QList<int>& shownModels, const BioStruct3DRendererSettings* settings);
 
 public:
-    virtual ~BioStruct3DGLRenderer() {}
+    virtual ~BioStruct3DGLRenderer() {
+    }
 
     /** Create and initialize all stuff.
         Can be called for full reinialization */
@@ -136,7 +133,8 @@ public:
     virtual void drawBioStruct3D() = 0;
 
     //! Used to completely update model, for ex to recreate display lists.
-    virtual void update() {}
+    virtual void update() {
+    }
 
     //! Used to update current color scheme, whenever it is changed.
     virtual void updateColorScheme() = 0;
@@ -151,32 +149,29 @@ public:
     void setColorScheme(const BioStruct3DColorScheme* s);
 
     //! @returns current color scheme.
-    const BioStruct3DColorScheme *getColorScheme() const { return colorScheme; }
+    const BioStruct3DColorScheme* getColorScheme() const;
 
     /** @returns shown models indexes list reference.
-      * indexes are just index numbers of models, NOT modelIds
-      */
-    const QList<int>& getShownModelsIndexes() const { return shownModels; }
+     * indexes are just index numbers of models, NOT modelIds
+     */
+    const QList<int>& getShownModelsIds() const;
 
     /** Sets shown models models list. */
-    void setShownModelsIndexes(const QList<int> &_shownModels) { shownModels = _shownModels; }
+    void setShownModelsIndexes(const QList<int>& _shownModels);
 
 public:
     /** Check if biostruct can be visualized by renderer */
-    static bool isAvailableFor(const BioStruct3D &) { return true; }
+    static bool isAvailableFor(const BioStruct3D&);
 
 protected:
     const BioStruct3D& bioStruct;
     const BioStruct3DColorScheme* colorScheme;
 
 protected:
-    QList<int> shownModels;
+    QList<int> shownModelsIds;
 
 protected:
     const BioStruct3DRendererSettings* settings;
 };
 
-
-} //namespace
-
-#endif // _U2_BIOSTRUCT3D_RENDERER_H_
+}  // namespace U2
