@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,13 +22,11 @@
 #include <math.h>
 #include <time.h>
 
-#include <QColorDialog>
 #include <QImageWriter>
 #include <QMessageBox>
 #include <QMouseEvent>
 #include <QOffscreenSurface>
 #include <QOpenGLContext>
-#include <QOpenGLShaderProgram>
 #include <QTime>
 
 #include <U2Algorithm/MolecularSurfaceFactoryRegistry.h>
@@ -36,7 +34,6 @@
 
 #include <U2Core/AnnotationSelection.h>
 #include <U2Core/AnnotationSettings.h>
-#include <U2Core/AnnotationTableObject.h>
 #include <U2Core/AppContext.h>
 #include <U2Core/BioStruct3D.h>
 #include <U2Core/BioStruct3DObject.h>
@@ -44,8 +41,8 @@
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/DNASequenceSelection.h>
 #include <U2Core/DocumentModel.h>
-#include <U2Core/GObjectRelationRoles.h>
 #include <U2Core/GUrlUtils.h>
+#include <U2Core/L10n.h>
 #include <U2Core/Log.h>
 #include <U2Core/ProjectModel.h>
 #include <U2Core/QObjectScopedPointer.h>
@@ -76,30 +73,13 @@ namespace U2 {
 
 int BioStruct3DGLWidget::widgetCount = 0;
 
-bool BioStruct3DGLWidget::checkShaderPrograms() {
-    QOffscreenSurface surf;
-    surf.create();
-
-    QOpenGLContext ctx;
-    ctx.create();
-    ctx.makeCurrent(&surf);
-
-    bool opgl = QOpenGLShaderProgram::hasOpenGLShaderPrograms(&ctx);
-    if (!opgl) {
-        coreLog.error(tr("The \"3D Structure Viewer\" was disabled, because shader programs written in the OpenGL Shading Language (GLSL) are not supported on this system. "
-                         "Please try to update drivers and reset the UGENE settings to default in the \"Application Settings\" dialog."));
-    }
-
-    return opgl;
-}
-
 void BioStruct3DGLWidget::tryGL() {
-    volatile QOpenGLWidget wgt;
-    Q_UNUSED(wgt);
+    // Basic OpenGL support must be provided for all platforms.
+    // If there is no vendor specific OpenGL driver UGENE must fall back to the software impl (see opengl32sw in Qt).
+    //    volatile QOpenGLWidget wgt;
+    //    Q_UNUSED(wgt);
 }
 
-const double BioStruct3DGLWidget::MINIMUM_ACCEPTABLE_VERSION = 2.0f;
-
 static QColor DEFAULT_BACKGROUND_COLOR = Qt::black;
 static QColor DEFAULT_SELECTION_COLOR = Qt::yellow;
 
@@ -107,7 +87,6 @@ static float DEFAULT_RENDER_DETAIL_LEVEL = 1.0;
 static int DEFAULT_SHADING_LEVEL = 50;
 
 const QString BioStruct3DGLWidget::BACKGROUND_COLOR_NAME("BackgroundColor");
-const QString BioStruct3DGLWidget::PRODUCT_NAME("Unipro Ugene");
 const QString BioStruct3DGLWidget::PLUGIN_NAME("BioStruct3D Viewer Plugin");
 const QString BioStruct3DGLWidget::COLOR_SCHEME_NAME("ColorScheme");
 const QString BioStruct3DGLWidget::RENDERER_NAME("GLRenderer");
@@ -118,12 +97,12 @@ const QString BioStruct3DGLWidget::SHADING_LEVEL_NAME("Shading Unselected Region
 const QString BioStruct3DGLWidget::RENDER_DETAIL_LEVEL_NAME("RenderDetailLevel");
 const QString BioStruct3DGLWidget::ANAGLYPH_STATUS_NAME("AnaglyphStatus");
 
-BioStruct3DGLWidget::BioStruct3DGLWidget(BioStruct3DObject *obj, const AnnotatedDNAView *_dnaView, GLFrameManager *manager, QWidget *parent /* = 0*/)
+BioStruct3DGLWidget::BioStruct3DGLWidget(BioStruct3DObject* obj, const AnnotatedDNAView* _dnaView, GLFrameManager* manager, QWidget* parent /* = 0*/)
     : QOpenGLWidget(parent),
       dnaView(_dnaView), contexts(),
       rendererSettings(DEFAULT_RENDER_DETAIL_LEVEL),
       frameManager(manager), glFrame(new GLFrame(this)),
-      molSurface(0), surfaceRenderer(), surfaceCalcTask(0),
+      molSurface(0), surfaceRenderer(),
       anaglyphStatus(DISABLED),
       anaglyph(new AnaglyphRenderer(this, AnaglyphSettings::defaultSettings())),
 
@@ -192,7 +171,7 @@ float BioStruct3DGLWidget::getSceneRadius() const {
     float maxRadius = 0;
     const Vector3D sceneCenter = getSceneCenter();
 
-    foreach (const BioStruct3DRendererContext &ctx, contexts) {
+    foreach (const BioStruct3DRendererContext& ctx, contexts) {
         Vector3D center = ctx.biostruct->getCenter();
         float radius = (center - sceneCenter).length() + ctx.biostruct->getRadius();
         if (maxRadius < radius) {
@@ -206,7 +185,7 @@ float BioStruct3DGLWidget::getSceneRadius() const {
 Vector3D BioStruct3DGLWidget::getSceneCenter() const {
     // good idea: ask renderer for center instead of asking biostruct
     Vector3D c;
-    foreach (const BioStruct3DRendererContext &ctx, contexts) {
+    foreach (const BioStruct3DRendererContext& ctx, contexts) {
         // TODO: transform should be applied in BioStruct
         Vector3D tmp = ctx.biostruct->getCenter();
         c += tmp.dot(ctx.biostruct->getTransform());
@@ -215,7 +194,7 @@ Vector3D BioStruct3DGLWidget::getSceneCenter() const {
     return c / float(contexts.length());
 }
 
-const BioStruct3D &BioStruct3DGLWidget::getBioStruct3D() const {
+const BioStruct3D& BioStruct3DGLWidget::getBioStruct3D() const {
     return *(contexts.first().biostruct);
 }
 
@@ -231,7 +210,7 @@ void BioStruct3DGLWidget::setImageRenderingMode(bool status) {
     imageRenderingMode = status;
 }
 
-GLFrame *BioStruct3DGLWidget::getGLFrame() {
+GLFrame* BioStruct3DGLWidget::getGLFrame() {
     return glFrame.data();
 }
 
@@ -254,7 +233,7 @@ void BioStruct3DGLWidget::initializeGL() {
 
     updateAllRenderers();
 
-    QString videoAdapterString(QLatin1String(reinterpret_cast<const char *>(glGetString(GL_VENDOR))));
+    QString videoAdapterString(QLatin1String(reinterpret_cast<const char*>(glGetString(GL_VENDOR))));
     if (videoAdapterString.contains("intel", Qt::CaseInsensitive)) {
         anaglyphStatus = NOT_AVAILABLE;
     } else if (!imageRenderingMode) {
@@ -318,7 +297,7 @@ void BioStruct3DGLWidget::draw() {
     glMultMatrixf(glFrame->getRotationMatrix());
     glTranslatef(-rotCenter.x, -rotCenter.y, -rotCenter.z);
 
-    foreach (const BioStruct3DRendererContext &ctx, contexts) {
+    foreach (const BioStruct3DRendererContext& ctx, contexts) {
         glPushMatrix();
 
         Matrix44 colmt = ctx.biostruct->getTransform();
@@ -361,9 +340,9 @@ Vector3D BioStruct3DGLWidget::getTrackballMapping(int x, int y) {
     return pos;
 }
 
-void BioStruct3DGLWidget::contextMenuEvent(QContextMenuEvent *event) {
+void BioStruct3DGLWidget::contextMenuEvent(QContextMenuEvent* event) {
     QMenu menu;
-    foreach (QAction *action, getDisplayMenu()->actions()) {
+    foreach (QAction* action, getDisplayMenu()->actions()) {
         menu.addAction(action);
     }
 
@@ -372,29 +351,29 @@ void BioStruct3DGLWidget::contextMenuEvent(QContextMenuEvent *event) {
     menu.exec(event->globalPos());
 }
 
-void BioStruct3DGLWidget::setLightPosition(const Vector3D &pos) {
+void BioStruct3DGLWidget::setLightPosition(const Vector3D& pos) {
     lightPosition[0] = pos.x;
     lightPosition[1] = pos.y;
     lightPosition[2] = pos.z;
     lightPosition[3] = 1.0;
 }
 
-static int getSequenceChainId(const U2SequenceObject *seqObj) {
+static int getSequenceChainId(const U2SequenceObject* seqObj) {
     bool isFound = false;
     qint64 result = seqObj->getSequenceInfo().value(DNAInfo::CHAIN_ID).toInt(&isFound);
     SAFE_POINT(isFound, "Sequence does not have the CHAIN_ID attribute", -1);
     return (int)result;
 }
 
-void BioStruct3DGLWidget::sl_onSequenceSelectionChanged(LRegionsSelection *s, const QVector<U2Region> &added, const QVector<U2Region> &removed) {
+void BioStruct3DGLWidget::sl_onSequenceSelectionChanged(LRegionsSelection* s, const QVector<U2Region>& added, const QVector<U2Region>& removed) {
     if (!isVisible())
         return;
 
-    DNASequenceSelection *selection = qobject_cast<DNASequenceSelection *>(s);
-    const U2SequenceObject *seqObj = selection->getSequenceObject();
+    auto selection = qobject_cast<DNASequenceSelection*>(s);
+    const U2SequenceObject* seqObj = selection->getSequenceObject();
     assert(seqObj);
 
-    const BioStruct3DRendererContext &ctx = contexts.first();
+    const BioStruct3DRendererContext& ctx = contexts.first();
 
     // check that biostruct and sequence objects are from the same document
     // appropriate relation check must be here
@@ -429,7 +408,7 @@ QVariantMap BioStruct3DGLWidget::getState() {
     return state;
 }
 
-void BioStruct3DGLWidget::setState(const QVariantMap &state) {
+void BioStruct3DGLWidget::setState(const QVariantMap& state) {
     // bug-2859: correct save/restore current selection.
     if (state.isEmpty()) {
         return;
@@ -468,14 +447,14 @@ void BioStruct3DGLWidget::setState(const QVariantMap &state) {
     update();
 }
 
-void BioStruct3DGLWidget::setupColorScheme(const QString &name) {
+void BioStruct3DGLWidget::setupColorScheme(const QString& name) {
     QList<BioStruct3DRendererContext>::iterator i = contexts.begin();
     for (; i != contexts.end(); ++i) {
-        BioStruct3DRendererContext &ctx = *(i);
+        BioStruct3DRendererContext& ctx = *(i);
 
         // TODO: this situation may be potentialy dangerous
         // if renderer starts draw right now, maybe SharedPointer will be good solution
-        BioStruct3DColorScheme *scheme = BioStruct3DColorSchemeRegistry::createColorScheme(name, ctx.obj);
+        BioStruct3DColorScheme* scheme = BioStruct3DColorSchemeRegistry::createColorScheme(name, ctx.obj);
         assert(scheme);
 
         scheme->setSelectionColor(selectionColor);
@@ -486,28 +465,28 @@ void BioStruct3DGLWidget::setupColorScheme(const QString &name) {
     }
 }
 
-void BioStruct3DGLWidget::setupRenderer(const QString &name) {
+void BioStruct3DGLWidget::setupRenderer(const QString& name) {
     QList<BioStruct3DRendererContext>::iterator i = contexts.begin();
     for (; i != contexts.end(); ++i) {
-        BioStruct3DRendererContext &ctx = *(i);
+        BioStruct3DRendererContext& ctx = *(i);
 
         // TODO: this situation may be potentialy dangerous
         // if renderer starts draw right now, maybe SharedPointer will be good solution
-        const QList<int> &shownModelsIndexes = ctx.renderer->getShownModelsIndexes();
-        BioStruct3DGLRenderer *rend = BioStruct3DGLRendererRegistry::createRenderer(name, *ctx.biostruct, ctx.colorScheme.data(), shownModelsIndexes, &rendererSettings);
+        const QList<int>& shownModelsIndexes = ctx.renderer->getShownModelsIds();
+        BioStruct3DGLRenderer* rend = BioStruct3DGLRendererRegistry::createRenderer(name, *ctx.biostruct, ctx.colorScheme.data(), shownModelsIndexes, &rendererSettings);
         assert(rend);
         ctx.renderer = QSharedPointer<BioStruct3DGLRenderer>(rend);
     }
 }
 
 void BioStruct3DGLWidget::updateAllColorSchemes() {
-    foreach (const BioStruct3DRendererContext &ctx, contexts) {
+    foreach (const BioStruct3DRendererContext& ctx, contexts) {
         ctx.renderer->updateColorScheme();
     }
 }
 
 void BioStruct3DGLWidget::updateAllRenderers() {
-    foreach (const BioStruct3DRendererContext &ctx, contexts) {
+    foreach (const BioStruct3DRendererContext& ctx, contexts) {
         ctx.renderer->update();
     }
 }
@@ -519,8 +498,8 @@ void BioStruct3DGLWidget::setBackgroundColor(QColor backgroundColor) {
 
 void BioStruct3DGLWidget::zoom(float delta) {
     bool syncLock = isSyncModeOn();
-    QList<GLFrame *> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
-    foreach (GLFrame *frame, frames) {
+    QList<GLFrame*> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
+    foreach (GLFrame* frame, frames) {
         frame->makeCurrent();
         frame->performZoom(delta);
         frame->updateViewPort();
@@ -530,8 +509,8 @@ void BioStruct3DGLWidget::zoom(float delta) {
 
 void BioStruct3DGLWidget::shift(float deltaX, float deltaY) {
     bool syncLock = isSyncModeOn();
-    QList<GLFrame *> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
-    foreach (GLFrame *frame, frames) {
+    QList<GLFrame*> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
+    foreach (GLFrame* frame, frames) {
         frame->makeCurrent();
         frame->performShift(deltaX, deltaY);
         frame->updateViewPort();
@@ -545,11 +524,11 @@ void BioStruct3DGLWidget::saveDefaultSettings() {
     defaultsSettings[RENDERER_NAME] = QVariant::fromValue(currentGLRendererName);
 }
 
-void BioStruct3DGLWidget::restoreDefaultSettigns() {
+void BioStruct3DGLWidget::restoreDefaultSettings() {
     assert(!defaultsSettings.isEmpty());
     bool syncLock = isSyncModeOn();
-    QList<GLFrame *> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
-    foreach (GLFrame *frame, frames) {
+    QList<GLFrame*> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
+    foreach (GLFrame* frame, frames) {
         frame->makeCurrent();
         frame->setState(defaultsSettings);
         frame->updateViewPort();
@@ -557,53 +536,23 @@ void BioStruct3DGLWidget::restoreDefaultSettigns() {
     }
 }
 
-void BioStruct3DGLWidget::showModel(int modelId, bool show) {
-    BioStruct3DRendererContext &ctx = contexts.first();
-
-    // this function uses modelId - key from BioStruct3D::modelMap
-    int idx = ctx.biostruct->modelMap.keys().indexOf(modelId);
-    assert(idx != -1);
-
-    QList<int> shownModelsIndexes = ctx.renderer->getShownModelsIndexes();
-
-    if (show && !shownModelsIndexes.contains(idx)) {
-        shownModelsIndexes.append(idx);
-    } else if (!show) {
-        shownModelsIndexes.removeAll(idx);
-    }
-    ctx.renderer->setShownModelsIndexes(shownModelsIndexes);
-}
-
-void BioStruct3DGLWidget::showAllModels(bool show) {
-    BioStruct3DRendererContext &ctx = contexts.first();
-
-    QList<int> shownModelsIndexes;
-    if (show) {
-        int numModels = ctx.biostruct->modelMap.size();
-        for (int i = 0; i < numModels; ++i) {
-            shownModelsIndexes.append(i);
-        }
-    }
-    ctx.renderer->setShownModelsIndexes(shownModelsIndexes);
-}
-
 void BioStruct3DGLWidget::sl_selectModels() {
-    BioStruct3DRendererContext &ctx = contexts.first();
-    QObjectScopedPointer<SelectModelsDialog> dlg = new SelectModelsDialog(ctx.biostruct->getModelsNames(), ctx.renderer->getShownModelsIndexes(), this);
+    BioStruct3DRendererContext& ctx = contexts.first();
+    QObjectScopedPointer<SelectModelsDialog> dlg = new SelectModelsDialog(ctx.biostruct->getModelsIds(), ctx.renderer->getShownModelsIds(), this);
     dlg->exec();
     CHECK(!dlg.isNull(), );
 
     if (dlg->result() == QDialog::Accepted) {
-        ctx.renderer->setShownModelsIndexes(dlg->getSelectedModelsIndexes());
+        ctx.renderer->setShownModelsIndexes(dlg->getSelectedModelsIds());
 
         contexts.first().renderer->updateShownModels();
         update();
     }
 }
 
-void BioStruct3DGLWidget::writeImage2DToFile(int format, int options, int nbcol, const char *fileName) {
-    FILE *fp = nullptr;
-    const char *FOPEN_ARGS = "wb";
+void BioStruct3DGLWidget::writeImage2DToFile(int format, int options, int nbcol, const char* fileName) {
+    FILE* fp = nullptr;
+    const char* FOPEN_ARGS = "wb";
     const QByteArray title(fileName);
     int state = GL2PS_OVERFLOW, buffsize = 0;
     GLint viewport[4];
@@ -616,8 +565,6 @@ void BioStruct3DGLWidget::writeImage2DToFile(int format, int options, int nbcol,
         return;
     }
 
-    glGetIntegerv(GL_VIEWPORT, viewport);
-
     if (format == GL2PS_EPS) {
         // hack -> make widget aspect ratio 1:1
         if (width() > height()) {
@@ -626,9 +573,26 @@ void BioStruct3DGLWidget::writeImage2DToFile(int format, int options, int nbcol,
         }
     }
 
+    glFrame->updateViewPort();
+    glGetIntegerv(GL_VIEWPORT, viewport);
+
     while (state == GL2PS_OVERFLOW) {
         buffsize += 2048 * 2048;
-        gl2psBeginPage(title.constData(), "Unipro UGENE BioStruct3D Viewer plugin", viewport, format, sort, options, GL_RGBA, 0, nullptr, nbcol, nbcol, nbcol, buffsize, fp, fileName);
+        gl2psBeginPage(title.constData(),
+                       "Unipro UGENE BioStruct3D Viewer plugin",
+                       viewport,
+                       format,
+                       sort,
+                       options,
+                       GL_RGBA,
+                       0,
+                       nullptr,
+                       nbcol,
+                       nbcol,
+                       nbcol,
+                       buffsize,
+                       fp,
+                       fileName);
         paintGL();
         state = gl2psEndPage();
     }
@@ -645,8 +609,8 @@ void BioStruct3DGLWidget::loadColorSchemes() {
     currentColorSchemeName = BioStruct3DColorSchemeRegistry::defaultFactoryName();
 
     // highlight default color scheme in menu
-    QList<QAction *>::iterator iter;
-    QList<QAction *> schemeActions = colorSchemeActions->actions();
+    QList<QAction*>::iterator iter;
+    QList<QAction*> schemeActions = colorSchemeActions->actions();
     for (iter = schemeActions.begin(); iter != schemeActions.end(); ++iter) {
         if ((*iter)->text() == currentColorSchemeName) {
             (*iter)->setChecked(true);
@@ -656,10 +620,10 @@ void BioStruct3DGLWidget::loadColorSchemes() {
     assert(iter != schemeActions.end());
 }
 
-void BioStruct3DGLWidget::loadGLRenderers(const QList<QString> &availableRenderers) {
+void BioStruct3DGLWidget::loadGLRenderers(const QList<QString>& availableRenderers) {
     // highlight current renderer in menu
 
-    foreach (QAction *ac, rendererActions->actions()) {
+    foreach (QAction* ac, rendererActions->actions()) {
         // disable all unavailable renderers in menu
         if (!availableRenderers.contains(ac->text())) {
             ac->setDisabled(true);
@@ -691,31 +655,32 @@ void BioStruct3DGLWidget::checkRenderingAndCreateLblError() {
     GLenum error = glGetError();
     bool canRender = error == GL_NO_ERROR;
     if (!canRender) {
-        coreLog.info(tr("The \"3D Structure Viewer\" was disabled, because OpenGL has error ") +
-                     QString("(%1): %2").arg(error).arg(reinterpret_cast<const char *>(gluErrorString(error))));
-        lblGlError = new QLabel("Failed to initialize OpenGL", this);
+        QString errorDetails = QString("(%1): %2").arg(error).arg(reinterpret_cast<const char*>(gluErrorString(error)));
+        coreLog.info(tr("The \"3D Structure Viewer\" was disabled, because OpenGL has error ") + errorDetails);
+        lblGlError = new QLabel("Failed to initialize OpenGL: " + errorDetails, this);
+        lblGlError->setObjectName("opengl_initialization_error_label");
         lblGlError->setAlignment(Qt::AlignCenter | Qt::AlignHCenter);
         lblGlError->setStyleSheet("QLabel { background-color : black; color : white; }");
     }
 }
 
 void BioStruct3DGLWidget::setUnselectedShadingLevel(int shading) {
-    foreach (const BioStruct3DRendererContext &ctx, contexts) {
+    foreach (const BioStruct3DRendererContext& ctx, contexts) {
         ctx.colorScheme->setUnselectedShadingLevel((double)shading / 100.0);
     }
     updateAllColorSchemes();
 }
 
-QMenu *BioStruct3DGLWidget::getDisplayMenu() {
+QMenu* BioStruct3DGLWidget::getDisplayMenu() {
     assert(displayMenu != nullptr);
     return displayMenu;
 }
 
-void BioStruct3DGLWidget::mousePressEvent(QMouseEvent *event) {
+void BioStruct3DGLWidget::mousePressEvent(QMouseEvent* event) {
     lastPos = getTrackballMapping(event->x(), event->y());
 }
 
-void BioStruct3DGLWidget::mouseMoveEvent(QMouseEvent *event) {
+void BioStruct3DGLWidget::mouseMoveEvent(QMouseEvent* event) {
     if (event->buttons() & Qt::LeftButton) {
         Vector3D curPos = getTrackballMapping(event->x(), event->y());
         Vector3D delta = curPos - lastPos;
@@ -725,8 +690,8 @@ void BioStruct3DGLWidget::mouseMoveEvent(QMouseEvent *event) {
             rotAxis = vector_cross(lastPos, curPos);
 
             bool syncLock = isSyncModeOn();
-            QList<GLFrame *> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
-            foreach (GLFrame *frame, frames) {
+            QList<GLFrame*> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
+            foreach (GLFrame* frame, frames) {
                 frame->makeCurrent();
 
                 if (event->modifiers() & Qt::CTRL)
@@ -742,38 +707,38 @@ void BioStruct3DGLWidget::mouseMoveEvent(QMouseEvent *event) {
     }
 }
 
-void BioStruct3DGLWidget::wheelEvent(QWheelEvent *event) {
+void BioStruct3DGLWidget::wheelEvent(QWheelEvent* event) {
     float numDegrees = event->delta() / 8;
     zoom(numDegrees / 10);
 }
 
 void BioStruct3DGLWidget::createActions() {
-    QAction *action = nullptr;
+    QAction* action = nullptr;
 
     animationTimer = new QTimer(this);
     animationTimer->setInterval(20);  // fixed interval
-    connect(animationTimer, SIGNAL(timeout()), this, SLOT(sl_updateAnnimation()));
+    connect(animationTimer, SIGNAL(timeout()), this, SLOT(sl_updateAnimation()));
 
     rendererActions = new QActionGroup(this);
-    connect(rendererActions, SIGNAL(triggered(QAction *)), this, SLOT(sl_selectGLRenderer(QAction *)));
+    connect(rendererActions, SIGNAL(triggered(QAction*)), this, SLOT(sl_selectGLRenderer(QAction*)));
 
-    foreach (const QString &key, BioStruct3DGLRendererRegistry::factoriesNames()) {
+    foreach (const QString& key, BioStruct3DGLRendererRegistry::factoriesNames()) {
         action = new QAction(key, rendererActions);
         action->setCheckable(true);
         action->setObjectName(action->text());
     }
 
     colorSchemeActions = new QActionGroup(this);
-    connect(colorSchemeActions, SIGNAL(triggered(QAction *)), this, SLOT(sl_selectColorScheme(QAction *)));
-    foreach (const QString &key, BioStruct3DColorSchemeRegistry::factoriesNames()) {
+    connect(colorSchemeActions, SIGNAL(triggered(QAction*)), this, SLOT(sl_selectColorScheme(QAction*)));
+    foreach (const QString& key, BioStruct3DColorSchemeRegistry::factoriesNames()) {
         action = new QAction(key, colorSchemeActions);
         action->setCheckable(true);
         action->setObjectName(key);
     }
 
     molSurfaceRenderActions = new QActionGroup(this);
-    connect(molSurfaceRenderActions, SIGNAL(triggered(QAction *)), this, SLOT(sl_selectSurfaceRenderer(QAction *)));
-    foreach (const QString &key, MolecularSurfaceRendererRegistry::factoriesNames()) {
+    connect(molSurfaceRenderActions, SIGNAL(triggered(QAction*)), this, SLOT(sl_selectSurfaceRenderer(QAction*)));
+    foreach (const QString& key, MolecularSurfaceRendererRegistry::factoriesNames()) {
         action = new QAction(key, molSurfaceRenderActions);
         action->setCheckable(true);
         if (key == ConvexMapRenderer::ID) {
@@ -796,14 +761,14 @@ void BioStruct3DGLWidget::createActions() {
     action->setChecked(true);
 
     selectModelsAction = 0;
-    if (!contexts.isEmpty() && contexts.first().biostruct->getModelsNames().size() > 1) {
+    if (!contexts.isEmpty() && contexts.first().biostruct->getModelsIds().size() > 1) {
         selectModelsAction = new QAction(tr("Models.."), this);
         connect(selectModelsAction, SIGNAL(triggered()), this, SLOT(sl_selectModels()));
     }
 
     spinAction = new QAction(tr("Spin"), this);
     spinAction->setCheckable(true);
-    connect(spinAction, SIGNAL(triggered()), this, SLOT(sl_acitvateSpin()));
+    connect(spinAction, SIGNAL(triggered()), this, SLOT(sl_activateSpin()));
 
     settingsAction = new QAction(tr("Settings..."), this);
     connect(settingsAction, SIGNAL(triggered()), this, SLOT(sl_settings()));
@@ -812,14 +777,13 @@ void BioStruct3DGLWidget::createActions() {
     connect(closeAction, SIGNAL(triggered()), this, SLOT(close()));
 
     exportImageAction = new QAction(tr("Export Image..."), this);
+    exportImageAction->setObjectName("bioStruct3DExportImageAction");
     connect(exportImageAction, SIGNAL(triggered()), this, SLOT(sl_exportImage()));
 
-    createStrucluralAlignmentActions();
-
-    connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task *)), SLOT(sl_onTaskFinished(Task *)));
+    createStructuralAlignmentActions();
 }
 
-void BioStruct3DGLWidget::createStrucluralAlignmentActions() {
+void BioStruct3DGLWidget::createStructuralAlignmentActions() {
     alignWithAction = new QAction(tr("Align With..."), this);
     alignWithAction->setObjectName("align_with");
     connect(alignWithAction, SIGNAL(triggered()), this, SLOT(sl_alignWith()));
@@ -840,11 +804,11 @@ void BioStruct3DGLWidget::createMenus() {
     selectColorSchemeMenu->menuAction()->setObjectName("Coloring Scheme");
 
     // Molecular surface
-    QMenu *surfaceMenu = new QMenu(tr("Molecular Surface Render Style"));
-    surfaceMenu->addActions(molSurfaceRenderActions->actions());
-    surfaceMenu->menuAction()->setObjectName("Molecular Surface Render Style");
+    auto surfaceRenderingStyleMenu = new QMenu(tr("Molecular Surface Render Style"));
+    surfaceRenderingStyleMenu->addActions(molSurfaceRenderActions->actions());
+    surfaceRenderingStyleMenu->menuAction()->setObjectName("Molecular Surface Render Style");
 
-    QMenu *surfaceTypeMenu = new QMenu(tr("Molecular Surface"));
+    auto surfaceTypeMenu = new QMenu(tr("Molecular Surface"));
     surfaceTypeMenu->addActions(molSurfaceTypeActions->actions());
     surfaceTypeMenu->menuAction()->setObjectName("Molecular Surface");
 
@@ -853,8 +817,10 @@ void BioStruct3DGLWidget::createMenus() {
     displayMenu->addMenu(selectRendererMenu);
     displayMenu->addMenu(selectColorSchemeMenu);
 
-    displayMenu->addMenu(surfaceMenu);
+    displayMenu->addSeparator();
     displayMenu->addMenu(surfaceTypeMenu);
+    displayMenu->addMenu(surfaceRenderingStyleMenu);
+    displayMenu->addSeparator();
 
     if (selectModelsAction) {
         displayMenu->addAction(selectModelsAction);
@@ -864,12 +830,12 @@ void BioStruct3DGLWidget::createMenus() {
     displayMenu->addAction(settingsAction);
     displayMenu->addAction(exportImageAction);
 
-    QMenu *saMenu = createStructuralAlignmentMenu();
-    displayMenu->addMenu(saMenu);
+    auto structuralAlignmentMenu = createStructuralAlignmentMenu();
+    displayMenu->addMenu(structuralAlignmentMenu);
 }
 
-QMenu *BioStruct3DGLWidget::createStructuralAlignmentMenu() {
-    QMenu *saMenu = new QMenu(tr("Structural Alignment"));
+QMenu* BioStruct3DGLWidget::createStructuralAlignmentMenu() {
+    QMenu* saMenu = new QMenu(tr("Structural Alignment"));
     saMenu->menuAction()->setObjectName("Structural Alignment");
 
     saMenu->addAction(alignWithAction);
@@ -879,53 +845,53 @@ QMenu *BioStruct3DGLWidget::createStructuralAlignmentMenu() {
 }
 
 void BioStruct3DGLWidget::connectExternalSignals() {
-    AnnotationSettingsRegistry *asr = AppContext::getAnnotationsSettingsRegistry();
-    connect(asr, SIGNAL(si_annotationSettingsChanged(const QStringList &)), this, SLOT(sl_updateRenderSettings(const QStringList &)));
+    AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
+    connect(asr, SIGNAL(si_annotationSettingsChanged(const QStringList&)), this, SLOT(sl_updateRenderSettings(const QStringList&)));
 
-    const QList<ADVSequenceObjectContext *> seqContexts = dnaView->getSequenceContexts();
+    const QList<ADVSequenceObjectContext*> seqContexts = dnaView->getSequenceContexts();
 
-    foreach (ADVSequenceObjectContext *ctx, seqContexts) {
+    foreach (ADVSequenceObjectContext* ctx, seqContexts) {
         connect(ctx->getSequenceSelection(),
-                SIGNAL(si_selectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)),
-                SLOT(sl_onSequenceSelectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)));
+                SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)),
+                SLOT(sl_onSequenceSelectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)));
     }
 
     connect(dnaView,
-            SIGNAL(si_sequenceAdded(ADVSequenceObjectContext *)),
-            SLOT(sl_onSequenceAddedToADV(ADVSequenceObjectContext *)));
+            SIGNAL(si_sequenceAdded(ADVSequenceObjectContext*)),
+            SLOT(sl_onSequenceAddedToADV(ADVSequenceObjectContext*)));
 
     connect(dnaView,
-            SIGNAL(si_sequenceRemoved(ADVSequenceObjectContext *)),
-            SLOT(sl_onSequenceRemovedFromADV(ADVSequenceObjectContext *)));
+            SIGNAL(si_sequenceRemoved(ADVSequenceObjectContext*)),
+            SLOT(sl_onSequenceRemovedFromADV(ADVSequenceObjectContext*)));
 }
 
-void BioStruct3DGLWidget::sl_onSequenceAddedToADV(ADVSequenceObjectContext *ctx) {
+void BioStruct3DGLWidget::sl_onSequenceAddedToADV(ADVSequenceObjectContext* ctx) {
     connect(ctx->getSequenceSelection(),
-            SIGNAL(si_selectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)),
-            SLOT(sl_onSequenceSelectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)));
+            SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)),
+            SLOT(sl_onSequenceSelectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)));
 }
 
-void BioStruct3DGLWidget::sl_onSequenceRemovedFromADV(ADVSequenceObjectContext *ctx) {
-    disconnect(ctx->getSequenceSelection(), SIGNAL(si_selectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)), this, SLOT(sl_onSequenceSelectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)));
+void BioStruct3DGLWidget::sl_onSequenceRemovedFromADV(ADVSequenceObjectContext* ctx) {
+    disconnect(ctx->getSequenceSelection(), SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)), this, SLOT(sl_onSequenceSelectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)));
 }
 
-void BioStruct3DGLWidget::sl_selectColorScheme(QAction *action) {
+void BioStruct3DGLWidget::sl_selectColorScheme(QAction* action) {
     QString schemeName = action->text();
 
     currentColorSchemeName = schemeName;
     setupColorScheme(schemeName);
 
-    GLFrame *frame = frameManager->getGLWidgetFrame(this);
+    GLFrame* frame = frameManager->getGLWidgetFrame(this);
     frame->makeCurrent();
     frame->updateGL();
 }
 
-void BioStruct3DGLWidget::sl_updateRenderSettings(const QStringList &list) {
+void BioStruct3DGLWidget::sl_updateRenderSettings(const QStringList& list) {
     Q_UNUSED(list);
     sl_selectColorScheme(colorSchemeActions->checkedAction());
 }
 
-void BioStruct3DGLWidget::sl_acitvateSpin() {
+void BioStruct3DGLWidget::sl_activateSpin() {
     if (spinAction->isChecked()) {
         animationTimer->start();
     } else {
@@ -935,14 +901,14 @@ void BioStruct3DGLWidget::sl_acitvateSpin() {
     update();
 }
 
-void BioStruct3DGLWidget::sl_updateAnnimation() {
+void BioStruct3DGLWidget::sl_updateAnimation() {
     static float velocity = 0.05f;
     spinAngle = velocity * animationTimer->interval();
     Vector3D rotAxis(0, 1, 0);
     bool syncLock = isSyncModeOn();
-    QList<GLFrame *> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
+    QList<GLFrame*> frames = frameManager->getActiveGLFrameList(glFrame.data(), syncLock);
 
-    foreach (GLFrame *frame, frames) {
+    foreach (GLFrame* frame, frames) {
         frame->makeCurrent();
         frame->rotateCamera(rotAxis, spinAngle);
         frame->updateGL();
@@ -950,12 +916,12 @@ void BioStruct3DGLWidget::sl_updateAnnimation() {
     update();
 }
 
-void BioStruct3DGLWidget::sl_selectGLRenderer(QAction *action) {
+void BioStruct3DGLWidget::sl_selectGLRenderer(QAction* action) {
     QString rendererName = action->text();
     currentGLRendererName = rendererName;
     setupRenderer(currentGLRendererName);
 
-    GLFrame *frame = frameManager->getGLWidgetFrame(this);
+    GLFrame* frame = frameManager->getGLWidgetFrame(this);
     frame->makeCurrent();
     frame->updateGL();
 }
@@ -983,7 +949,7 @@ void BioStruct3DGLWidget::sl_settings() {
         selectionColor = dialog->getSelectionColor();
         unselectedShadingLevel = dialog->getShadingLevel();
 
-        foreach (const BioStruct3DRendererContext &ctx, contexts) {
+        foreach (const BioStruct3DRendererContext& ctx, contexts) {
             ctx.colorScheme->setSelectionColor(selectionColor);
         }
         setUnselectedShadingLevel(unselectedShadingLevel);
@@ -1014,8 +980,15 @@ void BioStruct3DGLWidget::sl_showSurface() {
     BioStruct3DRendererContext ctx = contexts.first();
     atoms = ctx.biostruct->getAllAtoms();
 
-    QString surfaceType = qobject_cast<QAction *>(sender())->text();
-    surfaceCalcTask = new MolecularSurfaceCalcTask(surfaceType, atoms);
+    QString surfaceType = qobject_cast<QAction*>(sender())->text();
+    auto surfaceCalcTask = new MolecularSurfaceCalcTask(surfaceType, atoms);
+    connect(new TaskSignalMapper(surfaceCalcTask), &TaskSignalMapper::si_taskSucceeded, this, [this](Task* task) {
+        auto surfaceTask = qobject_cast<MolecularSurfaceCalcTask*>(task);
+        SAFE_POINT_NN(surfaceTask, );
+        molSurface.reset(surfaceTask->getCalculatedSurface());
+        makeCurrent();
+        update();
+    });
     AppContext::getTaskScheduler()->registerTopLevelTask(surfaceCalcTask);
 }
 
@@ -1026,7 +999,7 @@ void BioStruct3DGLWidget::sl_hideSurface() {
     update();
 }
 
-void BioStruct3DGLWidget::sl_selectSurfaceRenderer(QAction *action) {
+void BioStruct3DGLWidget::sl_selectSurfaceRenderer(QAction* action) {
     QString msRendererName = action->text();
     surfaceRenderer.reset(MolecularSurfaceRendererRegistry::createMSRenderer(msRendererName));
 
@@ -1034,47 +1007,23 @@ void BioStruct3DGLWidget::sl_selectSurfaceRenderer(QAction *action) {
     update();
 }
 
-void BioStruct3DGLWidget::sl_onTaskFinished(Task *task) {
-    if (surfaceCalcTask != task || surfaceCalcTask->getState() != Task::State_Finished) {
-        return;
-    }
-
-    molSurface.reset(surfaceCalcTask->getCalculatedSurface());
-
-    makeCurrent();
-    update();
-}
-
-/** Convert modelId's list to modelIndexes list */
-static QList<int> modelIdsToModelIdx(const BioStruct3D &bs, const QList<int> &modelsIds) {
-    QList<int> modelsIdx;
-    foreach (int modelId, modelsIds) {
-        int idx = bs.getModelsNames().indexOf(modelId);
-        assert(idx != -1 && "No such modelId in biostruct");
-        modelsIdx << idx;
-    }
-
-    return modelsIdx;
-}
-
-void BioStruct3DGLWidget::addBiostruct(const BioStruct3DObject *obj, const QList<int> &shownModels /* = QList<int>()*/) {
+void BioStruct3DGLWidget::addBiostruct(const BioStruct3DObject* obj, const QList<int>& shownModels /* = QList<int>()*/) {
     assert(contexts.size() < 2 && "Multiple models in one view is unsupported now");
     BioStruct3DRendererContext ctx(obj);
 
-    QList<int> shownModelsIdx = modelIdsToModelIdx(*ctx.biostruct, shownModels);
-
-    // show only first model if model list is empty
-    if (shownModelsIdx.isEmpty()) {
-        shownModelsIdx << 0;
+    QList<int> shownModelsIds = shownModels;
+    // Show only first model if model list is empty.
+    if (shownModelsIds.isEmpty()) {
+        shownModelsIds << obj->getBioStruct3D().modelMap.keys().first();
     }
 
-    BioStruct3DColorScheme *colorScheme = BioStruct3DColorSchemeRegistry::createColorScheme(currentColorSchemeName, ctx.obj);
+    BioStruct3DColorScheme* colorScheme = BioStruct3DColorSchemeRegistry::createColorScheme(currentColorSchemeName, ctx.obj);
     assert(colorScheme);
     ctx.colorScheme = QSharedPointer<BioStruct3DColorScheme>(colorScheme);
     ctx.colorScheme->setSelectionColor(selectionColor);
     ctx.colorScheme->setUnselectedShadingLevel((double)unselectedShadingLevel / 100.0);
 
-    BioStruct3DGLRenderer *renderer = BioStruct3DGLRendererRegistry::createRenderer(currentGLRendererName, *ctx.biostruct, ctx.colorScheme.data(), shownModelsIdx, &rendererSettings);
+    BioStruct3DGLRenderer* renderer = BioStruct3DGLRendererRegistry::createRenderer(currentGLRendererName, *ctx.biostruct, ctx.colorScheme.data(), shownModelsIds, &rendererSettings);
     assert(renderer);
     ctx.renderer = QSharedPointer<BioStruct3DGLRenderer>(renderer);
 
@@ -1085,21 +1034,21 @@ void BioStruct3DGLWidget::addBiostruct(const BioStruct3DObject *obj, const QList
 }
 
 void BioStruct3DGLWidget::sl_alignWith() {
-    const BioStruct3DRendererContext &ctx = contexts.first();
-    int currentModelId = ctx.biostruct->getModelsNames().at(ctx.renderer->getShownModelsIndexes().first());
+    const BioStruct3DRendererContext& ctx = contexts.first();
+    int currentModelId = ctx.renderer->getShownModelsIds().first();
 
     QObjectScopedPointer<StructuralAlignmentDialog> dlg = new StructuralAlignmentDialog(contexts.first().obj, currentModelId);
-    const int dialogResult = dlg->execIfAlgorithmAvailable();
+    int dialogResult = dlg->execIfAlgorithmAvailable();
     CHECK(!dlg.isNull(), );
 
-    if (QDialog::Accepted == dialogResult) {
+    if (dialogResult == QDialog::Accepted) {
         sl_resetAlignment();
 
-        Task *task = dlg->getTask();
+        Task* task = dlg->getTask();
         assert(task && "If dialog accepded it must return valid task");
 
-        TaskSignalMapper *taskMapper = new TaskSignalMapper(task);
-        connect(taskMapper, SIGNAL(si_taskFinished(Task *)), this, SLOT(sl_onAlignmentDone(Task *)));
+        TaskSignalMapper* taskMapper = new TaskSignalMapper(task);
+        connect(taskMapper, SIGNAL(si_taskFinished(Task*)), this, SLOT(sl_onAlignmentDone(Task*)));
 
         AppContext::getTaskScheduler()->registerTopLevelTask(task);
     }
@@ -1116,16 +1065,16 @@ void BioStruct3DGLWidget::sl_resetAlignment() {
     }
 }
 
-void BioStruct3DGLWidget::sl_onAlignmentDone(Task *task) {
+void BioStruct3DGLWidget::sl_onAlignmentDone(Task* task) {
     if (!task->hasError()) {
-        StructuralAlignmentTask *saTask = qobject_cast<StructuralAlignmentTask *>(task);
+        auto saTask = qobject_cast<StructuralAlignmentTask*>(task);
         assert(saTask && "Task should have type StructuralAlignmentTask");
 
         StructuralAlignment result = saTask->getResult();
         StructuralAlignmentTaskSettings settings = saTask->getSettings();
 
-        const Matrix44 &mt = result.transform;
-        const_cast<BioStruct3D *>(&settings.alt.obj->getBioStruct3D())->setTransform(mt);
+        const Matrix44& mt = result.transform;
+        const_cast<BioStruct3D*>(&settings.alt.obj->getBioStruct3D())->setTransform(mt);
 
         addBiostruct(settings.alt.obj, QList<int>() << settings.alt.modelId);
 
