@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BIOSTRUCT3D_SUBSET_EDITOR_H_
-#define _U2_BIOSTRUCT3D_SUBSET_EDITOR_H_
+#pragma once
 
 #include <QWidget>
 
@@ -40,7 +39,7 @@ public:
      * @param selected Pre selected biostruct
      * @param selectedModel Pre selected model
      */
-    BioStruct3DSubsetEditor(const QList<BioStruct3DObject *> &biostructs, const BioStruct3DObject *selected = 0, int selectedModel = -1, QWidget *parent = 0);
+    BioStruct3DSubsetEditor(const QList<BioStruct3DObject*>& biostructs, const BioStruct3DObject* selected = 0, int selectedModel = -1, QWidget* parent = 0);
 
     /** Fill model ComboBox respectively with current biostruct */
     void fillModelCombo();
@@ -67,7 +66,7 @@ private:
     U2Region getRegion() const;
 
     /** Set text in region Edit from U2Region */
-    void setRegion(const U2Region &region);
+    void setRegion(const U2Region& region);
 
 private slots:
     void sl_onBiostructChanged(int);
@@ -75,5 +74,3 @@ private slots:
 };
 
 }  // namespace U2
-
-#endif  // #ifndef _U2_BIOSTRUCT3D_SUBSET_EDITOR_H_
