@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,36 +19,34 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef U2_SELECTMODELSDIALOG_H
-#define U2_SELECTMODELSDIALOG_H
+#pragma once
+
+#include <QDialog>
 
 #include "ui_SelectModelsDialog.h"
-#include <QDialog>
 
 namespace U2 {
 
-class SelectModelsDialog : public QDialog, public Ui_SelectModelsDialog
-{
+class SelectModelsDialog : public QDialog, public Ui_SelectModelsDialog {
     Q_OBJECT
 
 public:
-    SelectModelsDialog(const QList<int> &modelIds, const QList<int> &selectedItems, QWidget *parent = 0);
-    ~SelectModelsDialog();
+    SelectModelsDialog(const QList<int>& modelIds, const QList<int>& initiallySelectedModelIds, QWidget* parent);
 
-    const QList<int> &getSelectedModelsIndexes() const { return selectedModelsIndexes; }
+    /** Returns list of selected models. Available after the dialog is accepted. */
+    const QList<int>& getSelectedModelsIds() const;
 
 public slots:
-    virtual void accept();
+    void accept() override;
 
-    void sl_onItemDoubleClicked(QListWidgetItem *item);
+    void sl_onItemDoubleClicked(QListWidgetItem* item);
 
-    void sl_onSlectAll();
+    void sl_onSelectAll();
     void sl_onInvertSelection();
 
 private:
-    QList<int> selectedModelsIndexes;
+    QList<int> modelIds;
+    QList<int> selectedModelIds;
 };
 
-}   // namespace U2
-
-#endif  // #ifndef U2_SELECTMODELSDIALOG_H
+}  // namespace U2
