@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SETTINGSDIALOG_H_
-#define _U2_SETTINGSDIALOG_H_
-
-#include <QColorDialog>
+#pragma once
 
 #include "AnaglyphRenderer.h"
 #include "BioStruct3DGLWidget.h"
@@ -65,10 +62,10 @@ private slots:
 public:
     // anaglyph related settings
     AnaglyphStatus getAnaglyphStatus() const;
-    const AnaglyphSettings &getAnaglyphSettings() const;
+    const AnaglyphSettings& getAnaglyphSettings() const;
 
     void setAnaglyphStatus(AnaglyphStatus status);
-    void setAnaglyphSettings(const AnaglyphSettings &settings);
+    void setAnaglyphSettings(const AnaglyphSettings& settings);
 
     void setRightEyeColor(QColor rightEyecolor);
     void setLeftEyeColor(QColor leftEyecolor);
@@ -82,18 +79,18 @@ public:
     void setBackgroundColor(QColor color);
     void setSelectionColor(QColor color);
 
-    void setGlassesColorScheme(QColor &leftEyeColor, QColor &rightEyeColor);
+    void setGlassesColorScheme(QColor& leftEyeColor, QColor& rightEyeColor);
     void setGlassesColorScheme(int num);
 
     void setRenderDetailLevel(float renderDetailLevel);
     void setShadingLevel(int shading);
 
-    void setWidget(BioStruct3DGLWidget *glWidget);
+    void setWidget(BioStruct3DGLWidget* glWidget);
 
 private:
     QVariantMap state;
 
-    BioStruct3DGLWidget *glWidget;
+    BioStruct3DGLWidget* glWidget;
     QList<GlassesColorScheme> glassesColorSchemes;
 
     void initColorSchemes();
@@ -109,5 +106,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_SETTINGSDIALOG_H_
