@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_STRUCTURAL_ALIGNMENT_DIALOG_H_
-#define _U2_STRUCTURAL_ALIGNMENT_DIALOG_H_
+#pragma once
 
 #include "ui_StructuralAlignmentDialog.h"
 
@@ -34,22 +33,21 @@ class StructuralAlignmentDialog : public QDialog, public Ui_StructuralAlignmentD
     Q_OBJECT
 
 public:
-    StructuralAlignmentDialog(const BioStruct3DObject *fixedRef = 0, int fixedRefModel = -1, QWidget *parent = 0);
+    StructuralAlignmentDialog(const BioStruct3DObject* fixedRef = 0, int fixedRefModel = -1, QWidget* parent = 0);
 
     /** Check if algorithm available and ::exec() */
     int execIfAlgorithmAvailable();
 
     /** @returns set up StructuralAlignmentTask */
-    StructuralAlignmentTask *getTask();
+    StructuralAlignmentTask* getTask();
 
 public slots:
-    virtual void accept();
+    void accept() override;
 
 private:
-    StructuralAlignmentTask *task;
-    BioStruct3DSubsetEditor *ref, *mob;
+    StructuralAlignmentTask* task = nullptr;
+    BioStruct3DSubsetEditor* ref = nullptr;
+    BioStruct3DSubsetEditor* mob = nullptr;
 };
 
 }  // namespace U2
-
-#endif  // #ifndef _U2_STRUCTURAL_ALIGNMENT_DIALOG_H_
