@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
-#define _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
+#pragma once
 
 #include "BioStruct3DGLRender.h"
 
@@ -28,7 +27,7 @@ namespace U2 {
 
 class VanDerWaalsGLRenderer : public BioStruct3DGLRenderer {
 protected:
-    VanDerWaalsGLRenderer(const BioStruct3D &struc, const BioStruct3DColorScheme *s, const QList<int> &shownModels, const BioStruct3DRendererSettings *settings);
+    VanDerWaalsGLRenderer(const BioStruct3D& struc, const BioStruct3DColorScheme* s, const QList<int>& shownModels, const BioStruct3DRendererSettings* settings);
 
 public:
     void drawBioStruct3D();
@@ -43,11 +42,9 @@ public:
     }
 
 private:
-    void drawAtoms(const BioStruct3DColorScheme *s);
+    void drawAtoms(const BioStruct3DColorScheme* s);
 
     RENDERER_FACTORY(VanDerWaalsGLRenderer)
 };
 
 }  // namespace U2
-
-#endif  // _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
