@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CHROMA_VIEW_PLUGIN_H_
-#define _U2_CHROMA_VIEW_PLUGIN_H_
+#pragma once
 
 #include <U2Core/AppContext.h>
 
@@ -39,30 +38,28 @@ public:
     ~ChromaViewPlugin();
 
 private:
-    GObjectViewWindowContext *viewCtx;
+    GObjectViewWindowContext* viewCtx;
 };
 
 class ChromaViewContext : public GObjectViewWindowContext {
     Q_OBJECT
 public:
-    ChromaViewContext(QObject *p);
+    ChromaViewContext(QObject* p);
 
-    bool canHandle(GObjectView *v, GObject *o) override;
+    bool canHandle(GObjectViewController* v, GObject* o) override;
 protected slots:
     void sl_showChromatogram();
-    void sl_sequenceWidgetAdded(ADVSequenceWidget *);
+    void sl_sequenceWidgetAdded(ADVSequenceWidget*);
 
 protected:
-    void initViewContext(GObjectView *view) override;
+    void initViewContext(GObjectViewController* view) override;
 };
 
 class ChromaViewAction : public ADVSequenceWidgetAction {
     Q_OBJECT
 public:
     ChromaViewAction();
-    ChromatogramView *view;
+    ChromatogramView* view;
 };
 
 }  // namespace U2
-
-#endif
