@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CHROMATOGRAM_VIEW_H_
-#define _U2_CHROMATOGRAM_VIEW_H_
+#pragma once
 
 #include <U2Core/DNAChromatogram.h>
 #include <U2Core/GObject.h>
@@ -34,7 +33,7 @@ namespace U2 {
 class ADVSequenceObjectContext;
 class ChromatogramViewRenderArea;
 class AnnotatedDNAView;
-class GObjectView;
+class GObjectViewController;
 class Task;
 
 struct ChromatogramViewSettings {
@@ -52,16 +51,16 @@ class ChromatogramView : public GSequenceLineView {
     friend class ChromatogramViewRenderArea;
 
 public:
-    ChromatogramView(QWidget *p, ADVSequenceObjectContext *v, GSequenceLineView *cv, const DNAChromatogram &chroma);
+    ChromatogramView(QWidget* p, ADVSequenceObjectContext* v, GSequenceLineView* cv, const DNAChromatogram& chroma);
 
-    virtual void buildPopupMenu(QMenu &m);
+    virtual void buildPopupMenu(QMenu& m);
 
-    virtual bool isWidgetOnlyObject(GObject *o) const;
+    virtual bool isWidgetOnlyObject(GObject* o) const;
 
-    U2SequenceObject *getEditedSequence() const {
+    U2SequenceObject* getEditedSequence() const {
         return editDNASeq;
     }
-    const ChromatogramViewSettings &getSettings() const {
+    const ChromatogramViewSettings& getSettings() const {
         return settings;
     }
     bool showQV() const {
@@ -70,48 +69,48 @@ public:
 
 protected:
     virtual void pack();
-    void mousePressEvent(QMouseEvent *me);
+    void mousePressEvent(QMouseEvent* me);
 
 private slots:
     void setRenderAreaHeight(int k);
-    void sl_onPopupMenuCkicked(QAction *a);
+    void sl_onPopupMenuCkicked(QAction* a);
     void sl_addNewSequenceObject();
     void sl_onAddExistingSequenceObject();
-    void sl_onSequenceObjectLoaded(Task *);
+    void sl_onSequenceObjectLoaded(Task*);
     void sl_clearEditableSequence();
     void sl_removeChanges();
-    void sl_onObjectRemoved(GObjectView *, GObject *);
+    void sl_onObjectRemoved(GObjectViewController*, GObject*);
     void sl_showHideTrace();
     void sl_showAllTraces();
 
 private:
     int getEditSeqIndex(int bcIndex);
-    QAction *createToggleTraceAction(const QString &actionName);
+    QAction* createToggleTraceAction(const QString& actionName);
 
-    AnnotatedDNAView *dnaView;
-    U2SequenceObject *editDNASeq;
+    AnnotatedDNAView* dnaView;
+    U2SequenceObject* editDNASeq;
     QByteArray currentBaseCalls;
     QSet<int> indexOfChangedChars;
     QList<int> gapIndexes;
 
-    ScaleBar *scaleBar;
+    ScaleBar* scaleBar;
     ChromatogramViewSettings settings;
-    ChromatogramViewRenderArea *ra;
-    QMenu *mP;
+    ChromatogramViewRenderArea* ra;
+    QMenu* mP;
     int selIndex;
-    QAction *addNewSeqAction;
-    QAction *addExistSeqAction;
-    QAction *clearEditableSequence;
-    QAction *removeChanges;
-    QAction *showQVAction;
-    QAction *showAllTraces;
-    QMenu *traceActionMenu;
+    QAction* addNewSeqAction;
+    QAction* addExistSeqAction;
+    QAction* clearEditableSequence;
+    QAction* removeChanges;
+    QAction* showQVAction;
+    QAction* showAllTraces;
+    QMenu* traceActionMenu;
 };
 
 class ChromatogramViewRenderArea : public GSequenceLineViewRenderArea {
     Q_OBJECT
 public:
-    ChromatogramViewRenderArea(ChromatogramView *p, const DNAChromatogram &chroma);
+    ChromatogramViewRenderArea(ChromatogramView* p, const DNAChromatogram& chroma);
     ~ChromatogramViewRenderArea();
 
     int getHeightAreaBC() const {
@@ -119,7 +118,7 @@ public:
     }
     void setAreaHeight(int newH);
 
-    qint64 coordToPos(const QPoint &coord) const override;
+    qint64 coordToPos(const QPoint& coord) const override;
 
     int posToCoord(qint64 p, bool useVirtualSpace = false) const override;
 
@@ -131,14 +130,14 @@ public:
     qreal addUpIfQVL;
 
 protected:
-    void drawAll(QPaintDevice *pd) override;
+    void drawAll(QPaintDevice* pd) override;
 
 private:
     QColor getBaseColor(char base);
-    void drawChromatogramTrace(qreal x, qreal y, qreal w, qreal h, QPainter &p, const U2Region &visible, const ChromatogramViewSettings &settings);
-    void drawOriginalBaseCalls(qreal x, qreal y, qreal w, qreal h, QPainter &p, const U2Region &visible, const QByteArray &ba, bool is = true);
-    void drawQualityValues(qreal x, qreal y, qreal w, qreal h, QPainter &p, const U2Region &visible, const QByteArray &ba);
-    void drawChromatogramBaseCallsLines(qreal x, qreal y, qreal w, qreal h, QPainter &p, const U2Region &visible, const QByteArray &ba, const ChromatogramViewSettings &settings);
+    void drawChromatogramTrace(qreal x, qreal y, qreal w, qreal h, QPainter& p, const U2Region& visible, const ChromatogramViewSettings& settings);
+    void drawOriginalBaseCalls(qreal x, qreal y, qreal w, qreal h, QPainter& p, const U2Region& visible, const QByteArray& ba, bool is = true);
+    void drawQualityValues(qreal x, qreal y, qreal w, qreal h, QPainter& p, const U2Region& visible, const QByteArray& ba);
+    void drawChromatogramBaseCallsLines(qreal x, qreal y, qreal w, qreal h, QPainter& p, const U2Region& visible, const QByteArray& ba, const ChromatogramViewSettings& settings);
 
     DNAChromatogram chroma;
     int chromaMax;
@@ -155,5 +154,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
