@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -25,23 +25,15 @@
 #include <QFileInfo>
 #include <QHBoxLayout>
 #include <QMessageBox>
-#include <QPainter>
-#include <QPixmap>
-#include <QPrinter>
 #include <QScrollArea>
 #include <QTreeWidget>
-#include <QVBoxLayout>
 
 #include <U2Core/DNASequenceObject.h>
-#include <U2Core/GObject.h>
-#include <U2Core/GObjectTypes.h>
 #include <U2Core/GUrlUtils.h>
-#include <U2Core/L10n.h>
 #include <U2Core/QObjectScopedPointer.h>
 #include <U2Core/Settings.h>
 #include <U2Core/U2SafePoints.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/ExportImageDialog.h>
 #include <U2Gui/OrderedToolbar.h>
 #include <U2Gui/WidgetWithLocalToolbar.h>
@@ -52,7 +44,7 @@
 
 namespace U2 {
 
-CircularViewSplitter::CircularViewSplitter(AnnotatedDNAView *view)
+CircularViewSplitter::CircularViewSplitter(AnnotatedDNAView* view)
     : ADVSplitWidget(view) {
     zoomInAction = new QAction(tr("Zoom In"), this);
     zoomInAction->setIcon(QIcon(":/core/images/zoom_in.png"));
@@ -82,14 +74,14 @@ CircularViewSplitter::CircularViewSplitter(AnnotatedDNAView *view)
 
     splitter = new QSplitter(Qt::Horizontal);
 
-    WidgetWithLocalToolbar *widgetWithToolBar = new WidgetWithLocalToolbar(this);
+    WidgetWithLocalToolbar* widgetWithToolBar = new WidgetWithLocalToolbar(this);
     widgetWithToolBar->setLocalToolBarObjectName("circular_view_local_toolbar");
     widgetWithToolBar->addActionToLocalToolbar(zoomInAction);
     widgetWithToolBar->addActionToLocalToolbar(zoomOutAction);
     widgetWithToolBar->addActionToLocalToolbar(fitInViewAction);
     widgetWithToolBar->addActionToLocalToolbar(exportAction);
     widgetWithToolBar->addActionToLocalToolbar(toggleRestrictionMapAction);
-    QVBoxLayout *layout = new QVBoxLayout();
+    QVBoxLayout* layout = new QVBoxLayout();
     layout->setSpacing(0);
     layout->setMargin(0);
     layout->addWidget(splitter);
@@ -99,11 +91,12 @@ CircularViewSplitter::CircularViewSplitter(AnnotatedDNAView *view)
     setBaseSize(600, 600);
     setAcceptDrops(false);
 
-    QVBoxLayout *outerLayout = new QVBoxLayout(this);
+    QVBoxLayout* outerLayout = new QVBoxLayout(this);
     outerLayout->setSpacing(0);
     outerLayout->setContentsMargins(0, 0, 0, 0);
 
     horScroll = new QScrollBar(Qt::Horizontal, this);
+    horScroll->setObjectName("CircularViewSplitter_horScroll");
     horScroll->setMinimum(0);
     horScroll->setMaximum(360);
     horScroll->setSingleStep(5);
@@ -113,17 +106,17 @@ CircularViewSplitter::CircularViewSplitter(AnnotatedDNAView *view)
     outerLayout->insertWidget(-1, horScroll);
 }
 
-void CircularViewSplitter::updateState(const QVariantMap &m) {
+void CircularViewSplitter::updateState(const QVariantMap& m) {
     Q_UNUSED(m);
     // TODO:
 }
 
-void CircularViewSplitter::saveState(QVariantMap &m) {
+void CircularViewSplitter::saveState(QVariantMap& m) {
     Q_UNUSED(m);
     // TODO:
 }
 
-void CircularViewSplitter::addView(CircularView *view, RestrctionMapWidget *rmapWidget) {
+void CircularViewSplitter::addView(CircularView* view, RestrctionMapWidget* rmapWidget) {
     fitInViewAction->setDisabled(true);
     connect(zoomInAction, SIGNAL(triggered()), view, SLOT(sl_zoomIn()));
     connect(zoomOutAction, SIGNAL(triggered()), view, SLOT(sl_zoomOut()));
@@ -136,7 +129,7 @@ void CircularViewSplitter::addView(CircularView *view, RestrctionMapWidget *rmap
     circularViewList.append(view);
     restrictionMapWidgets.append(rmapWidget);
 
-    QScrollArea *scrollArea = new QScrollArea(this);
+    QScrollArea* scrollArea = new QScrollArea(this);
     scrollArea->setWidget(view);
     scrollArea->setFrameStyle(QFrame::NoFrame);
     scrollArea->setWidgetResizable(true);
@@ -162,11 +155,11 @@ void CircularViewSplitter::sl_moveSlider(int delta) {
     horScroll->setSliderPosition(newPos);
 }
 
-void CircularViewSplitter::removeView(CircularView *view, RestrctionMapWidget *rmapWidget) {
+void CircularViewSplitter::removeView(CircularView* view, RestrctionMapWidget* rmapWidget) {
     SAFE_POINT(view != nullptr, tr("Circular View is NULL"), );
-    QWidget *viewport = view->parentWidget();
+    QWidget* viewport = view->parentWidget();
     SAFE_POINT(viewport != nullptr, tr("Circular View viewport is NULL"), );
-    QScrollArea *scrollArea = qobject_cast<QScrollArea *>(viewport->parentWidget());
+    auto scrollArea = qobject_cast<QScrollArea*>(viewport->parentWidget());
     SAFE_POINT(scrollArea != nullptr, tr("Scroll area is NULL"), );
     view->setParent(nullptr);
     delete scrollArea;
@@ -179,7 +172,7 @@ bool CircularViewSplitter::isEmpty() {
     return circularViewList.isEmpty();
 }
 
-bool noValidExtension(const QString &url) {
+bool noValidExtension(const QString& url) {
     QFileInfo fi(url);
     if (fi.suffix().isEmpty()) {
         return true;
@@ -205,14 +198,14 @@ bool noValidExtension(const QString &url) {
 }
 
 void CircularViewSplitter::updateViews() {
-    foreach (CircularView *cv, circularViewList) {
+    foreach (CircularView* cv, circularViewList) {
         cv->redraw();
     }
 }
 
 void CircularViewSplitter::sl_export() {
-    CircularView *cvInFocus = nullptr;
-    foreach (CircularView *cv, circularViewList) {
+    CircularView* cvInFocus = nullptr;
+    foreach (CircularView* cv, circularViewList) {
         if (cv->hasFocus()) {
             cvInFocus = cv;
             break;
@@ -223,29 +216,29 @@ void CircularViewSplitter::sl_export() {
     }
 
     SAFE_POINT(cvInFocus->getSequenceContext() != nullptr, tr("Sequence context is NULL"), );
-    U2SequenceObject *seqObj = cvInFocus->getSequenceContext()->getSequenceObject();
+    U2SequenceObject* seqObj = cvInFocus->getSequenceContext()->getSequenceObject();
     SAFE_POINT(seqObj != nullptr, tr("Sequence obejct is NULL"), );
 
     CircularViewImageExportController factory(circularViewList, cvInFocus);
 
     QString fileName = GUrlUtils::fixFileName(seqObj->getSequenceName());
-    QWidget *p = (QWidget *)AppContext::getMainWindow()->getQMainWindow();
+    QWidget* p = (QWidget*)AppContext::getMainWindow()->getQMainWindow();
     QObjectScopedPointer<ExportImageDialog> dialog = new ExportImageDialog(&factory, ExportImageDialog::CircularView, fileName, ExportImageDialog::SupportScaling, p);
     dialog->exec();
     CHECK(!dialog.isNull(), );
 }
 
 void CircularViewSplitter::sl_horSliderMoved(int newVal) {
-    foreach (CircularView *cv, circularViewList) {
+    foreach (CircularView* cv, circularViewList) {
         cv->setAngle(newVal);
     }
 }
 
 void CircularViewSplitter::adaptSize() {
-    QWidget *widget = parentWidget();
+    QWidget* widget = parentWidget();
 
     Q_ASSERT(widget != nullptr);
-    QSplitter *parentSplitter = qobject_cast<QSplitter *>(widget);
+    auto parentSplitter = qobject_cast<QSplitter*>(widget);
 
     int index = parentSplitter->indexOf(this);
     QList<int> sizes = parentSplitter->sizes();
@@ -300,7 +293,7 @@ void CircularViewSplitter::sl_updateFitInViewAction(bool disabled) {
 }
 
 void CircularViewSplitter::sl_toggleRestrictionMap(bool toggle) {
-    foreach (QWidget *w, restrictionMapWidgets) {
+    foreach (QWidget* w, restrictionMapWidgets) {
         w->setVisible(toggle);
     }
 }
