@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CIRCULAR_VIEW_SPLITTER_H_
-#define _U2_CIRCULAR_VIEW_SPLITTER_H_
+#pragma once
 
 #include <QAction>
 
@@ -39,19 +38,19 @@ class RestrctionMapWidget;
 class CircularViewSplitter : public ADVSplitWidget {
     Q_OBJECT
 public:
-    CircularViewSplitter(AnnotatedDNAView *view);
+    CircularViewSplitter(AnnotatedDNAView* view);
     // there are no special object handling with this view
     // it only shows existing AO only
-    virtual bool acceptsGObject(GObject *) {
+    virtual bool acceptsGObject(GObject*) {
         return false;
     }
-    virtual void updateState(const QVariantMap &m);
-    virtual void saveState(QVariantMap &m);
-    void addView(CircularView *view, RestrctionMapWidget *rmapWidget);
+    virtual void updateState(const QVariantMap& m);
+    virtual void saveState(QVariantMap& m);
+    void addView(CircularView* view, RestrctionMapWidget* rmapWidget);
     void adaptSize();
-    void removeView(CircularView *view, RestrctionMapWidget *rmapWidget);
+    void removeView(CircularView* view, RestrctionMapWidget* rmapWidget);
     bool isEmpty();
-    const QList<CircularView *> &getViewList() const {
+    const QList<CircularView*>& getViewList() const {
         return circularViewList;
     }
     void updateViews();
@@ -66,19 +65,17 @@ protected slots:
     void sl_toggleRestrictionMap(bool);
 
 private:
-    QSplitter *splitter;
-    QScrollBar *horScroll;
+    QSplitter* splitter;
+    QScrollBar* horScroll;
 
-    QAction *zoomInAction;
-    QAction *zoomOutAction;
-    QAction *fitInViewAction;
-    QAction *exportAction;
-    QAction *toggleRestrictionMapAction;
+    QAction* zoomInAction;
+    QAction* zoomOutAction;
+    QAction* fitInViewAction;
+    QAction* exportAction;
+    QAction* toggleRestrictionMapAction;
 
-    QList<CircularView *> circularViewList;
-    QList<RestrctionMapWidget *> restrictionMapWidgets;
+    QList<CircularView*> circularViewList;
+    QList<RestrctionMapWidget*> restrictionMapWidgets;
 };
 
 }  // namespace U2
-
-#endif  //_U2_CIRCULAR_VIEW_SPLITTER_H_
