@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_RESTRICTION_MAP_WIDGET_H_
-#define _U2_RESTRICTION_MAP_WIDGET_H_
+#pragma once
 
 #include <QTreeWidget>
 
@@ -32,23 +31,23 @@ class ADVSequenceObjectContext;
 
 class EnzymeItem : public QTreeWidgetItem {
 public:
-    EnzymeItem(const QString &locationStr, Annotation *a);
-    Annotation *getEnzymeAnnotation() const {
+    EnzymeItem(const QString& locationStr, Annotation* a);
+    Annotation* getEnzymeAnnotation() const {
         return annotation;
     }
 
 private:
-    Annotation *annotation;
+    Annotation* annotation;
 };
 
 class EnzymeFolderItem : public QTreeWidgetItem {
     QString enzymeName;
 
 public:
-    EnzymeFolderItem(const QString &name);
-    void addEnzymeItem(Annotation *enzAnn);
-    void removeEnzymeItem(Annotation *enzAnn);
-    const QString &getName() const {
+    EnzymeFolderItem(const QString& name);
+    void addEnzymeItem(Annotation* enzAnn);
+    void removeEnzymeItem(Annotation* enzAnn);
+    const QString& getName() const {
         return enzymeName;
     }
 };
@@ -56,24 +55,22 @@ public:
 class RestrctionMapWidget : public QWidget {
     Q_OBJECT
 public:
-    RestrctionMapWidget(ADVSequenceObjectContext *ctx, QWidget *p);
+    RestrctionMapWidget(ADVSequenceObjectContext* ctx, QWidget* p);
 
 private slots:
-    void sl_onAnnotationsAdded(const QList<Annotation *> &anns);
-    void sl_onAnnotationsRemoved(const QList<Annotation *> &anns);
-    void sl_onAnnotationsInGroupRemoved(const QList<Annotation *> &anns, AnnotationGroup *group);
-    void sl_onAnnotationsGroupCreated(AnnotationGroup *g);
+    void sl_onAnnotationsAdded(const QList<Annotation*>& anns);
+    void sl_onAnnotationsRemoved(const QList<Annotation*>& anns);
+    void sl_onAnnotationsInGroupRemoved(const QList<Annotation*>& anns, AnnotationGroup* group);
+    void sl_onAnnotationsGroupCreated(AnnotationGroup* g);
     void sl_itemSelectionChanged();
 
 private:
-    ADVSequenceObjectContext *ctx;
-    QTreeWidget *treeWidget;
-    EnzymeFolderItem *findEnzymeFolderByName(const QString &enzymeName);
+    ADVSequenceObjectContext* ctx;
+    QTreeWidget* treeWidget;
+    EnzymeFolderItem* findEnzymeFolderByName(const QString& enzymeName);
     void registerAnnotationObjects();
     void updateTreeWidget();
     void initTreeWidget();
 };
 
 }  // namespace U2
-
-#endif  //  _U2_RESTRICTION_MAP_WIDGET_H_
