@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SEQUENCE_ORIGIN_DIALOG_H_
-#define _U2_SEQUENCE_ORIGIN_DIALOG_H_
+#pragma once
 
 #include <ui_SetSequenceOriginDialog.h>
 
@@ -31,13 +30,11 @@ class ADVSequenceObjectContext;
 
 class SetSequenceOriginDialog : public QDialog, Ui_SetSequenceOriginDialog {
     Q_OBJECT
-    ADVSequenceObjectContext *seqContext;
+    ADVSequenceObjectContext* seqContext;
 
 public:
-    SetSequenceOriginDialog(ADVSequenceWidget *parent);
+    SetSequenceOriginDialog(ADVSequenceWidget* parent);
     int getSequenceShift();
 };
 
 }  // namespace U2
-
-#endif
