@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SHIFT_SEQUENCE_START_TASK_H_
-#define _U2_SHIFT_SEQUENCE_START_TASK_H_
+#pragma once
 
 #include <U2Core/DocumentModel.h>
 #include <U2Core/Task.h>
@@ -34,15 +33,13 @@ class ShiftSequenceStartTask : public Task {
     Q_OBJECT
 public:
     /** Shifts circular sequence start position to 'shift' symbols forward. */
-    ShiftSequenceStartTask(U2SequenceObject *sequenceObject, qint64 newSequenceStartPosition);
+    ShiftSequenceStartTask(U2SequenceObject* sequenceObject, qint64 newSequenceStartPosition);
 
     virtual Task::ReportResult report();
 
 private:
-    U2SequenceObject *sequenceObject;
+    U2SequenceObject* sequenceObject;
     qint64 newSequenceStartPosition;
 };
 
 }  // namespace U2
-
-#endif
