@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_ALIGNMENT_H_
-#define _U2_BAM_ALIGNMENT_H_
+#pragma once
 
 #include <QFlags>
 #include <QList>
@@ -62,40 +61,40 @@ public:
     int getPosition() const;
     int getBin() const;
     int getMapQuality() const;
-    qint64 getFlags() const;
+    const ReadFlags& getFlags() const;
     int getNextReferenceId() const;
     QByteArray getNextReferenceName() const;
     int getNextPosition() const;
     int getTemplateLength() const;
-    const QByteArray &getName() const;
-    const QList<CigarOperation> &getCigar() const;
-    const QByteArray &getSequence() const;
-    const QByteArray &getQuality() const;
-    const QList<U2AuxData> &getAuxData() const;
+    const QByteArray& getName() const;
+    const QList<CigarOperation>& getCigar() const;
+    const QByteArray& getSequence() const;
+    const QByteArray& getQuality() const;
+    const QList<U2AuxData>& getAuxData() const;
     void setReferenceId(int referenceId);
     void setPosition(int position);
     void setBin(int bin);
     void setMapQuality(int mapQuality);
-    void setFlags(qint64 flags);
+    void setFlags(const ReadFlags& flags);
     void setNextReferenceId(int nextReferenceId);
-    void setNextReferenceName(const QByteArray &nextReferenceName);
+    void setNextReferenceName(const QByteArray& nextReferenceName);
     void setNextPosition(int nextPosition);
     void setTemplateLength(int templateLength);
-    void setName(const QByteArray &name);
-    void setCigar(const QList<CigarOperation> &cigar);
-    void setSequence(const QByteArray &sequence);
-    void setQuality(const QByteArray &quality);
-    void setAuxData(const QList<U2AuxData> &aux);
+    void setName(const QByteArray& name);
+    void setCigar(const QList<CigarOperation>& cigar);
+    void setSequence(const QByteArray& sequence);
+    void setQuality(const QByteArray& quality);
+    void setAuxData(const QList<U2AuxData>& aux);
 
-    static int computeLength(const QList<CigarOperation> &cigar);
-    static int computeLength(const QList<U2CigarToken> &cigar);
+    static int computeLength(const QList<CigarOperation>& cigar);
+    static int computeLength(const QList<U2CigarToken>& cigar);
 
 private:
     int referenceId;
     int position;
     int bin;
     int mapQuality;
-    qint64 flags;
+    ReadFlags flags;
     int nextReferenceId;
     QByteArray nextReferenceName;
     int nextPosition;
@@ -109,5 +108,3 @@ private:
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_ALIGNMENT_H_
