@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_DBI_PLUGIN_H_
-#define _U2_BAM_DBI_PLUGIN_H_
+#pragma once
 
 #include <time.h>
 
@@ -50,9 +49,9 @@ class BAMImporter : public DocumentImporter {
 public:
     BAMImporter();
 
-    virtual FormatCheckResult checkRawData(const QByteArray &rawData, const GUrl &url);
+    virtual FormatCheckResult checkRawData(const QByteArray& rawData, const GUrl& url);
 
-    virtual DocumentProviderTask *createImportTask(const FormatDetectionResult &res, bool showGui, const QVariantMap &hints);
+    virtual DocumentProviderTask* createImportTask(const FormatDetectionResult& res, bool showGui, const QVariantMap& hints);
 };
 
 class LoadInfoTask;
@@ -61,10 +60,10 @@ class ConvertToSQLiteTask;
 class BAMImporterTask : public DocumentProviderTask {
     Q_OBJECT
 public:
-    BAMImporterTask(const GUrl &url, bool useGui, const QVariantMap &hints);
+    BAMImporterTask(const GUrl& url, bool useGui, const QVariantMap& hints);
 
     void prepare();
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
     ReportResult report();
 
 private:
@@ -74,12 +73,12 @@ private:
     void initCloneObjectTasks();
     void initLoadDocumentTask();
 
-    LoadInfoTask *loadInfoTask;
-    LoadInfoTask *loadBamInfoTask;
-    PrepareToImportTask *prepareToImportTask;
-    ConvertToSQLiteTask *convertTask;
-    QList<Task *> cloneTasks;
-    LoadDocumentTask *loadDocTask;
+    LoadInfoTask* loadInfoTask;
+    LoadInfoTask* loadBamInfoTask;
+    PrepareToImportTask* prepareToImportTask;
+    ConvertToSQLiteTask* convertTask;
+    QList<Task*> cloneTasks;
+    LoadDocumentTask* loadDocTask;
 
     bool isSqliteDbTransit;
     bool useGui;
@@ -93,5 +92,3 @@ private:
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_DBI_PLUGIN_H_
