@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_FORMAT_H_
-#define _U2_BAM_FORMAT_H_
+#pragma once
 
 #include <QStringList>
 
@@ -35,7 +34,7 @@ class BAMFormat : public DbiDocumentFormat {
 public:
     BAMFormat();
 
-    void storeDocument(Document *d, IOAdapter *io, U2OpStatus &os);
+    void storeDocument(Document* d, IOAdapter* io, U2OpStatus& os);
 };
 
 namespace BAM {
@@ -43,9 +42,9 @@ namespace BAM {
 class BAMFormatUtils : public QObject {
     Q_OBJECT
 public:
-    BAMFormatUtils(QObject *parent = nullptr);
+    BAMFormatUtils(QObject* parent = nullptr);
 
-    FormatCheckResult checkRawData(const QByteArray &rawData, const GUrl &url = GUrl()) const;
+    FormatCheckResult checkRawData(const QByteArray& rawData, const GUrl& url = GUrl()) const;
 
     QStringList getSupportedDocumentFileExtensions() const {
         return fileExtensions;
@@ -57,5 +56,3 @@ private:
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_FORMAT_H_
