@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_BAI_READER_H_
-#define _U2_BAM_BAI_READER_H_
+#pragma once
 
 #include <U2Core/IOAdapter.h>
 
@@ -31,20 +30,18 @@ namespace BAM {
 
 class BaiReader {
 public:
-    BaiReader(IOAdapter &ioAdapter);
+    BaiReader(IOAdapter& ioAdapter);
     Index readIndex();
 
 private:
-    void readBytes(char *buff, qint64 size);
+    void readBytes(char* buff, qint64 size);
     QByteArray readBytes(qint64 size);
     quint64 readUint64();
     qint32 readInt32();
     quint64 readUint32();
 
-    IOAdapter &ioAdapter;
+    IOAdapter& ioAdapter;
 };
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_BAI_READER_H_
