@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -27,40 +27,42 @@
 namespace U2 {
 namespace BAM {
 
-BaiWriter::BaiWriter(IOAdapter &ioAdapter)
+BaiWriter::BaiWriter(IOAdapter& ioAdapter)
     : ioAdapter(ioAdapter) {
 }
 
-void BaiWriter::writeIndex(const Index &index) {
+void BaiWriter::writeIndex(const Index& index) {
     writeBytes(QByteArray("BAI\001"));
     writeInt32(index.getReferenceIndices().size());
-    foreach (const Index::ReferenceIndex &referenceIndex, index.getReferenceIndices()) {
+    foreach (const Index::ReferenceIndex& referenceIndex, index.getReferenceIndices()) {
         writeInt32(referenceIndex.getBins().size());
         for (int i = 0; i < referenceIndex.getBins().size(); i++) {
-            const Index::ReferenceIndex::Bin &bin = referenceIndex.getBins()[i];
-            if (!bin.getChunks().isEmpty()) {
+            const Index::ReferenceIndex::Bin& bin = referenceIndex.getBins()[i];
+            QList<Index::ReferenceIndex::Chunk> chunks = bin.getChunks();
+            if (!chunks.isEmpty()) {
                 writeUint32(bin.getBin());
-                writeInt32(bin.getChunks().size());
-                foreach (const Index::ReferenceIndex::Chunk &chunk, bin.getChunks()) {
+                writeInt32(chunks.size());
+                for (const Index::ReferenceIndex::Chunk& chunk : qAsConst(chunks)) {
                     writeUint64(chunk.getStart().getPackedOffset());
                     writeUint64(chunk.getEnd().getPackedOffset());
                 }
             }
         }
-        writeInt32(referenceIndex.getIntervals().size());
-        foreach (const VirtualOffset &offset, referenceIndex.getIntervals()) {
+        QList<VirtualOffset> intervals = referenceIndex.getIntervals();
+        writeInt32(intervals.size());
+        for (const VirtualOffset& offset : qAsConst(intervals)) {
             writeUint64(offset.getPackedOffset());
         }
     }
 }
 
-void BaiWriter::writeBytes(const char *buff, qint64 size) {
+void BaiWriter::writeBytes(const char* buff, qint64 size) {
     if (ioAdapter.writeBlock(buff, size) != size) {
         throw IOException(BAMDbiPlugin::tr("Can't write output"));
     }
 }
 
-void BaiWriter::writeBytes(const QByteArray &buffer) {
+void BaiWriter::writeBytes(const QByteArray& buffer) {
     writeBytes(buffer.constData(), buffer.size());
 }
 
