@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_BAI_WRITER_H_
-#define _U2_BAM_BAI_WRITER_H_
+#pragma once
 
 #include <U2Core/IOAdapter.h>
 
@@ -31,20 +30,18 @@ namespace BAM {
 
 class BaiWriter {
 public:
-    BaiWriter(IOAdapter &ioAdapter);
-    void writeIndex(const Index &index);
+    BaiWriter(IOAdapter& ioAdapter);
+    void writeIndex(const Index& index);
 
 private:
-    void writeBytes(const char *buff, qint64 size);
-    void writeBytes(const QByteArray &buffer);
+    void writeBytes(const char* buff, qint64 size);
+    void writeBytes(const QByteArray& buffer);
     void writeUint64(quint64 value);
     void writeInt32(qint32 value);
     void writeUint32(quint32 value);
 
-    IOAdapter &ioAdapter;
+    IOAdapter& ioAdapter;
 };
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_BAI_WRITER_H_
