@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_BGZF_READER_H_
-#define _U2_BAM_BGZF_READER_H_
+#pragma once
 
 #include <3rdparty/zlib/zlib.h>
 
@@ -33,10 +32,10 @@ namespace BAM {
 
 class BgzfReader {
 public:
-    BgzfReader(IOAdapter &ioAdapter);
+    BgzfReader(IOAdapter& ioAdapter);
     ~BgzfReader();
 
-    qint64 read(char *buff, qint64 maxSize);
+    qint64 read(char* buff, qint64 maxSize);
     qint64 skip(qint64 size);
 
     bool isEof() const;
@@ -48,7 +47,7 @@ private:
     void nextBlock();
 
     static const int BUFFER_SIZE = 16384;
-    IOAdapter &ioAdapter;
+    IOAdapter& ioAdapter;
     z_stream stream;
     char buffer[BUFFER_SIZE];
     quint64 headerOffset;
@@ -57,5 +56,3 @@ private:
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_BGZF_READER_H_
