@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_CONVERT_TO_SQLITE_DIALOG_H_
-#define _U2_BAM_CONVERT_TO_SQLITE_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 #include <QList>
@@ -40,9 +39,9 @@ QT_FORWARD_DECLARE_CLASS(BAMInfo)
 class ConvertToSQLiteDialog : public QDialog {
     Q_OBJECT
 public:
-    ConvertToSQLiteDialog(const GUrl &sourceUrl, BAMInfo &bamInfo, bool sam);
+    ConvertToSQLiteDialog(const GUrl& sourceUrl, BAMInfo& bamInfo, bool sam);
 
-    const GUrl &getDestinationUrl() const;
+    const GUrl& getDestinationUrl() const;
     QString getReferenceUrl() const;
     bool addToProject() const;
     void hideAddToProjectOption();
@@ -51,7 +50,7 @@ public slots:
     virtual void accept();
 
 private slots:
-    void sl_assemblyCheckChanged(QTableWidgetItem *item);
+    void sl_assemblyCheckChanged(QTableWidgetItem* item);
     void sl_bamInfoButtonClicked();
     void sl_refUrlButtonClicked();
     void sl_selectAll();
@@ -66,15 +65,13 @@ private:
     bool checkReferencesState();
     void initSaveController();
 
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
     Ui_ConvertToSQLiteDialog ui;
 
     GUrl destinationUrl;
     GUrl sourceUrl;
-    BAMInfo &bamInfo;
+    BAMInfo& bamInfo;
 };
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_CONVERT_TO_SQLITE_DIALOG_H_
