@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_EXCEPTION_H_
-#define _U2_BAM_EXCEPTION_H_
+#pragma once
 
 #include <QString>
 
@@ -29,9 +28,9 @@ namespace BAM {
 
 class Exception {
 public:
-    Exception(const QString &message);
+    Exception(const QString& message);
     virtual ~Exception();
-    const QString &getMessage() const;
+    const QString& getMessage() const;
 
 private:
     QString message;
@@ -39,5 +38,3 @@ private:
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_EXCEPTION_H_
