@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_IO_EXCEPTION_H_
-#define _U2_BAM_IO_EXCEPTION_H_
+#pragma once
 
 #include "Exception.h"
 
@@ -29,10 +28,8 @@ namespace BAM {
 
 class IOException : public Exception {
 public:
-    IOException(const QString &message);
+    IOException(const QString& message);
 };
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_IO_EXCEPTION_H_
