@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BAM_INDEX_H_
-#define _U2_BAM_INDEX_H_
+#pragma once
 
 #include <QList>
 
@@ -49,29 +48,28 @@ public:
         class Bin {
         public:
             Bin(unsigned int bin, QList<Chunk> chunks);
-            const QList<Chunk> &getChunks() const;
+            const QList<Chunk>& getChunks() const;
             unsigned int getBin() const;
 
         private:
             unsigned int bin;
             QList<Chunk> chunks;
         };
-        ReferenceIndex(const QList<Bin> &bins, const QList<VirtualOffset> &intervals);
-        const QList<Bin> &getBins() const;
-        const QList<VirtualOffset> &getIntervals() const;
+        ReferenceIndex(const QList<Bin>& bins, const QList<VirtualOffset>& intervals);
+        const QList<Bin>& getBins() const;
+        const QList<VirtualOffset>& getIntervals() const;
 
     private:
         QList<Bin> bins;
         QList<VirtualOffset> intervals;
     };
-    Index(const QList<ReferenceIndex> &referenceIndices);
-    const QList<ReferenceIndex> &getReferenceIndices() const;
-
+    Index(const QList<ReferenceIndex>& referenceIndices);
+    const QList<ReferenceIndex>& getReferenceIndices() const;
+    bool isEmpty() const;
+    
 private:
     QList<ReferenceIndex> referenceIndices;
 };
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif  // _U2_BAM_INDEX_H_
