@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -36,12 +36,12 @@
 namespace U2 {
 namespace BAM {
 
-LoadInfoTask::LoadInfoTask(const GUrl &_sourceUrl, bool _sam)
+LoadInfoTask::LoadInfoTask(const GUrl& _sourceUrl, bool _sam)
     : Task(tr("Load BAM info"), TaskFlag_None), sourceUrl(_sourceUrl), sam(_sam) {
     setSubtaskProgressWeight(0);
 }
 
-const GUrl &LoadInfoTask::getSourceUrl() const {
+const GUrl& LoadInfoTask::getSourceUrl() const {
     return sourceUrl;
 }
 
@@ -49,14 +49,14 @@ void LoadInfoTask::run() {
     try {
         QScopedPointer<IOAdapter> ioAdapter;
         {
-            IOAdapterFactory *factory = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(sourceUrl));
+            IOAdapterFactory* factory = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(sourceUrl));
             ioAdapter.reset(factory->createIOAdapter());
         }
 
-        GUrl baiUrl = BAMUtils::getBamIndexUrl(sourceUrl);
+        GUrl baiUrl = BAMUtils::getBamIndexUrl(sourceUrl.getURLString());
 
         QScopedPointer<IOAdapter> ioIndexAdapter;
-        IOAdapterFactory *factory = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(baiUrl));
+        IOAdapterFactory* factory = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(baiUrl));
         ioIndexAdapter.reset(factory->createIOAdapter());
 
         if (!ioAdapter->open(sourceUrl, IOAdapterMode_Read)) {
@@ -90,7 +90,7 @@ void LoadInfoTask::run() {
                 bamInfo.setIndex(index);
             }
         }
-    } catch (const Exception &ex) {
+    } catch (const Exception& ex) {
         stateInfo.setError(tr("Loading BAM info for file '%1' failed: %2")
                                .arg(sourceUrl.getURLString())
                                .arg(ex.getMessage()));
