@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,12 +24,11 @@
 #include <QFileInfo>
 
 #include <U2Core/AppContext.h>
-#include <U2Core/AppSettings.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentImport.h>
 #include <U2Core/DocumentUtils.h>
+#include <U2Core/FileAndDirectoryUtils.h>
 #include <U2Core/U2SafePoints.h>
-#include <U2Core/UserApplicationsSettings.h>
 
 #include <U2Formats/BAMUtils.h>
 
@@ -38,55 +37,36 @@
 namespace U2 {
 namespace BAM {
 
-PrepareToImportTask::PrepareToImportTask(const GUrl &url, bool sam, const QString &refUrl, const QString &workingDir)
-    : Task("Prepare assembly file to import", TaskFlag_None),
-      sourceURL(url), refUrl(refUrl), workingDir(workingDir), samFormat(sam), newURL(false) {
+PrepareToImportTask::PrepareToImportTask(const GUrl& _assemblyUrl, bool _sam, const QString& _refUrl, const QString& _workDir)
+    : Task(tr("Prepare assembly file to import"), TaskFlag_None),
+      sourceURL(_assemblyUrl), refUrl(_refUrl), workDir(_workDir), samFormat(_sam), newURL(false) {
     tpm = Progress_Manual;
 }
 
-QString PrepareToImportTask::getBamUrl() const {
-    if (samFormat) {
-        QString samUrl = sourceURL.getURLString();
-        return workingDir + "/" + QFileInfo(samUrl).fileName() + ".bam";
-    } else {
-        return sourceURL.getURLString();
-    }
+QString PrepareToImportTask::getIndexedBamUrl(const QString& sortedBamUrl) const {
+    return workDir + "/" + QFileInfo(sortedBamUrl).fileName();
 }
 
-QString PrepareToImportTask::getSortedBamUrl(const QString &bamUrl) const {
-    return workingDir + "/" + QFileInfo(bamUrl).fileName() + "_sorted";
-}
-
-QString PrepareToImportTask::getIndexedBamUrl(const QString &sortedBamUrl) const {
-    return workingDir + "/" + QFileInfo(sortedBamUrl).fileName();
-}
-
-QString PrepareToImportTask::getFastaUrl() const {
-    return workingDir + "/" + QFileInfo(refUrl).fileName();
-}
-
-QString PrepareToImportTask::getCopyError(const QString &url1, const QString &url2) const {
+QString PrepareToImportTask::getCopyError(const QString& url1, const QString& url2) const {
     return LoadInfoTask::tr("Can not copy the '%1' file to '%2'").arg(url1).arg(url2);
 }
 
 namespace {
-bool equalUrls(const QString &url1, const QString &url2) {
+bool equalUrls(const QString& url1, const QString& url2) {
     return QFileInfo(url1).absoluteFilePath() == QFileInfo(url2).absoluteFilePath();
 }
 }  // namespace
 
-bool PrepareToImportTask::needToCopyBam(const QString &sortedBamUrl) const {
-    const QString indexedBamUrl = getIndexedBamUrl(sortedBamUrl);
+bool PrepareToImportTask::needToCopyBam(const QString& sortedBamUrl) const {
+    QString indexedBamUrl = getIndexedBamUrl(sortedBamUrl);
     return !equalUrls(indexedBamUrl, sortedBamUrl);
 }
 
-bool PrepareToImportTask::needToCopyFasta() const {
-    return !equalUrls(getFastaUrl(), refUrl);
-}
-
 void PrepareToImportTask::run() {
     // SAM to BAM if needed
-    QString bamUrl = getBamUrl();
+    QString bamUrl = samFormat
+                         ? workDir + "/" + QFileInfo(sourceURL.getURLString()).fileName() + ".bam"
+                         : sourceURL.getURLString();
     if (samFormat) {
         newURL = true;
         stateInfo.setDescription(LoadInfoTask::tr("Converting SAM to BAM"));
@@ -94,8 +74,7 @@ void PrepareToImportTask::run() {
         checkReferenceFile();
         CHECK_OP(stateInfo, );
 
-        BAMUtils::ConvertOption options(true /*SAM to BAM*/, refUrl);
-        BAMUtils::convertToSamOrBam(sourceURL, bamUrl, options, stateInfo);
+        BAMUtils::convertSamToBam(stateInfo, sourceURL.getURLString(), bamUrl, refUrl);
         CHECK_OP(stateInfo, );
     }
     stateInfo.setProgress(33);
@@ -111,7 +90,8 @@ void PrepareToImportTask::run() {
         newURL = true;
         stateInfo.setDescription(LoadInfoTask::tr("Sorting BAM"));
 
-        sortedBamUrl = BAMUtils::sortBam(bamUrl, getSortedBamUrl(bamUrl), stateInfo).getURLString();
+        QString sortedBamFilePathPrefix = workDir + "/" + QFileInfo(bamUrl).fileName() + "_sorted";
+        sortedBamUrl = BAMUtils::sortBam(bamUrl, sortedBamFilePathPrefix, stateInfo).getURLString();
         CHECK_OP(stateInfo, );
     }
     stateInfo.setProgress(66);
@@ -140,27 +120,25 @@ void PrepareToImportTask::run() {
     sourceURL = indexedBamUrl;
 }
 
-namespace {
-static bool isUnknownFormat(const QList<FormatDetectionResult> &formats) {
+static bool isUnknownFormat(const QList<FormatDetectionResult>& formats) {
     if (formats.isEmpty()) {
         return true;
     }
     FormatDetectionResult f = formats.first();
-    if (nullptr == f.format && nullptr == f.importer) {
+    if (f.format == nullptr && f.importer == nullptr) {
         return true;
     }
     return false;
 }
 
-static QString detectedFormatId(const FormatDetectionResult &f) {
-    if (nullptr == f.format && f.importer == nullptr) {
+static QString detectedFormatId(const FormatDetectionResult& f) {
+    if (f.format == nullptr && f.importer == nullptr) {
         return "";
-    } else if (nullptr == f.format) {
+    } else if (f.format == nullptr) {
         return f.importer->getImporterName();
     }
     return f.format->getFormatId();
 }
-}  // namespace
 
 void PrepareToImportTask::checkReferenceFile() {
     CHECK(!refUrl.isEmpty(), );
@@ -173,26 +151,31 @@ void PrepareToImportTask::checkReferenceFile() {
         return;
     }
     QString formatId = detectedFormatId(formats.first());
-    if (BaseDocumentFormats::FASTA != formatId) {
+    if (formatId != BaseDocumentFormats::FASTA) {
         setError(LoadInfoTask::tr("The detected reference sequence format is '%1'. Only FASTA is supported").arg(formatId));
         return;
     }
 
-    if (!BAMUtils::hasValidFastaIndex(refUrl)) {
-        if (needToCopyFasta()) {
-            bool copied = QFile::copy(refUrl, getFastaUrl());
-            CHECK_EXT(copied, setError(getCopyError(refUrl, getFastaUrl())), );
-
-            refUrl = getFastaUrl();
+    // Check if FASTA index will be created and ensure the reference dir is writable.
+    // Copy reference to the work dir if the reference dir is not writable.
+    bool isFaiBuildNeeded = !BAMUtils::hasValidFastaIndex(refUrl);
+    QString refUrlDir = QFileInfo(refUrl).absolutePath();
+    if (isFaiBuildNeeded && !FileAndDirectoryUtils::isDirectoryWritable(refUrlDir)) {
+        QString fastaUrl = workDir + "/" + QFileInfo(refUrl).fileName();
+        if (!equalUrls(fastaUrl, refUrl)) {
+            CHECK_EXT(QFileInfo::exists(fastaUrl), setError(tr("Can't copy reference file to the work dir. File already exists: %1").arg(fastaUrl)), );
+            bool copied = QFile::copy(refUrl, fastaUrl);
+            CHECK_EXT(copied, setError(getCopyError(refUrl, fastaUrl)), );
+            refUrl = fastaUrl;
         }
     }
 }
 
-const GUrl &PrepareToImportTask::getSourceUrl() const {
+const GUrl& PrepareToImportTask::getSourceUrl() const {
     return sourceURL;
 }
 
-bool PrepareToImportTask::isNewURL() {
+bool PrepareToImportTask::isNewURL() const {
     return newURL;
 }
 
