@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_PREPARE_TO_IMPORT_TASK_H
-#define _U2_PREPARE_TO_IMPORT_TASK_H
+#pragma once
 
 #include <U2Core/GUrl.h>
 #include <U2Core/Task.h>
@@ -31,30 +30,24 @@ namespace BAM {
 
 class PrepareToImportTask : public Task {
 public:
-    PrepareToImportTask(const GUrl &assebmlyUrl, bool sam, const QString &refUrl, const QString &workingDir);
-    void run();
-    const GUrl &getSourceUrl() const;
-    bool isNewURL();
+    PrepareToImportTask(const GUrl& assemblyUrl, bool sam, const QString& refUrl, const QString& _workDir);
+    void run() override;
+    const GUrl& getSourceUrl() const;
+    bool isNewURL() const;
 
 private:
     GUrl sourceURL;
     QString refUrl;
-    QString workingDir;
+    QString workDir;
     bool samFormat;
     bool newURL;
 
 private:
     void checkReferenceFile();
-    QString getBamUrl() const;
-    QString getSortedBamUrl(const QString &bamUrl) const;
-    QString getIndexedBamUrl(const QString &sortedBamUrl) const;
-    QString getFastaUrl() const;
-    QString getCopyError(const QString &url1, const QString &url2) const;
-    bool needToCopyBam(const QString &sortedBamUrl) const;
-    bool needToCopyFasta() const;
+    QString getIndexedBamUrl(const QString& sortedBamUrl) const;
+    QString getCopyError(const QString& url1, const QString& url2) const;
+    bool needToCopyBam(const QString& sortedBamUrl) const;
 };
 
 }  // namespace BAM
 }  // namespace U2
-
-#endif
