@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -36,9 +36,7 @@ const int SamReader::LOCAL_READ_BUFFER_SIZE = 100000;
 
 Alignment SamReader::parseAlignmentString(QByteArray line) {
     Alignment alignment;
-
     if (line.isEmpty()) {
-        assert(0);
         throw InvalidFormatException(BAMDbiPlugin::tr("Unexpected empty string"));
     }
     QByteArray recordTag;
@@ -50,7 +48,7 @@ Alignment SamReader::parseAlignmentString(QByteArray line) {
     }
 
     {
-        QByteArray &qname = tokens[0];
+        QByteArray& qname = tokens[0];
         // workaround for malformed SAMs
         if (!QRegExp("[ -~]{1,255}").exactMatch(qname)) {
             throw InvalidFormatException(BAMDbiPlugin::tr("Invalid query template name: %1").arg(QString(qname)));
@@ -59,48 +57,14 @@ Alignment SamReader::parseAlignmentString(QByteArray line) {
     }
     {
         bool ok = false;
-        int flagsValue = tokens[1].toInt(&ok);
+        quint16 flagsValue = tokens[1].toUShort(&ok);
         if (!ok) {
             throw InvalidFormatException(BAMDbiPlugin::tr("Invalid FLAG value: %1").arg(QString(tokens[1])));
         }
-        qint64 flags = 0;
-        if (flagsValue & 0x1) {
-            flags |= Fragmented;
-        }
-        if (flagsValue & 0x2) {
-            flags |= FragmentsAligned;
-        }
-        if (flagsValue & 0x4) {
-            flags |= Unmapped;
-        }
-        if (flagsValue & 0x8) {
-            flags |= NextUnmapped;
-        }
-        if (flagsValue & 0x10) {
-            flags |= Reverse;
-        }
-        if (flagsValue & 0x20) {
-            flags |= NextReverse;
-        }
-        if (flagsValue & 0x40) {
-            flags |= FirstInTemplate;
-        }
-        if (flagsValue & 0x80) {
-            flags |= LastInTemplate;
-        }
-        if (flagsValue & 0x100) {
-            flags |= SecondaryAlignment;
-        }
-        if (flagsValue & 0x200) {
-            flags |= FailsChecks;
-        }
-        if (flagsValue & 0x400) {
-            flags |= Duplicate;
-        }
-        alignment.setFlags(flags);
+        alignment.setFlags(ReadFlags(flagsValue));
     }
     {
-        QByteArray &rname = tokens[2];
+        QByteArray& rname = tokens[2];
         // workaround for malformed SAMs
         if (!QRegExp("[*]|[!-()+-<>-~][ -~]*").exactMatch(rname)) {
             throw InvalidFormatException(BAMDbiPlugin::tr("Invalid reference name: %1").arg(QString(rname)));
@@ -137,7 +101,7 @@ Alignment SamReader::parseAlignmentString(QByteArray line) {
         alignment.setMapQuality(mapQuality);
     }
     {
-        QByteArray &cigarString = tokens[5];
+        QByteArray& cigarString = tokens[5];
         if (!QRegExp("[*]|([0-9]+[MIDNSHPX=])+").exactMatch(cigarString)) {
             throw InvalidFormatException(BAMDbiPlugin::tr("Invalid cigar value: %1").arg(QString(cigarString)));
         }
@@ -182,8 +146,8 @@ Alignment SamReader::parseAlignmentString(QByteArray line) {
                     default:
                         throw InvalidFormatException(BAMDbiPlugin::tr("Invalid cigar operation code: %1").arg(res[i].op));
                 }
-                int operatonLength = res[i].count;
-                cigar.append(Alignment::CigarOperation(operatonLength, operation));
+                int operationLength = res[i].count;
+                cigar.append(Alignment::CigarOperation(operationLength, operation));
             }
             alignment.setCigar(cigar);
         }
@@ -223,11 +187,6 @@ Alignment SamReader::parseAlignmentString(QByteArray line) {
         if (!ok) {
             throw InvalidFormatException(BAMDbiPlugin::tr("Invalid template length value: %1").arg(QString(tokens[8])));
         }
-        if (!(alignment.getFlags() & Fragmented)) {
-            if (0 != templateLength) {
-                throw InvalidFormatException(BAMDbiPlugin::tr("Invalid template length of a single-fragment template: %1").arg(templateLength));
-            }
-        }
         alignment.setTemplateLength(templateLength);
     }
     {
@@ -262,27 +221,27 @@ Alignment SamReader::parseAlignmentString(QByteArray line) {
         // Validation of the CIGAR string.
         int totalLength = 0;
         int length = alignment.getSequence().length();
-        const QList<Alignment::CigarOperation> &cigar = alignment.getCigar();
+        const QList<Alignment::CigarOperation>& cigar = alignment.getCigar();
         CigarValidator validator(cigar);
         validator.validate(&totalLength);
         if (!cigar.isEmpty() && length != totalLength) {
-            const_cast<QList<Alignment::CigarOperation> &>(cigar).clear();  // Ignore invalid cigar
+            const_cast<QList<Alignment::CigarOperation>&>(cigar).clear();  // Ignore invalid cigar
         }
     }
     return alignment;
 }
 
-SamReader::SamReader(IOAdapter &ioAdapter)
+SamReader::SamReader(IOAdapter& ioAdapter)
     : Reader(ioAdapter),
       readBuffer(LOCAL_READ_BUFFER_SIZE, '\0') {
     readHeader();
 }
 
-const Header &SamReader::getHeader() const {
+const Header& SamReader::getHeader() const {
     return header;
 }
 
-Alignment SamReader::readAlignment(bool &eof) {
+Alignment SamReader::readAlignment(bool& eof) {
     QByteArray alignmentString = readString(eof);
 
     return parseAlignmentString(alignmentString);
@@ -292,8 +251,8 @@ bool SamReader::isEof() const {
     return ioAdapter.isEof();
 }
 
-QByteArray SamReader::readString(bool &eof) {
-    char *buff = readBuffer.data();
+QByteArray SamReader::readString(bool& eof) {
+    char* buff = readBuffer.data();
     bool lineOk = false;
     int len = 0;
     QByteArray result;
@@ -309,7 +268,7 @@ QByteArray SamReader::readString(bool &eof) {
 }
 
 void SamReader::readHeader() {
-    char *buff = readBuffer.data();
+    char* buff = readBuffer.data();
     bool lineOk = false;
     int len = 0;
     qint64 bRead = ioAdapter.bytesRead();
@@ -402,7 +361,7 @@ void SamReader::readHeader() {
                     header.setSortingOrder(Header::Unknown);
                 }
             } else if ("SQ" == recordTag) {
-                Header::Reference *reference = nullptr;
+                Header::Reference* reference = nullptr;
                 QByteArray name;
                 if (fields.contains("SN")) {
                     name = fields["SN"];
@@ -424,7 +383,7 @@ void SamReader::readHeader() {
                 } else {
                     throw InvalidFormatException(BAMDbiPlugin::tr("SQ record without LN field"));
                 }
-                assert(nullptr != reference);
+                assert(reference != nullptr);
                 if (fields.contains("AS")) {
                     reference->setAssemblyId(fields["AS"]);
                 }
@@ -521,7 +480,7 @@ void SamReader::readHeader() {
             }
         }
         for (int index = 0; index < programs.size(); index++) {
-            const QByteArray &previousProgramId = previousProgramIds[index];
+            const QByteArray& previousProgramId = previousProgramIds[index];
             if (!previousProgramId.isEmpty()) {
                 if (programsMap.contains(previousProgramId)) {
                     programs[index].setPreviousId(programsMap[previousProgramId]);
