@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -44,23 +44,31 @@ namespace BAM {
 
 static const QByteArray ATTRIBUTE_SEP(":~!ugene-attribute!~:");
 
+/** Closes BAM file previously opened with openNewBamFileHandler. */
+static void closeBamFileHandler(BGZF* file) {
+    CHECK(file != nullptr, );
+    SAFE_POINT(file->owned_file == 1, "Invalid owned_file flag", );
+    int rc = bgzf_close(file);
+    SAFE_POINT(rc == 0, "Failed to close BAM file", );
+}
+
 /************************************************************************/
 /* SamtoolsBasedDbi */
 /************************************************************************/
 SamtoolsBasedDbi::SamtoolsBasedDbi()
-    : U2AbstractDbi(SamtoolsBasedDbiFactory::ID), assembliesCount(0), bamHandler(nullptr), header(nullptr), index(nullptr) {
+    : U2AbstractDbi(SamtoolsBasedDbiFactory::ID), assembliesCount(0), header(nullptr), index(nullptr) {
 }
 
 SamtoolsBasedDbi::~SamtoolsBasedDbi() {
     this->cleanup();
 }
 
-QVariantMap SamtoolsBasedDbi::shutdown(U2OpStatus & /*os*/) {
+QVariantMap SamtoolsBasedDbi::shutdown(U2OpStatus& /*os*/) {
     cleanup();
     return QVariantMap();
 }
 
-void SamtoolsBasedDbi::init(const QHash<QString, QString> &properties, const QVariantMap & /*persistentData*/, U2OpStatus &os) {
+void SamtoolsBasedDbi::init(const QHash<QString, QString>& properties, const QVariantMap& /*persistentData*/, U2OpStatus& os) {
     try {
         if (U2DbiState_Void != state) {
             throw Exception(BAMDbiPlugin::tr("Invalid DBI state"));
@@ -73,7 +81,7 @@ void SamtoolsBasedDbi::init(const QHash<QString, QString> &properties, const QVa
         if (!url.isLocalFile()) {
             throw Exception(BAMDbiPlugin::tr("Non-local files are not supported"));
         }
-        bool sorted = BAMUtils::isSortedBam(url, os);
+        bool sorted = BAMUtils::isSortedBam(url.getURLString(), os);
         CHECK_OP_EXT(os, throw Exception(os.getError()), );
         if (!sorted) {
             throw Exception("Only indexed sorted BAM files could be used by this DBI");
@@ -95,33 +103,30 @@ void SamtoolsBasedDbi::init(const QHash<QString, QString> &properties, const QVa
         features.insert(U2DbiFeature_ReadAttributes);
         dbiId = url.getURLString();
         state = U2DbiState_Ready;
-    } catch (const Exception &e) {
+    } catch (const Exception& e) {
         os.setError(e.getMessage());
         this->cleanup();
     }
 }
 
-bool SamtoolsBasedDbi::initBamStructures(const GUrl &fileName) {
-    QByteArray urlBA = fileName.getURLString().toLocal8Bit();
-    const char *url = urlBA.constData();
-    bamHandler = bam_open(url, "r");
-    if (nullptr == bamHandler) {
-        throw IOException(BAMDbiPlugin::tr("Can't open file '%1'").arg(url));
+bool SamtoolsBasedDbi::initBamStructures(const GUrl& fileName) {
+    QString filePath = fileName.getURLString();
+    std::shared_ptr<BGZF> bamFile(openNewBamFileHandler(), [](BGZF* f) { closeBamFileHandler(f); });
+    if (bamFile == nullptr) {
+        throw IOException(BAMDbiPlugin::tr("Can't open file '%1'").arg(filePath));
     }
-
-    bool indexed = BAMUtils::hasValidBamIndex(fileName);
-    if (indexed) {
-        index = bam_index_load(url);
-    } else {
+    bool indexed = BAMUtils::hasValidBamIndex(filePath);
+    if (!indexed) {
         throw Exception("Only indexed sorted BAM files could be used by this DBI");
     }
-    if (nullptr == index) {
-        throw IOException(BAMDbiPlugin::tr("Can't load index file for '%1'").arg(url));
+    index = (bam_index_t*)BAMUtils::loadIndex(filePath);
+    if (index == nullptr) {
+        throw IOException(BAMDbiPlugin::tr("Can't load index file for '%1'").arg(filePath));
     }
 
-    header = bam_header_read(bamHandler);
-    if (nullptr == header) {
-        throw IOException(BAMDbiPlugin::tr("Can't read header from file '%1'").arg(url));
+    header = bam_header_read(bamFile.get());
+    if (header == nullptr) {
+        throw IOException(BAMDbiPlugin::tr("Can't read header from file '%1'").arg(filePath));
     }
     return true;
 }
@@ -130,18 +135,14 @@ void SamtoolsBasedDbi::cleanup() {
     assemblyDbi.reset();
     objectDbi.reset();
     attributeDbi.reset();
-    if (nullptr != header) {
+    if (header != nullptr) {
         bam_header_destroy(header);
         header = nullptr;
     }
-    if (nullptr != index) {
+    if (index != nullptr) {
         bam_index_destroy(index);
         index = nullptr;
     }
-    if (nullptr != bamHandler) {
-        bam_close(bamHandler);
-        bamHandler = nullptr;
-    }
     state = U2DbiState_Void;
 }
 
@@ -153,7 +154,7 @@ void SamtoolsBasedDbi::createObjectDbi() {
     objectDbi.reset(new SamtoolsBasedObjectDbi(*this, assemblyObjectIds));
 }
 
-U2DataType SamtoolsBasedDbi::getEntityTypeById(const U2DataId &id) const {
+U2DataType SamtoolsBasedDbi::getEntityTypeById(const U2DataId& id) const {
     QString idStr = id;
     if (idStr.endsWith(ATTRIBUTE_SEP + U2BaseAttributeName::reference_length)) {
         return U2Type::AttributeInteger;
@@ -171,19 +172,25 @@ U2DataType SamtoolsBasedDbi::getEntityTypeById(const U2DataId &id) const {
     }
 }
 
-bamFile SamtoolsBasedDbi::getBamFile() const {
-    return bamHandler;
+bamFile SamtoolsBasedDbi::openNewBamFileHandler() const {
+    QString filePath = url.getURLString();
+    NP<FILE> file = BAMUtils::openFile(filePath, "rb");
+    bamFile bFile = file != nullptr ? bgzf_fdopen(file, "r") : nullptr;
+    CHECK_EXT(bFile != nullptr, BAMUtils::closeFileIfOpen(file), nullptr);
+
+    bFile->owned_file = 1;
+    return bFile;
 }
 
-const bam_header_t *SamtoolsBasedDbi::getHeader() const {
+const bam_header_t* SamtoolsBasedDbi::getHeader() const {
     return header;
 }
 
-const bam_index_t *SamtoolsBasedDbi::getIndex() const {
+const bam_index_t* SamtoolsBasedDbi::getIndex() const {
     return index;
 }
 
-U2AssemblyDbi *SamtoolsBasedDbi::getAssemblyDbi() {
+U2AssemblyDbi* SamtoolsBasedDbi::getAssemblyDbi() {
     if (U2DbiState_Ready == state) {
         return assemblyDbi.data();
     } else {
@@ -191,7 +198,7 @@ U2AssemblyDbi *SamtoolsBasedDbi::getAssemblyDbi() {
     }
 }
 
-U2ObjectDbi *SamtoolsBasedDbi::getObjectDbi() {
+U2ObjectDbi* SamtoolsBasedDbi::getObjectDbi() {
     if (U2DbiState_Ready == state) {
         return objectDbi.data();
     } else {
@@ -199,7 +206,7 @@ U2ObjectDbi *SamtoolsBasedDbi::getObjectDbi() {
     }
 }
 
-U2AttributeDbi *SamtoolsBasedDbi::getAttributeDbi() {
+U2AttributeDbi* SamtoolsBasedDbi::getAttributeDbi() {
     if (U2DbiState_Ready == state) {
         return attributeDbi.data();
     } else {
@@ -214,15 +221,15 @@ bool SamtoolsBasedDbi::isReadOnly() const {
 /************************************************************************/
 /* SamtoolsBasedObjectDbi */
 /************************************************************************/
-SamtoolsBasedObjectDbi::SamtoolsBasedObjectDbi(SamtoolsBasedDbi &dbi, const QList<U2DataId> &assemblyObjectIds)
+SamtoolsBasedObjectDbi::SamtoolsBasedObjectDbi(SamtoolsBasedDbi& dbi, const QList<U2DataId>& assemblyObjectIds)
     : U2SimpleObjectDbi(&dbi), dbi(dbi), assemblyObjectIds(assemblyObjectIds) {
 }
 
-qint64 SamtoolsBasedObjectDbi::countObjects(U2OpStatus &os) {
+qint64 SamtoolsBasedObjectDbi::countObjects(U2OpStatus& os) {
     return countObjects(U2Type::Assembly, os);
 }
 
-qint64 SamtoolsBasedObjectDbi::countObjects(U2DataType type, U2OpStatus &os) {
+qint64 SamtoolsBasedObjectDbi::countObjects(U2DataType type, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               0);
@@ -234,7 +241,7 @@ qint64 SamtoolsBasedObjectDbi::countObjects(U2DataType type, U2OpStatus &os) {
     }
 }
 
-QHash<U2DataId, QString> SamtoolsBasedObjectDbi::getObjectNames(qint64 /*offset*/, qint64 /*count*/, U2OpStatus &os) {
+QHash<U2DataId, QString> SamtoolsBasedObjectDbi::getObjectNames(qint64 /*offset*/, qint64 /*count*/, U2OpStatus& os) {
     QHash<U2DataId, QString> result;
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
@@ -243,7 +250,7 @@ QHash<U2DataId, QString> SamtoolsBasedObjectDbi::getObjectNames(qint64 /*offset*
     return result;
 }
 
-void SamtoolsBasedObjectDbi::getObject(U2Object &object, const U2DataId &id, U2OpStatus &os) {
+void SamtoolsBasedObjectDbi::getObject(U2Object& object, const U2DataId& id, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")), );
 
@@ -251,11 +258,11 @@ void SamtoolsBasedObjectDbi::getObject(U2Object &object, const U2DataId &id, U2O
     object = dbi.getAssemblyDbi()->getAssemblyObject(id, os);
 }
 
-QList<U2DataId> SamtoolsBasedObjectDbi::getObjects(qint64 offset, qint64 count, U2OpStatus &os) {
+QList<U2DataId> SamtoolsBasedObjectDbi::getObjects(qint64 offset, qint64 count, U2OpStatus& os) {
     return getObjects(U2Type::Assembly, offset, count, os);
 }
 
-QList<U2DataId> SamtoolsBasedObjectDbi::getObjects(U2DataType type, qint64 offset, qint64 count, U2OpStatus &os) {
+QList<U2DataId> SamtoolsBasedObjectDbi::getObjects(U2DataType type, qint64 offset, qint64 count, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               QList<U2DataId>());
@@ -272,21 +279,21 @@ QList<U2DataId> SamtoolsBasedObjectDbi::getObjects(U2DataType type, qint64 offse
     }
 }
 
-QList<U2DataId> SamtoolsBasedObjectDbi::getParents(const U2DataId & /*entityId*/, U2OpStatus &os) {
+QList<U2DataId> SamtoolsBasedObjectDbi::getParents(const U2DataId& /*entityId*/, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               QList<U2DataId>());
     return QList<U2DataId>();
 }
 
-QStringList SamtoolsBasedObjectDbi::getFolders(U2OpStatus &os) {
+QStringList SamtoolsBasedObjectDbi::getFolders(U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               QStringList());
     return QStringList(U2ObjectDbi::ROOT_FOLDER);
 }
 
-qint64 SamtoolsBasedObjectDbi::countObjects(const QString &folder, U2OpStatus &os) {
+qint64 SamtoolsBasedObjectDbi::countObjects(const QString& folder, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               0);
@@ -298,7 +305,7 @@ qint64 SamtoolsBasedObjectDbi::countObjects(const QString &folder, U2OpStatus &o
     return countObjects(os);
 }
 
-QList<U2DataId> SamtoolsBasedObjectDbi::getObjects(const QString &folder, qint64 offset, qint64 count, U2OpStatus &os) {
+QList<U2DataId> SamtoolsBasedObjectDbi::getObjects(const QString& folder, qint64 offset, qint64 count, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               QList<U2DataId>());
@@ -310,7 +317,7 @@ QList<U2DataId> SamtoolsBasedObjectDbi::getObjects(const QString &folder, qint64
     return getObjects(offset, count, os);
 }
 
-QStringList SamtoolsBasedObjectDbi::getObjectFolders(const U2DataId &objectId, U2OpStatus &os) {
+QStringList SamtoolsBasedObjectDbi::getObjectFolders(const U2DataId& objectId, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               QStringList());
@@ -322,7 +329,7 @@ QStringList SamtoolsBasedObjectDbi::getObjectFolders(const U2DataId &objectId, U
     }
 }
 
-qint64 SamtoolsBasedObjectDbi::getObjectVersion(const U2DataId & /*objectId*/, U2OpStatus &os) {
+qint64 SamtoolsBasedObjectDbi::getObjectVersion(const U2DataId& /*objectId*/, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               0);
@@ -330,7 +337,7 @@ qint64 SamtoolsBasedObjectDbi::getObjectVersion(const U2DataId & /*objectId*/, U
     return 0;
 }
 
-qint64 SamtoolsBasedObjectDbi::getFolderLocalVersion(const QString &folder, U2OpStatus &os) {
+qint64 SamtoolsBasedObjectDbi::getFolderLocalVersion(const QString& folder, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               0);
@@ -342,7 +349,7 @@ qint64 SamtoolsBasedObjectDbi::getFolderLocalVersion(const QString &folder, U2Op
     return 0;
 }
 
-qint64 SamtoolsBasedObjectDbi::getFolderGlobalVersion(const QString &folder, U2OpStatus &os) {
+qint64 SamtoolsBasedObjectDbi::getFolderGlobalVersion(const QString& folder, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               0);
@@ -354,25 +361,25 @@ qint64 SamtoolsBasedObjectDbi::getFolderGlobalVersion(const QString &folder, U2O
     return 0;
 }
 
-U2DbiIterator<U2DataId> *SamtoolsBasedObjectDbi::getObjectsByVisualName(const QString &, U2DataType, U2OpStatus &) {
+U2DbiIterator<U2DataId>* SamtoolsBasedObjectDbi::getObjectsByVisualName(const QString&, U2DataType, U2OpStatus&) {
     // TODO:
     return nullptr;
 }
 
-void SamtoolsBasedObjectDbi::renameObject(const U2DataId & /*id*/, const QString & /*newName*/, U2OpStatus &os) {
+void SamtoolsBasedObjectDbi::renameObject(const U2DataId& /*id*/, const QString& /*newName*/, U2OpStatus& os) {
     os.setError("Not implemented!");
 }
 
-void SamtoolsBasedObjectDbi::setObjectRank(const U2DataId & /*objectId*/, U2DbiObjectRank /*newRank*/, U2OpStatus &os) {
+void SamtoolsBasedObjectDbi::setObjectRank(const U2DataId& /*objectId*/, U2DbiObjectRank /*newRank*/, U2OpStatus& os) {
     os.setError("Not implemented!");
 }
 
-U2DbiObjectRank SamtoolsBasedObjectDbi::getObjectRank(const U2DataId & /*objectId*/, U2OpStatus &os) {
+U2DbiObjectRank SamtoolsBasedObjectDbi::getObjectRank(const U2DataId& /*objectId*/, U2OpStatus& os) {
     os.setError("Not implemented!");
     return U2DbiObjectRank_TopLevel;
 }
 
-void SamtoolsBasedObjectDbi::setParent(const U2DataId & /*parentId*/, const U2DataId & /*childId*/, U2OpStatus &os) {
+void SamtoolsBasedObjectDbi::setParent(const U2DataId& /*parentId*/, const U2DataId& /*childId*/, U2OpStatus& os) {
     os.setError("Not implemented!");
 }
 
@@ -383,9 +390,9 @@ const int SamtoolsBasedReadsIterator::BUFFERED_INTERVAL_SIZE = 1000;
 
 SamtoolsBasedReadsIterator::SamtoolsBasedReadsIterator(
     int assemblyId,
-    const U2Region &_r,
-    SamtoolsBasedDbi &_dbi,
-    const QByteArray &_nameFilter)
+    const U2Region& _r,
+    SamtoolsBasedDbi& _dbi,
+    const QByteArray& _nameFilter)
     : U2DbiIterator<U2AssemblyRead>(), assemblyId(assemblyId), dbi(_dbi), nameFilter(_nameFilter) {
     current = reads.begin();
     bool errorRegion = false;
@@ -480,14 +487,14 @@ static const int RNEXT_COL = 6;
 static const int SEQ_COL = 9;
 static const int QUAL_COL = 10;
 
-int bamFetchFunction(const bam1_t *b, void *data) {
-    SamtoolsBasedReadsIterator *it = (SamtoolsBasedReadsIterator *)data;
-    QList<U2AssemblyRead> &reads = it->reads;
-    SamtoolsBasedDbi &dbi = it->dbi;
+int bamFetchFunction(const bam1_t* b, void* data) {
+    SamtoolsBasedReadsIterator* it = (SamtoolsBasedReadsIterator*)data;
+    QList<U2AssemblyRead>& reads = it->reads;
+    SamtoolsBasedDbi& dbi = it->dbi;
 
     U2AssemblyRead read(new U2AssemblyReadData());
     {
-        char *samStr = bam_format1(dbi.getHeader(), b);
+        char* samStr = bam_format1(dbi.getHeader(), b);
         QByteArray samArr(samStr);
         QList<QByteArray> values = samArr.split('\t');
 
@@ -509,7 +516,7 @@ int bamFetchFunction(const bam1_t *b, void *data) {
         read->id = read->name + ";" + QByteArray::number(read->leftmostPos) + ";" + QByteArray::number(read->effectiveLen);
         read->rnext = values[RNEXT_COL];
         read->pnext = b->core.mpos;
-        QByteArray auxStr((const char *)bam1_aux(b), b->l_aux);
+        QByteArray auxStr((const char*)bam1_aux(b), b->l_aux);
         read->aux = SamtoolsAdapter::string2aux(auxStr);
     }
 
@@ -526,30 +533,32 @@ int bamFetchFunction(const bam1_t *b, void *data) {
 }
 
 void SamtoolsBasedReadsIterator::fetchNextChunk() {
-    bamFile bam = dbi.getBamFile();
-    const bam_index_t *idx = dbi.getIndex();
-    SAFE_POINT_EXT(nullptr != bam, nextPosToRead = INT_MAX, );
-    SAFE_POINT_EXT(nullptr != idx, nextPosToRead = INT_MAX, );
+    if (bamFile.get() == nullptr) {
+        bamFile.reset(dbi.openNewBamFileHandler(), [](BGZF* f) { closeBamFileHandler(f); });
+    }
+    SAFE_POINT(bamFile != nullptr, nextPosToRead = INT_MAX, );
 
-    void *data = (void *)(this);
+    const bam_index_t* idx = dbi.getIndex();
+    SAFE_POINT_EXT(idx != nullptr, nextPosToRead = INT_MAX, );
+
+    void* data = (void*)(this);
     borderReadIds = newBorderReadIds;
     newBorderReadIds.clear();
     int startPos = (int)nextPosToRead;
     int endPos = (int)(nextPosToRead + BUFFERED_INTERVAL_SIZE);
     nextPosToRead += BUFFERED_INTERVAL_SIZE;
-    bam_fetch(bam, idx, assemblyId, startPos, endPos, data, bamFetchFunction);
-
+    bam_fetch(bamFile.get(), idx, assemblyId, startPos, endPos, data, bamFetchFunction);
     current = reads.begin();
 }
 
 /************************************************************************/
 /* SamtoolsBasedAssemblyDbi */
 /************************************************************************/
-SamtoolsBasedAssemblyDbi::SamtoolsBasedAssemblyDbi(SamtoolsBasedDbi &dbi)
+SamtoolsBasedAssemblyDbi::SamtoolsBasedAssemblyDbi(SamtoolsBasedDbi& dbi)
     : U2SimpleAssemblyDbi(&dbi), dbi(dbi) {
 }
 
-int SamtoolsBasedAssemblyDbi::toSamtoolsId(const U2DataId &assemblyId, U2OpStatus &os) {
+int SamtoolsBasedAssemblyDbi::toSamtoolsId(const U2DataId& assemblyId, U2OpStatus& os) {
     bool ok = false;
     int dbId = assemblyId.toInt(&ok);
     if (!ok) {
@@ -558,13 +567,13 @@ int SamtoolsBasedAssemblyDbi::toSamtoolsId(const U2DataId &assemblyId, U2OpStatu
     return dbId;
 }
 
-U2Assembly SamtoolsBasedAssemblyDbi::getAssemblyObject(const U2DataId &id, U2OpStatus &os) {
+U2Assembly SamtoolsBasedAssemblyDbi::getAssemblyObject(const U2DataId& id, U2OpStatus& os) {
     CHECK_EXT(U2DbiState_Ready == dbi.getState(),
               os.setError(BAMDbiPlugin::tr("Invalid samtools DBI state")),
               U2Assembly());
 
-    const bam_header_t *header = dbi.getHeader();
-    SAFE_POINT(nullptr != header, "NULL BAM header", U2Assembly());
+    const bam_header_t* header = dbi.getHeader();
+    SAFE_POINT(header != nullptr, "NULL BAM header", U2Assembly());
 
     CHECK_EXT(U2Type::Assembly == dbi.getEntityTypeById(id),
               os.setError(BAMDbiPlugin::tr("The specified object is not an assembly")),
@@ -582,56 +591,59 @@ U2Assembly SamtoolsBasedAssemblyDbi::getAssemblyObject(const U2DataId &id, U2OpS
     return result;
 }
 
-int bamCountFunction(const bam1_t * /*b*/, void *data) {
-    qint64 *count = (qint64 *)data;
+int bamCountFunction(const bam1_t* /*b*/, void* data) {
+    qint64* count = (qint64*)data;
     (*count)++;
     return 0;
 }
 
-qint64 SamtoolsBasedAssemblyDbi::countReads(const U2DataId &assemblyId, const U2Region &r, U2OpStatus &os) {
+qint64 SamtoolsBasedAssemblyDbi::countReads(const U2DataId& assemblyId, const U2Region& r, U2OpStatus& os) {
     int id = SamtoolsBasedAssemblyDbi::toSamtoolsId(assemblyId, os);
     CHECK_OP(os, 0);
 
     qint64 result = 0;
-    void *data = &result;
+    void* data = &result;
     U2Region targetReg = this->getCorrectRegion(assemblyId, r, os);
     CHECK_OP(os, 0);
     qint64 endPos = targetReg.endPos() - 1;
-    bam_fetch(dbi.getBamFile(), dbi.getIndex(), id, (int)targetReg.startPos, (int)endPos, data, bamCountFunction);
+
+    std::shared_ptr<BGZF> bamFile(dbi.openNewBamFileHandler(), [](BGZF* f) { closeBamFileHandler(f); });
+    SAFE_POINT(bamFile != nullptr, "Failed to open BAM file", result);
+    bam_fetch(bamFile.get(), dbi.getIndex(), id, (int)targetReg.startPos, (int)endPos, data, bamCountFunction);
 
     return result;
 }
 
-U2DbiIterator<U2AssemblyRead> *SamtoolsBasedAssemblyDbi::getReads(const U2DataId &assemblyId, const U2Region &r, U2OpStatus &os, bool /*sortedHint*/) {
+U2DbiIterator<U2AssemblyRead>* SamtoolsBasedAssemblyDbi::getReads(const U2DataId& assemblyId, const U2Region& r, U2OpStatus& os, bool /*sortedHint*/) {
     int id = SamtoolsBasedAssemblyDbi::toSamtoolsId(assemblyId, os);
     CHECK_OP(os, nullptr);
     U2Region targetReg = this->getCorrectRegion(assemblyId, r, os);
     return new SamtoolsBasedReadsIterator(id, targetReg, dbi);
 }
 
-qint64 SamtoolsBasedAssemblyDbi::getMaxPackedRow(const U2DataId &, const U2Region &, U2OpStatus &os) {
+qint64 SamtoolsBasedAssemblyDbi::getMaxPackedRow(const U2DataId&, const U2Region&, U2OpStatus& os) {
     os.setError("Operation not supported: BAM::SamtoolsBasedAssemblyDbi::getMaxPackedRow");
     return 0;
 }
 
-U2DbiIterator<U2AssemblyRead> *SamtoolsBasedAssemblyDbi::getReadsByRow(const U2DataId &, const U2Region &, qint64, qint64, U2OpStatus &os) {
+U2DbiIterator<U2AssemblyRead>* SamtoolsBasedAssemblyDbi::getReadsByRow(const U2DataId&, const U2Region&, qint64, qint64, U2OpStatus& os) {
     os.setError("Operation not supported: BAM::SamtoolsBasedAssemblyDbi::getReadsByRow");
     return nullptr;
 }
 
-U2DbiIterator<U2AssemblyRead> *SamtoolsBasedAssemblyDbi::getReadsByName(const U2DataId &assemblyId, const QByteArray &name, U2OpStatus &os) {
+U2DbiIterator<U2AssemblyRead>* SamtoolsBasedAssemblyDbi::getReadsByName(const U2DataId& assemblyId, const QByteArray& name, U2OpStatus& os) {
     int id = SamtoolsBasedAssemblyDbi::toSamtoolsId(assemblyId, os);
     CHECK_OP(os, nullptr);
     U2Region targetReg = this->getCorrectRegion(assemblyId, U2_REGION_MAX, os);
     return new SamtoolsBasedReadsIterator(id, targetReg, dbi, name);
 }
 
-qint64 SamtoolsBasedAssemblyDbi::getMaxEndPos(const U2DataId &assemblyId, U2OpStatus &os) {
+qint64 SamtoolsBasedAssemblyDbi::getMaxEndPos(const U2DataId& assemblyId, U2OpStatus& os) {
     int id = SamtoolsBasedAssemblyDbi::toSamtoolsId(assemblyId, os);
     CHECK_OP(os, 0);
 
-    const bam_header_t *header = dbi.getHeader();
-    CHECK_EXT(nullptr != header, os.setError("NULL header"), 0);
+    const bam_header_t* header = dbi.getHeader();
+    CHECK_EXT(header != nullptr, os.setError("NULL header"), 0);
     CHECK_EXT(id < header->n_targets, os.setError("Unknown assembly id"), 0);
 
     qint64 targetLength = header->target_len[id];
@@ -639,7 +651,7 @@ qint64 SamtoolsBasedAssemblyDbi::getMaxEndPos(const U2DataId &assemblyId, U2OpSt
     return targetLength == 0 ? 0 : targetLength - 1;
 }
 
-U2Region SamtoolsBasedAssemblyDbi::getCorrectRegion(const U2DataId &assemblyId, const U2Region &r, U2OpStatus &os) {
+U2Region SamtoolsBasedAssemblyDbi::getCorrectRegion(const U2DataId& assemblyId, const U2Region& r, U2OpStatus& os) {
     qint64 assemblyLength = getMaxEndPos(assemblyId, os) + 1;
     CHECK_OP(os, U2Region());
     qint64 startPos = r.startPos;
@@ -668,18 +680,18 @@ U2Region SamtoolsBasedAssemblyDbi::getCorrectRegion(const U2DataId &assemblyId,
 /************************************************************************/
 /* SamtoolsBasedAttributeDbi */
 /************************************************************************/
-SamtoolsBasedAttributeDbi::SamtoolsBasedAttributeDbi(SamtoolsBasedDbi &_dbi)
+SamtoolsBasedAttributeDbi::SamtoolsBasedAttributeDbi(SamtoolsBasedDbi& _dbi)
     : U2SimpleAttributeDbi(&_dbi), dbi(_dbi) {
 }
 
-QStringList SamtoolsBasedAttributeDbi::getAvailableAttributeNames(U2OpStatus & /*os*/) {
+QStringList SamtoolsBasedAttributeDbi::getAvailableAttributeNames(U2OpStatus& /*os*/) {
     QStringList result;
     result << U2BaseAttributeName::reference_length;
 
     return result;
 }
 
-QList<U2DataId> SamtoolsBasedAttributeDbi::getObjectAttributes(const U2DataId &objectId, const QString &attributeName, U2OpStatus & /*os*/) {
+QList<U2DataId> SamtoolsBasedAttributeDbi::getObjectAttributes(const U2DataId& objectId, const QString& attributeName, U2OpStatus& /*os*/) {
     QList<U2DataId> result;
     if (attributeName.isEmpty()) {
         result << objectId + ATTRIBUTE_SEP + U2BaseAttributeName::reference_length.toLatin1();
@@ -690,11 +702,11 @@ QList<U2DataId> SamtoolsBasedAttributeDbi::getObjectAttributes(const U2DataId &o
     return result;
 }
 
-QList<U2DataId> SamtoolsBasedAttributeDbi::getObjectPairAttributes(const U2DataId & /*objectId*/, const U2DataId & /*childId*/, const QString & /*attributeName*/, U2OpStatus & /*os*/) {
+QList<U2DataId> SamtoolsBasedAttributeDbi::getObjectPairAttributes(const U2DataId& /*objectId*/, const U2DataId& /*childId*/, const QString& /*attributeName*/, U2OpStatus& /*os*/) {
     return QList<U2DataId>();
 }
 
-U2IntegerAttribute SamtoolsBasedAttributeDbi::getIntegerAttribute(const U2DataId &attributeId, U2OpStatus &os) {
+U2IntegerAttribute SamtoolsBasedAttributeDbi::getIntegerAttribute(const U2DataId& attributeId, U2OpStatus& os) {
     U2IntegerAttribute result;
     QString idStr = attributeId;
     QStringList tokens = idStr.split(ATTRIBUTE_SEP);
@@ -706,8 +718,8 @@ U2IntegerAttribute SamtoolsBasedAttributeDbi::getIntegerAttribute(const U2DataId
         int id = SamtoolsBasedAssemblyDbi::toSamtoolsId(objIdStr, os);
         CHECK_OP(os, result);
 
-        const bam_header_t *header = dbi.getHeader();
-        CHECK_EXT(nullptr != header, os.setError("NULL header"), result);
+        const bam_header_t* header = dbi.getHeader();
+        CHECK_EXT(header != nullptr, os.setError("NULL header"), result);
         CHECK_EXT(id < header->n_targets, os.setError("Unknown assembly id"), result);
         qint64 length = header->target_len[id];
         result = U2IntegerAttribute(objIdStr, U2BaseAttributeName::reference_length, length);
@@ -718,19 +730,19 @@ U2IntegerAttribute SamtoolsBasedAttributeDbi::getIntegerAttribute(const U2DataId
     return result;
 }
 
-U2RealAttribute SamtoolsBasedAttributeDbi::getRealAttribute(const U2DataId & /*attributeId*/, U2OpStatus & /*os*/) {
+U2RealAttribute SamtoolsBasedAttributeDbi::getRealAttribute(const U2DataId& /*attributeId*/, U2OpStatus& /*os*/) {
     return U2RealAttribute();
 }
 
-U2StringAttribute SamtoolsBasedAttributeDbi::getStringAttribute(const U2DataId & /*attributeId*/, U2OpStatus & /*os*/) {
+U2StringAttribute SamtoolsBasedAttributeDbi::getStringAttribute(const U2DataId& /*attributeId*/, U2OpStatus& /*os*/) {
     return U2StringAttribute();
 }
 
-U2ByteArrayAttribute SamtoolsBasedAttributeDbi::getByteArrayAttribute(const U2DataId & /*attributeId*/, U2OpStatus & /*os*/) {
+U2ByteArrayAttribute SamtoolsBasedAttributeDbi::getByteArrayAttribute(const U2DataId& /*attributeId*/, U2OpStatus& /*os*/) {
     return U2ByteArrayAttribute();
 }
 
-QList<U2DataId> SamtoolsBasedAttributeDbi::sort(const U2DbiSortConfig & /*sc*/, qint64 /*offset*/, qint64 /*count*/, U2OpStatus &os) {
+QList<U2DataId> SamtoolsBasedAttributeDbi::sort(const U2DbiSortConfig& /*sc*/, qint64 /*offset*/, qint64 /*count*/, U2OpStatus& os) {
     U2DbiUtils::logNotSupported(U2DbiFeature_WriteAttributes, getRootDbi(), os);
     return QList<U2DataId>();
 }
@@ -744,7 +756,7 @@ SamtoolsBasedDbiFactory::SamtoolsBasedDbiFactory()
     : U2DbiFactory() {
 }
 
-U2Dbi *SamtoolsBasedDbiFactory::createDbi() {
+U2Dbi* SamtoolsBasedDbiFactory::createDbi() {
     return new SamtoolsBasedDbi();
 }
 
@@ -752,13 +764,13 @@ U2DbiFactoryId SamtoolsBasedDbiFactory::getId() const {
     return ID;
 }
 
-FormatCheckResult SamtoolsBasedDbiFactory::isValidDbi(const QHash<QString, QString> &properties, const QByteArray &rawData, U2OpStatus & /*os*/) const {
+FormatCheckResult SamtoolsBasedDbiFactory::isValidDbi(const QHash<QString, QString>& properties, const QByteArray& rawData, U2OpStatus& /*os*/) const {
     BAMFormatUtils f;
     FormatCheckResult res = f.checkRawData(rawData, properties.value(U2DbiOptions::U2_DBI_OPTION_URL));
     return res;
 }
 
-bool SamtoolsBasedDbiFactory::isDbiExists(const U2DbiId &id) const {
+bool SamtoolsBasedDbiFactory::isDbiExists(const U2DbiId& id) const {
     return QFile::exists(id);
 }
 
