@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,19 +19,18 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CSV_COLUMN_CONFIGURATION_DIALOG_H_
-#define _U2_CSV_COLUMN_CONFIGURATION_DIALOG_H_
-
-#include <ui_CSVColumnConfigurationDialog.h>
+#pragma once
 
 #include "CSVColumnConfiguration.h"
 
+#include <ui_CSVColumnConfigurationDialog.h>
+
 namespace U2 {
 
 class CSVColumnConfigurationDialog : public QDialog, Ui_CSVColumnConfigurationDialog {
     Q_OBJECT
 public:
-    CSVColumnConfigurationDialog(QWidget *w, const ColumnConfig &config);
+    CSVColumnConfigurationDialog(QWidget* w, const ColumnConfig& config);
 
     ColumnConfig config;
 
@@ -44,5 +43,3 @@ private slots:
 };
 
 }  // namespace U2
-
-#endif
