@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_EXPORT_PLUGIN_H_
-#define _U2_DNA_EXPORT_PLUGIN_H_
+#pragma once
 
 #include <U2Core/PluginModel.h>
 #include <U2Core/ServiceModel.h>
@@ -49,12 +48,10 @@ public:
 protected:
     virtual void serviceStateChangedCallback(ServiceState oldState, bool enabledStateChanged);
 
-    ExportProjectViewItemsContoller *projectViewController;
-    ExportSequenceViewItemsController *sequenceViewController;
-    ExportAlignmentViewItemsController *alignmentViewController;
-    McaEditorContext *mcaEditorContext;
+    ExportProjectViewItemsContoller* projectViewController;
+    ExportSequenceViewItemsController* sequenceViewController;
+    ExportAlignmentViewItemsController* alignmentViewController;
+    McaEditorContext* mcaEditorContext;
 };
 
 }  // namespace U2
-
-#endif  // _U2_DNA_EXPORT_PLUGIN_H_
