@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_EXPORT_PLUGIN_TESTS_H_
-#define _U2_DNA_EXPORT_PLUGIN_TESTS_H_
+#pragma once
 
 #include <QDomElement>
 
@@ -42,7 +41,7 @@ public:
 
     void prepare() override;
 
-    QList<U2SequenceObject *> seqList;
+    QList<U2SequenceObject*> seqList;
     QStringList seqNameList;
     QString fileName;
 };
@@ -55,7 +54,7 @@ public:
 
     void prepare() override;
     ReportResult report() override;
-    QList<Task *> onSubTaskFinished(Task *subTask) override;
+    QList<Task*> onSubTaskFinished(Task* subTask) override;
 
     int transTable;
     bool includeGaps = false;
@@ -65,17 +64,15 @@ public:
     QString outputFileName;
     QString expectedOutputFile;
     U2Region selectedRows;
-    ExportMSA2MSATask *exportTask;
-    LoadDocumentTask *resultLoadTask;
+    ExportMSA2MSATask* exportTask;
+    LoadDocumentTask* resultLoadTask;
     MultipleSequenceAlignment srcAl;
     MultipleSequenceAlignment resAl;
 };
 
 class DNAExportPluginTests {
 public:
-    static QList<XMLTestFactory *> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 }  // namespace U2
-
-#endif
