@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,6 +30,7 @@
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/DocumentModel.h>
+#include <U2Core/FileFilters.h>
 #include <U2Core/IOAdapter.h>
 #include <U2Core/IOAdapterUtils.h>
 #include <U2Core/LoadDocumentTask.h>
@@ -43,7 +44,6 @@
 #include <U2Core/U2SequenceDbi.h>
 #include <U2Core/U2SequenceUtils.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/OpenViewTask.h>
 
 static const int MBYTE_TO_BYTE = 1048576;
@@ -53,16 +53,14 @@ namespace U2 {
 const QString DNASequenceGenerator::ID("dna_generator");
 
 QString DNASequenceGenerator::prepareReferenceFileFilter() {
-    QString filter = DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::SEQUENCE, true) +
-                     ";;" + DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT, false);
-    return filter;
+    return FileFilters::createFileFilterByObjectTypes({GObjectTypes::SEQUENCE, GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT});
 }
 
-void DNASequenceGenerator::generateSequence(const QMap<char, qreal> &charFreqs,
+void DNASequenceGenerator::generateSequence(const QMap<char, qreal>& charFreqs,
                                             int length,
-                                            QByteArray &result,
-                                            QRandomGenerator &randomGenerator,
-                                            U2OpStatus &os) {
+                                            QByteArray& result,
+                                            QRandomGenerator& randomGenerator,
+                                            U2OpStatus& os) {
     GTIMER(cvar, tvar, "DNASequenceGenerator::generateSequence");
     SAFE_POINT(!charFreqs.isEmpty(), "charFreqs is empty", );
     SAFE_POINT(length >= 0, "Invalid sequence length: " + QString::number(length), );
@@ -84,13 +82,13 @@ void DNASequenceGenerator::generateSequence(const QMap<char, qreal> &charFreqs,
     CHECK_EXT(result.size() == length, os.setError(GenerateDNASequenceTask::tr("Failed to allocate memory for the result sequence.")), )
 
     for (int idx = 0; idx < length; idx++) {
-        int randomCharIndex = randomGenerator.generate() % characterBySlotIndex.length();
+        int randomCharIndex = (int)(randomGenerator.generate() % characterBySlotIndex.length());
         char ch = characterBySlotIndex[randomCharIndex];
         result[idx] = ch;
     }
 }
 
-static void evaluate(const QByteArray &seq, QMap<char, qreal> &result) {
+static void evaluate(const QByteArray& seq, QMap<char, qreal>& result) {
     QMap<char, int> occurrencesMap;
     for (char ch : qAsConst(seq)) {
         if (!occurrencesMap.contains(ch)) {
@@ -110,13 +108,13 @@ static void evaluate(const QByteArray &seq, QMap<char, qreal> &result) {
     }
 }
 
-void DNASequenceGenerator::evaluateBaseContent(const DNASequence &sequence, QMap<char, qreal> &result) {
+void DNASequenceGenerator::evaluateBaseContent(const DNASequence& sequence, QMap<char, qreal>& result) {
     evaluate(sequence.seq, result);
 }
 
-void DNASequenceGenerator::evaluateBaseContent(const MultipleSequenceAlignment &ma, QMap<char, qreal> &result) {
+void DNASequenceGenerator::evaluateBaseContent(const MultipleSequenceAlignment& ma, QMap<char, qreal>& result) {
     QList<QMap<char, qreal>> rowsContents;
-    foreach (const MultipleSequenceAlignmentRow &row, ma->getMsaRows()) {
+    foreach (const MultipleSequenceAlignmentRow& row, ma->getMsaRows()) {
         QMap<char, qreal> rowContent;
         evaluate(row->getData(), rowContent);
         rowsContents.append(rowContent);
@@ -124,7 +122,7 @@ void DNASequenceGenerator::evaluateBaseContent(const MultipleSequenceAlignment &
 
     QListIterator<QMap<char, qreal>> listIter(rowsContents);
     while (listIter.hasNext()) {
-        const QMap<char, qreal> &cm = listIter.next();
+        const QMap<char, qreal>& cm = listIter.next();
         QMapIterator<char, qreal> mapIter(cm);
         while (mapIter.hasNext()) {
             mapIter.next();
@@ -138,7 +136,7 @@ void DNASequenceGenerator::evaluateBaseContent(const MultipleSequenceAlignment &
         }
     }
 
-    int rowsNum = ma->getNumRows();
+    int rowsNum = ma->getRowCount();
     QMutableMapIterator<char, qreal> i(result);
     while (i.hasNext()) {
         i.next();
@@ -150,7 +148,7 @@ void DNASequenceGenerator::evaluateBaseContent(const MultipleSequenceAlignment &
 //////////////////////////////////////////////////////////////////////////
 
 /** Returns estimated progress weight per phase in DNASequenceGeneratorTask. */
-static qreal getTaskProgressWeightPerPhase(const DNASequenceGeneratorConfig &config) {
+static float getTaskProgressWeightPerPhase(const DNASequenceGeneratorConfig& config) {
     int nPhases = 2;  // Generate + Save.
     if (config.useReference()) {
         nPhases += 2;  // Load + Evaluate.
@@ -158,12 +156,12 @@ static qreal getTaskProgressWeightPerPhase(const DNASequenceGeneratorConfig &con
     if (config.addToProj) {
         nPhases += 1;  // Add to project.
     }
-    return 1.0 / nPhases;
+    return (float)(1.0 / nPhases);
 }
 
-EvaluateBaseContentTask *DNASequenceGeneratorTask::createEvaluationTask(Document *doc, QString &err) {
+EvaluateBaseContentTask* DNASequenceGeneratorTask::createEvaluationTask(Document* doc, QString& err) {
     SAFE_POINT(doc->isLoaded(), "Document must be loaded", nullptr);
-    QList<GObject *> gobjects = doc->findGObjectByType(GObjectTypes::SEQUENCE);
+    QList<GObject*> gobjects = doc->findGObjectByType(GObjectTypes::SEQUENCE);
     gobjects << doc->findGObjectByType(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT);
     if (!gobjects.isEmpty()) {
         return new EvaluateBaseContentTask(gobjects.first());
@@ -172,20 +170,19 @@ EvaluateBaseContentTask *DNASequenceGeneratorTask::createEvaluationTask(Document
     return nullptr;
 }
 
-DNASequenceGeneratorTask::DNASequenceGeneratorTask(const DNASequenceGeneratorConfig &cfg)
+DNASequenceGeneratorTask::DNASequenceGeneratorTask(const DNASequenceGeneratorConfig& cfg)
     : Task(tr("Generate sequence task"), TaskFlag_NoRun),
-      cfg(cfg),
-      loadRefTask(nullptr),
-      evalTask(nullptr),
-      generateTask(nullptr),
-      saveTask(nullptr) {
+      cfg(cfg) {
     GCOUNTER(cvar, "DNASequenceGeneratorTask");
+}
+
+void DNASequenceGeneratorTask::prepare() {
     if (cfg.useReference()) {
         // do not load reference file if it is already in project and has loaded state
-        const QString &docUrl = cfg.getReferenceUrl();
-        Project *project = AppContext::getProject();
+        const QString& docUrl = cfg.getReferenceUrl();
+        Project* project = AppContext::getProject();
         if (project) {
-            Document *doc = project->findDocumentByURL(docUrl);
+            Document* doc = project->findDocumentByURL(docUrl);
             if (doc && doc->isLoaded()) {
                 QString err;
                 evalTask = createEvaluationTask(doc, err);
@@ -210,12 +207,12 @@ DNASequenceGeneratorTask::DNASequenceGeneratorTask(const DNASequenceGeneratorCon
     }
 }
 
-QList<Task *> DNASequenceGeneratorTask::onSubTaskFinished(Task *subTask) {
-    QList<Task *> tasks;
+QList<Task*> DNASequenceGeneratorTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> tasks;
+    propagateSubtaskError();
     if (hasError() || isCanceled() || subTask->isCanceled()) {
         return tasks;
     }
-    propagateSubtaskError();
 
     if (subTask == loadRefTask) {
         tasks << onLoadRefTaskFinished();
@@ -226,19 +223,19 @@ QList<Task *> DNASequenceGeneratorTask::onSubTaskFinished(Task *subTask) {
     } else if (saveTask == subTask) {
         tasks << onSaveTaskFinished();
     }
-    for (Task *task : tasks) {
+    for (Task* task : tasks) {
         task->setSubtaskProgressWeight(getTaskProgressWeightPerPhase(cfg));
     }
     return tasks;
 }
 
-QList<Task *> DNASequenceGeneratorTask::onLoadRefTaskFinished() {
-    QList<Task *> resultTasks;
+QList<Task*> DNASequenceGeneratorTask::onLoadRefTaskFinished() {
+    QList<Task*> resultTasks;
     SAFE_POINT(loadRefTask->isFinished() && !loadRefTask->getStateInfo().isCoR(),
                "Invalid task encountered",
                resultTasks);
     QString err;
-    Document *doc = loadRefTask->getDocument();
+    Document* doc = loadRefTask->getDocument();
     evalTask = createEvaluationTask(doc, err);
     if (evalTask) {
         resultTasks << evalTask;
@@ -248,8 +245,8 @@ QList<Task *> DNASequenceGeneratorTask::onLoadRefTaskFinished() {
     return resultTasks;
 }
 
-QList<Task *> DNASequenceGeneratorTask::onEvalTaskFinished() {
-    QList<Task *> resultTasks;
+QList<Task*> DNASequenceGeneratorTask::onEvalTaskFinished() {
+    QList<Task*> resultTasks;
     SAFE_POINT(evalTask->isFinished() && !evalTask->getStateInfo().isCoR(),
                "Invalid task encountered",
                resultTasks);
@@ -260,19 +257,19 @@ QList<Task *> DNASequenceGeneratorTask::onEvalTaskFinished() {
     return resultTasks;
 }
 
-QList<Task *> DNASequenceGeneratorTask::onGenerateTaskFinished() {
-    QList<Task *> resultTasks;
+QList<Task*> DNASequenceGeneratorTask::onGenerateTaskFinished() {
+    QList<Task*> resultTasks;
     SAFE_POINT(generateTask->isFinished() && !generateTask->getStateInfo().isCoR(),
                "Invalid task encountered",
                resultTasks);
-    IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(
+    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(
         IOAdapterUtils::url2io(cfg.getOutUrlString()));
 
     if (cfg.saveDoc) {
-        DocumentFormat *format = AppContext::getDocumentFormatRegistry()->getFormatById(cfg.getDocumentFormatId());
-        Document *doc = format->createNewLoadedDocument(iof, cfg.getOutUrlString(), stateInfo);
+        DocumentFormat* format = AppContext::getDocumentFormatRegistry()->getFormatById(cfg.getDocumentFormatId());
+        Document* doc = format->createNewLoadedDocument(iof, cfg.getOutUrlString(), stateInfo);
         CHECK_OP(stateInfo, resultTasks);
-        const QSet<QString> &supportedFormats = format->getSupportedObjectTypes();
+        const QSet<QString>& supportedFormats = format->getSupportedObjectTypes();
         bool isSequenceFormat = supportedFormats.contains(GObjectTypes::SEQUENCE);
         if (isSequenceFormat) {
             addSequencesToSeqDoc(doc);
@@ -282,10 +279,10 @@ QList<Task *> DNASequenceGeneratorTask::onGenerateTaskFinished() {
                        resultTasks);
             addSequencesToMsaDoc(doc);
         }
-        saveTask = new SaveDocumentTask(doc, SaveDoc_Overwrite);
+        saveTask = new SaveDocumentTask(doc);
         resultTasks << saveTask;
     } else {  // TODO: avoid high memory consumption here
-        const DNAAlphabet *alp = cfg.getAlphabet();
+        const DNAAlphabet* alp = cfg.getAlphabet();
         SAFE_POINT(alp != nullptr, "Generated sequence has invalid alphabet", resultTasks);
         U2DbiRef dbiRef = generateTask->getDbiRef();
         QString baseSeqName = cfg.getSequenceName();
@@ -295,7 +292,7 @@ QList<Task *> DNASequenceGeneratorTask::onGenerateTaskFinished() {
             QString seqName = totalSeqCount > 1 ? baseSeqName + " " + QString::number(sequenceIndex + 1) : baseSeqName;
             DbiConnection con(dbiRef, stateInfo);
             CHECK_OP(stateInfo, resultTasks);
-            U2SequenceDbi *sequenceDbi = con.dbi->getSequenceDbi();
+            U2SequenceDbi* sequenceDbi = con.dbi->getSequenceDbi();
             QByteArray seqContent = sequenceDbi->getSequenceData(seqs[sequenceIndex].id, U2_REGION_MAX, stateInfo);
             results << DNASequence(seqName, seqContent, alp);
         }
@@ -303,13 +300,13 @@ QList<Task *> DNASequenceGeneratorTask::onGenerateTaskFinished() {
     return resultTasks;
 }
 
-void DNASequenceGeneratorTask::addSequencesToMsaDoc(Document *source) {
-    const QSet<QString> &supportedFormats = source->getDocumentFormat()->getSupportedObjectTypes();
+void DNASequenceGeneratorTask::addSequencesToMsaDoc(Document* source) {
+    const QSet<QString>& supportedFormats = source->getDocumentFormat()->getSupportedObjectTypes();
     SAFE_POINT(supportedFormats.contains(GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT),
                "Invalid document format", );
     SAFE_POINT(generateTask != nullptr, "Invalid generate task", );
     U2DbiRef dbiRef = generateTask->getDbiRef();
-    const DNAAlphabet *alp = cfg.alphabet;
+    const DNAAlphabet* alp = cfg.alphabet;
     SAFE_POINT(alp != nullptr, "Generated sequence has invalid alphabet", );
     QString baseSeqName = cfg.getSequenceName();
     QList<U2Sequence> seqs = generateTask->getResults();
@@ -323,13 +320,13 @@ void DNASequenceGeneratorTask::addSequencesToMsaDoc(Document *source) {
         QByteArray seqContent = con.dbi->getSequenceDbi()->getSequenceData(seqs[sequenceIndex].id, U2_REGION_MAX, stateInfo);
         msa->addRow(seqName, seqContent, sequenceIndex);
     }
-    MultipleSequenceAlignmentObject *alnObject = MultipleSequenceAlignmentImporter::createAlignment(source->getDbiRef(), msa, stateInfo);
+    MultipleSequenceAlignmentObject* alnObject = MultipleSequenceAlignmentImporter::createAlignment(source->getDbiRef(), msa, stateInfo);
     CHECK_OP(stateInfo, );
     source->addObject(alnObject);
 }
 
-void DNASequenceGeneratorTask::addSequencesToSeqDoc(Document *source) {
-    const QSet<QString> &supportedFormats = source->getDocumentFormat()->getSupportedObjectTypes();
+void DNASequenceGeneratorTask::addSequencesToSeqDoc(Document* source) {
+    const QSet<QString>& supportedFormats = source->getDocumentFormat()->getSupportedObjectTypes();
     SAFE_POINT(supportedFormats.contains(GObjectTypes::SEQUENCE), "Invalid document format", );
     SAFE_POINT(generateTask != nullptr, "Invalid generate task", );
     U2DbiRef dbiRef = generateTask->getDbiRef();
@@ -343,17 +340,17 @@ void DNASequenceGeneratorTask::addSequencesToSeqDoc(Document *source) {
     }
 }
 
-QList<Task *> DNASequenceGeneratorTask::onSaveTaskFinished() {
-    Document *doc = saveTask->getDocument();
-    QList<Task *> resultTasks;
+QList<Task*> DNASequenceGeneratorTask::onSaveTaskFinished() {
+    Document* doc = saveTask->getDocument();
+    QList<Task*> resultTasks;
 
     if (!cfg.addToProj) {
         doc->unload();
         delete doc;
     } else {
-        Project *prj = AppContext::getProject();
+        Project* prj = AppContext::getProject();
         if (prj) {
-            Document *d = prj->findDocumentByURL(doc->getURL());
+            Document* d = prj->findDocumentByURL(doc->getURL());
             if (d == nullptr) {
                 prj->addDocument(doc);
                 resultTasks << new OpenViewTask(doc);
@@ -364,7 +361,7 @@ QList<Task *> DNASequenceGeneratorTask::onSaveTaskFinished() {
                 delete doc;
             }
         } else {
-            Task *openWithProjectTask = AppContext::getProjectLoader()->openWithProjectTask(QList<GUrl>() << doc->getURL());
+            Task* openWithProjectTask = AppContext::getProjectLoader()->openWithProjectTask(QList<GUrl>() << doc->getURL());
             if (openWithProjectTask != nullptr) {
                 resultTasks << openWithProjectTask;
             }
@@ -377,17 +374,17 @@ QList<Task *> DNASequenceGeneratorTask::onSaveTaskFinished() {
 }
 
 // EvaluateBaseContentTask
-EvaluateBaseContentTask::EvaluateBaseContentTask(GObject *obj)
+EvaluateBaseContentTask::EvaluateBaseContentTask(GObject* obj)
     : Task(tr("Evaluate base content task"), TaskFlag_None), _obj(obj), alp(nullptr) {
 }
 
 void EvaluateBaseContentTask::run() {
     if (_obj->getGObjectType() == GObjectTypes::SEQUENCE) {
-        U2SequenceObject *dnaObj = qobject_cast<U2SequenceObject *>(_obj);
+        auto dnaObj = qobject_cast<U2SequenceObject*>(_obj);
         alp = dnaObj->getAlphabet();
         DNASequenceGenerator::evaluateBaseContent(dnaObj->getWholeSequence(stateInfo), result);
     } else if (_obj->getGObjectType() == GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT) {
-        MultipleSequenceAlignmentObject *maObj = qobject_cast<MultipleSequenceAlignmentObject *>(_obj);
+        auto maObj = qobject_cast<MultipleSequenceAlignmentObject*>(_obj);
         alp = maObj->getAlphabet();
         DNASequenceGenerator::evaluateBaseContent(maObj->getMultipleAlignment(), result);
     } else {
@@ -396,7 +393,7 @@ void EvaluateBaseContentTask::run() {
 }
 
 // GenerateTask
-GenerateDNASequenceTask::GenerateDNASequenceTask(const QMap<char, qreal> &baseContent_,
+GenerateDNASequenceTask::GenerateDNASequenceTask(const QMap<char, qreal>& baseContent_,
                                                  int length_,
                                                  int window_,
                                                  int count_,
@@ -404,12 +401,13 @@ GenerateDNASequenceTask::GenerateDNASequenceTask(const QMap<char, qreal> &baseCo
     : Task(tr("Generate DNA sequence task"), TaskFlag_None), baseContent(baseContent_),
       length(length_), window(window_), count(count_), seed(seed_), dbiRef() {
     tpm = Progress_Manual;
+    window = qMin(window, length);
 }
 
 void GenerateDNASequenceTask::prepare() {
-    qint64 memUseMB = window / MBYTE_TO_BYTE;
+    int memUseMB = window / MBYTE_TO_BYTE;
     coreLog.trace(QString("Generate DNA sequence task: Memory resource %1").arg(memUseMB));
-    addTaskResource(TaskResourceUsage(RESOURCE_MEMORY, memUseMB));
+    addTaskResource(TaskResourceUsage(UGENE_RESOURCE_ID_MEMORY, memUseMB, TaskResourceStage::Run));
 }
 
 void GenerateDNASequenceTask::run() {
@@ -422,15 +420,11 @@ void GenerateDNASequenceTask::run() {
     results.reserve(count);
 
     QRandomGenerator generator(seed >= 0 ? (quint32)seed : QRandomGenerator::system()->generate());
-    for (int seqCount = 0; seqCount < count; seqCount++) {
+    for (int sequenceIndex = 0; sequenceIndex < count; sequenceIndex++) {
         U2SequenceImporter seqImporter(QVariantMap(), true);
 
         QByteArray sequenceChunk;
-        if (window > length) {
-            window = length;
-        }
-
-        seqImporter.startSequence(stateInfo, dbiRef, U2ObjectDbi::ROOT_FOLDER, QString("default"), false);
+        seqImporter.startSequence(stateInfo, dbiRef, U2ObjectDbi::ROOT_FOLDER, "sequence_" + QString::number(sequenceIndex + 1), false);
         CHECK_OP_BREAK(stateInfo);
 
         for (int chunkCount = 0; chunkCount < length / window && !isCanceled(); chunkCount++) {
@@ -438,7 +432,7 @@ void GenerateDNASequenceTask::run() {
             CHECK_OP_BREAK(stateInfo);
             seqImporter.addBlock(sequenceChunk.constData(), sequenceChunk.length(), stateInfo);
             CHECK_OP_BREAK(stateInfo);
-            int currentProgress = int(100 * (seqCount + chunkCount * double(window) / double(length)) / double(count));
+            int currentProgress = int(100 * (sequenceIndex + chunkCount * (double)window / length) / count);
             stateInfo.setProgress(currentProgress);
         }
         CHECK_OP_BREAK(stateInfo);
@@ -455,7 +449,7 @@ void GenerateDNASequenceTask::run() {
         CHECK_OP_BREAK(stateInfo);
         results.append(seq);
 
-        stateInfo.setProgress(seqCount / count * 100);
+        stateInfo.setProgress(int(100 * (double)sequenceIndex / count));
     }
 }
 
