@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +22,6 @@
 #include "DNASequenceGeneratorDialog.h"
 
 #include <QMessageBox>
-#include <QPushButton>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/BaseDocumentFormats.h>
@@ -58,7 +57,7 @@ static QMap<char, qreal> initContent() {
 
 QMap<char, qreal> DNASequenceGeneratorDialog::content = initContent();
 
-DNASequenceGeneratorDialog::DNASequenceGeneratorDialog(QWidget *p)
+DNASequenceGeneratorDialog::DNASequenceGeneratorDialog(QWidget* p)
     : QDialog(p),
       saveController(nullptr),
       generateButton(nullptr),
@@ -149,7 +148,7 @@ void DNASequenceGeneratorDialog::sl_generate() {
     cfg.seed = seedCheckBox->isChecked() ? seedSpinBox->value() : -1;
 
     if (cfg.window > cfg.length) {
-        QMessageBox::critical(this, tr("DNA Sequence Generator"), tr("Windows size bigger than sequence length"));
+        QMessageBox::critical(this, tr("DNA Sequence Generator"), tr("Windows size is bigger than the sequence length"));
         return;
     }
 
@@ -163,7 +162,7 @@ void DNASequenceGeneratorDialog::sl_generate() {
         return;
     }
 
-    Settings *s = AppContext::getSettings();
+    Settings* s = AppContext::getSettings();
     if (baseContentRadioButton->isChecked()) {
         s->setValue(ROOT_SETTING + SELECTED_OPTION, OPTION_BASE_CONTENT);
         int percentA = percentASpin->value();
