@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_SEQUENCE_GENERATOR_DIALOG_H_
-#define _U2_DNA_SEQUENCE_GENERATOR_DIALOG_H_
+#pragma once
 
 #include "ui_DNASequenceGeneratorDialog.h"
 
@@ -31,7 +30,7 @@ class SaveDocumentController;
 class DNASequenceGeneratorDialog : public QDialog, public Ui_DNASequenceGeneratorDialog {
     Q_OBJECT
 public:
-    DNASequenceGeneratorDialog(QWidget *p = nullptr);
+    DNASequenceGeneratorDialog(QWidget* p = nullptr);
 
 private slots:
     void sl_browseReference();
@@ -44,14 +43,12 @@ private slots:
 private:
     void initSaveController();
 
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
     static QMap<char, qreal> content;
-    QPushButton *generateButton;
-    QPushButton *cancelButton;
-    QMap<char, qreal> &percentMap;
+    QPushButton* generateButton;
+    QPushButton* cancelButton;
+    QMap<char, qreal>& percentMap;
     float gcSkew;
 };
 
 }  // namespace U2
-
-#endif
