@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_ALIGNMENT_VIEW_ITEMS_H_
-#define _U2_EXPORT_ALIGNMENT_VIEW_ITEMS_H_
+#pragma once
 
 #include <U2Core/U2Region.h>
 
@@ -38,30 +37,31 @@ class MSAEditor;
 class ExportAlignmentViewItemsController : public GObjectViewWindowContext {
     Q_OBJECT
 public:
-    ExportAlignmentViewItemsController(QObject *p);
+    ExportAlignmentViewItemsController(QObject* p);
 
 protected:
-    void initViewContext(GObjectView *view) override;
+    void initViewContext(GObjectViewController* view) override;
 
-    void buildStaticOrContextMenu(GObjectView *view, QMenu *menu) override;
+    void buildStaticOrContextMenu(GObjectViewController* view, QMenu* menu) override;
 };
 
 class MSAExportContext : public QObject {
     Q_OBJECT
 public:
-    MSAExportContext(MSAEditor *e);
-    void buildMenu(QMenu *m);
+    MSAExportContext(MSAEditor* e);
+    void buildMenu(QMenu* m);
 
 protected slots:
     void sl_exportNucleicMsaToAmino();
+    void sl_exportSelectedMsaRowsToSeparateFiles();
 
     void updateActions();
 
 private:
-    MSAEditor *editor;
-    QAction *translateMSAAction;
+    MSAEditor* editor = nullptr;
+    QAction* exportNucleicMsaToAminoAction = nullptr;
+    QAction* exportMsaToSequenceFileFormatAction = nullptr;
+    QAction* exportSelectedMsaRowsToSeparateFilesAction = nullptr;
 };
 
 }  // namespace U2
-
-#endif
