@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,20 +22,17 @@
 #include "ExportBlastResultDialog.h"
 
 #include <QMessageBox>
-#include <QPushButton>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/L10n.h>
-#include <U2Core/Settings.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/HelpButton.h>
 #include <U2Gui/SaveDocumentController.h>
 
 namespace U2 {
 
-ExportBlastResultDialog::ExportBlastResultDialog(QWidget *p, const QString &defaultUrl)
+ExportBlastResultDialog::ExportBlastResultDialog(QWidget* p, const QString& defaultUrl)
     : QDialog(p),
       saveController(nullptr) {
     setupUi(this);
@@ -63,12 +60,12 @@ void ExportBlastResultDialog::accept() {
     url = saveController->getSaveFileName();
     format = saveController->getFormatIdToSave();
     addToProjectFlag = addToProjectBox->isChecked();
-    qualiferId = nameIdBox->currentText();
+    qualifierId = nameIdBox->currentText();
     addRefFlag = addRefBox->isChecked();
     QDialog::accept();
 }
 
-void ExportBlastResultDialog::initSaveController(const QString &defaultUrl) {
+void ExportBlastResultDialog::initSaveController(const QString& defaultUrl) {
     SaveDocumentControllerConfig config;
     config.defaultFileName = defaultUrl;
     config.defaultFormatId = BaseDocumentFormats::CLUSTAL_ALN;
@@ -84,12 +81,7 @@ void ExportBlastResultDialog::initSaveController(const QString &defaultUrl) {
     saveController = new SaveDocumentController(config, formatConstraints, this);
 }
 
-void ExportBlastResultDialog::setOkButtonText(const QString &text) const {
-    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
-    okButton->setText(text);
-}
-
-void ExportBlastResultDialog::setFileLabelText(const QString &text) const {
+void ExportBlastResultDialog::setFileLabelText(const QString& text) const {
     fileLabel->setText(text);
 }
 
