@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,15 +19,14 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_BLAST_RESULT_DIALOG_H_
-#define _U2_EXPORT_BLAST_RESULT_DIALOG_H_
-
-#include <ui_ExportBlastResultDialog.h>
+#pragma once
 
 #include <QDialog>
 
 #include <U2Core/global.h>
 
+#include <ui_ExportBlastResultDialog.h>
+
 namespace U2 {
 
 class SaveDocumentController;
@@ -35,27 +34,23 @@ class SaveDocumentController;
 class ExportBlastResultDialog : public QDialog, private Ui_ExportBlastResultDialog {
     Q_OBJECT
 public:
-    ExportBlastResultDialog(QWidget *p, const QString &defaultUrl = QString());
+    ExportBlastResultDialog(QWidget* p, const QString& defaultUrl = QString());
 
-    void setOkButtonText(const QString &text) const;
-    void setFileLabelText(const QString &text) const;
+    void setFileLabelText(const QString& text) const;
 
-    virtual void accept();
+    void accept() override;
 
 public:
     QString url;
     DocumentFormatId format;
-    QString qualiferId;
+    QString qualifierId;
     bool addToProjectFlag;
-    bool useGenbankHeader;
     bool addRefFlag;
 
 private:
-    void initSaveController(const QString &defaultUrl);
+    void initSaveController(const QString& defaultUrl);
 
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
 };
 
 }  // namespace U2
-
-#endif  // _U2_EXPORT_BLAST_RESULT_DIALOG_H_
