@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_CHROMATOGRAM_DIALOG_H_
-#define _U2_EXPORT_CHROMATOGRAM_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -36,7 +35,7 @@ class SaveDocumentController;
 class ExportChromatogramDialog : public QDialog, Ui_ExportChromatogramDialog {
     Q_OBJECT
 public:
-    ExportChromatogramDialog(QWidget *p, const GUrl &fileName);
+    ExportChromatogramDialog(QWidget* p, const GUrl& fileName);
 
     void accept();
 
@@ -47,11 +46,9 @@ public:
     bool complemented;
 
 private:
-    void initSaveController(const GUrl &fileUrl);
+    void initSaveController(const GUrl& fileUrl);
 
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
 };
 
 }  // namespace U2
-
-#endif
