@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_PROJECT_VIEW_ITEMS_H_
-#define _U2_EXPORT_PROJECT_VIEW_ITEMS_H_
+#pragma once
 
 #include <QObject>
 
@@ -35,10 +34,10 @@ class GUrl;
 class ExportProjectViewItemsContoller : public QObject {
     Q_OBJECT
 public:
-    ExportProjectViewItemsContoller(QObject *p);
+    ExportProjectViewItemsContoller(QObject* p);
 
 private slots:
-    void sl_addToProjectViewMenu(QMenu &);
+    void sl_addToProjectViewMenu(QMenu&);
 
     void sl_saveSequencesToSequenceFormat();
     void sl_saveCorrespondingSequence();
@@ -53,22 +52,20 @@ private slots:
     void sl_exportObject();
 
 private:
-    void addExportImportMenu(QMenu &m);
-    void exportSequences(const QList<GObject *> &seqs);
+    void addExportImportMenu(QMenu& m);
+    void exportSequences(const QList<GObject*>& seqs);
 
-    QAction *exportSequencesToSequenceFormatAction;
-    QAction *exportCorrespondingSeqsAction;
-    QAction *exportSequencesAsAlignmentAction;
-    QAction *exportAlignmentAsSequencesAction;
-    QAction *exportMcaToMsaAction;
-    QAction *exportNucleicAlignmentToAminoAction;
-    QAction *importAnnotationsFromCSVAction;
-    QAction *exportDNAChromatogramAction;
-    QAction *exportAnnotations2CSV;
-    QAction *exportSequenceQuality;
-    QAction *exportObjectAction;
+    QAction* exportSequencesToSequenceFormatAction;
+    QAction* exportCorrespondingSeqsAction;
+    QAction* exportSequencesAsAlignmentAction;
+    QAction* exportAlignmentAsSequencesAction;
+    QAction* exportMcaToMsaAction;
+    QAction* exportNucleicAlignmentToAminoAction;
+    QAction* importAnnotationsFromCSVAction;
+    QAction* exportDNAChromatogramAction;
+    QAction* exportAnnotations2CSV;
+    QAction* exportSequenceQuality;
+    QAction* exportObjectAction;
 };
 
 }  // namespace U2
-
-#endif
