@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _EXPORT_PHRED_QUALITY_WORKER_H_
-#define _EXPORT_PHRED_QUALITY_WORKER_H_
+#pragma once
 
 #include <U2Core/DNASequence.h>
 
@@ -38,7 +37,7 @@ namespace LocalWorkflow {
 class ExportPhredQualityPrompter : public PrompterBase<ExportPhredQualityPrompter> {
     Q_OBJECT
 public:
-    ExportPhredQualityPrompter(Actor *p = 0)
+    ExportPhredQualityPrompter(Actor* p = 0)
         : PrompterBase<ExportPhredQualityPrompter>(p) {
     }
 
@@ -49,17 +48,17 @@ protected:
 class ExportPhredQualityWorker : public BaseWorker {
     Q_OBJECT
 public:
-    ExportPhredQualityWorker(Actor *a);
+    ExportPhredQualityWorker(Actor* a);
 
     virtual void init();
-    virtual Task *tick();
+    virtual Task* tick();
     virtual void cleanup();
 
 protected:
-    CommunicationChannel *input;
+    CommunicationChannel* input;
     QString fileName;
-    QList<U2SequenceObject *> seqObjList;
-    Task *currentTask;
+    QList<U2SequenceObject*> seqObjList;
+    Task* currentTask;
 };
 
 class ExportPhredQualityWorkerFactory : public DomainFactory {
@@ -69,10 +68,8 @@ public:
     ExportPhredQualityWorkerFactory()
         : DomainFactory(ACTOR_ID) {
     }
-    virtual Worker *createWorker(Actor *a);
+    virtual Worker* createWorker(Actor* a);
 };
 
 }  // namespace LocalWorkflow
 }  // namespace U2
-
-#endif  // _EXPORT_PHRED_QUALITY_WORKER_H_
