@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,7 +28,6 @@
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNASequenceObject.h>
-#include <U2Core/DNATranslation.h>
 #include <U2Core/DNATranslationImpl.h>
 #include <U2Core/DocumentModel.h>
 #include <U2Core/GObjectRelationRoles.h>
@@ -57,7 +56,7 @@ ExportSequenceItem::ExportSequenceItem()
     : circular(false), alphabet(nullptr), length(0), complTT(nullptr), aminoTT(nullptr), backTT(nullptr) {
 }
 
-ExportSequenceItem::ExportSequenceItem(const ExportSequenceItem &other)
+ExportSequenceItem::ExportSequenceItem(const ExportSequenceItem& other)
     : seqRef(other.seqRef), name(other.name), circular(other.circular), alphabet(other.alphabet), length(other.length),
       annotations(other.annotations), complTT(other.complTT), aminoTT(other.aminoTT), backTT(other.backTT) {
     if (ownsSeq()) {
@@ -65,7 +64,7 @@ ExportSequenceItem::ExportSequenceItem(const ExportSequenceItem &other)
     }
 }
 
-ExportSequenceItem &ExportSequenceItem::operator=(const ExportSequenceItem &other) {
+ExportSequenceItem& ExportSequenceItem::operator=(const ExportSequenceItem& other) {
     seqRef = other.seqRef;
     name = other.name;
     circular = other.circular;
@@ -82,7 +81,7 @@ ExportSequenceItem &ExportSequenceItem::operator=(const ExportSequenceItem &othe
     return *this;
 }
 
-bool ExportSequenceItem::operator==(const ExportSequenceItem &other) const {
+bool ExportSequenceItem::operator==(const ExportSequenceItem& other) const {
     return seqRef == other.seqRef &&
            name == other.name &&
            circular == other.circular &&
@@ -135,7 +134,7 @@ void ExportSequenceItem::stopSeqOwnership() {
     sequencesRefCounts.remove(seqRef);
 }
 
-void ExportSequenceItem::setOwnershipOverSeq(const U2Sequence &seq, const U2DbiRef &dbiRef) {
+void ExportSequenceItem::setOwnershipOverSeq(const U2Sequence& seq, const U2DbiRef& dbiRef) {
     SAFE_POINT(seq.hasValidId() && dbiRef.isValid(), "Invalid DBI reference", );
 
     releaseOwnedSeq();
@@ -149,7 +148,7 @@ void ExportSequenceItem::setOwnershipOverSeq(const U2Sequence &seq, const U2DbiR
     startSeqOwnership();
 }
 
-U2SequenceObject *ExportSequenceItem::takeOwnedSeq() {
+U2SequenceObject* ExportSequenceItem::takeOwnedSeq() {
     stopSeqOwnership();
     return new U2SequenceObject(name, seqRef);
 }
@@ -164,8 +163,8 @@ bool ExportSequenceItem::isEmpty() const {
     return *this == empty;
 }
 
-void ExportSequenceItem::setSequenceInfo(U2SequenceObject *seqObj) {
-    SAFE_POINT(nullptr != seqObj, L10N::nullPointerError("sequence object"), );
+void ExportSequenceItem::setSequenceInfo(U2SequenceObject* seqObj) {
+    SAFE_POINT_NN(seqObj, );
 
     seqRef = seqObj->getEntityRef();
     name = seqObj->getGObjectName();
@@ -188,7 +187,7 @@ ExportSequenceTaskSettings::ExportSequenceTaskSettings()
 //////////////////////////////////////////////////////////////////////////
 // ExportSequenceTask
 
-ExportSequenceTask::ExportSequenceTask(const ExportSequenceTaskSettings &s)
+ExportSequenceTask::ExportSequenceTask(const ExportSequenceTaskSettings& s)
     : DocumentProviderTask(tr("Export sequence to %1").arg(s.fileName), TaskFlag_None), config(s) {
     documentDescription = QFileInfo(s.fileName).fileName();
     setVerboseLogMode(true);
@@ -196,8 +195,8 @@ ExportSequenceTask::ExportSequenceTask(const ExportSequenceTaskSettings &s)
 
 namespace {
 
-bool checkFrame(const QVector<U2Region> &regions, int frame) {
-    foreach (const U2Region &r, regions) {
+bool checkFrame(const QVector<U2Region>& regions, int frame) {
+    foreach (const U2Region& r, regions) {
         if (r.startPos % 3 != frame) {
             return false;
         }
@@ -205,9 +204,9 @@ bool checkFrame(const QVector<U2Region> &regions, int frame) {
     return true;
 }
 
-ExportSequenceItem toRevComplement(ExportSequenceItem &ei, const U2DbiRef &resultDbiRef, U2OpStatus &os) {
+ExportSequenceItem toRevComplement(ExportSequenceItem& ei, const U2DbiRef& resultDbiRef, U2OpStatus& os) {
     ExportSequenceItem complEi = ei;
-    CHECK_EXT(nullptr != ei.complTT, os.setError(ExportSequenceTask::tr("Complement translation not found")), complEi);
+    CHECK_EXT(ei.complTT != nullptr, os.setError(ExportSequenceTask::tr("Complement translation not found")), complEi);
 
     U2SequenceImporter importer(QVariantMap(), true);
     importer.startSequence(os, resultDbiRef, U2ObjectDbi::ROOT_FOLDER, ei.name + "|rev-compl", ei.circular);
@@ -221,7 +220,7 @@ ExportSequenceItem toRevComplement(ExportSequenceItem &ei, const U2DbiRef &resul
         QByteArray chunkContent = seqObject.getSequenceData(chunkRegion, os);
         CHECK_OP(os, complEi);
 
-        char *rawChunkContent = chunkContent.data();
+        char* rawChunkContent = chunkContent.data();
         ei.complTT->translate(rawChunkContent, currentChunkSize);
         TextUtils::reverse(rawChunkContent, currentChunkSize);
 
@@ -236,7 +235,7 @@ ExportSequenceItem toRevComplement(ExportSequenceItem &ei, const U2DbiRef &resul
 
     // fix annotation locations
     for (int a = 0; a < complEi.annotations.size(); a++) {
-        SharedAnnotationData &ad = complEi.annotations[a];
+        SharedAnnotationData& ad = complEi.annotations[a];
         ad->setStrand(ad->getStrand() == U2Strand::Direct ? U2Strand::Complementary : U2Strand::Direct);
         U2Region::mirror(ei.length, ad->location->regions);
         U2Region::reverse(ad->location->regions);
@@ -245,10 +244,10 @@ ExportSequenceItem toRevComplement(ExportSequenceItem &ei, const U2DbiRef &resul
     return complEi;
 }
 
-QList<ExportSequenceItem> toAmino(ExportSequenceItem &ei, bool allFrames, const U2DbiRef &resultDbiRef, U2OpStatus &os) {
+QList<ExportSequenceItem> toAmino(ExportSequenceItem& ei, bool allFrames, const U2DbiRef& resultDbiRef, U2OpStatus& os) {
     QList<ExportSequenceItem> res;
 
-    CHECK_EXT(nullptr != ei.aminoTT, os.setError(ExportSequenceTask::tr("Amino translation not found")), res);
+    CHECK_EXT(ei.aminoTT != nullptr, os.setError(ExportSequenceTask::tr("Amino translation not found")), res);
     SAFE_POINT(ei.aminoTT->isThree2One(), "Invalid amino translation", res);
 
     const int nFrames = allFrames ? 3 : 1;
@@ -278,7 +277,7 @@ QList<ExportSequenceItem> toAmino(ExportSequenceItem &ei, bool allFrames, const
             }
             chunkRemainders[frameNumber] = frameChunkContent.right(frameChunkContent.size() % 3);
 
-            const DNAAlphabet *dstAlphabet = ei.aminoTT->getDstAlphabet();
+            const DNAAlphabet* dstAlphabet = ei.aminoTT->getDstAlphabet();
             QByteArray transContent(frameChunkContent.size() / 3, dstAlphabet->getDefaultSymbol());
 
             ei.aminoTT->translate(frameChunkContent.constData(), frameChunkContent.length(), transContent.data(), transContent.length());
@@ -302,7 +301,7 @@ QList<ExportSequenceItem> toAmino(ExportSequenceItem &ei, bool allFrames, const
 
         // fix annotation locations
         transEi.annotations.clear();
-        foreach (const SharedAnnotationData &ad, ei.annotations) {
+        foreach (const SharedAnnotationData& ad, ei.annotations) {
             if (checkFrame(ad->getRegions(), frameNumber)) {
                 SharedAnnotationData r = ad;
                 U2Region::divide(3, r->location->regions);
@@ -315,9 +314,9 @@ QList<ExportSequenceItem> toAmino(ExportSequenceItem &ei, bool allFrames, const
     return res;
 }
 
-ExportSequenceItem backToNucleic(ExportSequenceItem &ei, bool mostProbable, const U2DbiRef &resultDbiRef, U2OpStatus &os) {
+ExportSequenceItem backToNucleic(ExportSequenceItem& ei, bool mostProbable, const U2DbiRef& resultDbiRef, U2OpStatus& os) {
     ExportSequenceItem backEi = ei;
-    CHECK_EXT(nullptr != ei.backTT, os.setError(ExportSequenceTask::tr("Back-translation not found")), backEi);
+    CHECK_EXT(ei.backTT != nullptr, os.setError(ExportSequenceTask::tr("Back-translation not found")), backEi);
     SAFE_POINT(ei.backTT->isOne2Three(), "Invalid reverse translation", backEi);
 
     U2SequenceImporter importer(QVariantMap(), true);
@@ -325,8 +324,8 @@ ExportSequenceItem backToNucleic(ExportSequenceItem &ei, bool mostProbable, cons
     CHECK_OP(os, backEi);
 
     // translate
-    const DNATranslation1to3Impl *trans = dynamic_cast<const DNATranslation1to3Impl *>(ei.backTT);
-    SAFE_POINT(nullptr != trans, L10N::nullPointerError("DNA translation"), backEi);
+    const DNATranslation1to3Impl* trans = dynamic_cast<const DNATranslation1to3Impl*>(ei.backTT);
+    SAFE_POINT_NN(trans, backEi);
     const BackTranslationMode translationMode = mostProbable ? USE_MOST_PROBABLE_CODONS : USE_FREQUENCE_DISTRIBUTION;
 
     U2SequenceObject seqObject(ei.name, ei.seqRef);
@@ -350,19 +349,19 @@ ExportSequenceItem backToNucleic(ExportSequenceItem &ei, bool mostProbable, cons
 
     // fix annotation locations
     for (int a = 0; a < backEi.annotations.size(); a++) {
-        SharedAnnotationData &ad = backEi.annotations[a];
+        SharedAnnotationData& ad = backEi.annotations[a];
         U2Region::multiply(3, ad->location->regions);
     }
     return backEi;
 }
 
-ExportSequenceItem mergeExportItems(QList<ExportSequenceItem> &items, int mergeGap, U2OpStatus &os) {
+ExportSequenceItem mergeExportItems(QList<ExportSequenceItem>& items, int mergeGap, U2OpStatus& os) {
     ExportSequenceItem mergedEi = items.takeFirst();
     QByteArray gapSequence(mergeGap, mergedEi.alphabet->getDefaultSymbol());
 
     U2SequenceObject mergedSeqObject(mergedEi.name, mergedEi.seqRef);
     for (int i = 0, n = items.size(); i < n; ++i) {
-        ExportSequenceItem &ei2 = items[i];
+        ExportSequenceItem& ei2 = items[i];
 
         mergedSeqObject.replaceRegion(U2Region(mergedEi.length, 0), DNASequence(gapSequence, mergedEi.alphabet), os);
         CHECK_OP(os, mergedEi);
@@ -380,7 +379,7 @@ ExportSequenceItem mergeExportItems(QList<ExportSequenceItem> &items, int mergeG
         }
 
         // fix annotation locations
-        foreach (const SharedAnnotationData &ad, ei2.annotations) {
+        foreach (const SharedAnnotationData& ad, ei2.annotations) {
             SharedAnnotationData ma = ad;
             U2Region::shift(mergedEi.length, ma->location->regions);
             mergedEi.annotations.append(ma);
@@ -390,13 +389,13 @@ ExportSequenceItem mergeExportItems(QList<ExportSequenceItem> &items, int mergeG
     return mergedEi;
 }
 
-void saveExportItems2Doc(const QList<ExportSequenceItem> &items, const QString &seqName, Document *doc, U2OpStatus &os) {
+void saveExportItems2Doc(const QList<ExportSequenceItem>& items, const QString& seqName, Document* doc, U2OpStatus& os) {
     QVariantMap hints;
     hints[DocumentFormat::DBI_FOLDER_HINT] = U2ObjectDbi::ROOT_FOLDER;
     QSet<QString> usedNames;
     int itemCount = 0;
     foreach (ExportSequenceItem ri, items) {
-        U2SequenceObject *seqObj = ri.ownsSeq() ? ri.takeOwnedSeq() : qobject_cast<U2SequenceObject *>(U2SequenceObject(ri.name, ri.seqRef).clone(doc->getDbiRef(), os, hints));
+        U2SequenceObject* seqObj = ri.ownsSeq() ? ri.takeOwnedSeq() : qobject_cast<U2SequenceObject*>(U2SequenceObject(ri.name, ri.seqRef).clone(doc->getDbiRef(), os, hints));
         CHECK_OP(os, );
         seqObj->moveToThread(doc->thread());
 
@@ -414,7 +413,7 @@ void saveExportItems2Doc(const QList<ExportSequenceItem> &items, const QString &
         bool annotationsSupported = doc->checkConstraints(c);
         if (annotationsSupported && !ri.annotations.isEmpty()) {
             const QString aName = ExportUtils::genUniqueName(usedNames, name + " annotations");
-            AnnotationTableObject *annObj = new AnnotationTableObject(aName, doc->getDbiRef());
+            AnnotationTableObject* annObj = new AnnotationTableObject(aName, doc->getDbiRef());
             usedNames.insert(aName);
             annObj->addAnnotations(ri.annotations);
             annObj->addObjectRelation(seqObj, ObjectRole_Sequence);
@@ -425,11 +424,11 @@ void saveExportItems2Doc(const QList<ExportSequenceItem> &items, const QString &
     }
 }
 
-QList<ExportSequenceItem> getTranslatedItems(QList<ExportSequenceItem> &items, bool allAminoFrames, bool mostProbableTranslation, const U2DbiRef &resDbiRef, U2OpStatus &os) {
+QList<ExportSequenceItem> getTranslatedItems(QList<ExportSequenceItem>& items, bool allAminoFrames, bool mostProbableTranslation, const U2DbiRef& resDbiRef, U2OpStatus& os) {
     // translate to amino or back-translate if needed
     QList<ExportSequenceItem> result;
     for (int i = 0, n = items.size(); i < n; ++i) {
-        ExportSequenceItem &ei = items[i];
+        ExportSequenceItem& ei = items[i];
         if (ei.aminoTT != nullptr) {
             result.append(toAmino(ei, allAminoFrames, resDbiRef, os));
         } else if (ei.backTT != nullptr) {
@@ -447,10 +446,10 @@ QList<ExportSequenceItem> getTranslatedItems(QList<ExportSequenceItem> &items, b
 void ExportSequenceTask::run() {
     GTIMER(cvar, tvar, "ExportSequenceTask");
 
-    DocumentFormat *format = AppContext::getDocumentFormatRegistry()->getFormatById(config.formatId);
-    SAFE_POINT(format != nullptr, L10N::nullPointerError("sequence document format"), );
-    IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(config.fileName));
-    SAFE_POINT(iof != nullptr, L10N::nullPointerError("I/O adapter factory"), );
+    DocumentFormat* format = AppContext::getDocumentFormatRegistry()->getFormatById(config.formatId);
+    SAFE_POINT_NN(format, );
+    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(IOAdapterUtils::url2io(config.fileName));
+    SAFE_POINT_NN(iof, );
     QScopedPointer<Document> exportedDocument(format->createNewLoadedDocument(iof, config.fileName, stateInfo));
     CHECK_OP(stateInfo, );
 
@@ -461,7 +460,7 @@ void ExportSequenceTask::run() {
 
     QList<ExportSequenceItem> notMergedItems;
     for (int i = 0, n = config.items.size(); i < n; ++i) {
-        ExportSequenceItem &ei0 = config.items[i];
+        ExportSequenceItem& ei0 = config.items[i];
 
         QList<ExportSequenceItem> r1Items;
         if (config.strand == TriState_Yes || config.strand == TriState_Unknown) {
@@ -501,7 +500,7 @@ void ExportSequenceTask::run() {
     resultDocument = format->loadDocument(iof, config.fileName, {}, stateInfo);
 }
 
-ExportSequenceItem ExportSequenceTask::mergedCircularItem(const ExportSequenceItem &first, const ExportSequenceItem &second, U2OpStatus &os) {
+ExportSequenceItem ExportSequenceTask::mergedCircularItem(const ExportSequenceItem& first, const ExportSequenceItem& second, U2OpStatus& os) {
     return mergeExportItems(QList<ExportSequenceItem>() << first << second, 0, os);
 }
 
@@ -512,14 +511,14 @@ ExportSequenceAItem::ExportSequenceAItem()
     : aminoTT(nullptr), complTT(nullptr) {
 }
 
-ExportAnnotationSequenceTask::ExportAnnotationSequenceTask(const ExportAnnotationSequenceTaskSettings &s)
+ExportAnnotationSequenceTask::ExportAnnotationSequenceTask(const ExportAnnotationSequenceTaskSettings& s)
     : DocumentProviderTask(tr("Export annotations"), TaskFlags_NR_FOSE_COSC), config(s), exportSubTask(nullptr) {
     extractSubTask = new ExportAnnotationSequenceSubTask(config);
     addSubTask(extractSubTask);
 }
 
-QList<Task *> ExportAnnotationSequenceTask::onSubTaskFinished(Task *subTask) {
-    QList<Task *> res;
+QList<Task*> ExportAnnotationSequenceTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> res;
     CHECK(!isCanceled(), res);
 
     if (subTask == extractSubTask && !extractSubTask->hasError()) {
@@ -532,15 +531,15 @@ QList<Task *> ExportAnnotationSequenceTask::onSubTaskFinished(Task *subTask) {
     return res;
 }
 
-ExportAnnotationSequenceSubTask::ExportAnnotationSequenceSubTask(ExportAnnotationSequenceTaskSettings &s)
+ExportAnnotationSequenceSubTask::ExportAnnotationSequenceSubTask(ExportAnnotationSequenceTaskSettings& s)
     : Task(tr("Extract annotation regions"), TaskFlag_None), config(s) {
 }
 
 namespace {
 
-int totalAnnotationCount(const ExportAnnotationSequenceTaskSettings &config) {
+int totalAnnotationCount(const ExportAnnotationSequenceTaskSettings& config) {
     int result = 0;
-    foreach (const ExportSequenceAItem &item, config.items) {
+    foreach (const ExportSequenceAItem& item, config.items) {
         result += item.annotations.length();
     }
     return result;
@@ -548,42 +547,45 @@ int totalAnnotationCount(const ExportAnnotationSequenceTaskSettings &config) {
 
 }  // namespace
 
-U2Sequence ExportAnnotationSequenceSubTask::importAnnotatedSeq2Dbi(const SharedAnnotationData &ad, const ExportSequenceAItem &ei, const U2DbiRef &resultDbiRef, QVector<U2Region> &resultRegions, U2OpStatus &os) {
+U2Sequence ExportAnnotationSequenceSubTask::importAnnotatedSeq2Dbi(const SharedAnnotationData& ad,
+                                                                   const ExportSequenceAItem& ei,
+                                                                   const U2DbiRef& resultDbiRef,
+                                                                   QVector<U2Region>& resultRegions,
+                                                                   U2OpStatus& os) {
     U2SequenceImporter importer(QVariantMap(), true);
+
+    bool isReverseComplement = ad->getStrand().isComplementary() && ei.complTT != nullptr;
+    importer.enableReverseComplement(isReverseComplement ? ei.complTT : nullptr);
+
+    importer.enableAminoTranslation(ei.aminoTT);
+
     importer.startSequence(os, resultDbiRef, U2ObjectDbi::ROOT_FOLDER, ad->name, false);
-    CHECK_OP(os, U2Sequence());
+    CHECK_OP(os, {});
 
-    foreach (const U2Region &annotatedRegion, ad->location->regions) {
+    QVector<U2Region> regions = ad->location->regions;
+    if (isReverseComplement) {
+        std::reverse(regions.begin(), regions.end());
+    }
+    for (const U2Region& region : qAsConst(regions)) {
         qint64 currentRegionLength = 0;
-        for (qint64 pos = annotatedRegion.startPos; pos < annotatedRegion.endPos(); pos += MAX_CHUNK_LENGTH) {
-            const qint64 currentChunkSize = qMin(MAX_CHUNK_LENGTH, annotatedRegion.endPos() - pos);
-            const U2Region chunkRegion(pos, currentChunkSize);
-            QByteArray chunkContent = ei.sequence->getSequenceData(chunkRegion, os);
-            CHECK_OP(os, U2Sequence());
-            if (chunkContent.isEmpty()) {
-                continue;
-            }
-
-            if (ad->getStrand().isCompementary() && nullptr != ei.complTT) {
-                TextUtils::reverse(chunkContent.data(), currentChunkSize);
-                ei.complTT->translate(chunkContent.data(), currentChunkSize);
-            }
-
-            if (nullptr != ei.aminoTT) {
-                int translationSize = currentChunkSize / 3;
-                QByteArray translation(translationSize, ei.aminoTT->getDstAlphabet()->getDefaultSymbol());
-                ei.aminoTT->translate(chunkContent.constData(), currentChunkSize, translation.data(), translationSize);
-                chunkContent = translation;
-            }
-
+        for (qint64 currentChunkOffset = 0; currentChunkOffset < region.length; currentChunkOffset += MAX_CHUNK_LENGTH) {
+            int currentChunkSize = (int)qMin(MAX_CHUNK_LENGTH, region.length - currentChunkOffset);
+            U2Region currentChunkRegion(isReverseComplement
+                                            ? region.endPos() - currentChunkOffset - currentChunkSize
+                                            : region.startPos + currentChunkOffset,
+                                        currentChunkSize);
+            QByteArray chunkContent = ei.sequence->getSequenceData(currentChunkRegion, os);
+            CHECK_OP(os, {});
             importer.addBlock(chunkContent.constData(), chunkContent.length(), os);
-            CHECK_OP(os, U2Sequence());
+            CHECK_OP(os, {});
             currentRegionLength += chunkContent.length();
         }
-        CHECK_EXT(currentRegionLength == annotatedRegion.length,
+        CHECK_EXT(currentRegionLength == region.length,
                   os.setError(tr("Sequences of the selected annotations can't be exported. At least one of the annotations is out of boundaries")),
-                  U2Sequence());
-        resultRegions.append(U2Region(resultRegions.isEmpty() ? 0 : resultRegions.last().endPos(), currentRegionLength));
+                  {});
+        qint64 resultRegionStart = resultRegions.isEmpty() ? 0 : resultRegions.last().endPos();
+        qint64 resultRegionLength = ei.aminoTT == nullptr ? currentRegionLength : currentRegionLength / 3;
+        resultRegions.append({resultRegionStart, resultRegionLength});
     }
     return importer.finalizeSequence(os);
 }
@@ -597,12 +599,12 @@ void ExportAnnotationSequenceSubTask::run() {
     const int allAnnotationSize = totalAnnotationCount(config);
     int annotationCount = 0;
     // extract sequences for every annotation & form ExportSequenceTaskSettings
-    foreach (const ExportSequenceAItem &ei, config.items) {
+    foreach (const ExportSequenceAItem& ei, config.items) {
         if (ei.sequence.isNull()) {
             coreLog.info(tr("Exported sequence has been deleted unexpectedly"));
             continue;
         }
-        foreach (const SharedAnnotationData &ad, ei.annotations) {
+        for (const SharedAnnotationData& ad : qAsConst(ei.annotations)) {
             QVector<U2Region> resultRegions;
             const U2Sequence annSeqDbiObject = importAnnotatedSeq2Dbi(ad, ei, dbiRef, resultRegions, stateInfo);
             CHECK_OP(stateInfo, );
