@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -29,6 +29,7 @@
 #include <U2Core/AnnotationTableObject.h>
 #include <U2Core/AppContext.h>
 #include <U2Core/BaseDocumentFormats.h>
+#include <U2Core/DBXRefRegistry.h>
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/DNASequenceSelection.h>
@@ -38,6 +39,7 @@
 #include <U2Core/GUrlUtils.h>
 #include <U2Core/L10n.h>
 #include <U2Core/LoadRemoteDocumentTask.h>
+#include <U2Core/MultiTask.h>
 #include <U2Core/QObjectScopedPointer.h>
 #include <U2Core/SelectionUtils.h>
 #include <U2Core/U2DbiRegistry.h>
@@ -70,22 +72,22 @@ namespace U2 {
 //////////////////////////////////////////////////////////////////////////
 // ExportSequenceViewItemsController
 
-ExportSequenceViewItemsController::ExportSequenceViewItemsController(QObject *p)
+ExportSequenceViewItemsController::ExportSequenceViewItemsController(QObject* p)
     : GObjectViewWindowContext(p, ANNOTATED_DNA_VIEW_FACTORY_ID),
       av(nullptr) {
 }
 
-void ExportSequenceViewItemsController::initViewContext(GObjectView *v) {
-    av = qobject_cast<AnnotatedDNAView *>(v);
-    ADVExportContext *vc = new ADVExportContext(av);
+void ExportSequenceViewItemsController::initViewContext(GObjectViewController* v) {
+    av = qobject_cast<AnnotatedDNAView*>(v);
+    ADVExportContext* vc = new ADVExportContext(av);
     addViewResource(av, vc);
 }
 
-void ExportSequenceViewItemsController::buildStaticOrContextMenu(GObjectView *v, QMenu *m) {
-    QList<QObject *> resources = viewResources.value(v);
+void ExportSequenceViewItemsController::buildStaticOrContextMenu(GObjectViewController* v, QMenu* m) {
+    QList<QObject*> resources = viewResources.value(v);
     assert(resources.size() == 1);
-    QObject *r = resources.first();
-    ADVExportContext *vc = qobject_cast<ADVExportContext *>(r);
+    QObject* r = resources.first();
+    ADVExportContext* vc = qobject_cast<ADVExportContext*>(r);
     assert(vc != nullptr);
     vc->buildMenu(m);
 }
@@ -93,8 +95,8 @@ void ExportSequenceViewItemsController::buildStaticOrContextMenu(GObjectView *v,
 void ExportSequenceViewItemsController::init() {
     GObjectViewWindowContext::init();
     if (!viewResources.value(av).isEmpty()) {
-        QMenu *actions = AppContext::getMainWindow()->getTopLevelMenu(MWMENU_ACTIONS);
-        SAFE_POINT(nullptr != actions, "Actions menu not found.", );
+        QMenu* actions = AppContext::getMainWindow()->getTopLevelMenu(MWMENU_ACTIONS);
+        SAFE_POINT(actions != nullptr, "Actions menu not found.", );
         actions->clear();
         AppContext::getMainWindow()->getMDIManager()->getActiveWindow()->setupViewMenu(actions);
     }
@@ -106,7 +108,7 @@ void ExportSequenceViewItemsController::init() {
 // TODO: define global BLAST text constants in CoreLibs
 #define BLAST_ANNOTATION_NAME "blast result"
 
-ADVExportContext::ADVExportContext(AnnotatedDNAView *v)
+ADVExportContext::ADVExportContext(AnnotatedDNAView* v)
     : view(v) {
     sequence2SequenceAction = new QAction(tr("Export selected sequence region..."), this);
     sequence2SequenceAction->setObjectName("action_export_selected_sequence_region");
@@ -148,35 +150,35 @@ ADVExportContext::ADVExportContext(AnnotatedDNAView *v)
     connect(blastResultToAlignmentAction, SIGNAL(triggered()), SLOT(sl_exportBlastResultToAlignment()));
 
     connect(view->getAnnotationsSelection(),
-            SIGNAL(si_selectionChanged(AnnotationSelection *, const QList<Annotation *> &, const QList<Annotation *> &)),
+            SIGNAL(si_selectionChanged(AnnotationSelection*, const QList<Annotation*>&, const QList<Annotation*>&)),
             SLOT(updateActions()));
 
     connect(view->getAnnotationsGroupSelection(),
-            SIGNAL(si_selectionChanged(AnnotationGroupSelection *, const QList<AnnotationGroup *> &, const QList<AnnotationGroup *> &)),
+            SIGNAL(si_selectionChanged(AnnotationGroupSelection*, const QList<AnnotationGroup*>&, const QList<AnnotationGroup*>&)),
             SLOT(updateActions()));
 
-    connect(view, SIGNAL(si_sequenceAdded(ADVSequenceObjectContext *)), SLOT(sl_onSequenceContextAdded(ADVSequenceObjectContext *)));
-    connect(view, SIGNAL(si_sequenceRemoved(ADVSequenceObjectContext *)), SLOT(sl_onSequenceContextRemoved(ADVSequenceObjectContext *)));
-    foreach (ADVSequenceObjectContext *sCtx, view->getSequenceContexts()) {
+    connect(view, SIGNAL(si_sequenceAdded(ADVSequenceObjectContext*)), SLOT(sl_onSequenceContextAdded(ADVSequenceObjectContext*)));
+    connect(view, SIGNAL(si_sequenceRemoved(ADVSequenceObjectContext*)), SLOT(sl_onSequenceContextRemoved(ADVSequenceObjectContext*)));
+    foreach (ADVSequenceObjectContext* sCtx, view->getSequenceContexts()) {
         sl_onSequenceContextAdded(sCtx);
     }
 }
 
-void ADVExportContext::sl_onSequenceContextAdded(ADVSequenceObjectContext *c) {
+void ADVExportContext::sl_onSequenceContextAdded(ADVSequenceObjectContext* c) {
     connect(c->getSequenceSelection(),
-            SIGNAL(si_selectionChanged(LRegionsSelection *, const QVector<U2Region> &, const QVector<U2Region> &)),
+            SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)),
             SLOT(updateActions()));
 
     updateActions();
 }
 
-void ADVExportContext::sl_onSequenceContextRemoved(ADVSequenceObjectContext *c) {
+void ADVExportContext::sl_onSequenceContextRemoved(ADVSequenceObjectContext* c) {
     c->getSequenceSelection()->disconnect(this);
     updateActions();
 }
 
-static bool allNucleic(const QList<ADVSequenceObjectContext *> &seqs) {
-    foreach (const ADVSequenceObjectContext *s, seqs) {
+static bool allNucleic(const QList<ADVSequenceObjectContext*>& seqs) {
+    foreach (const ADVSequenceObjectContext* s, seqs) {
         if (!s->getAlphabet()->isNucleic()) {
             return false;
         }
@@ -188,7 +190,7 @@ void ADVExportContext::updateActions() {
     bool hasSelectedAnnotations = !view->getAnnotationsSelection()->isEmpty();
     bool hasSelectedGroups = !view->getAnnotationsGroupSelection()->isEmpty();
     int nSequenceSelections = 0;
-    foreach (ADVSequenceObjectContext *c, view->getSequenceContexts()) {
+    foreach (ADVSequenceObjectContext* c, view->getSequenceContexts()) {
         nSequenceSelections += c->getSequenceSelection()->getSelectedRegions().count();
     }
 
@@ -207,15 +209,15 @@ void ADVExportContext::updateActions() {
     sequenceToAlignmentWithTranslationAction->setEnabled(hasMultiSequenceSelection && _allNucleic);
 }
 
-void ADVExportContext::buildMenu(QMenu *m) {
-    QMenu *alignMenu = GUIUtils::findSubMenu(m, ADV_MENU_ALIGN);
+void ADVExportContext::buildMenu(QMenu* m) {
+    QMenu* alignMenu = GUIUtils::findSubMenu(m, ADV_MENU_ALIGN);
     SAFE_POINT(alignMenu != nullptr, "alignMenu", );
     alignMenu->addAction(sequenceToAlignmentAction);
     alignMenu->addAction(sequenceToAlignmentWithTranslationAction);
     alignMenu->addAction(annotationsToAlignmentAction);
     alignMenu->addAction(annotationsToAlignmentWithTranslatedAction);
 
-    QMenu *exportMenu = GUIUtils::findSubMenu(m, ADV_MENU_EXPORT);
+    QMenu* exportMenu = GUIUtils::findSubMenu(m, ADV_MENU_EXPORT);
     SAFE_POINT(exportMenu != nullptr, "exportMenu", );
     exportMenu->addAction(sequence2SequenceAction);
     exportMenu->addAction(annotations2SequenceAction);
@@ -230,7 +232,7 @@ void ADVExportContext::buildMenu(QMenu *m) {
     if (!view->getAnnotationsSelection()->getAnnotations().isEmpty()) {
         name = view->getAnnotationsSelection()->getAnnotations().first()->getName();
     }
-    foreach (const Annotation *annotation, view->getAnnotationsSelection()->getAnnotations()) {
+    foreach (const Annotation* annotation, view->getAnnotationsSelection()->getAnnotations()) {
         if (name != annotation->getName()) {
             name = "";
         }
@@ -248,7 +250,7 @@ void ADVExportContext::buildMenu(QMenu *m) {
 
     if (isShowId || isShowAccession || isShowDBXref) {
         name = name.isEmpty() ? "" : tr("from '") + name + "'";
-        QMenu *fetchMenu = new QMenu(tr("Fetch sequences from remote database"));
+        QMenu* fetchMenu = new QMenu(tr("Fetch sequences from remote database"));
         m->insertMenu(exportMenu->menuAction(), fetchMenu);
         if (isShowId) {
             sequenceById->setText(tr("Fetch sequences by 'id' %1").arg(name));
@@ -269,12 +271,12 @@ void ADVExportContext::buildMenu(QMenu *m) {
 }
 
 void ADVExportContext::sl_saveSelectedAnnotationsSequence() {
-    AnnotationSelection *as = view->getAnnotationsSelection();
-    AnnotationGroupSelection *ags = view->getAnnotationsGroupSelection();
+    AnnotationSelection* as = view->getAnnotationsSelection();
+    AnnotationGroupSelection* ags = view->getAnnotationsGroupSelection();
 
-    QList<Annotation *> annotations = as->getAnnotations();
-    const QList<AnnotationGroup *> groups = ags->getSelection();
-    foreach (AnnotationGroup *g, groups) {
+    QList<Annotation*> annotations = as->getAnnotations();
+    const QList<AnnotationGroup*> groups = ags->getSelection();
+    foreach (AnnotationGroup* g, groups) {
         g->findAllAnnotationsInGroupSubTree(annotations);
     }
 
@@ -287,19 +289,19 @@ void ADVExportContext::sl_saveSelectedAnnotationsSequence() {
     bool allowTranslation = true;
     bool allowBackTranslation = true;
 
-    QMap<const ADVSequenceObjectContext *, QList<SharedAnnotationData>> annotationsPerSeq;
-    foreach (Annotation *a, annotations) {
-        ADVSequenceObjectContext *seqCtx = view->getSequenceContext(a->getGObject());
+    QMap<const ADVSequenceObjectContext*, QList<SharedAnnotationData>> annotationsPerSeq;
+    foreach (Annotation* a, annotations) {
+        ADVSequenceObjectContext* seqCtx = view->getSequenceContext(a->getGObject());
         if (seqCtx == nullptr) {
             continue;
         }
 
-        QList<SharedAnnotationData> &annsPerSeq = annotationsPerSeq[seqCtx];
+        QList<SharedAnnotationData>& annsPerSeq = annotationsPerSeq[seqCtx];
         annsPerSeq.append(a->getData());
         if (annsPerSeq.size() > 1) {
             continue;
         }
-        U2SequenceObject *seqObj = seqCtx->getSequenceObject();
+        U2SequenceObject* seqObj = seqCtx->getSequenceObject();
         if (GObjectUtils::findComplementTT(seqObj->getAlphabet()) == nullptr) {
             allowComplement = false;
         }
@@ -327,7 +329,7 @@ void ADVExportContext::sl_saveSelectedAnnotationsSequence() {
                                                                               fileBaseName,
                                                                               BaseDocumentFormats::FASTA,
                                                                               AppContext::getMainWindow()->getQMainWindow());
-    d->setWindowTitle("Export Sequence of Selected Annotations");
+    d->setWindowTitle(tr("Export Sequence of Selected Annotations"));
     d->disableAllFramesOption(true);  // only 1 frame is suitable
     d->disableStrandOption(true);  // strand is already recorded in annotation
     d->disableAnnotationsOption(true);  // here we do not export annotations for sequence under another annotations
@@ -341,25 +343,25 @@ void ADVExportContext::sl_saveSelectedAnnotationsSequence() {
 
     ExportAnnotationSequenceTaskSettings s;
     ExportUtils::loadDNAExportSettingsFromDlg(s.exportSequenceSettings, d.data());
-    foreach (const ADVSequenceObjectContext *seqCtx, annotationsPerSeq.keys()) {
+    foreach (const ADVSequenceObjectContext* seqCtx, annotationsPerSeq.keys()) {
         ExportSequenceAItem ei;
         ei.sequence = seqCtx->getSequenceObject();
         ei.complTT = seqCtx->getComplementTT();
         ei.aminoTT = d->translate ? seqCtx->getAminoTT() : nullptr;
         if (d->useSpecificTable && ei.sequence->getAlphabet()->isNucleic()) {
-            DNATranslationRegistry *tr = AppContext::getDNATranslationRegistry();
+            DNATranslationRegistry* tr = AppContext::getDNATranslationRegistry();
             ei.aminoTT = tr->lookupTranslation(ei.sequence->getAlphabet(), DNATranslationType_NUCL_2_AMINO, d->translationTable);
         }
         ei.annotations = annotationsPerSeq.value(seqCtx);
         s.items.append(ei);
     }
-    Task *t = ExportUtils::wrapExportTask(new ExportAnnotationSequenceTask(s), d->addToProject);
+    Task* t = ExportUtils::wrapExportTask(new ExportAnnotationSequenceTask(s), d->addToProject);
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
 void ADVExportContext::sl_saveSelectedSequences() {
-    ADVSequenceObjectContext *seqCtx = view->getActiveSequenceContext();
-    DNASequenceSelection *sel = nullptr;
+    ADVSequenceObjectContext* seqCtx = view->getActiveSequenceContext();
+    DNASequenceSelection* sel = nullptr;
     if (seqCtx != nullptr) {
         // TODO: support multi-export..
         sel = seqCtx->getSequenceSelection();
@@ -369,7 +371,7 @@ void ADVExportContext::sl_saveSelectedSequences() {
         return;
     }
 
-    const QVector<U2Region> &regions = sel->getSelectedRegions();
+    const QVector<U2Region>& regions = sel->getSelectedRegions();
     bool merge = regions.size() > 1;
     bool complement = seqCtx->getComplementTT() != nullptr;
     bool amino = seqCtx->getAminoTT() != nullptr;
@@ -391,7 +393,7 @@ void ADVExportContext::sl_saveSelectedSequences() {
                                                                               fileBaseName,
                                                                               BaseDocumentFormats::FASTA,
                                                                               AppContext::getMainWindow()->getQMainWindow());
-    d->setWindowTitle("Export Selected Sequence Region");
+    d->setWindowTitle(tr("Export Selected Sequence Region"));
     const int rc = d->exec();
     CHECK(!d.isNull(), );
     CHECK(rc != QDialog::Rejected, );
@@ -400,21 +402,21 @@ void ADVExportContext::sl_saveSelectedSequences() {
     ExportSequenceTaskSettings s;
     ExportUtils::loadDNAExportSettingsFromDlg(s, d.data());
 
-    const DNATranslation *aminoTrans = nullptr;
+    const DNATranslation* aminoTrans = nullptr;
     if (d->translate) {
         aminoTrans = d->useSpecificTable ? GObjectUtils::findAminoTT(seqCtx->getSequenceObject(), false, d->translationTable) : seqCtx->getAminoTT();
     }
-    const DNATranslation *backTrans = d->backTranslate ? GObjectUtils::findBackTranslationTT(seqCtx->getSequenceObject(), d->translationTable) : nullptr;
-    const DNATranslation *complTrans = seqCtx->getComplementTT();
-    Task *t = ExportUtils::wrapExportTask(new ExportSelectedSeqRegionsTask(seqCtx->getSequenceObject(), seqCtx->getAnnotationObjects(true), regions, s, aminoTrans, backTrans, complTrans), d->addToProject);
+    const DNATranslation* backTrans = d->backTranslate ? GObjectUtils::findBackTranslationTT(seqCtx->getSequenceObject(), d->translationTable) : nullptr;
+    const DNATranslation* complTrans = seqCtx->getComplementTT();
+    Task* t = ExportUtils::wrapExportTask(new ExportSelectedSeqRegionsTask(seqCtx->getSequenceObject(), seqCtx->getAnnotationObjects(true), regions, s, aminoTrans, backTrans, complTrans), d->addToProject);
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
 void ADVExportContext::sl_saveSelectedAnnotations() {
     // find annotations: selected annotations, selected groups
-    AnnotationSelection *as = view->getAnnotationsSelection();
-    QList<Annotation *> annotationSet = as->getAnnotations();
-    foreach (AnnotationGroup *group, view->getAnnotationsGroupSelection()->getSelection()) {
+    AnnotationSelection* as = view->getAnnotationsSelection();
+    QList<Annotation*> annotationSet = as->getAnnotations();
+    foreach (AnnotationGroup* group, view->getAnnotationsGroupSelection()->getSelection()) {
         group->findAllAnnotationsInGroupSubTree(annotationSet);
     }
 
@@ -423,9 +425,9 @@ void ADVExportContext::sl_saveSelectedAnnotations() {
         return;
     }
 
-    Annotation *first = *annotationSet.begin();
-    Document *doc = first->getGObject()->getDocument();
-    ADVSequenceObjectContext *sequenceContext = view->getActiveSequenceContext();
+    Annotation* first = *annotationSet.begin();
+    Document* doc = first->getGObject()->getDocument();
+    ADVSequenceObjectContext* sequenceContext = view->getActiveSequenceContext();
 
     GUrl url;
     if (doc != nullptr) {
@@ -449,7 +451,7 @@ void ADVExportContext::sl_saveSelectedAnnotations() {
     std::stable_sort(annotationSet.begin(), annotationSet.end(), Annotation::annotationLessThan);
 
     // run task
-    Task *t = nullptr;
+    Task* t = nullptr;
     if (d->fileFormat() == ExportAnnotationsDialog::CSV_FORMAT_ID) {
         U2OpStatusImpl os;
         QByteArray seqData = sequenceContext->getSequenceObject()->getWholeSequenceData(os);
@@ -466,22 +468,22 @@ void ADVExportContext::sl_saveSelectedAnnotations() {
 
 #define MAX_ALI_MODEL (10 * 1000 * 1000)
 
-void ADVExportContext::prepareMAFromBlastAnnotations(MultipleSequenceAlignment &ma, const QString &qualiferId, bool includeRef, U2OpStatus &os) {
+void ADVExportContext::prepareMAFromBlastAnnotations(MultipleSequenceAlignment& ma, const QString& qualiferId, bool includeRef, U2OpStatus& os) {
     SAFE_POINT_EXT(ma->isEmpty(), os.setError(tr("Illegal parameter: input alignment is not empty!")), );
-    const QList<Annotation *> &selection = view->getAnnotationsSelection()->getAnnotations();
+    const QList<Annotation*>& selection = view->getAnnotationsSelection()->getAnnotations();
     CHECK_EXT(selection.size() >= 2, os.setError(tr("At least 2 annotations are required")), );
 
-    AnnotationTableObject *ao = selection.first()->getGObject();
-    ADVSequenceObjectContext *commonSeq = view->getSequenceContext(ao);
+    AnnotationTableObject* ao = selection.first()->getGObject();
+    ADVSequenceObjectContext* commonSeq = view->getSequenceContext(ao);
     qint64 maxLen = commonSeq->getSequenceLength();
     ma->setAlphabet(commonSeq->getAlphabet());
     QSet<QString> names;
     int rowIdx = 0;
 
-    for (const Annotation *annotation : qAsConst(selection)) {
+    for (const Annotation* annotation : qAsConst(selection)) {
         SAFE_POINT(annotation->getName() == BLAST_ANNOTATION_NAME, tr("%1 is not a BLAST annotation").arg(annotation->getName()), );
 
-        ADVSequenceObjectContext *seqCtx = view->getSequenceContext(annotation->getGObject());
+        ADVSequenceObjectContext* seqCtx = view->getSequenceContext(annotation->getGObject());
         CHECK_EXT(seqCtx != nullptr, os.setError(tr("No sequence object found")), );
         CHECK_EXT(seqCtx == commonSeq, os.setError(tr("Can not export BLAST annotations from different sequences")), );
 
@@ -492,14 +494,13 @@ void ADVExportContext::prepareMAFromBlastAnnotations(MultipleSequenceAlignment &
         U2EntityRef seqRef = seqCtx->getSequenceObject()->getSequenceRef();
 
         maxLen = qMax(maxLen, annotation->getRegionsLen());
-        CHECK_EXT(maxLen * ma->getNumRows() <= MAX_ALI_MODEL, os.setError(tr("Alignment is too large")), );
+        CHECK_EXT(maxLen * ma->getRowCount() <= MAX_ALI_MODEL, os.setError(tr("Alignment is too large")), );
 
-        QByteArray rowSequence;
         QString subjSeq = annotation->findFirstQualifierValue("subj_seq");
         if (!subjSeq.isEmpty()) {
             ma->addRow(rowName, subjSeq.toLatin1());
         } else {
-            AnnotationSelection::getSequenceInRegions(rowSequence, annotation->getRegions(), U2Msa::GAP_CHAR, seqRef, nullptr, nullptr, os);
+            QByteArray rowSequence = AnnotationSelection::getSequenceUnderAnnotation(seqRef, annotation, nullptr, nullptr, os);
             CHECK_OP(os, );
             ma->addRow(rowName, rowSequence);
         }
@@ -519,21 +520,21 @@ void ADVExportContext::prepareMAFromBlastAnnotations(MultipleSequenceAlignment &
     }
 }
 
-void ADVExportContext::prepareMAFromAnnotations(MultipleSequenceAlignment &ma, bool translate, U2OpStatus &os) {
+void ADVExportContext::prepareMAFromAnnotations(MultipleSequenceAlignment& ma, bool translate, U2OpStatus& os) {
     SAFE_POINT_EXT(ma->isEmpty(), os.setError(tr("Illegal parameter: input alignment is not empty!")), );
-    const QList<Annotation *> &selection = view->getAnnotationsSelection()->getAnnotations();
+    const QList<Annotation*>& selection = view->getAnnotationsSelection()->getAnnotations();
     CHECK_EXT(selection.size() >= 2, os.setError(tr("At least 2 annotations are required")), );
 
     // check that all sequences are present and have the same alphabets
-    const DNAAlphabet *al = nullptr;
-    foreach (const Annotation *annotation, selection) {
-        AnnotationTableObject *ao = annotation->getGObject();
-        ADVSequenceObjectContext *seqCtx = view->getSequenceContext(ao);
+    const DNAAlphabet* al = nullptr;
+    foreach (const Annotation* annotation, selection) {
+        AnnotationTableObject* ao = annotation->getGObject();
+        ADVSequenceObjectContext* seqCtx = view->getSequenceContext(ao);
         CHECK_EXT(seqCtx != nullptr, os.setError(tr("No sequence object found")), );
         if (al == nullptr) {
             al = seqCtx->getAlphabet();
         } else {
-            const DNAAlphabet *al2 = seqCtx->getAlphabet();
+            const DNAAlphabet* al2 = seqCtx->getAlphabet();
             // BUG524: support alphabet reduction
             CHECK_EXT(al->getType() == al2->getType(), os.setError(tr("Different sequence alphabets")), );
             al = al->getMap().count(true) >= al2->getMap().count(true) ? al : al2;
@@ -542,18 +543,17 @@ void ADVExportContext::prepareMAFromAnnotations(MultipleSequenceAlignment &ma, b
     qint64 maxLen = 0;
     ma->setAlphabet(al);
     QSet<QString> names;
-    foreach (const Annotation *annotation, selection) {
+    foreach (const Annotation* annotation, selection) {
         QString rowName = annotation->getName();
-        AnnotationTableObject *ao = annotation->getGObject();
-        ADVSequenceObjectContext *seqCtx = view->getSequenceContext(ao);
+        AnnotationTableObject* ao = annotation->getGObject();
+        ADVSequenceObjectContext* seqCtx = view->getSequenceContext(ao);
         U2EntityRef seqRef = seqCtx->getSequenceObject()->getSequenceRef();
 
         maxLen = qMax(maxLen, annotation->getRegionsLen());
-        CHECK_EXT(maxLen * ma->getNumRows() <= MAX_ALI_MODEL, os.setError(tr("Alignment is too large")), );
-        const DNATranslation *complTT = annotation->getStrand().isCompementary() ? seqCtx->getComplementTT() : nullptr;
-        const DNATranslation *aminoTT = translate ? seqCtx->getAminoTT() : nullptr;
-        QByteArray rowSequence;
-        AnnotationSelection::getSequenceInRegions(rowSequence, annotation->getRegions(), U2Msa::GAP_CHAR, seqRef, complTT, aminoTT, os);
+        CHECK_EXT(maxLen * ma->getRowCount() <= MAX_ALI_MODEL, os.setError(tr("Alignment is too large")), );
+        const DNATranslation* complTT = annotation->getStrand().isComplementary() ? seqCtx->getComplementTT() : nullptr;
+        const DNATranslation* aminoTT = translate ? seqCtx->getAminoTT() : nullptr;
+        QByteArray rowSequence = AnnotationSelection::getSequenceUnderAnnotation(seqRef, annotation, complTT, aminoTT, os);
         CHECK_OP(os, );
 
         ma->addRow(rowName, rowSequence);
@@ -562,20 +562,20 @@ void ADVExportContext::prepareMAFromAnnotations(MultipleSequenceAlignment &ma, b
     }
 }
 
-void ADVExportContext::prepareMAFromSequences(MultipleSequenceAlignment &ma, bool translate, U2OpStatus &os) {
+void ADVExportContext::prepareMAFromSequences(MultipleSequenceAlignment& ma, bool translate, U2OpStatus& os) {
     SAFE_POINT_EXT(ma->isEmpty(), os.setError(tr("Illegal parameter: Input alignment is not empty!")), );
 
-    const DNAAlphabet *al = translate ? AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::AMINO_DEFAULT()) : nullptr;
+    const DNAAlphabet* al = translate ? AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::AMINO_DEFAULT()) : nullptr;
 
     // derive alphabet
     int nItems = 0;
     bool forceTranslation = false;
-    foreach (ADVSequenceObjectContext *c, view->getSequenceContexts()) {
+    foreach (ADVSequenceObjectContext* c, view->getSequenceContexts()) {
         if (c->getSequenceSelection()->isEmpty()) {
             continue;
         }
         nItems += c->getSequenceSelection()->getSelectedRegions().count();
-        const DNAAlphabet *seqAl = c->getAlphabet();
+        const DNAAlphabet* seqAl = c->getAlphabet();
         if (al == nullptr) {
             al = seqAl;
         } else if (al != seqAl) {
@@ -597,15 +597,16 @@ void ADVExportContext::prepareMAFromSequences(MultipleSequenceAlignment &ma, boo
     // cache sequences
     QSet<QString> names;
     qint64 maxLen = 0;
-    foreach (ADVSequenceObjectContext *seqCtx, view->getSequenceContexts()) {
+    foreach (ADVSequenceObjectContext* seqCtx, view->getSequenceContexts()) {
         if (seqCtx->getSequenceSelection()->isEmpty()) {
             continue;
         }
-        const DNAAlphabet *seqAl = seqCtx->getAlphabet();
-        DNATranslation *aminoTT = ((translate || forceTranslation) && seqAl->isNucleic()) ? seqCtx->getAminoTT() : nullptr;
-        foreach (const U2Region &r, seqCtx->getSequenceSelection()->getSelectedRegions()) {
+        const DNAAlphabet* seqAl = seqCtx->getAlphabet();
+        DNATranslation* aminoTT = ((translate || forceTranslation) && seqAl->isNucleic()) ? seqCtx->getAminoTT() : nullptr;
+        QVector<U2Region> regions = seqCtx->getSequenceSelection()->getSelectedRegions();
+        for (const U2Region& r : qAsConst(regions)) {
             maxLen = qMax(maxLen, r.length);
-            CHECK_EXT(maxLen * ma->getNumRows() <= MAX_ALI_MODEL, os.setError(tr("Alignment is too large")), );
+            CHECK_EXT(maxLen * ma->getRowCount() <= MAX_ALI_MODEL, os.setError(tr("Alignment is too large")), );
             QByteArray seq = seqCtx->getSequenceData(r, os);
             CHECK_OP(os, );
             if (aminoTT != nullptr) {
@@ -619,7 +620,7 @@ void ADVExportContext::prepareMAFromSequences(MultipleSequenceAlignment &ma, boo
     }
 }
 
-void ADVExportContext::selectionToAlignment(const QString &title, bool annotations, bool translate) {
+void ADVExportContext::selectionToAlignment(const QString& title, bool annotations, bool translate) {
     MultipleSequenceAlignment ma(MA_OBJECT_NAME);
     U2OpStatusImpl os;
     if (annotations) {
@@ -646,10 +647,22 @@ void ADVExportContext::selectionToAlignment(const QString &title, bool annotatio
     if (rc != QDialog::Accepted) {
         return;
     }
-    Task *t = ExportUtils::wrapExportTask(new ExportAlignmentTask(ma, d->url, d->format), d->addToProjectFlag);
+    Task* t = ExportUtils::wrapExportTask(new ExportAlignmentTask(ma, d->url, d->format), d->addToProjectFlag);
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
+QString ADVExportContext::getDbByCurrentAlphabet() const {
+    const DNAAlphabet* seqAl = view->getSequenceObjectsWithContexts().first()->getAlphabet();
+    QString db;
+    if (seqAl->getId() == BaseDNAAlphabetIds::NUCL_DNA_DEFAULT()) {
+        db = "NCBI GenBank (DNA sequence)";
+    } else if (seqAl->getId() == BaseDNAAlphabetIds::AMINO_DEFAULT()) {
+        db = "NCBI rotein sequence database";
+    }
+
+    return db;
+}
+
 void ADVExportContext::sl_saveSelectedAnnotationsToAlignment() {
     selectionToAlignment(annotationsToAlignmentAction->text(), true, false);
 }
@@ -667,75 +680,92 @@ void ADVExportContext::sl_saveSelectedSequenceToAlignmentWithTranslation() {
 }
 
 void ADVExportContext::sl_getSequenceByDBXref() {
-    const QList<Annotation *> &selection = view->getAnnotationsSelection()->getAnnotations();
+    const QList<Annotation*>& selection = view->getAnnotationsSelection()->getAnnotations();
+    auto dbEntries = AppContext::getDBXRefRegistry()->getEntries();
+    QMap<QString, QStringList> databaseAccessionsMap;
+    for (const Annotation* ann : qAsConst(selection)) {
+        QList<U2Qualifier> res;
+        ann->findQualifiers("db_xref", res);
+        for (const auto& qual : qAsConst(res)) {
+            auto value = qual.value.split(":");
+            CHECK_CONTINUE(value.size() == 2);
 
-    QStringList genbankID;
-    foreach (const Annotation *ann, selection) {
-        const QString tmp = ann->findFirstQualifierValue("db_xref");
-        if (!tmp.isEmpty()) {
-            genbankID << tmp.split(":").last();
+            auto database = value.first();
+            CHECK_CONTINUE(dbEntries.contains(database));
+            CHECK_CONTINUE(!dbEntries.value(database).fileUrl.isEmpty());
+
+            auto accession = value.last();
+            auto dbAccessions = databaseAccessionsMap.value(database);
+            dbAccessions.append(accession);
+            databaseAccessionsMap.insert(database, dbAccessions);
         }
     }
-    QString listId = genbankID.join(",");
-    fetchSequencesFromRemoteDB(listId);
+
+    fetchSequencesFromRemoteDB(databaseAccessionsMap);
 }
 
 void ADVExportContext::sl_getSequenceByAccession() {
-    const QList<Annotation *> &selection = view->getAnnotationsSelection()->getAnnotations();
+    const QList<Annotation*>& selection = view->getAnnotationsSelection()->getAnnotations();
 
     QStringList genbankID;
-    foreach (const Annotation *ann, selection) {
-        const QString tmp = ann->findFirstQualifierValue("accession");
-        if (!tmp.isEmpty()) {
-            genbankID << tmp;
+    for (const Annotation* ann : qAsConst(selection)) {
+        QList<U2Qualifier> res;
+        ann->findQualifiers("accession", res);
+        for (const auto& qual : qAsConst(res)) {
+            genbankID << qual.value;
         }
     }
-    QString listId = genbankID.join(",");
-    fetchSequencesFromRemoteDB(listId);
+    auto db = getDbByCurrentAlphabet();
+    CHECK(!db.isEmpty(), )
+
+    fetchSequencesFromRemoteDB({ {db, genbankID} });
 }
 
 void ADVExportContext::sl_getSequenceById() {
-    const QList<Annotation *> &selection = view->getAnnotationsSelection()->getAnnotations();
+    const QList<Annotation*>& selection = view->getAnnotationsSelection()->getAnnotations();
 
     QStringList genbankID;
-    foreach (const Annotation *ann, selection) {
-        const QString tmp = ann->findFirstQualifierValue("id");
-        if (!tmp.isEmpty()) {
-            int off = tmp.indexOf("|");
-            int off1 = tmp.indexOf("|", off + 1);
-            genbankID << tmp.mid(off + 1, off1 - off - 1);
+    for (const Annotation* ann : qAsConst(selection)) {
+        QList<U2Qualifier> res;
+        ann->findQualifiers("id", res);
+        for (const auto& qual : qAsConst(res)) {
+            if (!qual.value.isEmpty()) {
+                int off = qual.value.indexOf("|");
+                int off1 = qual.value.indexOf("|", off + 1);
+                genbankID << qual.value.mid(off + 1, off1 - off - 1);
+            }
         }
     }
-    QString listId = genbankID.join(",");
-    fetchSequencesFromRemoteDB(listId);
+    auto db = getDbByCurrentAlphabet();
+    CHECK(!db.isEmpty(), )
+
+    fetchSequencesFromRemoteDB({ {db, genbankID} });
 }
 
-void ADVExportContext::fetchSequencesFromRemoteDB(const QString &listId) {
-    const DNAAlphabet *seqAl = view->getSequenceObjectsWithContexts().first()->getAlphabet();
-
-    QString db;
-    if (seqAl->getId() == BaseDNAAlphabetIds::NUCL_DNA_DEFAULT()) {
-        db = "NCBI GenBank (DNA sequence)";
-    } else if (seqAl->getId() == BaseDNAAlphabetIds::AMINO_DEFAULT()) {
-        db = "NCBI protein sequence database";
-    } else {
-        return;
-    }
-
+void ADVExportContext::fetchSequencesFromRemoteDB(const QMap<QString, QStringList>& databaseAccessionsMap) {
     QObjectScopedPointer<GetSequenceByIdDialog> dlg = new GetSequenceByIdDialog(view->getWidget());
     dlg->exec();
     CHECK(!dlg.isNull(), );
+    CHECK(dlg->result() == QDialog::Accepted, );
 
-    if (dlg->result() == QDialog::Accepted) {
-        QString dir = dlg->getDirectory();
-        Task *t;
-        if (dlg->isAddToProject()) {
-            t = new LoadRemoteDocumentAndAddToProjectTask(listId, db, dir);
-        } else {
-            t = new LoadRemoteDocumentTask(listId, db, dir);
+    bool addToProject = dlg->isAddToProject();
+    QString dir = dlg->getDirectory();
+    auto databases = databaseAccessionsMap.keys();
+    QList<Task*> tasks;
+    for (const auto& database : qAsConst(databases)) {
+        const auto& accessions = databaseAccessionsMap.value(database);
+        for (const auto& acc : qAsConst(accessions)) {
+            if (addToProject) {
+                tasks << new LoadRemoteDocumentAndAddToProjectTask(acc, database, dir);
+            } else {
+                tasks << new LoadRemoteDocumentTask(acc, database, dir);
+            }
         }
-        AppContext::getTaskScheduler()->registerTopLevelTask(t);
     }
+
+    TaskFlags flags = TaskFlag_NoRun | TaskFlag_ReportingIsSupported | TaskFlag_ReportingIsEnabled;
+    Task* topLevelTask = new MultiTask(tr("Download remote documents by qualifiers"), tasks, false, flags);
+    AppContext::getTaskScheduler()->registerTopLevelTask(topLevelTask);
 }
 
 void ADVExportContext::sl_exportBlastResultToAlignment() {
@@ -753,14 +783,14 @@ void ADVExportContext::sl_exportBlastResultToAlignment() {
     MultipleSequenceAlignment ma(MA_OBJECT_NAME);
     U2OpStatusImpl os;
 
-    prepareMAFromBlastAnnotations(ma, d->qualiferId, d->addRefFlag, os);
+    prepareMAFromBlastAnnotations(ma, d->qualifierId, d->addRefFlag, os);
 
     if (os.hasError()) {
         QMessageBox::critical(nullptr, L10N::errorTitle(), os.getError());
         return;
     }
 
-    Task *t = ExportUtils::wrapExportTask(new ExportAlignmentTask(ma, d->url, d->format), d->addToProjectFlag);
+    Task* t = ExportUtils::wrapExportTask(new ExportAlignmentTask(ma, d->url, d->format), d->addToProjectFlag);
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
