@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,15 +19,14 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_SEQUENCES_DIALOG_H_
-#define _U2_EXPORT_SEQUENCES_DIALOG_H_
-
-#include <ui_ExportSequencesDialog.h>
+#pragma once
 
 #include <QDialog>
 
 #include <U2Core/global.h>
 
+#include <ui_ExportSequencesDialog.h>
+
 namespace U2 {
 
 class SaveDocumentController;
@@ -35,7 +34,7 @@ class SaveDocumentController;
 class ExportSequencesDialog : public QDialog, Ui_ExportSequencesDialog {
     Q_OBJECT
 public:
-    ExportSequencesDialog(bool multiMode, bool allowComplement, bool allowTranslation, bool allowBackTranslation, const QString &defaultFileName, const QString &sourceFileBaseName, const DocumentFormatId &f, QWidget *p);
+    ExportSequencesDialog(bool multiMode, bool allowComplement, bool allowTranslation, bool allowBackTranslation, const QString& defaultFileName, const QString& sourceFileBaseName, const DocumentFormatId& f, QWidget* p);
 
     void updateModel();
     bool multiMode;
@@ -65,16 +64,14 @@ public:
 private slots:
     void sl_exportClicked();
     void sl_translationTableEnabler();
-    void sl_formatChanged(const QString &newFormatId);
+    void sl_formatChanged(const QString& newFormatId);
 
 private:
-    void initSaveController(const DocumentFormatId &defaultFormatId);
+    void initSaveController(const DocumentFormatId& defaultFormatId);
 
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
     const QString defaultFileName;
     QList<QString> tableID;
 };
 
 }  // namespace U2
-
-#endif
