@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_UTILS_H_
-#define _U2_EXPORT_UTILS_H_
+#pragma once
 
 #include <QObject>
 
@@ -39,16 +38,14 @@ class Task;
 class ExportUtils : public QObject {
     Q_OBJECT
 public:
-    static void loadDNAExportSettingsFromDlg(ExportSequenceTaskSettings &s, U2::ExportSequencesDialog *d);
+    static void loadDNAExportSettingsFromDlg(ExportSequenceTaskSettings& s, U2::ExportSequencesDialog* d);
 
-    static Task *wrapExportTask(DocumentProviderTask *t, bool addToProject);
+    static Task* wrapExportTask(DocumentProviderTask* t, bool addToProject);
 
     // generates unique name using prefix + numbers
-    static QString genUniqueName(const QSet<QString> &names, QString prefix);
+    static QString genUniqueName(const QSet<QString>& names, QString prefix);
 
-    static void launchExportMca2MsaTask(MultipleChromatogramAlignmentObject *mcaObject);
+    static void launchExportMca2MsaTask(MultipleChromatogramAlignmentObject* mcaObject);
 };
 
 }  // namespace U2
-
-#endif
