@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GENERATE_DNA_WORKER_H_
-#define _U2_GENERATE_DNA_WORKER_H_
+#pragma once
 
 #include <U2Lang/LocalDomain.h>
 #include <U2Lang/WorkflowUtils.h>
@@ -31,7 +30,7 @@ namespace LocalWorkflow {
 class GenerateDNAPrompter : public PrompterBase<GenerateDNAPrompter> {
     Q_OBJECT
 public:
-    GenerateDNAPrompter(Actor *p = 0)
+    GenerateDNAPrompter(Actor* p = 0)
         : PrompterBase<GenerateDNAPrompter>(p) {
     }
 
@@ -42,20 +41,20 @@ protected:
 class GenerateDNAWorker : public BaseWorker {
     Q_OBJECT
 public:
-    GenerateDNAWorker(Actor *a)
+    GenerateDNAWorker(Actor* a)
         : BaseWorker(a), ch(nullptr) {
     }
 
     virtual void init();
-    virtual Task *tick();
+    virtual Task* tick();
     virtual void cleanup() {
     }
 
 private slots:
-    void sl_taskFinished(Task *);
+    void sl_taskFinished(Task*);
 
 private:
-    CommunicationChannel *ch;
+    CommunicationChannel* ch;
 };
 
 class GenerateDNAWorkerFactory : public DomainFactory {
@@ -65,12 +64,10 @@ public:
     GenerateDNAWorkerFactory()
         : DomainFactory(ACTOR_ID) {
     }
-    virtual Worker *createWorker(Actor *a) {
+    virtual Worker* createWorker(Actor* a) {
         return new GenerateDNAWorker(a);
     }
 };
 
 }  // namespace LocalWorkflow
 }  // namespace U2
-
-#endif
