@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_IMPORT_ANNOTATIONS_FROM_CSV_TASK_H_
-#define _U2_IMPORT_ANNOTATIONS_FROM_CSV_TASK_H_
+#pragma once
 
 #include <QMap>
 #include <QPointer>
@@ -73,26 +72,26 @@ class Document;
 class ImportAnnotationsFromCSVTask : public Task {
     Q_OBJECT
 public:
-    ImportAnnotationsFromCSVTask(ImportAnnotationsFromCSVTaskConfig &config);
+    ImportAnnotationsFromCSVTask(ImportAnnotationsFromCSVTaskConfig& config);
 
-    QList<Task *> onSubTaskFinished(Task *subTask);
+    QList<Task*> onSubTaskFinished(Task* subTask);
 
 private:
     QMap<QString, QList<SharedAnnotationData>> prepareAnnotations() const;
 
-    Document *prepareNewDocument(const QMap<QString, QList<SharedAnnotationData>> &annotations);
+    Document* prepareNewDocument(const QMap<QString, QList<SharedAnnotationData>>& annotations);
 
     ImportAnnotationsFromCSVTaskConfig config;
-    ReadCSVAsAnnotationsTask *readTask;
-    SaveDocumentTask *writeTask;
-    AddDocumentTask *addTask;
+    ReadCSVAsAnnotationsTask* readTask;
+    SaveDocumentTask* writeTask;
+    AddDocumentTask* addTask;
     QPointer<Document> doc;
 };
 
 class ReadCSVAsAnnotationsTask : public Task {
     Q_OBJECT
 public:
-    ReadCSVAsAnnotationsTask(const QString &file, const CSVParsingConfig &config);
+    ReadCSVAsAnnotationsTask(const QString& file, const CSVParsingConfig& config);
 
     void run();
 
@@ -100,11 +99,11 @@ public:
         return result;
     }
 
-    static QList<QStringList> parseLinesIntoTokens(const QString &text, const CSVParsingConfig &config, int &maxColumns, TaskStateInfo &ti);
+    static QList<QStringList> parseLinesIntoTokens(const QString& text, const CSVParsingConfig& config, int& maxColumns, TaskStateInfo& ti);
 
-    static QStringList parseLineIntoTokens(const QString &line, const CSVParsingConfig &config, TaskStateInfo &ti, int lineNum = 1);
+    static QStringList parseLineIntoTokens(const QString& line, const CSVParsingConfig& config, TaskStateInfo& ti, int lineNum = 1);
 
-    static QString guessSeparatorString(const QString &text, const CSVParsingConfig &config);
+    static QString guessSeparatorString(const QString& text, const CSVParsingConfig& config);
 
     // script variable that holds line value
     static QString LINE_VAR;
@@ -119,5 +118,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
