@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _IMPORT_PHRED_QUALITY_WORKER_H_
-#define _IMPORT_PHRED_QUALITY_WORKER_H_
+#pragma once
 
 #include <U2Core/DNASequence.h>
 
@@ -38,7 +37,7 @@ namespace LocalWorkflow {
 class ImportPhredQualityPrompter : public PrompterBase<ImportPhredQualityPrompter> {
     Q_OBJECT
 public:
-    ImportPhredQualityPrompter(Actor *p = 0)
+    ImportPhredQualityPrompter(Actor* p = 0)
         : PrompterBase<ImportPhredQualityPrompter>(p) {
     }
 
@@ -49,15 +48,15 @@ protected:
 class ImportPhredQualityWorker : public BaseWorker {
     Q_OBJECT
 public:
-    ImportPhredQualityWorker(Actor *a);
+    ImportPhredQualityWorker(Actor* a);
 
     virtual void init();
-    virtual Task *tick();
+    virtual Task* tick();
     virtual void cleanup();
 
 protected:
     CommunicationChannel *input, *output;
-    ReadQualityScoresTask *readTask;
+    ReadQualityScoresTask* readTask;
     QString fileName;
     DNAQualityType type;
     DNAQualityFormat format;
@@ -70,12 +69,10 @@ public:
     ImportPhredQualityWorkerFactory()
         : DomainFactory(ACTOR_ID) {
     }
-    virtual Worker *createWorker(Actor *a) {
+    virtual Worker* createWorker(Actor* a) {
         return new ImportPhredQualityWorker(a);
     }
 };
 
 }  // namespace LocalWorkflow
 }  // namespace U2
-
-#endif  // _IMPORT_PHRED_QUALITY_WORKER_H_
