@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,39 +32,39 @@
 
 namespace U2 {
 
-McaEditorContext::McaEditorContext(QObject *parent)
+McaEditorContext::McaEditorContext(QObject* parent)
     : GObjectViewWindowContext(parent, McaEditorFactory::ID) {
 }
 
 void McaEditorContext::sl_exportMca2Msa() {
-    GObjectViewAction *action = qobject_cast<GObjectViewAction *>(sender());
-    SAFE_POINT(nullptr != action, "action is NULL", );
-    McaEditor *mcaEditor = qobject_cast<McaEditor *>(action->getObjectView());
-    SAFE_POINT(nullptr != mcaEditor, "Mca Editor is NULL", );
+    GObjectViewAction* action = qobject_cast<GObjectViewAction*>(sender());
+    SAFE_POINT(action != nullptr, "action is NULL", );
+    McaEditor* mcaEditor = qobject_cast<McaEditor*>(action->getObjectView());
+    SAFE_POINT(mcaEditor != nullptr, "Mca Editor is NULL", );
 
-    MultipleChromatogramAlignmentObject *mcaObject = mcaEditor->getMaObject();
+    MultipleChromatogramAlignmentObject* mcaObject = mcaEditor->getMaObject();
     ExportUtils::launchExportMca2MsaTask(mcaObject);
 }
 
-void McaEditorContext::initViewContext(GObjectView *view) {
-    McaEditor *mcaEditor = qobject_cast<McaEditor *>(view);
-    SAFE_POINT(nullptr != mcaEditor, "Mca Editor is NULL", );
-    CHECK(nullptr != mcaEditor->getMaObject(), );
+void McaEditorContext::initViewContext(GObjectViewController* view) {
+    McaEditor* mcaEditor = qobject_cast<McaEditor*>(view);
+    SAFE_POINT(mcaEditor != nullptr, "Mca Editor is NULL", );
+    CHECK(mcaEditor->getMaObject() != nullptr, );
 
-    GObjectViewAction *action = new GObjectViewAction(this, view, tr("Export alignment without chromatograms..."));
+    GObjectViewAction* action = new GObjectViewAction(this, view, tr("Export alignment without chromatograms..."));
     connect(action, SIGNAL(triggered()), SLOT(sl_exportMca2Msa()));
     addViewAction(action);
 }
 
-void McaEditorContext::buildStaticOrContextMenu(GObjectView *view, QMenu *menu) {
-    McaEditor *mcaEditor = qobject_cast<McaEditor *>(view);
-    SAFE_POINT(nullptr != mcaEditor, "Mca Editor is NULL", );
-    SAFE_POINT(nullptr != menu, "Menu is NULL", );
-    CHECK(nullptr != mcaEditor->getMaObject(), );
+void McaEditorContext::buildStaticOrContextMenu(GObjectViewController* view, QMenu* menu) {
+    McaEditor* mcaEditor = qobject_cast<McaEditor*>(view);
+    SAFE_POINT(mcaEditor != nullptr, "Mca Editor is NULL", );
+    SAFE_POINT(menu != nullptr, "Menu is NULL", );
+    CHECK(mcaEditor->getMaObject() != nullptr, );
 
-    QList<GObjectViewAction *> list = getViewActions(view);
+    QList<GObjectViewAction*> list = getViewActions(view);
     SAFE_POINT(1 == list.size(), "List size is incorrect", );
-    QMenu *alignmentMenu = GUIUtils::findSubMenu(menu, MCAE_MENU_ALIGNMENT);
+    QMenu* alignmentMenu = GUIUtils::findSubMenu(menu, MCAE_MENU_ALIGNMENT);
     SAFE_POINT(alignmentMenu != nullptr, "menu 'Alignment' is NULL", );
     alignmentMenu->addAction(list.first());
 }
