@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_MCA_EDITOR_CONTEXT_H_
-#define _U2_MCA_EDITOR_CONTEXT_H_
+#pragma once
 
 #include <U2Gui/ObjectViewModel.h>
 
@@ -29,16 +28,14 @@ namespace U2 {
 class McaEditorContext : public GObjectViewWindowContext {
     Q_OBJECT
 public:
-    McaEditorContext(QObject *parent);
+    McaEditorContext(QObject* parent);
 
 private slots:
     void sl_exportMca2Msa();
 
 private:
-    void initViewContext(GObjectView *view) override;
-    void buildStaticOrContextMenu(GObjectView *view, QMenu *menu) override;
+    void initViewContext(GObjectViewController* view) override;
+    void buildStaticOrContextMenu(GObjectViewController* view, QMenu* menu) override;
 };
 
 }  // namespace U2
-
-#endif  // _U2_MCA_EDITOR_CONTEXT_H_
