@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_MCA_2_MSA_DIALOG_H_
-#define _U2_EXPORT_MCA_2_MSA_DIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -33,7 +32,7 @@ class SaveDocumentController;
 class ExportMca2MsaDialog : public QDialog, public Ui_ExportMca2MsaDialog {
     Q_OBJECT
 public:
-    ExportMca2MsaDialog(const QString &defaultFilePath, QWidget *parent);
+    ExportMca2MsaDialog(const QString& defaultFilePath, QWidget* parent);
 
     QString getSavePath() const;
     QString getFormatId() const;
@@ -41,12 +40,10 @@ public:
     bool getIncludeReferenceOption() const;
 
 private:
-    void initSaveController(const QString &defaultFilePath);
+    void initSaveController(const QString& defaultFilePath);
 
     const QString defaultFilePath;
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
 };
 
 }  // namespace U2
-
-#endif  // _U2_EXPORT_MCA_2_MSA_DIALOG_H_
