@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CONVERT_MCA_2_MSA_TASK_H_
-#define _U2_CONVERT_MCA_2_MSA_TASK_H_
+#pragma once
 
 #include <U2Core/MultipleSequenceAlignment.h>
 #include <U2Core/StateLockableDataModel.h>
@@ -33,7 +32,7 @@ class MultipleChromatogramAlignmentObject;
 class ConvertMca2MsaTask : public Task {
     Q_OBJECT
 public:
-    ConvertMca2MsaTask(MultipleChromatogramAlignmentObject *mcaObject, bool includeReference);
+    ConvertMca2MsaTask(MultipleChromatogramAlignmentObject* mcaObject, bool includeReference);
 
     MultipleSequenceAlignment getMsa() const;
 
@@ -42,7 +41,7 @@ private:
     void run();
     ReportResult report();
 
-    MultipleChromatogramAlignmentObject *mcaObject;
+    MultipleChromatogramAlignmentObject* mcaObject;
     const bool includeReference;
 
     MultipleSequenceAlignment msa;
@@ -50,5 +49,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif  // _U2_CONVERT_MCA_2_MSA_TASK_H_
