@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,9 +32,9 @@
 
 namespace U2 {
 
-ExportMca2MsaTask::ExportMca2MsaTask(MultipleChromatogramAlignmentObject *mcaObject,
-                                     const QString &fileName,
-                                     const DocumentFormatId &formatId,
+ExportMca2MsaTask::ExportMca2MsaTask(MultipleChromatogramAlignmentObject* mcaObject,
+                                     const QString& fileName,
+                                     const DocumentFormatId& formatId,
                                      bool includeReference)
     : DocumentProviderTask(tr("Export Sanger reads task"), TaskFlags_NR_FOSE_COSC),
       mcaObject(mcaObject),
@@ -44,7 +44,7 @@ ExportMca2MsaTask::ExportMca2MsaTask(MultipleChromatogramAlignmentObject *mcaObj
       convertTask(nullptr),
       exportTask(nullptr) {
     GCOUNTER(cvar, "ExportMca2MsaTask");
-    SAFE_POINT_EXT(nullptr != mcaObject, setError(L10N::nullPointerError("MCA object")), );
+    SAFE_POINT_EXT(mcaObject != nullptr, setError(L10N::nullPointerError("MCA object")), );
 }
 
 void ExportMca2MsaTask::prepare() {
@@ -52,8 +52,8 @@ void ExportMca2MsaTask::prepare() {
     addSubTask(convertTask);
 }
 
-QList<Task *> ExportMca2MsaTask::onSubTaskFinished(Task *subTask) {
-    QList<Task *> newSubTasks;
+QList<Task*> ExportMca2MsaTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> newSubTasks;
     CHECK_OP(stateInfo, newSubTasks);
 
     if (convertTask == subTask) {
