@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_FLEX_DIALOG_H_
-#define _U2_DNA_FLEX_DIALOG_H_
+#pragma once
 
 #include "HighFlexSettings.h"
 #include "ui_DNAFlexDialog.h"
@@ -37,7 +36,7 @@ class DNAFlexDialog : public QDialog, public Ui_DNAFlexDialog {
     Q_OBJECT
 
 public:
-    DNAFlexDialog(ADVSequenceObjectContext *ctx);
+    DNAFlexDialog(ADVSequenceObjectContext* ctx);
     virtual void accept();
 
 private slots:
@@ -49,13 +48,11 @@ private slots:
     void sl_updateSizes(int);
 
 private:
-    ADVSequenceObjectContext *ctx;
-    CreateAnnotationWidgetController *annotController;
+    ADVSequenceObjectContext* ctx;
+    CreateAnnotationWidgetController* annotController;
     HighFlexSettings settings;
 
     void updateHighFlexValues();
 };
 
 }  // namespace U2
-
-#endif
