@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_FLEX_PLUGIN_H_
-#define _U2_DNA_FLEX_PLUGIN_H_
+#pragma once
 
 #include <U2Core/PluginModel.h>
 
@@ -37,25 +36,23 @@ public:
     DNAFlexPlugin();
 
 private:
-    GObjectViewWindowContext *viewCtx;
+    GObjectViewWindowContext* viewCtx;
 };
 
 class DNAFlexViewContext : public GObjectViewWindowContext {
     Q_OBJECT
 
 public:
-    DNAFlexViewContext(QObject *p);
+    DNAFlexViewContext(QObject* p);
 
 private slots:
     void sl_showDNAFlexDialog();
-    void sl_sequenceWidgetAdded(ADVSequenceWidget *);
+    void sl_sequenceWidgetAdded(ADVSequenceWidget*);
 
 private:
-    GSequenceGraphFactory *graphFactory;
+    GSequenceGraphFactory* graphFactory;
 
-    void initViewContext(GObjectView *view) override;
+    void initViewContext(GObjectViewController* view) override;
 };
 
 }  // namespace U2
-
-#endif
