@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_FLEX_TASK_H_
-#define _U2_DNA_FLEX_TASK_H_
+#pragma once
 
 #include <QPointer>
 
@@ -43,15 +42,15 @@ class DNASequence;
 class DNAFlexTask : public Task {
     Q_OBJECT
 public:
-    DNAFlexTask(const HighFlexSettings &settings,
-                AnnotationTableObject *annotObject,
-                const QString &annotName,
-                const QString &annotGroup,
-                const QString &annDescription,
-                const DNASequence &sequence);
+    DNAFlexTask(const HighFlexSettings& settings,
+                AnnotationTableObject* annotObject,
+                const QString& annotName,
+                const QString& annotGroup,
+                const QString& annDescription,
+                const DNASequence& sequence);
 
-    QList<Task *> onSubTaskFinished(Task *subTask);
-    QList<SharedAnnotationData> getAnnotationsFromResults(const QList<HighFlexResult> &results);
+    QList<Task*> onSubTaskFinished(Task* subTask);
+    QList<SharedAnnotationData> getAnnotationsFromResults(const QList<HighFlexResult>& results);
 
 private:
     HighFlexSettings settings;
@@ -61,9 +60,7 @@ private:
     QString annotGroup;
     const QString annDescription;
     DNASequence sequence;
-    FindHighFlexRegions *findHighFlexTask;
+    FindHighFlexRegions* findHighFlexTask;
 };
 
 }  // namespace U2
-
-#endif
