@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_HIGH_FLEX_REGIONS_H_
-#define _U2_FIND_HIGH_FLEX_REGIONS_H_
+#pragma once
 
 #include <U2Core/AnnotationData.h>
 #include <U2Core/DNASequence.h>
@@ -41,7 +40,7 @@ class FindHighFlexRegionsListener {
 public:
     virtual ~FindHighFlexRegionsListener() {
     }
-    virtual void onResult(const HighFlexResult &result) = 0;
+    virtual void onResult(const HighFlexResult& result) = 0;
 };
 
 /**
@@ -52,13 +51,13 @@ class FindHighFlexRegions : public Task, public FindHighFlexRegionsListener {
     Q_OBJECT
 
 public:
-    FindHighFlexRegions(const DNASequence &sequence,
-                        const HighFlexSettings &settings);
+    FindHighFlexRegions(const DNASequence& sequence,
+                        const HighFlexSettings& settings);
 
     void run();
     QList<HighFlexResult> getResults() const;
 
-    virtual void onResult(const HighFlexResult &result);
+    virtual void onResult(const HighFlexResult& result);
 
 private:
     const DNASequence sequence;
@@ -67,5 +66,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
