@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_FIND_HIGH_FLEX_REGIONS_ALGORITHM_H_
-#define _U2_FIND_HIGH_FLEX_REGIONS_ALGORITHM_H_
+#pragma once
 
 #include <QMap>
 
@@ -35,19 +34,17 @@ class FindHighFlexRegionsListener;
 
 class FindHighFlexRegionsAlgorithm : public Task {
 public:
-    static void find(FindHighFlexRegionsListener *resultsListener,
-                     const HighFlexSettings &settings,
+    static void find(FindHighFlexRegionsListener* resultsListener,
+                     const HighFlexSettings& settings,
                      const QByteArray sequence,
                      const int seqLength,
-                     int &stopFlag,
-                     int &percentsCompleted);
+                     int& stopFlag,
+                     int& percentsCompleted);
 
     static double flexibilityAngle(char firstNucleotide, char secondNucleotide);
 
 private:
-    static void addToResults(FindHighFlexRegionsListener *listener, const HighFlexResult &result);
+    static void addToResults(FindHighFlexRegionsListener* listener, const HighFlexResult& result);
 };
 
 }  // namespace U2
-
-#endif
