@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_HIGH_FLEX_RESULT_H_
-#define _U2_HIGH_FLEX_RESULT_H_
+#pragma once
 
 #include <U2Core/U2Region.h>
 
@@ -31,7 +30,7 @@ public:
     HighFlexResult()
         : averageThreshold(0.0), windowsNumber(0), totalThreshold(0) {
     }
-    HighFlexResult(const U2Region &_region, double _averageThreshold, int _windowsNumber, double _totalThreshold)
+    HighFlexResult(const U2Region& _region, double _averageThreshold, int _windowsNumber, double _totalThreshold)
         : region(_region),
           averageThreshold(_averageThreshold),
           windowsNumber(_windowsNumber),
@@ -45,5 +44,3 @@ public:
 };
 
 }  // namespace U2
-
-#endif
