@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GRAPHPACK_DEVIATION_H_
-#define _U2_GRAPHPACK_DEVIATION_H_
+#pragma once
 
 #include <QAction>
 #include <QBitArray>
@@ -38,9 +37,9 @@ class DeviationGraphFactory : public GSequenceGraphFactory {
 public:
     enum GDeviationType { GC,
                           AT };
-    DeviationGraphFactory(GDeviationType t, QObject *p);
-    QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView *v);
-    bool isEnabled(const U2SequenceObject *o) const;
+    DeviationGraphFactory(GDeviationType t, QObject* p);
+    QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView* v);
+    bool isEnabled(const U2SequenceObject* o) const;
 
 private:
     QPair<char, char> devPair;
@@ -48,17 +47,16 @@ private:
 
 class DeviationGraphAlgorithm : public GSequenceGraphAlgorithm {
 public:
-    DeviationGraphAlgorithm(const QPair<char, char> &_p);
+    DeviationGraphAlgorithm(const QPair<char, char>& _p);
 
-    void calculate(QVector<float> &res, U2SequenceObject *o, qint64 window, qint64 step, U2OpStatus &os) override;
+    void calculate(QVector<float>& res, U2SequenceObject* o, qint64 window, qint64 step, U2OpStatus& os) override;
 
 private:
-    void windowStrategyWithoutMemorize(QVector<float> &res, const QByteArray &seq, qint64 startPos, qint64 window, qint64 step, qint64 nSteps, U2OpStatus &os);
-    void sequenceStrategyWithMemorize(QVector<float> &res, const QByteArray &seq, const U2Region &vr, qint64 window, qint64 step, U2OpStatus &os);
-    QPair<int, int> matchOnStep(const QByteArray &seq, int begin, int end);
+    void windowStrategyWithoutMemorize(QVector<float>& res, const QByteArray& seq, qint64 startPos, qint64 window, qint64 step, qint64 nSteps, U2OpStatus& os);
+    void sequenceStrategyWithMemorize(QVector<float>& res, const QByteArray& seq, const U2Region& visualRegion, qint64 window, qint64 step, U2OpStatus& os);
+    QPair<int, int> matchOnStep(const QByteArray& seq, int begin, int end);
 
     QPair<char, char> p;
 };
 
 }  // namespace U2
-#endif
