@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GC_FRAME_PLOT_H_
-#define _U2_GC_FRAME_PLOT_H_
+#pragma once
 
 #include <QAction>
 #include <QBitArray>
@@ -37,24 +36,22 @@ class AnnotatedDNAView;
 class GCFramePlotFactory : public GSequenceGraphFactory {
     Q_OBJECT
 public:
-    GCFramePlotFactory(QObject *p);
-    QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView *v);
-    GSequenceGraphDrawer *getDrawer(GSequenceGraphView *v);
-    bool isEnabled(const U2SequenceObject *o) const;
+    GCFramePlotFactory(QObject* p);
+    QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView* v);
+    GSequenceGraphDrawer* getDrawer(GSequenceGraphView* v);
+    bool isEnabled(const U2SequenceObject* o) const;
 };
 
 class GCFramePlotAlgorithm : public GSequenceGraphAlgorithm {
 public:
     GCFramePlotAlgorithm(int offset);
 
-    void calculate(QVector<float> &result, U2SequenceObject *sequenceObject, qint64 window, qint64 step, U2OpStatus &os) override;
+    void calculate(QVector<float>& result, U2SequenceObject* sequenceObject, qint64 window, qint64 step, U2OpStatus& os) override;
 
 private:
-    void windowStrategyWithoutMemorize(QVector<float> &res, const QByteArray &seq, int startPos, qint64 window, qint64 step, qint64 nSteps, U2OpStatus &os);
+    void windowStrategyWithoutMemorize(QVector<float>& res, const QByteArray& seq, int startPos, qint64 window, qint64 step, qint64 nSteps, U2OpStatus& os);
 
     int offset;
 };
 
 }  // namespace U2
-
-#endif  // _U2_GC_FRAME_PLOT_H_
