@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GRAPHPACK_KARLIN_H_
-#define _U2_GRAPHPACK_KARLIN_H_
+#pragma once
 
 #include <QAction>
 #include <QBitArray>
@@ -35,9 +34,9 @@ namespace U2 {
 class KarlinGraphFactory : public GSequenceGraphFactory {
     Q_OBJECT
 public:
-    KarlinGraphFactory(QObject *p);
-    QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView *v);
-    bool isEnabled(const U2SequenceObject *o) const;
+    KarlinGraphFactory(QObject* p);
+    QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView* v);
+    bool isEnabled(const U2SequenceObject* o) const;
 };
 
 class KarlinGraphAlgorithm : public GSequenceGraphAlgorithm {
@@ -45,15 +44,14 @@ public:
     KarlinGraphAlgorithm();
     ~KarlinGraphAlgorithm();
 
-    void calculate(QVector<float> &result, U2SequenceObject *sequenceObject, qint64 window, qint64 step, U2OpStatus &os) override;
+    void calculate(QVector<float>& result, U2SequenceObject* sequenceObject, qint64 window, qint64 step, U2OpStatus& os) override;
 
 private:
-    float getValue(int start, int end, const QByteArray &s, U2OpStatus &os);
-    void calculateRelativeAbundance(const char *seq, int length, float *results, U2OpStatus &os);
+    float getValue(int start, int end, const QByteArray& s, U2OpStatus& os);
+    void calculateRelativeAbundance(const char* seq, int length, float* results, U2OpStatus& os);
 
-    float *global_relative_abundance_values;
+    float* global_relative_abundance_values;
     QByteArray mapTrans;
 };
 
 }  // namespace U2
-#endif
