@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNASTAT_MSA_PROFILE_DIALOG_H_
-#define _U2_DNASTAT_MSA_PROFILE_DIALOG_H_
+#pragma once
 
 #include <QHash>
 #include <QSet>
@@ -40,20 +39,20 @@ class DNAStatMSAProfileDialog : public QDialog, public Ui_DNAStatMSAProfileDialo
     Q_OBJECT
 
 public:
-    DNAStatMSAProfileDialog(QWidget *p, MSAEditor *ctx);
+    DNAStatMSAProfileDialog(QWidget* p, MSAEditor* ctx);
 
     void accept();
     /*Notify user about problems with big report, and disable opening report in UGENE*/
     void showAlignmentIsTooBigWarning();
 private slots:
     void sl_formatSelected();
-    void sl_formatChanged(const QString &newFormat);
+    void sl_formatChanged(const QString& newFormat);
 
 private:
     void initSaveController();
 
-    MSAEditor *ctx;
-    SaveDocumentController *saveController;
+    MSAEditor* ctx;
+    SaveDocumentController* saveController;
 
     static const QString HTML;
     static const QString CSV;
@@ -89,7 +88,7 @@ public:
 class DNAStatMSAProfileTask : public Task {
     Q_OBJECT
 public:
-    DNAStatMSAProfileTask(const DNAStatMSAProfileTaskSettings &s);
+    DNAStatMSAProfileTask(const DNAStatMSAProfileTaskSettings& s);
 
     void run();
     QString generateReport() const;
@@ -117,5 +116,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
