@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DNA_STAT_PLUGIN_H_
-#define _U2_DNA_STAT_PLUGIN_H_
+#pragma once
 
 #include <U2Core/PluginModel.h>
 
@@ -34,21 +33,21 @@ public:
     DNAStatPlugin();
 
 private:
-    GObjectViewWindowContext *statViewCtx;
-    GObjectViewWindowContext *distanceViewCtx;
+    GObjectViewWindowContext* statViewCtx;
+    GObjectViewWindowContext* distanceViewCtx;
 };
 
 class DNAStatMSAEditorContext : public GObjectViewWindowContext {
     Q_OBJECT
 public:
-    DNAStatMSAEditorContext(QObject *p);
+    DNAStatMSAEditorContext(QObject* p);
 
 protected slots:
     void sl_showMSAProfileDialog();
-    void buildStaticOrContextMenu(GObjectView *view, QMenu *menu) override;
+    void buildStaticOrContextMenu(GObjectViewController* view, QMenu* menu) override;
 
 protected:
-    void initViewContext(GObjectView *view) override;
+    void initViewContext(GObjectViewController* view) override;
 
 private:
     /* Alignment length limint for opening grid report in UGENE */
@@ -58,16 +57,14 @@ private:
 class DistanceMatrixMSAEditorContext : public GObjectViewWindowContext {
     Q_OBJECT
 public:
-    DistanceMatrixMSAEditorContext(QObject *p);
+    DistanceMatrixMSAEditorContext(QObject* p);
 
 protected slots:
     void sl_showDistanceMatrixDialog();
-    void buildStaticOrContextMenu(GObjectView *view, QMenu *menu) override;
+    void buildStaticOrContextMenu(GObjectViewController* view, QMenu* menu) override;
 
 protected:
-    void initViewContext(GObjectView *view) override;
+    void initViewContext(GObjectViewController* view) override;
 };
 
 }  // namespace U2
-
-#endif
