@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOT_PLOT_CLASSES_H_
-#define _U2_DOT_PLOT_CLASSES_H_
+#pragma once
 
 #include <QMessageBox>
 #include <QMutex>
@@ -38,10 +37,10 @@ namespace U2 {
 class DotPlotMiniMap {
 public:
     DotPlotMiniMap(int bigMapW, int bigMapH, float ratio);
-    void draw(QPainter &p, int shiftX, int shiftY, const QPointF &zoom) const;
+    void draw(QPainter& p, int shiftX, int shiftY, const QPointF& zoom) const;
 
     QRectF getBoundary() const;
-    QPointF fromMiniMap(const QPointF &p, const QPointF &zoom) const;
+    QPointF fromMiniMap(const QPointF& p, const QPointF& zoom) const;
 
     void updatePosition(int bigMapW, int bigMapH);
 
@@ -70,7 +69,7 @@ struct DotPlotResults {
     int y;
     int len;
 
-    inline bool intersectRegion(const U2Region &r, const FilterIntersectionParameter &currentIntersParam) {
+    inline bool intersectRegion(const U2Region& r, const FilterIntersectionParameter& currentIntersParam) {
         qint64 sd = -r.startPos;
         if (currentIntersParam == SequenceY) {
             sd += y;
@@ -89,10 +88,10 @@ public:
     DotPlotResultsListener();
     virtual ~DotPlotResultsListener();
 
-    void setTask(Task *);
+    void setTask(Task*);
 
-    virtual void onResult(const RFResult &r);
-    virtual void onResults(const QVector<RFResult> &v);
+    virtual void onResult(const RFResult& r);
+    virtual void onResults(const QVector<RFResult>& v);
 
 private:
     QSharedPointer<QList<DotPlotResults>> dotPlotList;
@@ -101,7 +100,7 @@ private:
     bool stateOk;
 
     static const int maxResults = 8 * 1024 * 1024;
-    Task *rfTask;
+    Task* rfTask;
 };
 
 // apply rev-compl transformation for X sequence results
@@ -110,12 +109,10 @@ public:
     DotPlotRevComplResultsListener()
         : xLen(0) {
     }
-    virtual void onResult(const RFResult &r);
-    virtual void onResults(const QVector<RFResult> &v);
+    virtual void onResult(const RFResult& r);
+    virtual void onResults(const QVector<RFResult>& v);
 
     int xLen;
 };
 
 }  // namespace U2
-
-#endif  // _U2_DOT_PLOT_CLASSES_H_
