@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -21,17 +21,16 @@
 
 #include <math.h>
 
-#include <QColorDialog>
 #include <QDesktopWidget>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNASequenceObject.h>
+#include <U2Core/FileFilters.h>
 #include <U2Core/GObjectUtils.h>
 #include <U2Core/ProjectModel.h>
 #include <U2Core/QObjectScopedPointer.h>
 #include <U2Core/U2SafePoints.h>
-#include <U2Core/global.h>
 
 #include <U2Gui/CreateAnnotationWidgetController.h>
 #include <U2Gui/DialogUtils.h>
@@ -47,7 +46,7 @@
 
 namespace U2 {
 
-DotPlotDialog::DotPlotDialog(QWidget *parent, AnnotatedDNAView *currentADV, int minLen, int identity, ADVSequenceObjectContext *sequenceX, ADVSequenceObjectContext *sequenceY, bool dir, bool inv, const QColor &dColor, const QColor &iColor, bool hideLoadSequences)
+DotPlotDialog::DotPlotDialog(QWidget* parent, AnnotatedDNAView* currentADV, int minLen, int identity, ADVSequenceObjectContext* sequenceX, ADVSequenceObjectContext* sequenceY, bool dir, bool inv, const QColor& dColor, const QColor& iColor, bool hideLoadSequences)
     : QDialog(parent), xSeq(sequenceX), ySeq(sequenceY), adv(currentADV), directColor(dColor), invertedColor(iColor), openSequenceTask(nullptr) {
     setupUi(this);
 
@@ -85,9 +84,9 @@ DotPlotDialog::DotPlotDialog(QWidget *parent, AnnotatedDNAView *currentADV, int
     connect(loadSequenceButton, SIGNAL(clicked()), SLOT(sl_loadSequenceButton()));
 
     // listen to project modification to update list of available sequence objects.
-    Project *project = AppContext::getProject();
-    connect(project, SIGNAL(si_documentAdded(Document *)), SLOT(sl_documentAddedOrRemoved()));
-    connect(project, SIGNAL(si_documentRemoved(Document *)), SLOT(sl_documentAddedOrRemoved()));
+    Project* project = AppContext::getProject();
+    connect(project, SIGNAL(si_documentAdded(Document*)), SLOT(sl_documentAddedOrRemoved()));
+    connect(project, SIGNAL(si_documentRemoved(Document*)), SLOT(sl_documentAddedOrRemoved()));
     reconnectAllProjectDocuments();
     updateSequenceSelectors();
 
@@ -101,11 +100,11 @@ DotPlotDialog::DotPlotDialog(QWidget *parent, AnnotatedDNAView *currentADV, int
 }
 
 void DotPlotDialog::reconnectAllProjectDocuments() {
-    Project *project = AppContext::getProject();
-    foreach (Document *d, project->getDocuments()) {
+    Project* project = AppContext::getProject();
+    foreach (Document* d, project->getDocuments()) {
         d->disconnect(this);
-        connect(d, SIGNAL(si_objectAdded(GObject *)), SLOT(sl_objectAddedOrRemoved()));
-        connect(d, SIGNAL(si_objectRemoved(GObject *)), SLOT(sl_objectAddedOrRemoved()));
+        connect(d, SIGNAL(si_objectAdded(GObject*)), SLOT(sl_objectAddedOrRemoved()));
+        connect(d, SIGNAL(si_objectRemoved(GObject*)), SLOT(sl_objectAddedOrRemoved()));
         connect(d, SIGNAL(si_loadedStateChanged()), SLOT(sl_loadedStateChanged()));
     }
 }
@@ -117,9 +116,9 @@ void DotPlotDialog::updateSequenceSelectors() {
     int xSeqIndex = -1, ySeqIndex = -1, curIndex = 0;
 
     // sequences in the project
-    QList<GObject *> sequenceObjects = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
-    foreach (GObject *obj, sequenceObjects) {
-        U2SequenceObject *seqObj = qobject_cast<U2SequenceObject *>(obj);
+    QList<GObject*> sequenceObjects = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
+    foreach (GObject* obj, sequenceObjects) {
+        auto seqObj = qobject_cast<U2SequenceObject*>(obj);
         QString name = seqObj->getGObjectName();
 
         xAxisCombo->addItem(name);
@@ -161,38 +160,36 @@ void DotPlotDialog::sl_sequenceSelectorIndexChanged() {
     int xIdx = xAxisCombo->currentIndex();
     int yIdx = yAxisCombo->currentIndex();
 
-    QList<GObject *> sequenceObjects = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
-    SAFE_POINT(xIdx >= 0 && xIdx < sequenceObjects.length(), QString("DotPlotDialog: index is out of range: %1").arg(xIdx), );
-    SAFE_POINT(yIdx >= 0 && yIdx < sequenceObjects.length(), QString("DotPlotDialog: index is out of range: %1").arg(yIdx), );
+    QList<GObject*> sequenceObjects = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
+    // 'sl_sequenceSelectorIndexChanged' is called twice: when the first and when the second index is set.
+    // Process only valid callbacks, ignore non-valid ones.
+    CHECK(xIdx >= 0 && xIdx < sequenceObjects.length(), );
+    CHECK(yIdx >= 0 && yIdx < sequenceObjects.length(), );
 
-    U2SequenceObject *objX = qobject_cast<U2SequenceObject *>(sequenceObjects[xIdx]);
-    U2SequenceObject *objY = qobject_cast<U2SequenceObject *>(sequenceObjects[yIdx]);
-    if (!objX->getAlphabet()->isNucleic() || !objY->getAlphabet()->isNucleic()) {
-        invertedCheckBox->setDisabled(true);
-        invertedColorButton->setDisabled(true);
-        invertedDefaultColorButton->setDisabled(true);
-    } else {
-        invertedCheckBox->setDisabled(false);
-        invertedColorButton->setDisabled(false);
-        invertedDefaultColorButton->setDisabled(false);
-    }
-    int defaultWindow = qMin(objX->getSequenceLength(), objY->getSequenceLength());
-    defaultWindow = defaultWindow < 100 ? defaultWindow : 100;
-    if (minLenBox->value() > defaultWindow) {
-        minLenBox->setValue(defaultWindow);
-    }
+    auto objX = qobject_cast<U2SequenceObject*>(sequenceObjects[xIdx]);
+    auto objY = qobject_cast<U2SequenceObject*>(sequenceObjects[yIdx]);
+    SAFE_POINT(objX != nullptr, "First object is not a sequence object", )
+    SAFE_POINT(objY != nullptr, "Second object is not a sequence object", )
+
+    bool isInvertModeAvailable = objX->getAlphabet()->isNucleic() && objY->getAlphabet()->isNucleic();
+    invertedCheckBox->setEnabled(isInvertModeAvailable);
+    invertedColorButton->setEnabled(isInvertModeAvailable);
+    invertedDefaultColorButton->setEnabled(isInvertModeAvailable);
+
+    int defaultWindow = qMin((int)qMin(objX->getSequenceLength(), objY->getSequenceLength()), 100);
+    minLenBox->setValue(qMin(defaultWindow, minLenBox->value()));
 }
 
 void DotPlotDialog::accept() {
     int xIdx = xAxisCombo->currentIndex();
     int yIdx = yAxisCombo->currentIndex();
 
-    QList<GObject *> sequenceObjects = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
+    QList<GObject*> sequenceObjects = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
     SAFE_POINT(xIdx >= 0 && xIdx < sequenceObjects.length(), QString("DotPlotDialog: index is out of range: %1").arg(xIdx), );
     SAFE_POINT(yIdx >= 0 && yIdx < sequenceObjects.length(), QString("DotPlotDialog: index is out of range: %1").arg(yIdx), );
 
-    U2SequenceObject *objX = qobject_cast<U2SequenceObject *>(sequenceObjects[xIdx]);
-    U2SequenceObject *objY = qobject_cast<U2SequenceObject *>(sequenceObjects[yIdx]);
+    auto objX = qobject_cast<U2SequenceObject*>(sequenceObjects[xIdx]);
+    auto objY = qobject_cast<U2SequenceObject*>(sequenceObjects[yIdx]);
 
     if (!isObjectInADV(objX)) {
         adv->addObject(objX);
@@ -219,12 +216,12 @@ void DotPlotDialog::sl_minLenHeuristics() {
     int xIdx = xAxisCombo->currentIndex();
     int yIdx = yAxisCombo->currentIndex();
 
-    QList<GObject *> sequenceObjects = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
+    QList<GObject*> sequenceObjects = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
     SAFE_POINT(xIdx >= 0 && xIdx < sequenceObjects.length(), QString("DotPlotDialog: index is out of range: %1").arg(xIdx), );
     SAFE_POINT(yIdx >= 0 && yIdx < sequenceObjects.length(), QString("DotPlotDialog: index is out of range: %1").arg(yIdx), );
 
-    U2SequenceObject *objX = qobject_cast<U2SequenceObject *>(sequenceObjects[xIdx]);
-    U2SequenceObject *objY = qobject_cast<U2SequenceObject *>(sequenceObjects[yIdx]);
+    auto objX = qobject_cast<U2SequenceObject*>(sequenceObjects[xIdx]);
+    auto objY = qobject_cast<U2SequenceObject*>(sequenceObjects[yIdx]);
 
     qint64 xSeqLen = objX->getSequenceLength();
     qint64 ySeqLen = objY->getSequenceLength();
@@ -272,7 +269,7 @@ void DotPlotDialog::sl_directInvertedCheckBox() {
 static const QString COLOR_STYLE("QPushButton { background-color: %1 }");
 
 void DotPlotDialog::sl_directColorButton() {
-    QObjectScopedPointer<QColorDialog> d = new QColorDialog(directColor, this);
+    QObjectScopedPointer<QColorDialog> d = new U2ColorDialog(directColor, this);
     d->exec();
     CHECK(!d.isNull(), );
 
@@ -285,7 +282,7 @@ void DotPlotDialog::sl_directColorButton() {
 }
 
 void DotPlotDialog::sl_invertedColorButton() {
-    QObjectScopedPointer<QColorDialog> d = new QColorDialog(invertedColor, this);
+    QObjectScopedPointer<QColorDialog> d = new U2ColorDialog(invertedColor, this);
     d->exec();
     CHECK(!d.isNull(), );
 
@@ -310,11 +307,11 @@ void DotPlotDialog::sl_invertedDefaultColorButton() {
 }
 
 void DotPlotDialog::sl_loadSequenceButton() {
-    QString filter = DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::SEQUENCE, true);
+    QString filter = FileFilters::createFileFilterByObjectTypes({GObjectTypes::SEQUENCE});
     LastUsedDirHelper lod("DotPlot file");
     lod.url = U2FileDialog::getOpenFileName(this, tr("Open file"), lod.dir, filter);
     if (!lod.url.isEmpty()) {
-        Task *tasks = new Task("Adding document to the project", TaskFlag_NoRun);
+        Task* tasks = new Task("Adding document to the project", TaskFlag_NoRun);
 
         if (!AppContext::getProject()) {
             tasks->addSubTask(AppContext::getProjectLoader()->createNewProjectTask());
@@ -329,14 +326,14 @@ void DotPlotDialog::sl_loadSequenceButton() {
         }
         tasks->addSubTask(openSequenceTask);
 
-        connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task *)), SLOT(sl_loadTaskStateChanged(Task *)));
+        connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task*)), SLOT(sl_loadTaskStateChanged(Task*)));
 
         AppContext::getTaskScheduler()->registerTopLevelTask(tasks);
     }
 }
 
-void DotPlotDialog::sl_loadTaskStateChanged(Task *t) {
-    DotPlotLoadDocumentsTask *loadTask = qobject_cast<DotPlotLoadDocumentsTask *>(t);
+void DotPlotDialog::sl_loadTaskStateChanged(Task* t) {
+    auto loadTask = qobject_cast<DotPlotLoadDocumentsTask*>(t);
     if (loadTask == nullptr) {
         return;
     }
@@ -351,16 +348,16 @@ void DotPlotDialog::updateColors() {
     invertedColorButton->setStyleSheet(COLOR_STYLE.arg(invertedColor.name()));
 }
 
-bool DotPlotDialog::isObjectInADV(GObject *obj) {
+bool DotPlotDialog::isObjectInADV(GObject* obj) {
     SAFE_POINT(obj != nullptr, "Object is NULL in DotPlotDialog::isObjectInADV(GObject* obj)", false);
 
     return adv->containsObject(obj);
 }
 
-GObject *DotPlotDialog::getGObjectByName(const QString &gObjectName) {
-    QList<GObject *> allSequences = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
-    GObject *obj = nullptr;
-    foreach (GObject *s, allSequences) {
+GObject* DotPlotDialog::getGObjectByName(const QString& gObjectName) {
+    QList<GObject*> allSequences = GObjectUtils::findAllObjects(UOF_LoadedOnly, GObjectTypes::SEQUENCE);
+    GObject* obj = nullptr;
+    foreach (GObject* s, allSequences) {
         if (gObjectName == s->getGObjectName()) {
             obj = s;
         }
