@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOT_PLOT_FILES_DIALOG_H_
-#define _U2_DOT_PLOT_FILES_DIALOG_H_
+#pragma once
 
 #include <ui_DotPlotFilesDialog.h>
 
@@ -30,7 +29,7 @@ class ADVSequenceObjectContext;
 class DotPlotFilesDialog : public QDialog, public Ui_DotPlotFilesDialog {
     Q_OBJECT
 public:
-    DotPlotFilesDialog(QWidget *parent);
+    DotPlotFilesDialog(QWidget* parent);
 
     virtual void accept();
 
@@ -61,5 +60,3 @@ private:
 };
 
 }  // namespace U2
-
-#endif
