@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DOT_PLOT_SPLITTER_H_
-#define _U2_DOT_PLOT_SPLITTER_H_
+#pragma once
 
 #include <QIcon>
 
@@ -31,7 +30,7 @@ class QToolButton;
 
 namespace U2 {
 
-class GObjectView;
+class GObjectViewController;
 class DotPlotWidget;
 class ADVSequenceObjectContext;
 
@@ -39,41 +38,41 @@ class DotPlotSplitter : public ADVSplitWidget {
     Q_OBJECT
 
 public:
-    DotPlotSplitter(AnnotatedDNAView *);
+    DotPlotSplitter(AnnotatedDNAView*);
 
-    virtual bool acceptsGObject(GObject *objects) {
+    virtual bool acceptsGObject(GObject* objects) {
         Q_UNUSED(objects);
         return false;
     }
-    virtual void updateState(const QVariantMap &) {
+    virtual void updateState(const QVariantMap&) {
     }
-    virtual void saveState(QVariantMap &) {
+    virtual void saveState(QVariantMap&) {
     }
 
-    void addView(DotPlotWidget *);
-    void removeView(DotPlotWidget *);
+    void addView(DotPlotWidget*);
+    void removeView(DotPlotWidget*);
     bool isEmpty() const;
-    void buildPopupMenu(QMenu *);
+    void buildPopupMenu(QMenu*);
 
 protected:
     virtual bool onCloseEvent();
 
 private:
-    QAction *createAction(const QString &iconPath, const QString &toolTip, const char *slot, bool checkable = true);
-    QAction *createAction(const QIcon &ic, const QString &toolTip, const char *slot, bool checkable = true);
+    QAction* createAction(const QString& iconPath, const QString& toolTip, const char* slot, bool checkable = true);
+    QAction* createAction(const QIcon& ic, const QString& toolTip, const char* slot, bool checkable = true);
 
-    QSplitter *splitter;
-    QList<DotPlotWidget *> dotPlotList;
+    QSplitter* splitter;
+    QList<DotPlotWidget*> dotPlotList;
 
     bool locked;
-    QAction *syncLockAction;
-    QAction *filterAction;
-    QAction *zoomInAction;
-    QAction *zoomOutAction;
-    QAction *resetZoomingAction;
-    QAction *zoomToAction;
-    QAction *handAction;
-    QAction *selAction;
+    QAction* syncLockAction;
+    QAction* filterAction;
+    QAction* zoomInAction;
+    QAction* zoomOutAction;
+    QAction* resetZoomingAction;
+    QAction* zoomToAction;
+    QAction* handAction;
+    QAction* selAction;
 
     void updateButtonState();
     void checkLockButtonState();
@@ -88,10 +87,8 @@ private slots:
     void sl_toggleZoomOut();
     void sl_toggleZoomReset();
 
-    void sl_dotPlotChanged(ADVSequenceObjectContext *, ADVSequenceObjectContext *, float, float, QPointF);
+    void sl_dotPlotChanged(ADVSequenceObjectContext*, ADVSequenceObjectContext*, float, float, QPointF);
     void sl_dotPlotSelecting();
 };
 
 }  // namespace U2
-
-#endif  // _U2_DOT_PLOT_SPLITTER_H_
