@@ -39,58 +39,58 @@
         <translation>Идентичность повторов</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="154"/>
+        <location filename="../src/DotPlotDialog.ui" line="158"/>
         <source>bp</source>
         <translation>нк</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="182"/>
+        <location filename="../src/DotPlotDialog.ui" line="186"/>
         <source>Heuristic based selection of repeat length so the number of repeats in the sequence will not exceed 1000</source>
         <translation>Эвристический подбор длины повторов, с тем чтобы кол-во повторов в последовательности не превысило 1000</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="185"/>
+        <location filename="../src/DotPlotDialog.ui" line="189"/>
         <source>1k</source>
         <translation>1к</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="210"/>
+        <location filename="../src/DotPlotDialog.ui" line="218"/>
         <source>%</source>
         <translation>%</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="232"/>
+        <location filename="../src/DotPlotDialog.ui" line="240"/>
         <source>Resets repeats identity to 100%</source>
         <translation>Сбросить к 100%</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="235"/>
+        <location filename="../src/DotPlotDialog.ui" line="243"/>
         <source>100</source>
         <translation>100</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="290"/>
+        <location filename="../src/DotPlotDialog.ui" line="298"/>
         <source>Search inverted repeats</source>
         <translation>Искать инвертированные повторы</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="297"/>
+        <location filename="../src/DotPlotDialog.ui" line="305"/>
         <source>Search direct repeats</source>
         <translation>Искать прямые повторы</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="336"/>
-        <location filename="../src/DotPlotDialog.ui" line="343"/>
+        <location filename="../src/DotPlotDialog.ui" line="344"/>
+        <location filename="../src/DotPlotDialog.ui" line="351"/>
         <source>default</source>
         <translation>По умолчанию</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="368"/>
+        <location filename="../src/DotPlotDialog.ui" line="376"/>
         <source>Click to load a sequence from the file system. The sequence will be added to the combo boxes when it is loaded to the project</source>
         <translation>Нажмите, чтобы загрузить последовательности из файловой системы. Последовательности будут добавлены в комбо-боксы, когда они будут загружены в проект</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.ui" line="371"/>
+        <location filename="../src/DotPlotDialog.ui" line="379"/>
         <source>Load Sequence</source>
         <translation>Загрузить</translation>
     </message>
@@ -232,42 +232,42 @@
 <context>
     <name>U2::DotPlotDialog</name>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="55"/>
+        <location filename="../src/DotPlotDialog.cpp" line="54"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="56"/>
+        <location filename="../src/DotPlotDialog.cpp" line="55"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="66"/>
+        <location filename="../src/DotPlotDialog.cpp" line="65"/>
         <source>Auto</source>
         <translation>Автовыбор</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="67"/>
+        <location filename="../src/DotPlotDialog.cpp" line="66"/>
         <source>Suffix index</source>
         <translation>Суффиксный индекс</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="68"/>
+        <location filename="../src/DotPlotDialog.cpp" line="67"/>
         <source>Diagonals</source>
         <translation>Диагональный</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="315"/>
+        <location filename="../src/DotPlotDialog.cpp" line="312"/>
         <source>Open file</source>
         <translation>Открыть файл</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="344"/>
+        <location filename="../src/DotPlotDialog.cpp" line="341"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="344"/>
+        <location filename="../src/DotPlotDialog.cpp" line="341"/>
         <source>Error opening files</source>
         <translation>Ошибка открытия файлов</translation>
     </message>
@@ -275,50 +275,50 @@
 <context>
     <name>U2::DotPlotFilesDialog</name>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="43"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="41"/>
         <source>Next</source>
         <translation>Далее</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="44"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="42"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="75"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="73"/>
         <source>Open first file</source>
         <translation>Открыть первый файл</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="106"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="104"/>
         <source>Open second file</source>
         <translation>Открыть второй файл</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="142"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="140"/>
         <source>Select a file with a sequence to build dotplot!</source>
         <translation>Выберите файл с последовательностью!</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="142"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="140"/>
         <source>Select first file with a sequence to build dotplot!</source>
         <translation>Выберите первый файл с последовательностью!</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="143"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="141"/>
         <source>Input the second sequence or check the &apos;Compare sequence against itself&apos; option.</source>
         <translation>Выберите вторую последовательность или выберите опцию &apos;Сравнить последовательность саму с собой&apos;.</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="152"/>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="160"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="150"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="158"/>
         <source>Unable to detect file format %1.</source>
         <translation>Невозможно определить формат файла %1.</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="144"/>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="152"/>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="160"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="142"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="150"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="158"/>
         <source>Select files</source>
         <translation>Выберите файлы</translation>
     </message>
@@ -349,7 +349,7 @@
 <context>
     <name>U2::DotPlotFilterTask</name>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="311"/>
+        <location filename="../src/DotPlotTasks.cpp" line="308"/>
         <source>Applying filter to dotplot</source>
         <translation>Применение фильтра к dotplot</translation>
     </message>
@@ -388,12 +388,12 @@
 <context>
     <name>U2::DotPlotLoadDocumentsTask</name>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="218"/>
+        <location filename="../src/DotPlotTasks.cpp" line="215"/>
         <source>DotPlot loading</source>
         <translation>Dotplot загружается</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="260"/>
+        <location filename="../src/DotPlotTasks.cpp" line="257"/>
         <source>Detecting format error for file %1</source>
         <translation>Ошибка определения формата файла %1</translation>
     </message>
@@ -457,7 +457,7 @@
 <context>
     <name>U2::DotPlotViewAction</name>
     <message>
-        <location filename="../src/DotPlotPlugin.h" line="82"/>
+        <location filename="../src/DotPlotPlugin.h" line="81"/>
         <source>Show dot plot</source>
         <translation>Показать dotplot</translation>
     </message>
@@ -466,7 +466,7 @@
     <name>U2::DotPlotViewContext</name>
     <message>
         <location filename="../src/DotPlotPlugin.cpp" line="72"/>
-        <location filename="../src/DotPlotPlugin.cpp" line="218"/>
+        <location filename="../src/DotPlotPlugin.cpp" line="221"/>
         <source>Build dotplot...</source>
         <translation>Построение точечной диаграммы (dotplot)...</translation>
     </message>
@@ -484,169 +484,172 @@
 <context>
     <name>U2::DotPlotWidget</name>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="119"/>
+        <location filename="../src/DotPlotWidget.cpp" line="120"/>
         <source>Parameters</source>
         <translation>Параметры</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="122"/>
+        <location filename="../src/DotPlotWidget.cpp" line="123"/>
         <source>Save as image</source>
         <translation>Сохранить как изображение</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="126"/>
+        <location filename="../src/DotPlotWidget.cpp" line="127"/>
         <source>Save</source>
         <translation>Сохранить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="130"/>
+        <location filename="../src/DotPlotWidget.cpp" line="131"/>
         <source>Load</source>
         <translation>Загрузить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="133"/>
+        <location filename="../src/DotPlotWidget.cpp" line="134"/>
         <source>Remove</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="137"/>
+        <location filename="../src/DotPlotWidget.cpp" line="138"/>
         <source>Filter Results</source>
         <translation>Фильтрация результатов</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="207"/>
+        <location filename="../src/DotPlotWidget.cpp" line="208"/>
         <source>Save/Load</source>
         <translation>Сохранить/Загрузить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="384"/>
+        <location filename="../src/DotPlotWidget.cpp" line="385"/>
         <source>Too many results</source>
         <translation>Слишком много результатов</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="384"/>
+        <location filename="../src/DotPlotWidget.cpp" line="385"/>
         <source>Too many results. Try to increase minimum repeat length</source>
         <translation>Слишком много результатов. Попробуйте уменьшить минимальную длину повтора</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="533"/>
-        <location filename="../src/DotPlotWidget.cpp" line="590"/>
+        <location filename="../src/DotPlotWidget.cpp" line="536"/>
+        <location filename="../src/DotPlotWidget.cpp" line="592"/>
         <source>File opening error</source>
         <translation>Ошибка открытия файла</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="533"/>
-        <location filename="../src/DotPlotWidget.cpp" line="590"/>
+        <location filename="../src/DotPlotWidget.cpp" line="536"/>
+        <location filename="../src/DotPlotWidget.cpp" line="592"/>
         <source>Error opening file %1</source>
         <translation>Ошибка открытия файла %1</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="541"/>
-        <location filename="../src/DotPlotWidget.cpp" line="572"/>
-        <location filename="../src/DotPlotWidget.cpp" line="640"/>
+        <location filename="../src/DotPlotWidget.cpp" line="544"/>
+        <location filename="../src/DotPlotWidget.cpp" line="574"/>
+        <location filename="../src/DotPlotWidget.cpp" line="642"/>
         <source>Task is already running</source>
         <translation>Задача уже запущена</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="541"/>
-        <location filename="../src/DotPlotWidget.cpp" line="572"/>
-        <location filename="../src/DotPlotWidget.cpp" line="640"/>
+        <location filename="../src/DotPlotWidget.cpp" line="544"/>
+        <location filename="../src/DotPlotWidget.cpp" line="574"/>
+        <location filename="../src/DotPlotWidget.cpp" line="642"/>
         <source>Build or Load DotPlot task is already running</source>
         <translation>Задача построения или загрузки dotplot уже запущена</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="594"/>
+        <location filename="../src/DotPlotWidget.cpp" line="596"/>
         <source>Sequences are different</source>
         <translation>Последовательности отличаются</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="594"/>
+        <location filename="../src/DotPlotWidget.cpp" line="596"/>
         <source>Current and loading sequences are different. Continue loading dot-plot anyway?</source>
         <translation>Текущая и загружаемая последовательность различаются. Продолжить загрузку?</translation>
     </message>
     <message>
-        <source>Sequence size is too large!</source>
-        <translation type="vanished">Последовательность слишком большая!</translation>
-    </message>
-    <message>
-        <location filename="../src/DotPlotWidget.cpp" line="695"/>
-        <location filename="../src/DotPlotWidget.cpp" line="700"/>
+        <location filename="../src/DotPlotWidget.cpp" line="697"/>
+        <location filename="../src/DotPlotWidget.cpp" line="702"/>
         <source>Invalid sequence</source>
         <translation>Некорректная последовательность</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="695"/>
+        <location filename="../src/DotPlotWidget.cpp" line="697"/>
         <source>First selected sequence is invalid</source>
         <translation>Первая выделенная последовательность некорректна</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="700"/>
+        <location filename="../src/DotPlotWidget.cpp" line="702"/>
         <source>Second selected sequence is invalid</source>
         <translation>Вторая выделенная последовательность некорректна</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="708"/>
+        <location filename="../src/DotPlotWidget.cpp" line="710"/>
         <source>Wrong alphabet types</source>
         <translation>Неправильные типы алфавитов</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="708"/>
+        <location filename="../src/DotPlotWidget.cpp" line="710"/>
         <source>Both sequence must have the same alphabet</source>
         <translation>Обе последовательности должны иметь одинаковый алфавит</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="785"/>
+        <location filename="../src/DotPlotWidget.cpp" line="789"/>
+        <location filename="../src/DotPlotWidget.cpp" line="791"/>
         <source>Save dot-plot</source>
         <translation>Сохранить dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="785"/>
+        <location filename="../src/DotPlotWidget.cpp" line="789"/>
+        <location filename="../src/DotPlotWidget.cpp" line="791"/>
         <source>Save dot-plot data before closing?</source>
         <translation>Сохранить данные dotplot перед закрытием?</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="923"/>
+        <location filename="../src/DotPlotWidget.cpp" line="931"/>
         <source>Invalid weight and height parameters!</source>
         <translation>Некорректные параметры!</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="974"/>
+        <location filename="../src/DotPlotWidget.cpp" line="980"/>
+        <source>Dotplot widget is too small</source>
+        <translation>Виджет точечной диаграммы слишком маленький</translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotWidget.cpp" line="991"/>
         <source>Dotplot is calculating...</source>
         <translation>Выполняется расчёт...</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="1021"/>
+        <location filename="../src/DotPlotWidget.cpp" line="1035"/>
         <source> (min length %1, identity %2%)</source>
-        <translation>(мин. длина %1, идентичность %2%)</translation>
+        <translation> (мин. длина %1, идентичность %2%)</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="205"/>
+        <location filename="../src/DotPlotWidget.cpp" line="206"/>
         <source>Dotplot</source>
         <translation>Dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="518"/>
+        <location filename="../src/DotPlotWidget.cpp" line="521"/>
         <source>Error Saving Dotplot</source>
         <translation>Ошибка сохранения</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="518"/>
+        <location filename="../src/DotPlotWidget.cpp" line="521"/>
         <source>The dotplot can&apos;t be saved as it is empty.</source>
         <translation>Дотплот не может быть сохранён, т.к. он пуст.</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="522"/>
+        <location filename="../src/DotPlotWidget.cpp" line="525"/>
         <source>Save Dotplot</source>
         <translation>Сохранить dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="522"/>
-        <location filename="../src/DotPlotWidget.cpp" line="565"/>
+        <location filename="../src/DotPlotWidget.cpp" line="525"/>
+        <location filename="../src/DotPlotWidget.cpp" line="567"/>
         <source>Dotplot files (*.dpt)</source>
         <translation>Файлы dotplot (*.dpt)</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="565"/>
+        <location filename="../src/DotPlotWidget.cpp" line="567"/>
         <source>Load Dotplot</source>
         <translation>Загрузить dotplot</translation>
     </message>
@@ -667,7 +670,7 @@
 <context>
     <name>U2::SaveDotPlotTask</name>
     <message>
-        <location filename="../src/DotPlotTasks.h" line="50"/>
+        <location filename="../src/DotPlotTasks.h" line="49"/>
         <source>DotPlot saving</source>
         <translation>Dotplot сохраняется</translation>
     </message>
