@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CLONING_UTIL_TASKS_H_
-#define _U2_CLONING_UTIL_TASKS_H_
+#pragma once
 
 #include <limits>
 
@@ -60,7 +59,7 @@ struct GenomicPosition {
     GenomicPosition(int crd, bool strnd)
         : coord(crd), directStrand(strnd) {
     }
-    friend bool operator<(const GenomicPosition &left, const GenomicPosition &right);
+    friend bool operator<(const GenomicPosition& left, const GenomicPosition& right);
 
     int coord;
     bool directStrand;
@@ -69,7 +68,7 @@ struct GenomicPosition {
 class DigestSequenceTask : public Task {
     Q_OBJECT
 public:
-    DigestSequenceTask(U2SequenceObject *dnaObj, AnnotationTableObject *destTable, AnnotationTableObject *sourceTable, const DigestSequenceTaskConfig &cfg);
+    DigestSequenceTask(U2SequenceObject* dnaObj, AnnotationTableObject* destTable, AnnotationTableObject* sourceTable, const DigestSequenceTaskConfig& cfg);
     virtual void prepare();
     virtual void run();
     virtual QString generateReport() const;
@@ -78,14 +77,14 @@ public:
 private:
     void findCutSites();
     void saveResults();
-    SharedAnnotationData createFragment(int pos1, const DNAFragmentTerm &leftTerm, int pos2, const DNAFragmentTerm &rightTerm);
+    SharedAnnotationData createFragment(int pos1, const DNAFragmentTerm& leftTerm, int pos2, const DNAFragmentTerm& rightTerm);
     void checkForConservedAnnotations();
     qint64 correctPos(const qint64 pos) const;
-    QByteArray getOverhang(const U2Region &region) const;
+    QByteArray getOverhang(const U2Region& region) const;
     bool isCircular;
     U2Region seqRange;
     AnnotationTableObject *sourceObj, *destObj;
-    U2SequenceObject *dnaObj;
+    U2SequenceObject* dnaObj;
     DigestSequenceTaskConfig cfg;
     QMap<GenomicPosition, SEnzymeData> cutSiteMap;
     QList<SharedAnnotationData> results;
@@ -111,29 +110,27 @@ class DNAAlphabet;
 class LigateFragmentsTask : public Task {
     Q_OBJECT
 public:
-    LigateFragmentsTask(const QList<DNAFragment> &fragments, const LigateFragmentsTaskConfig &cfg);
-    Document *getResultDocument() {
+    LigateFragmentsTask(const QList<DNAFragment>& fragments, const LigateFragmentsTaskConfig& cfg);
+    Document* getResultDocument() {
         return resultDoc;
     }
     void prepare();
 
 private:
-    static QList<SharedAnnotationData> cloneAnnotationsInRegion(const U2Region &region, AnnotationTableObject *source, int globalOffset);
-    static QList<SharedAnnotationData> cloneAnnotationsInFragmentRegion(const DNAFragment &fragment, AnnotationTableObject *source, int globalOffset);
+    static QList<SharedAnnotationData> cloneAnnotationsInRegion(const U2Region& region, AnnotationTableObject* source, int globalOffset);
+    static QList<SharedAnnotationData> cloneAnnotationsInFragmentRegion(const DNAFragment& fragment, AnnotationTableObject* source, int globalOffset);
     static SharedAnnotationData createSourceAnnotation(int regLen);
-    static SharedAnnotationData createFragmentAnnotation(const DNAFragment &, int startPos);
-    void createDocument(const QByteArray &seq, const QList<SharedAnnotationData> &annotations);
-    void processOverhangs(const DNAFragment &leftFragment, const DNAFragment &rightFragment, QByteArray &overhangAddition);
-    bool overhangsAreConsistent(const DNAFragmentTerm &leftTerm, const DNAFragmentTerm &rightTerm);
+    static SharedAnnotationData createFragmentAnnotation(const DNAFragment&, int startPos);
+    void createDocument(const QByteArray& seq, const QList<SharedAnnotationData>& annotations);
+    void processOverhangs(const DNAFragment& leftFragment, const DNAFragment& rightFragment, QByteArray& overhangAddition);
+    bool overhangsAreConsistent(const DNAFragmentTerm& leftTerm, const DNAFragmentTerm& rightTerm);
 
     QList<DNAFragment> fragmentList;
     QList<SharedAnnotationData> annotations;
     LigateFragmentsTaskConfig cfg;
-    Document *resultDoc;
-    const DNAAlphabet *resultAlphabet;
+    Document* resultDoc;
+    const DNAAlphabet* resultAlphabet;
     QMap<AnnotationData, int> offsetMap;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CLONING_UTIL_TASKS_H_
