@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -49,7 +49,7 @@
 
 namespace U2 {
 
-ConstructMoleculeDialog::ConstructMoleculeDialog(const QList<DNAFragment> &fragmentList, QWidget *p)
+ConstructMoleculeDialog::ConstructMoleculeDialog(const QList<DNAFragment>& fragmentList, QWidget* p)
     : QDialog(p),
       fragments(fragmentList),
       saveController(nullptr) {
@@ -61,7 +61,7 @@ ConstructMoleculeDialog::ConstructMoleculeDialog(const QList<DNAFragment> &fragm
     tabWidget->setCurrentIndex(0);
     QString coreLengthStr = ConstructMoleculeDialog::tr("core length");
 
-    foreach (const DNAFragment &frag, fragments) {
+    foreach (const DNAFragment& frag, fragments) {
         QString fragItem = QString("%1 (%2) %3 [%4 - %5 bp]")
                                .arg(frag.getSequenceName())
                                .arg(frag.getSequenceDocName())
@@ -76,7 +76,7 @@ ConstructMoleculeDialog::ConstructMoleculeDialog(const QList<DNAFragment> &fragm
     fragmentListWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
     molConstructWidget->setColumnWidth(1, molConstructWidget->width() * 0.5);
 
-    connect(fragmentListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem *)), SLOT(sl_onTakeButtonClicked()));
+    connect(fragmentListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), SLOT(sl_onTakeButtonClicked()));
     connect(takeButton, SIGNAL(clicked()), SLOT(sl_onTakeButtonClicked()));
     connect(takeAllButton, SIGNAL(clicked()), SLOT(sl_onTakeAllButtonClicked()));
     connect(fromProjectButton, SIGNAL(clicked()), SLOT(sl_onAddFromProjectButtonClicked()));
@@ -87,7 +87,7 @@ ConstructMoleculeDialog::ConstructMoleculeDialog(const QList<DNAFragment> &fragm
     connect(makeCircularBox, SIGNAL(clicked()), SLOT(sl_makeCircularBoxClicked()));
     connect(makeBluntBox, SIGNAL(clicked()), SLOT(sl_forceBluntBoxClicked()));
     connect(editFragmentButton, SIGNAL(clicked()), SLOT(sl_onEditFragmentButtonClicked()));
-    connect(molConstructWidget, SIGNAL(itemClicked(QTreeWidgetItem *, int)), SLOT(sl_onItemClicked(QTreeWidgetItem *, int)));
+    connect(molConstructWidget, SIGNAL(itemClicked(QTreeWidgetItem*, int)), SLOT(sl_onItemClicked(QTreeWidgetItem*, int)));
 
     molConstructWidget->installEventFilter(this);
 }
@@ -100,7 +100,7 @@ void ConstructMoleculeDialog::accept() {
 
     QList<DNAFragment> toLigate;
     foreach (int idx, selected) {
-        const DNAFragment &fragment = fragments[idx];
+        const DNAFragment& fragment = fragments[idx];
         toLigate.append(fragment);
     }
     LigateFragmentsTaskConfig cfg;
@@ -111,16 +111,16 @@ void ConstructMoleculeDialog::accept() {
     cfg.saveDoc = saveImmediatlyBox->isChecked();
     cfg.annotateFragments = annotateFragmentsBox->isChecked();
 
-    Task *task = new LigateFragmentsTask(toLigate, cfg);
+    Task* task = new LigateFragmentsTask(toLigate, cfg);
     AppContext::getTaskScheduler()->registerTopLevelTask(task);
 
     QDialog::accept();
 }
 
 void ConstructMoleculeDialog::sl_onTakeButtonClicked() {
-    QList<QListWidgetItem *> items = fragmentListWidget->selectedItems();
+    QList<QListWidgetItem*> items = fragmentListWidget->selectedItems();
 
-    foreach (QListWidgetItem *item, items) {
+    foreach (QListWidgetItem* item, items) {
         int curRow = fragmentListWidget->row(item);
         if (!selected.contains(curRow)) {
             selected.append(curRow);
@@ -146,7 +146,7 @@ void ConstructMoleculeDialog::sl_onClearButtonClicked() {
 }
 
 void ConstructMoleculeDialog::sl_onUpButtonClicked() {
-    QTreeWidgetItem *item = molConstructWidget->currentItem();
+    QTreeWidgetItem* item = molConstructWidget->currentItem();
     if (item == nullptr || selected.size() == 1) {
         return;
     }
@@ -162,7 +162,7 @@ void ConstructMoleculeDialog::sl_onUpButtonClicked() {
 }
 
 void ConstructMoleculeDialog::sl_onDownButtonClicked() {
-    QTreeWidgetItem *item = molConstructWidget->currentItem();
+    QTreeWidgetItem* item = molConstructWidget->currentItem();
     if (item == nullptr || selected.size() == 1) {
         return;
     }
@@ -178,7 +178,7 @@ void ConstructMoleculeDialog::sl_onDownButtonClicked() {
 }
 
 void ConstructMoleculeDialog::sl_onRemoveButtonClicked() {
-    QTreeWidgetItem *item = molConstructWidget->currentItem();
+    QTreeWidgetItem* item = molConstructWidget->currentItem();
     if (item == nullptr) {
         return;
     }
@@ -192,11 +192,11 @@ void ConstructMoleculeDialog::update() {
     molConstructWidget->clear();
 
     foreach (int index, selected) {
-        QListWidgetItem *item = fragmentListWidget->item(index);
+        QListWidgetItem* item = fragmentListWidget->item(index);
         assert(item != nullptr);
         if (item != nullptr) {
-            QTreeWidgetItem *newItem = new QTreeWidgetItem(molConstructWidget);
-            const DNAFragment &fragment = fragments.at(index);
+            QTreeWidgetItem* newItem = new QTreeWidgetItem(molConstructWidget);
+            const DNAFragment& fragment = fragments.at(index);
             if (fragment.getLeftTerminus().type == OVERHANG_TYPE_STICKY) {
                 newItem->setText(0, QString("%1 (%2)").arg(QString(fragment.getLeftTerminus().overhang)).arg(fragment.getLeftTerminus().isDirect ? tr("Fwd") : tr("Rev")));
             } else {
@@ -221,10 +221,10 @@ void ConstructMoleculeDialog::update() {
     bool checkTermsConsistency = !makeBluntBox->isChecked();
 
     if (checkTermsConsistency) {
-        QTreeWidgetItem *prevItem = nullptr;
+        QTreeWidgetItem* prevItem = nullptr;
         int count = molConstructWidget->topLevelItemCount();
         for (int i = 0; i < count; ++i) {
-            QTreeWidgetItem *item = molConstructWidget->topLevelItem(i);
+            QTreeWidgetItem* item = molConstructWidget->topLevelItem(i);
             if (prevItem != nullptr) {
                 QStringList prevItems = prevItem->text(2).split(" ");
                 QString prevOverhang = prevItems.at(0);
@@ -233,7 +233,10 @@ void ConstructMoleculeDialog::update() {
                 QString overhang = items.at(0);
                 QString strand = items.count() > 1 ? items.at(1) : QString();
 
-                QColor color = (prevOverhang == overhang && strand != prevStrand) ? Qt::green : Qt::red;
+                bool equaledOverhangs = prevOverhang == overhang;
+                bool differentStrands = strand != prevStrand;
+                bool noStrands = strand.isEmpty() && prevStrand.isEmpty();
+                QColor color = (equaledOverhangs && (differentStrands || noStrands)) ? Qt::green : Qt::red;
 
                 prevItem->setTextColor(2, color);
                 item->setTextColor(0, color);
@@ -241,8 +244,8 @@ void ConstructMoleculeDialog::update() {
             prevItem = item;
         }
         if (makeCircularBox->isChecked() && count > 0) {
-            QTreeWidgetItem *first = molConstructWidget->topLevelItem(0);
-            QTreeWidgetItem *last = molConstructWidget->topLevelItem(count - 1);
+            QTreeWidgetItem* first = molConstructWidget->topLevelItem(0);
+            QTreeWidgetItem* last = molConstructWidget->topLevelItem(count - 1);
 
             QStringList firstItems = first->text(0).split(" ");
             QStringList lastItems = last->text(2).split(" ");
@@ -287,13 +290,13 @@ void ConstructMoleculeDialog::sl_forceBluntBoxClicked() {
 }
 
 void ConstructMoleculeDialog::sl_onEditFragmentButtonClicked() {
-    QTreeWidgetItem *item = molConstructWidget->currentItem();
+    QTreeWidgetItem* item = molConstructWidget->currentItem();
     if (item == nullptr) {
         return;
     }
 
     int idx = molConstructWidget->indexOfTopLevelItem(item);
-    DNAFragment &fragment = fragments[selected[idx]];
+    DNAFragment& fragment = fragments[selected[idx]];
 
     QObjectScopedPointer<EditFragmentDialog> dlg = new EditFragmentDialog(fragment, this);
     dlg->exec();
@@ -306,7 +309,7 @@ void ConstructMoleculeDialog::sl_onEditFragmentButtonClicked() {
     update();
 }
 
-bool ConstructMoleculeDialog::eventFilter(QObject *obj, QEvent *event) {
+bool ConstructMoleculeDialog::eventFilter(QObject* obj, QEvent* event) {
     if (obj == molConstructWidget && event->type() == QEvent::FocusOut) {
         molConstructWidget->clearSelection();
     }
@@ -314,10 +317,10 @@ bool ConstructMoleculeDialog::eventFilter(QObject *obj, QEvent *event) {
     return QDialog::eventFilter(obj, event);
 }
 
-void ConstructMoleculeDialog::sl_onItemClicked(QTreeWidgetItem *item, int column) {
+void ConstructMoleculeDialog::sl_onItemClicked(QTreeWidgetItem* item, int column) {
     if (column == 3) {
         int idx = molConstructWidget->indexOfTopLevelItem(item);
-        DNAFragment &fragment = fragments[selected[idx]];
+        DNAFragment& fragment = fragments[selected[idx]];
         if (item->checkState(column) == Qt::Checked) {
             fragment.setInverted(true);
         } else {
@@ -329,35 +332,30 @@ void ConstructMoleculeDialog::sl_onItemClicked(QTreeWidgetItem *item, int column
 
 void ConstructMoleculeDialog::sl_onAddFromProjectButtonClicked() {
     ProjectTreeControllerModeSettings settings;
+    settings.allowMultipleSelection = false;
     settings.objectTypesToShow.insert(GObjectTypes::SEQUENCE);
     QScopedPointer<U2SequenceObjectConstraints> seqConstraints(new U2SequenceObjectConstraints());
     seqConstraints->alphabetType = DNAAlphabet_NUCL;
     settings.objectConstraints.insert(seqConstraints.data());
+    QList<GObject*> objects = ProjectTreeItemSelectorDialog::selectObjects(settings, this);
+    CHECK(!objects.isEmpty(), );
+    SAFE_POINT(objects.size() == 1, QString("Incorrect selected objects size, expected: 1, current: %1").arg(objects.size()), );
 
-    QList<GObject *> objects = ProjectTreeItemSelectorDialog::selectObjects(settings, this);
+    auto obj = objects.first();
+    CHECK(!obj->isUnloaded(), );
 
-    if (!objects.isEmpty()) {
-        foreach (GObject *obj, objects) {
-            if (obj->isUnloaded()) {
-                continue;
-            }
-            U2SequenceObject *seqObj = qobject_cast<U2SequenceObject *>(obj);
+    auto seqObj = qobject_cast<U2SequenceObject*>(obj);
+    CHECK(seqObj != nullptr, );
 
-            if (seqObj) {
-                QObjectScopedPointer<CreateFragmentDialog> dlg = new CreateFragmentDialog(seqObj, U2Region(0, seqObj->getSequenceLength()), this);
-                dlg->exec();
-                CHECK(!dlg.isNull(), );
+    QObjectScopedPointer<CreateFragmentDialog> dlg = new CreateFragmentDialog(seqObj, U2Region(0, seqObj->getSequenceLength()), this);
+    dlg->exec();
+    CHECK(!dlg.isNull(), );
+    CHECK(dlg->result() == QDialog::Accepted, );
 
-                if (dlg->result() == QDialog::Accepted) {
-                    DNAFragment frag = dlg->getFragment();
-                    QString fragItem = QString("%1 (%2) %3").arg(frag.getSequenceName()).arg(frag.getSequenceDocName()).arg(frag.getName());
-                    fragments.append(frag);
-                    fragmentListWidget->addItem(fragItem);
-                    break;
-                }
-            }
-        }
-    }
+    DNAFragment frag = dlg->getFragment();
+    QString fragItem = QString("%1 (%2) %3").arg(frag.getSequenceName()).arg(frag.getSequenceDocName()).arg(frag.getName());
+    fragments.append(frag);
+    fragmentListWidget->addItem(fragItem);
 }
 
 }  // namespace U2
