@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_CONSTRUCT_MOLECULE_DIALOG_H_
-#define _U2_CONSTRUCT_MOLECULE_DIALOG_H_
+#pragma once
 
 #include <QList>
 
@@ -35,7 +34,7 @@ class SaveDocumentController;
 class ConstructMoleculeDialog : public QDialog, public Ui_ConstructMoleculeDialog {
     Q_OBJECT
 public:
-    ConstructMoleculeDialog(const QList<DNAFragment> &fragments, QWidget *parent);
+    ConstructMoleculeDialog(const QList<DNAFragment>& fragments, QWidget* parent);
     virtual void accept();
 
 private slots:
@@ -49,10 +48,10 @@ private slots:
     void sl_makeCircularBoxClicked();
     void sl_forceBluntBoxClicked();
     void sl_onEditFragmentButtonClicked();
-    void sl_onItemClicked(QTreeWidgetItem *item, int column);
+    void sl_onItemClicked(QTreeWidgetItem* item, int column);
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *event);
+    bool eventFilter(QObject* obj, QEvent* event);
 
 private:
     void update();
@@ -60,9 +59,7 @@ private:
 
     QList<DNAFragment> fragments;
     QList<int> selected;
-    SaveDocumentController *saveController;
+    SaveDocumentController* saveController;
 };
 
 }  // namespace U2
-
-#endif  // _U2_CONSTRUCT_MOLECULE_DIALOG_H_
